commit f34e22a4c73eb2555a3d3800b723ad743142fc24
Author: Richard Biener <rguenther@suse.de>
Date:   Thu Jul 23 08:42:42 2020 +0200

    Update BASE-VER after GCC 10.2 release
    
    2020-07-23  Richard Biener  <rguenther@suse.de>
    
            * BASE-VER: Set to 10.2.1.

diff --git a/gcc/BASE-VER b/gcc/BASE-VER
index 2bd6f7e3927..26ee5b054e1 100644
--- a/gcc/BASE-VER
+++ b/gcc/BASE-VER
@@ -1 +1 @@
-10.2.0
+10.2.1

commit 83f1fbb9e7afaa77d52b200c7937788faa5f24d7
Author: Kito Cheng <kito.cheng@sifive.com>
Date:   Wed Jul 22 14:50:40 2020 +0800

    PR target/96260 - KASAN should work even back-end not porting anything.
    
     - Most KASAN function don't need any porting anything in back-end
       except asan stack protection.
    
     - However kernel will given shadow offset when enable asan stack
       protection, so eveything in KASAN can work if shadow offset is given.
    
     - Verified with x86 and risc-v.
    
     - Verified with RISC-V linux kernel.
    
    gcc/ChangeLog:
    
            PR target/96260
            * asan.c (asan_shadow_offset_set_p): New.
            * asan.h (asan_shadow_offset_set_p): Ditto.
            * toplev.c (process_options): Allow -fsanitize=kernel-address
            even TARGET_ASAN_SHADOW_OFFSET not implemented, only check when
            asan stack protection is enabled.
    
    gcc/testsuite/ChangeLog:
    
            PR target/96260
            * gcc.target/riscv/pr91441.c: Update warning message.
            * gcc.target/riscv/pr96260.c: New.
    
    (cherry picked from commit 2ca1b6d009b194286c3ec91f9c51cc6b0a475458)

diff --git a/gcc/asan.c b/gcc/asan.c
index 4ec22162c12..30baf414655 100644
--- a/gcc/asan.c
+++ b/gcc/asan.c
@@ -344,6 +344,13 @@ asan_shadow_offset ()
   return asan_shadow_offset_value;
 }
 
+/* Returns Asan shadow offset has been set.  */
+bool
+asan_shadow_offset_set_p ()
+{
+  return asan_shadow_offset_computed;
+}
+
 alias_set_type asan_shadow_set = -1;
 
 /* Pointer types to 1, 2 or 4 byte integers in shadow memory.  A separate
diff --git a/gcc/asan.h b/gcc/asan.h
index 9efd33f9b86..114b457ef91 100644
--- a/gcc/asan.h
+++ b/gcc/asan.h
@@ -129,6 +129,8 @@ asan_var_and_redzone_size (unsigned HOST_WIDE_INT size)
 
 extern bool set_asan_shadow_offset (const char *);
 
+extern bool asan_shadow_offset_set_p ();
+
 extern void set_sanitized_sections (const char *);
 
 extern bool asan_sanitize_stack_p (void);
diff --git a/gcc/testsuite/gcc.target/riscv/pr91441.c b/gcc/testsuite/gcc.target/riscv/pr91441.c
index 593a2972a0f..b55df5e7f00 100644
--- a/gcc/testsuite/gcc.target/riscv/pr91441.c
+++ b/gcc/testsuite/gcc.target/riscv/pr91441.c
@@ -7,4 +7,4 @@ int *f( int a)
 {
   return bar(&a);
 }
-/* { dg-warning ".'-fsanitize=address' and '-fsanitize=kernel-address' are not supported for this target" "" { target *-*-* } 0 } */
+/* { dg-warning ".'-fsanitize=kernel-address' with stack protection is not supported without '-fasan-shadow-offset=' for this target" "" { target *-*-* } 0 } */
diff --git a/gcc/testsuite/gcc.target/riscv/pr96260.c b/gcc/testsuite/gcc.target/riscv/pr96260.c
new file mode 100644
index 00000000000..229997f877b
--- /dev/null
+++ b/gcc/testsuite/gcc.target/riscv/pr96260.c
@@ -0,0 +1,9 @@
+/* PR target/96260 */
+/* { dg-do compile } */
+/* { dg-options "--param asan-stack=1 -fsanitize=kernel-address -fasan-shadow-offset=0x100000" } */
+
+int *bar(int *);
+int *f( int a)
+{
+  return bar(&a);
+}
diff --git a/gcc/toplev.c b/gcc/toplev.c
index deccd7f15ba..42af2f587af 100644
--- a/gcc/toplev.c
+++ b/gcc/toplev.c
@@ -1827,7 +1827,7 @@ process_options (void)
   /* Address Sanitizer needs porting to each target architecture.  */
 
   if ((flag_sanitize & SANITIZE_ADDRESS)
-      && (!FRAME_GROWS_DOWNWARD || targetm.asan_shadow_offset == NULL))
+      && !FRAME_GROWS_DOWNWARD)
     {
       warning_at (UNKNOWN_LOCATION, 0,
 		  "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> "
@@ -1835,6 +1835,26 @@ process_options (void)
       flag_sanitize &= ~SANITIZE_ADDRESS;
     }
 
+  if ((flag_sanitize & SANITIZE_USER_ADDRESS)
+      && targetm.asan_shadow_offset == NULL)
+    {
+      warning_at (UNKNOWN_LOCATION, 0,
+		  "%<-fsanitize=address%> not supported for this target");
+      flag_sanitize &= ~SANITIZE_ADDRESS;
+    }
+
+  if ((flag_sanitize & SANITIZE_KERNEL_ADDRESS)
+      && (targetm.asan_shadow_offset == NULL
+	  && param_asan_stack
+	  && !asan_shadow_offset_set_p ()))
+    {
+      warning_at (UNKNOWN_LOCATION, 0,
+		  "%<-fsanitize=kernel-address%> with stack protection "
+		  "is not supported without %<-fasan-shadow-offset=%> "
+		  "for this target");
+      flag_sanitize &= ~SANITIZE_ADDRESS;
+    }
+
  /* Do not use IPA optimizations for register allocation if profiler is active
     or patchable function entries are inserted for run-time instrumentation
     or port does not emit prologue and epilogue as RTL.  */

commit 677b80db41f5345b32ce18cd000e45ea39b80d8f
Author: Martin Liska <mliska@suse.cz>
Date:   Thu Jul 23 10:45:47 2020 +0200

    Fix ChangeLog entry: reverted backport commit.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 0aa626ccc0a..f91a7c2b223 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -71,9 +71,9 @@
 	_mm512_mask_cmpord_ps_mask): Move outside of __OPTIMIZE__ guarded
 	section.
 
-2020-07-14  Matthias Klose  <doko@ubuntu.com>
+2020-07-15  Richard Biener  <rguenther@suse.de>
 
-	Backported from master:
+	Revert:
 	2020-07-14  Matthias Klose  <doko@ubuntu.com>
 
 	PR lto/95604

commit ec62c020c530ade74f4fa559528e7c227d52a54d
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Fri Jul 17 09:53:19 2020 +0100

    gcc-changelog: Fix typo in output
    
    contrib/ChangeLog:
    
            * gcc-changelog/git_update_version.py: Fix typo.
    
    (cherry picked from commit 0c1d1c01039a96c191a7aded40e5df40b14d387a)

diff --git a/contrib/gcc-changelog/git_update_version.py b/contrib/gcc-changelog/git_update_version.py
index ac1b206d238..d2cadb8811c 100755
--- a/contrib/gcc-changelog/git_update_version.py
+++ b/contrib/gcc-changelog/git_update_version.py
@@ -39,7 +39,7 @@ def prepend_to_changelog_files(repo, folder, git_commit, add_to_git):
         raise AssertionError()
     for entry, output in git_commit.to_changelog_entries(use_commit_ts=True):
         full_path = os.path.join(folder, entry, 'ChangeLog')
-        print('writting to %s' % full_path)
+        print('writing to %s' % full_path)
         if os.path.exists(full_path):
             with open(full_path) as f:
                 content = f.read()

commit 2980fc28c5f9f1414cc34e5e3deaaaacc8c480c9
Author: Martin Liska <mliska@suse.cz>
Date:   Thu Jul 23 10:39:00 2020 +0200

    gcc-changelog: fix when somebody reverts a backport
    
    contrib/ChangeLog:
    
            * gcc-changelog/git_commit.py: When reverting a backport,
            we should print only Revert header.
    
    (cherry picked from commit 02cada26e4783b4bfeaf6512a6c22df24d7a25fc)

diff --git a/contrib/gcc-changelog/git_commit.py b/contrib/gcc-changelog/git_commit.py
index 827976c2f84..5a9cc4c7563 100755
--- a/contrib/gcc-changelog/git_commit.py
+++ b/contrib/gcc-changelog/git_commit.py
@@ -628,7 +628,11 @@ class GitCommit:
         for entry in self.changelog_entries:
             output = ''
             timestamp = entry.datetime
-            if self.cherry_pick_commit:
+            if self.revert_commit:
+                timestamp = current_timestamp
+                orig_date = self.original_info.date
+                current_timestamp = orig_date.strftime(DATE_FORMAT)
+            elif self.cherry_pick_commit:
                 info = self.commit_to_info_hook(self.cherry_pick_commit)
                 # it can happen that it is a cherry-pick for a different
                 # repository
@@ -636,10 +640,6 @@ class GitCommit:
                     timestamp = info.date.strftime(DATE_FORMAT)
                 else:
                     timestamp = current_timestamp
-            elif self.revert_commit:
-                timestamp = current_timestamp
-                orig_date = self.original_info.date
-                current_timestamp = orig_date.strftime(DATE_FORMAT)
             elif not timestamp or use_commit_ts:
                 timestamp = current_timestamp
             authors = entry.authors if entry.authors else [self.info.author]
@@ -649,12 +649,13 @@ class GitCommit:
                     authors.append(author)
 
             if self.cherry_pick_commit or self.revert_commit:
-                output += self.format_authors_in_changelog([self.info.author],
+                original_author = self.original_info.author
+                output += self.format_authors_in_changelog([original_author],
                                                            current_timestamp)
-                if self.cherry_pick_commit:
-                    output += '\tBackported from master:\n'
-                else:
+                if self.revert_commit:
                     output += '\tRevert:\n'
+                else:
+                    output += '\tBackported from master:\n'
                 output += self.format_authors_in_changelog(authors,
                                                            timestamp, '\t')
             else:

commit 3373a73172d0e39fe054ab2d4bbff746b36c0fe8
Author: Thomas Koenig <tkoenig@gcc.gnu.org>
Date:   Thu Jul 23 17:56:09 2020 +0200

    Fix handling of implicit_pure by checking if non-pure procedures are called.
    
    Procedures are marked as implicit_pure if they fulfill the criteria of
    pure procedures.  In this case, a procedure was not marked as not being
    implicit_pure which called another procedure, which had not yet been
    marked as not being implicit_impure.
    
    Fixed by iterating over all procedures, setting callers of procedures
    which are non-pure and non-implicit_pure as non-implicit_pure and
    doing this until no more procedure has been changed.
    
    Backport from trunk r11-2215-g3055d879edb1bc2a3923f92a5e681c8f6774fbc3 .
    
    gcc/fortran/ChangeLog:
    
    2020-07-10  Thomas Koenig  <tkoenig@gcc.gnu.org>
    
            PR fortran/96018
            * frontend-passes.c (gfc_check_externals): Adjust formatting.
            (implicit_pure_call): New function.
            (implicit_pure_expr): New function.
            (gfc_fix_implicit_pure): New function.
            * gfortran.h (gfc_fix_implicit_pure): New prototype.
            * parse.c (translate_all_program_units): Call gfc_fix_implicit_pure.

diff --git a/gcc/fortran/frontend-passes.c b/gcc/fortran/frontend-passes.c
index d5d71b5fda4..5e768b12854 100644
--- a/gcc/fortran/frontend-passes.c
+++ b/gcc/fortran/frontend-passes.c
@@ -5516,3 +5516,77 @@ gfc_check_externals (gfc_namespace *ns)
 
   gfc_errors_to_warnings (false);
 }
+
+/* Callback function. If there is a call to a subroutine which is
+   neither pure nor implicit_pure, unset the implicit_pure flag for
+   the caller and return -1.  */
+
+static int
+implicit_pure_call (gfc_code **c, int *walk_subtrees ATTRIBUTE_UNUSED,
+		    void *sym_data)
+{
+  gfc_code *co = *c;
+  gfc_symbol *caller_sym;
+  symbol_attribute *a;
+
+  if (co->op != EXEC_CALL || co->resolved_sym == NULL)
+    return 0;
+
+  a = &co->resolved_sym->attr;
+  if (a->intrinsic || a->pure || a->implicit_pure)
+    return 0;
+
+  caller_sym = (gfc_symbol *) sym_data;
+  gfc_unset_implicit_pure (caller_sym);
+  return 1;
+}
+
+/* Callback function. If there is a call to a function which is
+   neither pure nor implicit_pure, unset the implicit_pure flag for
+   the caller and return 1.  */
+
+static int
+implicit_pure_expr (gfc_expr **e, int *walk ATTRIBUTE_UNUSED, void *sym_data)
+{
+  gfc_expr *expr = *e;
+  gfc_symbol *caller_sym;
+  gfc_symbol *sym;
+  symbol_attribute *a;
+
+  if (expr->expr_type != EXPR_FUNCTION || expr->value.function.isym)
+    return 0;
+
+  sym = expr->symtree->n.sym;
+  a = &sym->attr;
+  if (a->pure || a->implicit_pure)
+    return 0;
+
+  caller_sym = (gfc_symbol *) sym_data;
+  gfc_unset_implicit_pure (caller_sym);
+  return 1;
+}
+
+/* Go through all procedures in the namespace and unset the
+   implicit_pure attribute for any procedure that calls something not
+   pure or implicit pure.  */
+
+bool
+gfc_fix_implicit_pure (gfc_namespace *ns)
+{
+  bool changed = false;
+  gfc_symbol *proc = ns->proc_name;
+
+  if (proc && proc->attr.flavor == FL_PROCEDURE && proc->attr.implicit_pure
+      && ns->code
+      && gfc_code_walker (&ns->code, implicit_pure_call, implicit_pure_expr,
+			  (void *) ns->proc_name))
+    changed = true;
+
+  for (ns = ns->contained; ns; ns = ns->sibling)
+    {
+      if (gfc_fix_implicit_pure (ns))
+	changed = true;
+    }
+
+  return changed;
+}
diff --git a/gcc/fortran/gfortran.h b/gcc/fortran/gfortran.h
index 24c5101c4cb..264822ef9f8 100644
--- a/gcc/fortran/gfortran.h
+++ b/gcc/fortran/gfortran.h
@@ -3623,6 +3623,7 @@ int gfc_expr_walker (gfc_expr **, walk_expr_fn_t, void *);
 int gfc_code_walker (gfc_code **, walk_code_fn_t, walk_expr_fn_t, void *);
 bool gfc_has_dimen_vector_ref (gfc_expr *e);
 void gfc_check_externals (gfc_namespace *);
+bool gfc_fix_implicit_pure (gfc_namespace *);
 
 /* simplify.c */
 
diff --git a/gcc/fortran/parse.c b/gcc/fortran/parse.c
index f71a95dd871..3e19d5fdfbe 100644
--- a/gcc/fortran/parse.c
+++ b/gcc/fortran/parse.c
@@ -6446,6 +6446,11 @@ loop:
 
   gfc_resolve (gfc_current_ns);
 
+  /* Fix the implicit_pure attribute for those procedures who should
+     not have it.  */
+  while (gfc_fix_implicit_pure (gfc_current_ns))
+    ;
+
   /* Dump the parse tree if requested.  */
   if (flag_dump_fortran_original)
     gfc_dump_parse_tree (gfc_current_ns, stdout);
@@ -6491,6 +6496,23 @@ done:
   /* Do the resolution.  */
   resolve_all_program_units (gfc_global_ns_list);
 
+  /* Go through all top-level namespaces and unset the implicit_pure
+     attribute for any procedures that call something not pure or
+     implicit_pure.  Because the a procedure marked as not implicit_pure
+     in one sweep may be called by another routine, we repeat this
+     process until there are no more changes.  */
+  bool changed;
+  do
+    {
+      changed = false;
+      for (gfc_current_ns = gfc_global_ns_list; gfc_current_ns;
+	   gfc_current_ns = gfc_current_ns->sibling)
+	{
+	  if (gfc_fix_implicit_pure (gfc_current_ns))
+	    changed = true;
+	}
+    }
+  while (changed);
 
   /* Fixup for external procedures.  */
   for (gfc_current_ns = gfc_global_ns_list; gfc_current_ns;
diff --git a/gcc/testsuite/gfortran.dg/implicit_pure_5.c b/gcc/testsuite/gfortran.dg/implicit_pure_5.c
new file mode 100644
index 00000000000..67a6d9ca45e
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/implicit_pure_5.c
@@ -0,0 +1,7 @@
+#include <stdio.h>
+
+extern int num_calls;
+int side_effect_c()
+{
+  num_calls ++;
+}
diff --git a/gcc/testsuite/gfortran.dg/implicit_pure_5.f90 b/gcc/testsuite/gfortran.dg/implicit_pure_5.f90
new file mode 100644
index 00000000000..7f1c887e3f9
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/implicit_pure_5.f90
@@ -0,0 +1,63 @@
+! { dg-do run }
+! { dg-additional-sources implicit_pure_5.c }
+! PR fortran/96018 - a wrongly marked implicit_pure
+! function caused wrong code.
+module wrapper
+  use, intrinsic :: iso_c_binding, only : c_int
+  implicit none
+  integer(kind=c_int), bind(C) :: num_calls
+contains
+
+  integer function call_side_effect() result(ierr)
+    call side_effect(ierr)
+  end function call_side_effect
+
+  integer function inner_3d(array) result(ierr)
+    real, intent(in) :: array(:,:,:)
+    integer dimensions(3)
+    dimensions = shape(array)
+    ierr = call_side_effect()
+  end function inner_3d
+
+  integer function inner_4d(array) result(ierr)
+    real, intent(in) :: array(:,:,:,:)
+    integer dimensions(4)
+    dimensions = shape(array)
+    ierr = call_side_effect()
+  end function inner_4d
+
+  subroutine write_3d()
+    real :: array(1,1,1)
+    integer ierr
+    ierr = inner_3d(array)
+    ierr = call_side_effect()
+  end subroutine write_3d
+
+  subroutine write_4d()
+    real array(1,1,1,1)
+    integer ierr
+    ierr = inner_4d(array)
+    ierr = call_side_effect()
+  end subroutine write_4d
+
+  subroutine side_effect(ierr)
+    integer, intent(out) :: ierr        ! Error code
+    interface
+       integer(c_int) function side_effect_c() bind(C,name='side_effect_c')
+         use, intrinsic :: iso_c_binding, only: c_int
+       end function side_effect_c
+    end interface
+    ierr = side_effect_c()
+  end subroutine side_effect
+
+end module wrapper
+
+program self_contained
+  use wrapper
+  implicit none
+  call write_3d()
+  if (num_calls /= 2) stop 1
+  call write_4d()
+  if (num_calls /= 4) stop 2
+end program self_contained
+

commit 5b9f6489081520b7cb10d3ddfae6f010e0986314
Author: Thomas Koenig <tkoenig@gcc.gnu.org>
Date:   Sun Jul 19 17:27:45 2020 +0200

    Always use name from c_interop_kinds_table for -fc-prototypes.
    
    When a user specified a KIND that was a parameter taking the value
    of an iso_c_binding KIND, the code used the name of that parameter
    to look up the type name.  Corrected by always looking it up in
    the table of C interop kinds (which was previously done for
    non-C-interop types, anyway).
    
    gcc/fortran/ChangeLog:
    
            PR fortran/96220
            * dump-parse-tree.c (get_c_type_name): Always use the entries from
            c_interop_kinds_table to find the correct C type.
    
    (cherry picked from commit 2e1b25350aa96b3f5678a056d0b55bb323c452d9)

diff --git a/gcc/fortran/dump-parse-tree.c b/gcc/fortran/dump-parse-tree.c
index f32330685e7..e79494d59bf 100644
--- a/gcc/fortran/dump-parse-tree.c
+++ b/gcc/fortran/dump-parse-tree.c
@@ -3257,45 +3257,28 @@ get_c_type_name (gfc_typespec *ts, gfc_array_spec *as, const char **pre,
   if (ts->type == BT_REAL || ts->type == BT_INTEGER || ts->type == BT_COMPLEX)
     {
       if (ts->is_c_interop && ts->interop_kind)
-	{
-	  *type_name = ts->interop_kind->name + 2;
-	  if (strcmp (*type_name, "signed_char") == 0)
-	    *type_name = "signed char";
-	  else if (strcmp (*type_name, "size_t") == 0)
-	    *type_name = "ssize_t";
-	  else if (strcmp (*type_name, "float_complex") == 0)
-	    *type_name = "__GFORTRAN_FLOAT_COMPLEX";
-	  else if (strcmp (*type_name, "double_complex") == 0)
-	    *type_name = "__GFORTRAN_DOUBLE_COMPLEX";
-	  else if (strcmp (*type_name, "long_double_complex") == 0)
-	    *type_name = "__GFORTRAN_LONG_DOUBLE_COMPLEX";
-
-	  ret = T_OK;
-	}
+	ret = T_OK;
       else
+	ret = T_WARN;
+
+      for (int i = 0; i < ISOCBINDING_NUMBER; i++)
 	{
-	  /* The user did not specify a C interop type.  Let's look through
-	     the available table and use the first one, but warn.  */
-	  for (int i = 0; i < ISOCBINDING_NUMBER; i++)
+	  if (c_interop_kinds_table[i].f90_type == ts->type
+	      && c_interop_kinds_table[i].value == ts->kind)
 	    {
-	      if (c_interop_kinds_table[i].f90_type == ts->type
-		  && c_interop_kinds_table[i].value == ts->kind)
-		{
-		  *type_name = c_interop_kinds_table[i].name + 2;
-		  if (strcmp (*type_name, "signed_char") == 0)
-		    *type_name = "signed char";
-		  else if (strcmp (*type_name, "size_t") == 0)
-		    *type_name = "ssize_t";
-		  else if (strcmp (*type_name, "float_complex") == 0)
-		    *type_name = "__GFORTRAN_FLOAT_COMPLEX";
-		  else if (strcmp (*type_name, "double_complex") == 0)
-		    *type_name = "__GFORTRAN_DOUBLE_COMPLEX";
-		  else if (strcmp (*type_name, "long_double_complex") == 0)
-		    *type_name = "__GFORTRAN_LONG_DOUBLE_COMPLEX";
-
-		  ret = T_WARN;
-		  break;
-		}
+	      *type_name = c_interop_kinds_table[i].name + 2;
+	      if (strcmp (*type_name, "signed_char") == 0)
+		*type_name = "signed char";
+	      else if (strcmp (*type_name, "size_t") == 0)
+		*type_name = "ssize_t";
+	      else if (strcmp (*type_name, "float_complex") == 0)
+		*type_name = "__GFORTRAN_FLOAT_COMPLEX";
+	      else if (strcmp (*type_name, "double_complex") == 0)
+		*type_name = "__GFORTRAN_DOUBLE_COMPLEX";
+	      else if (strcmp (*type_name, "long_double_complex") == 0)
+		*type_name = "__GFORTRAN_LONG_DOUBLE_COMPLEX";
+
+	      break;
 	    }
 	}
     }

commit 5497677b497b95a261089d19f5295cc80f99a2b6
Author: Peter Bergner <bergner@linux.ibm.com>
Date:   Wed Jul 22 11:44:35 2020 -0500

    rs6000: __builtin_mma_disassemble_acc() doesn't store elements correctly in LE mode
    
    PR96236 shows a problem where we don't correctly store our 512-bit accumulators
    correctly in little-endian mode.  The patch below detects when we're doing a
    little-endian memory access and stores to the correct memory locations.
    
    2020-07-22  Peter Bergner  <bergner@linux.ibm.com>
    
    gcc/
            PR target/96236
            * config/rs6000/rs6000-call.c (rs6000_gimple_fold_mma_builtin): Handle
            little-endian memory ordering.
    
    gcc/testsuite/
            PR target/96236
            * gcc.target/powerpc/mma-double-test.c: Update storing results for
            correct little-endian ordering.
            * gcc.target/powerpc/mma-single-test.c: Likewise.
    
    (cherry picked from commit ae575662833d70cb7d74b9538096c7becc79af14)

diff --git a/gcc/config/rs6000/rs6000-call.c b/gcc/config/rs6000/rs6000-call.c
index 243601e90c1..6af7e2d50c6 100644
--- a/gcc/config/rs6000/rs6000-call.c
+++ b/gcc/config/rs6000/rs6000-call.c
@@ -10834,11 +10834,12 @@ rs6000_gimple_fold_mma_builtin (gimple_stmt_iterator *gsi)
       tree src_array = build1 (VIEW_CONVERT_EXPR, array_type, src);
       for (unsigned i = 0; i < 4; i++)
 	{
+	  unsigned index = WORDS_BIG_ENDIAN ? i : 3 - i;
 	  tree ref = build4 (ARRAY_REF, unsigned_V16QI_type_node, src_array,
 			     build_int_cst (size_type_node, i),
 			     NULL_TREE, NULL_TREE);
 	  tree dst = build2 (MEM_REF, unsigned_V16QI_type_node, dst_base,
-			     build_int_cst (dst_type, i * 16));
+			     build_int_cst (dst_type, index * 16));
 	  gimplify_assign (dst, ref, &new_seq);
 	}
       pop_gimplify_context (NULL);
diff --git a/gcc/testsuite/gcc.target/powerpc/mma-double-test.c b/gcc/testsuite/gcc.target/powerpc/mma-double-test.c
index ac84ae30004..044a288ebcc 100755
--- a/gcc/testsuite/gcc.target/powerpc/mma-double-test.c
+++ b/gcc/testsuite/gcc.target/powerpc/mma-double-test.c
@@ -12,13 +12,13 @@ typedef double v4sf_t __attribute__ ((vector_size (16)));
 #define SAVE_ACC(ACC, ldc, J)  \
 	  __builtin_mma_disassemble_acc (result, ACC); \
 	  rowC = (v4sf_t *) &CO[0*ldc+J]; \
-          rowC[0] += result[3] ; \
+          rowC[0] += result[0]; \
           rowC = (v4sf_t *) &CO[1*ldc+J]; \
-          rowC[0] += result[2] ; \
+          rowC[0] += result[1]; \
           rowC = (v4sf_t *) &CO[2*ldc+J]; \
-          rowC[0] += result[1] ; \
+          rowC[0] += result[2]; \
           rowC = (v4sf_t *) &CO[3*ldc+J]; \
-	  rowC[0] += result[0] ;
+	  rowC[0] += result[3];
 
 void
 MMA (int m, int n, int k, double *A, double *B, double *C)
diff --git a/gcc/testsuite/gcc.target/powerpc/mma-single-test.c b/gcc/testsuite/gcc.target/powerpc/mma-single-test.c
index 15369a64025..7e628df45b7 100755
--- a/gcc/testsuite/gcc.target/powerpc/mma-single-test.c
+++ b/gcc/testsuite/gcc.target/powerpc/mma-single-test.c
@@ -12,24 +12,24 @@ typedef float v4sf_t __attribute__ ((vector_size (16)));
 #define SAVE_ACC(ACC, ldc,J)  \
 	  __builtin_mma_disassemble_acc (result, ACC); \
 	  rowC = (v4sf_t *) &CO[0*ldc+J]; \
-          rowC[0] += result[3] ; \
+          rowC[0] += result[0]; \
           rowC = (v4sf_t *) &CO[1*ldc+J]; \
-          rowC[0] += result[2] ; \
+          rowC[0] += result[1]; \
           rowC = (v4sf_t *) &CO[2*ldc+J]; \
-          rowC[0] += result[1] ; \
+          rowC[0] += result[2]; \
           rowC = (v4sf_t *) &CO[3*ldc+J]; \
-	  rowC[0] += result[0] ;
+	  rowC[0] += result[3];
 
 #define SAVE_ACC1(ACC,ldc, J)  \
 	  __builtin_mma_disassemble_acc (result, ACC); \
 	  rowC = (v4sf_t *) &CO[4* ldc+J]; \
-          rowC[0] += result[3] ; \
+          rowC[0] += result[0]; \
           rowC = (v4sf_t *) &CO[5*ldc+J]; \
-          rowC[0] += result[2] ; \
+          rowC[0] += result[1]; \
           rowC = (v4sf_t *) &CO[6*ldc+J]; \
-          rowC[0] += result[1] ; \
+          rowC[0] += result[2]; \
           rowC = (v4sf_t *) &CO[7*ldc+J]; \
-	  rowC[0] += result[0] ;
+	  rowC[0] += result[3];
 void
 MMA (int m, int n, int k, float *A, float *B, float *C)
 {

commit bab0c51af90f475dab8f1b306737cd04b06d4b04
Author: Harald Anlauf <anlauf@gmx.de>
Date:   Tue Jul 21 21:37:30 2020 +0200

    PR fortran/89574 - ICE in conv_function_val, at fortran/trans-expr.c:3792
    
    When checking for an external procedure from the same file, do not
    consider symbols from different modules.
    
    gcc/fortran/
            PR fortran/89574
            * trans-decl.c (gfc_get_extern_function_decl): Check whether a
            symbol belongs to a different module.
    
    (cherry picked from commit 28f2a080cc27531a8c78aec9f44aeff4961c2a4c)

diff --git a/gcc/fortran/trans-decl.c b/gcc/fortran/trans-decl.c
index 769ab20c82d..45a739ac860 100644
--- a/gcc/fortran/trans-decl.c
+++ b/gcc/fortran/trans-decl.c
@@ -2090,12 +2090,17 @@ gfc_get_extern_function_decl (gfc_symbol * sym, gfc_actual_arglist *actual_args)
       if (gsym && !gsym->bind_c)
 	gsym = NULL;
     }
-  else
+  else if (sym->module == NULL)
     {
       gsym = gfc_find_gsymbol (gfc_gsym_root, sym->name);
       if (gsym && gsym->bind_c)
 	gsym = NULL;
     }
+  else
+    {
+      /* Procedure from a different module.  */
+      gsym = NULL;
+    }
 
   if (gsym && !gsym->defined)
     gsym = NULL;
diff --git a/gcc/testsuite/gfortran.dg/pr89574.f90 b/gcc/testsuite/gfortran.dg/pr89574.f90
new file mode 100644
index 00000000000..48dd0680a48
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr89574.f90
@@ -0,0 +1,29 @@
+! { dg-do compile }
+! PR fortran/89574 - ICE in conv_function_val, at fortran/trans-expr.c:3792
+
+module mod1
+contains
+  subroutine init
+  end subroutine
+end module
+
+module mod2
+contains
+  subroutine init
+  end subroutine
+end module
+
+module init
+  use mod1, only : test_init1 => init
+  use mod2, only : test_init2 => init
+  implicit none
+contains
+  subroutine sub
+    call test_init1
+    call test_init2
+    call init
+  contains
+    subroutine init
+    end subroutine
+  end subroutine
+end module

commit 6dd74062d215682e1f9b3ca618a9d38585dd4831
Author: Harald Anlauf <anlauf@gmx.de>
Date:   Fri Jul 10 21:00:13 2020 +0200

    PR fortran/96086 - ICE in gfc_match_select_rank, at fortran/match.c:6645
    
    Handle NULL pointer dereference on SELECT RANK with an invalid
    assumed-rank array declaration.
    
    gcc/fortran/
            PR fortran/96086
            * match.c (gfc_match_select_rank): Catch NULL pointer
            dereference.
            * resolve.c (resolve_assoc_var): Catch NULL pointer dereference
            that may occur after an illegal declaration.
    
    (cherry picked from commit 8a0b69f0b089c05d233b8e1a941825b1ceac93bd)

diff --git a/gcc/fortran/match.c b/gcc/fortran/match.c
index db5174f3f21..31e302b6b8a 100644
--- a/gcc/fortran/match.c
+++ b/gcc/fortran/match.c
@@ -6642,7 +6642,8 @@ gfc_match_select_rank (void)
       if (expr2->symtree)
 	{
 	  sym2 = expr2->symtree->n.sym;
-	  as = sym2->ts.type == BT_CLASS ? CLASS_DATA (sym2)->as : sym2->as;
+	  as = (sym2->ts.type == BT_CLASS
+		&& CLASS_DATA (sym2)) ? CLASS_DATA (sym2)->as : sym2->as;
 	}
 
       if (expr2->expr_type != EXPR_VARIABLE
@@ -6654,7 +6655,7 @@ gfc_match_select_rank (void)
 	  goto cleanup;
 	}
 
-      if (expr2->ts.type == BT_CLASS)
+      if (expr2->ts.type == BT_CLASS && CLASS_DATA (sym2))
 	{
 	  copy_ts_from_selector_to_associate (expr1, expr2);
 
diff --git a/gcc/fortran/resolve.c b/gcc/fortran/resolve.c
index 354702bda0b..8f7477b6a49 100644
--- a/gcc/fortran/resolve.c
+++ b/gcc/fortran/resolve.c
@@ -8998,7 +8998,9 @@ resolve_assoc_var (gfc_symbol* sym, bool resolve_target)
 	  if (as->corank != 0)
 	    sym->attr.codimension = 1;
 	}
-      else if (sym->ts.type == BT_CLASS && (!CLASS_DATA (sym)->as || sym->assoc->rankguessed))
+      else if (sym->ts.type == BT_CLASS
+	       && CLASS_DATA (sym)
+	       && (!CLASS_DATA (sym)->as || sym->assoc->rankguessed))
 	{
 	  if (!CLASS_DATA (sym)->as)
 	    CLASS_DATA (sym)->as = gfc_get_array_spec ();
diff --git a/gcc/testsuite/gfortran.dg/pr96086.f90 b/gcc/testsuite/gfortran.dg/pr96086.f90
new file mode 100644
index 00000000000..b80967a7a07
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr96086.f90
@@ -0,0 +1,8 @@
+! { dg-do compile }
+! PR fortran/96086 - ICE in gfc_match_select_rank, at fortran/match.c:6645
+
+subroutine s
+  class(*) :: x(..)     ! { dg-error "Assumed-rank array" }
+  select rank (y => x)  ! { dg-error "CLASS variable" }
+  end select
+end

commit a3980ada1bd99cf8df22284862693088e5d1ca7c
Author: Harald Anlauf <anlauf@gmx.de>
Date:   Mon Jul 6 18:58:23 2020 +0200

    PR fortran/95980 - ICE on using sync images with -fcheck=bounds
    
    In SELECT TYPE, the argument may be an incorrectly specified unlimited
    polymorphic variable.  Avoid a NULL pointer dereference for clean error
    recovery.
    
    gcc/fortran/
            PR fortran/95980
            * match.c (copy_ts_from_selector_to_associate, build_class_sym):
            Distinguish between unlimited polymorphic and ordinary variables
            to avoid NULL pointer dereference.
            * resolve.c (resolve_select_type):
            Distinguish between unlimited polymorphic and ordinary variables
            to avoid NULL pointer dereference.
    
    (cherry picked from commit f2151227dfe90a5fe73297c370786be98b0b090f)

diff --git a/gcc/fortran/match.c b/gcc/fortran/match.c
index 31e302b6b8a..cb09c5f8ec5 100644
--- a/gcc/fortran/match.c
+++ b/gcc/fortran/match.c
@@ -6159,14 +6159,18 @@ copy_ts_from_selector_to_associate (gfc_expr *associate, gfc_expr *selector)
   while (ref && ref->next)
     ref = ref->next;
 
-  if (selector->ts.type == BT_CLASS && CLASS_DATA (selector)->as
+  if (selector->ts.type == BT_CLASS
+      && CLASS_DATA (selector)
+      && CLASS_DATA (selector)->as
       && CLASS_DATA (selector)->as->type == AS_ASSUMED_RANK)
     {
       assoc_sym->attr.dimension = 1;
       assoc_sym->as = gfc_copy_array_spec (CLASS_DATA (selector)->as);
       goto build_class_sym;
     }
-  else if (selector->ts.type == BT_CLASS && CLASS_DATA (selector)->as
+  else if (selector->ts.type == BT_CLASS
+	   && CLASS_DATA (selector)
+	   && CLASS_DATA (selector)->as
 	   && ref && ref->type == REF_ARRAY)
     {
       /* Ensure that the array reference type is set.  We cannot use
@@ -6223,7 +6227,8 @@ build_class_sym:
     {
       /* The correct class container has to be available.  */
       assoc_sym->ts.type = BT_CLASS;
-      assoc_sym->ts.u.derived = CLASS_DATA (selector)->ts.u.derived;
+      assoc_sym->ts.u.derived = CLASS_DATA (selector)
+	? CLASS_DATA (selector)->ts.u.derived : selector->ts.u.derived;
       assoc_sym->attr.pointer = 1;
       gfc_build_class_symbol (&assoc_sym->ts, &assoc_sym->attr, &assoc_sym->as);
     }
diff --git a/gcc/fortran/resolve.c b/gcc/fortran/resolve.c
index 8f7477b6a49..74a0bbe5e53 100644
--- a/gcc/fortran/resolve.c
+++ b/gcc/fortran/resolve.c
@@ -9229,7 +9229,8 @@ resolve_select_type (gfc_code *code, gfc_namespace *old_ns)
 	{
 	  if (code->expr1->symtree->n.sym->attr.untyped)
 	    code->expr1->symtree->n.sym->ts = code->expr2->ts;
-	  selector_type = CLASS_DATA (code->expr2)->ts.u.derived;
+	  selector_type = CLASS_DATA (code->expr2)
+	    ? CLASS_DATA (code->expr2)->ts.u.derived : code->expr2->ts.u.derived;
 	}
 
       if (code->expr2->rank && CLASS_DATA (code->expr1)->as)
diff --git a/gcc/testsuite/gfortran.dg/pr95980.f90 b/gcc/testsuite/gfortran.dg/pr95980.f90
new file mode 100644
index 00000000000..7c8260a96e0
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr95980.f90
@@ -0,0 +1,10 @@
+! { dg-do compile }
+! PR fortran/95980 - ICE in get_unique_type_string, at fortran/class.c:485
+
+program p
+  type t
+  end type t
+  class(t) :: x        ! { dg-error "must be dummy, allocatable or pointer" }
+  select type (y => x)
+  end select
+end

commit 76a8ff3948ad5a36ccae7305a2e9a7c2499418e5
Author: Harald Anlauf <anlauf@gmx.de>
Date:   Fri Jul 10 21:35:35 2020 +0200

    PR fortran/95980 - ICE in get_unique_type_string, at fortran/class.c:485
    
    In SELECT TYPE, the argument may be an incorrectly specified unlimited
    CLASS variable.  Avoid NULL pointer dereferences for clean error
    recovery.
    
    gcc/fortran/
            PR fortran/95980
            * class.c (gfc_add_component_ref, gfc_build_class_symbol):
            Add checks for NULL pointer dereference.
            * primary.c (gfc_variable_attr): Likewise.
            * resolve.c (resolve_variable, resolve_assoc_var)
            (resolve_fl_var_and_proc, resolve_fl_variable_derived)
            (resolve_symbol): Likewise.
    
    (cherry picked from commit 70c884a4b82733027ac0e2620d09169b177080d7)

diff --git a/gcc/fortran/class.c b/gcc/fortran/class.c
index d6847eb0004..dfa48400712 100644
--- a/gcc/fortran/class.c
+++ b/gcc/fortran/class.c
@@ -228,7 +228,7 @@ gfc_add_component_ref (gfc_expr *e, const char *name)
 	break;
       tail = &((*tail)->next);
     }
-  if (derived->components && derived->components->next &&
+  if (derived && derived->components && derived->components->next &&
       derived->components->next->ts.type == BT_DERIVED &&
       derived->components->next->ts.u.derived == NULL)
     {
@@ -663,6 +663,10 @@ gfc_build_class_symbol (gfc_typespec *ts, symbol_attribute *attr,
 
   /* Determine the name of the encapsulating type.  */
   rank = !(*as) || (*as)->rank == -1 ? GFC_MAX_DIMENSIONS : (*as)->rank;
+
+  if (!ts->u.derived)
+    return false;
+
   get_unique_hashed_string (tname, ts->u.derived);
   if ((*as) && attr->allocatable)
     name = xasprintf ("__class_%s_%d_%da", tname, rank, (*as)->corank);
diff --git a/gcc/fortran/primary.c b/gcc/fortran/primary.c
index 7c221c8d209..a6626c806fd 100644
--- a/gcc/fortran/primary.c
+++ b/gcc/fortran/primary.c
@@ -2597,7 +2597,7 @@ gfc_variable_attr (gfc_expr *expr, gfc_typespec *ts)
   sym = expr->symtree->n.sym;
   attr = sym->attr;
 
-  if (sym->ts.type == BT_CLASS && sym->attr.class_ok)
+  if (sym->ts.type == BT_CLASS && sym->attr.class_ok && sym->ts.u.derived)
     {
       dimension = CLASS_DATA (sym)->attr.dimension;
       codimension = CLASS_DATA (sym)->attr.codimension;
diff --git a/gcc/fortran/resolve.c b/gcc/fortran/resolve.c
index 74a0bbe5e53..3166cc3afc4 100644
--- a/gcc/fortran/resolve.c
+++ b/gcc/fortran/resolve.c
@@ -5557,6 +5557,7 @@ resolve_variable (gfc_expr *e)
     }
   /* TS 29113, C535b.  */
   else if (((sym->ts.type == BT_CLASS && sym->attr.class_ok
+	     && sym->ts.u.derived && CLASS_DATA (sym)
 	     && CLASS_DATA (sym)->as
 	     && CLASS_DATA (sym)->as->type == AS_ASSUMED_RANK)
 	    || (sym->ts.type != BT_CLASS && sym->as
@@ -5604,6 +5605,7 @@ resolve_variable (gfc_expr *e)
 
   /* TS 29113, C535b.  */
   if (((sym->ts.type == BT_CLASS && sym->attr.class_ok
+	&& sym->ts.u.derived && CLASS_DATA (sym)
 	&& CLASS_DATA (sym)->as
 	&& CLASS_DATA (sym)->as->type == AS_ASSUMED_RANK)
        || (sym->ts.type != BT_CLASS && sym->as
@@ -9017,7 +9019,7 @@ resolve_assoc_var (gfc_symbol* sym, bool resolve_target)
     {
       /* target's rank is 0, but the type of the sym is still array valued,
 	 which has to be corrected.  */
-      if (sym->ts.type == BT_CLASS
+      if (sym->ts.type == BT_CLASS && sym->ts.u.derived
 	  && CLASS_DATA (sym) && CLASS_DATA (sym)->as)
 	{
 	  gfc_array_spec *as;
@@ -12603,7 +12605,8 @@ resolve_fl_var_and_proc (gfc_symbol *sym, int mp_flag)
 {
   gfc_array_spec *as;
 
-  if (sym->ts.type == BT_CLASS && sym->attr.class_ok)
+  if (sym->ts.type == BT_CLASS && sym->attr.class_ok
+      && sym->ts.u.derived && CLASS_DATA (sym))
     as = CLASS_DATA (sym)->as;
   else
     as = sym->as;
@@ -12613,7 +12616,8 @@ resolve_fl_var_and_proc (gfc_symbol *sym, int mp_flag)
     {
       bool pointer, allocatable, dimension;
 
-      if (sym->ts.type == BT_CLASS && sym->attr.class_ok)
+      if (sym->ts.type == BT_CLASS && sym->attr.class_ok
+	  && sym->ts.u.derived && CLASS_DATA (sym))
 	{
 	  pointer = CLASS_DATA (sym)->attr.class_pointer;
 	  allocatable = CLASS_DATA (sym)->attr.allocatable;
@@ -12664,6 +12668,7 @@ resolve_fl_var_and_proc (gfc_symbol *sym, int mp_flag)
     {
       /* F03:C502.  */
       if (sym->attr.class_ok
+	  && sym->ts.u.derived
 	  && !sym->attr.select_type_temporary
 	  && !UNLIMITED_POLY (sym)
 	  && !gfc_type_is_extensible (CLASS_DATA (sym)->ts.u.derived))
@@ -12702,7 +12707,8 @@ resolve_fl_variable_derived (gfc_symbol *sym, int no_init_flag)
      associated by the presence of another class I symbol in the same
      namespace.  14.6.1.3 of the standard and the discussion on
      comp.lang.fortran.  */
-  if (sym->ns != sym->ts.u.derived->ns
+  if (sym->ts.u.derived
+      && sym->ns != sym->ts.u.derived->ns
       && !sym->ts.u.derived->attr.use_assoc
       && sym->ns->proc_name->attr.if_source != IFSRC_IFBODY)
     {
@@ -15333,7 +15339,7 @@ resolve_symbol (gfc_symbol *sym)
       specification_expr = saved_specification_expr;
     }
 
-  if (sym->ts.type == BT_CLASS && sym->attr.class_ok)
+  if (sym->ts.type == BT_CLASS && sym->attr.class_ok && sym->ts.u.derived)
     {
       as = CLASS_DATA (sym)->as;
       class_attr = CLASS_DATA (sym)->attr;
@@ -15734,6 +15740,7 @@ resolve_symbol (gfc_symbol *sym)
   /* F2008, C525.  */
   if ((((sym->ts.type == BT_DERIVED && sym->ts.u.derived->attr.coarray_comp)
 	 || (sym->ts.type == BT_CLASS && sym->attr.class_ok
+	     && sym->ts.u.derived && CLASS_DATA (sym)
 	     && CLASS_DATA (sym)->attr.coarray_comp))
        || class_attr.codimension)
       && (sym->attr.result || sym->result == sym))
@@ -15755,6 +15762,7 @@ resolve_symbol (gfc_symbol *sym)
   /* F2008, C525.  */
   if (((sym->ts.type == BT_DERIVED && sym->ts.u.derived->attr.coarray_comp)
 	|| (sym->ts.type == BT_CLASS && sym->attr.class_ok
+	    && sym->ts.u.derived && CLASS_DATA (sym)
 	    && CLASS_DATA (sym)->attr.coarray_comp))
       && (class_attr.codimension || class_attr.pointer || class_attr.dimension
 	  || class_attr.allocatable))
@@ -15798,6 +15806,7 @@ resolve_symbol (gfc_symbol *sym)
   /* F2008, C541.  */
   if ((((sym->ts.type == BT_DERIVED && sym->ts.u.derived->attr.coarray_comp)
 	|| (sym->ts.type == BT_CLASS && sym->attr.class_ok
+	    && sym->ts.u.derived && CLASS_DATA (sym)
 	    && CLASS_DATA (sym)->attr.coarray_comp))
        || (class_attr.codimension && class_attr.allocatable))
       && sym->attr.dummy && sym->attr.intent == INTENT_OUT)
diff --git a/gcc/testsuite/gfortran.dg/pr95980_2.f90 b/gcc/testsuite/gfortran.dg/pr95980_2.f90
new file mode 100644
index 00000000000..d1fe9c76bd0
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr95980_2.f90
@@ -0,0 +1,11 @@
+! { dg-do compile }
+! PR fortran/95980 - ICE in get_unique_type_string, at fortran/class.c:485
+
+program p
+  type t
+     integer :: a
+  end type t
+  class(t) :: x         ! { dg-error "must be dummy, allocatable or pointer" }
+  select type (y => x)
+  end select
+end

commit ca47325f300462b6f4ea84de2103eef81a4a7684
Author: Sergei Trofimovich <siarheit@google.com>
Date:   Thu Jul 23 23:58:35 2020 +0100

    sparc/sparc64: use crtendS.o for default-pie executables [PR96190]
    
    In --enable-default-pie mode compiler should switch from
    using crtend.o to crtendS.o. On sparc it is especially important
    because crtend.o contains PIC-unfriendly code.
    
    We use GNU_USER_TARGET_ENDFILE_SPEC as a baseline spec to get
    crtendS.o instead of crtend.o in !no-pie mode.
    
    gcc:
    
    2020-07-14  Sergei Trofimovich  <siarheit@google.com>
    
            PR target/96190
            * config/sparc/linux.h (ENDFILE_SPEC): Use GNU_USER_TARGET_ENDFILE_SPEC
            to get crtendS.o for !no-pie mode.
            * config/sparc/linux64.h (ENDFILE_SPEC): Ditto.
    
    (cherry picked from commit 87891d5eafe8d1de90b9d9b056eca81c508d1c77)

diff --git a/gcc/config/sparc/linux.h b/gcc/config/sparc/linux.h
index 81201e67a2f..63853e60c03 100644
--- a/gcc/config/sparc/linux.h
+++ b/gcc/config/sparc/linux.h
@@ -27,16 +27,10 @@ along with GCC; see the file COPYING3.  If not see
     }						\
   while (0)
 
-/* Provide a ENDFILE_SPEC appropriate for GNU/Linux.  Here we tack on
-   the GNU/Linux magical crtend.o file (see crtstuff.c) which
-   provides part of the support for getting C++ file-scope static
-   object constructed before entering `main', followed by a normal
-   GNU/Linux "finalizer" file, `crtn.o'.  */
-
 #undef  ENDFILE_SPEC
 #define ENDFILE_SPEC \
-  "%{shared|pie:crtendS.o%s;:crtend.o%s} crtn.o%s\
-   %{Ofast|ffast-math|funsafe-math-optimizations:crtfastmath.o%s}"
+  GNU_USER_TARGET_ENDFILE_SPEC \
+  "%{Ofast|ffast-math|funsafe-math-optimizations:crtfastmath.o%s}"
 
 /* -mcpu=native handling only makes sense with compiler running on
    a SPARC chip.  */
diff --git a/gcc/config/sparc/linux64.h b/gcc/config/sparc/linux64.h
index a1a0efd8f28..19ce84d7adb 100644
--- a/gcc/config/sparc/linux64.h
+++ b/gcc/config/sparc/linux64.h
@@ -44,16 +44,10 @@ along with GCC; see the file COPYING3.  If not see
 #undef ASM_CPU64_DEFAULT_SPEC
 #define ASM_CPU64_DEFAULT_SPEC "-Av9a"
 
-/* Provide a ENDFILE_SPEC appropriate for GNU/Linux.  Here we tack on
-   the GNU/Linux magical crtend.o file (see crtstuff.c) which
-   provides part of the support for getting C++ file-scope static
-   object constructed before entering `main', followed by a normal
-   GNU/Linux "finalizer" file, `crtn.o'.  */
-
 #undef	ENDFILE_SPEC
 #define ENDFILE_SPEC \
-  "%{shared|pie:crtendS.o%s;:crtend.o%s} crtn.o%s\
-   %{Ofast|ffast-math|funsafe-math-optimizations:crtfastmath.o%s}"
+  GNU_USER_TARGET_ENDFILE_SPEC \
+  "%{Ofast|ffast-math|funsafe-math-optimizations:crtfastmath.o%s}"
 
 /* The default code model.  */
 #undef SPARC_DEFAULT_CMODEL

commit 20ac8584c11c54c843c927942607876bb4df4902
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Jul 24 00:16:57 2020 +0000

    Daily bump.

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index 303b9854c37..88c668a53ca 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,18 @@
+2020-07-23  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2020-07-23  Martin Liska  <mliska@suse.cz>
+
+	* gcc-changelog/git_commit.py: When reverting a backport,
+	we should print only Revert header.
+
+2020-07-23  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2020-07-17  Jonathan Wakely  <jwakely@redhat.com>
+
+	* gcc-changelog/git_update_version.py: Fix typo.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index f91a7c2b223..fa5830e15b6 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,34 @@
+2020-07-23  Sergei Trofimovich  <siarheit@google.com>
+
+	Backported from master:
+	2020-07-20  Sergei Trofimovich  <siarheit@google.com>
+
+	PR target/96190
+	* config/sparc/linux.h (ENDFILE_SPEC): Use GNU_USER_TARGET_ENDFILE_SPEC
+	to get crtendS.o for !no-pie mode.
+	* config/sparc/linux64.h (ENDFILE_SPEC): Ditto.
+
+2020-07-23  Peter Bergner  <bergner@linux.ibm.com>
+
+	Backported from master:
+	2020-07-22  Peter Bergner  <bergner@linux.ibm.com>
+
+	PR target/96236
+	* config/rs6000/rs6000-call.c (rs6000_gimple_fold_mma_builtin): Handle
+	little-endian memory ordering.
+
+2020-07-23  Kito Cheng  <kito.cheng@sifive.com>
+
+	Backported from master:
+	2020-07-23  Kito Cheng  <kito.cheng@sifive.com>
+
+	PR target/96260
+	* asan.c (asan_shadow_offset_set_p): New.
+	* asan.h (asan_shadow_offset_set_p): Ditto.
+	* toplev.c (process_options): Allow -fsanitize=kernel-address
+	even TARGET_ASAN_SHADOW_OFFSET not implemented, only check when
+	asan stack protection is enabled.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 659a031602d..09a13ab3781 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200723
+20200724
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 2fdd3e8daa8..9cfa0c10c11 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,68 @@
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-10  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/95980
+	* class.c (gfc_add_component_ref, gfc_build_class_symbol):
+	Add checks for NULL pointer dereference.
+	* primary.c (gfc_variable_attr): Likewise.
+	* resolve.c (resolve_variable, resolve_assoc_var)
+	(resolve_fl_var_and_proc, resolve_fl_variable_derived)
+	(resolve_symbol): Likewise.
+
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-06  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/95980
+	* match.c (copy_ts_from_selector_to_associate, build_class_sym):
+	Distinguish between unlimited polymorphic and ordinary variables
+	to avoid NULL pointer dereference.
+	* resolve.c (resolve_select_type):
+	Distinguish between unlimited polymorphic and ordinary variables
+	to avoid NULL pointer dereference.
+
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-10  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/96086
+	* match.c (gfc_match_select_rank): Catch NULL pointer
+	dereference.
+	* resolve.c (resolve_assoc_var): Catch NULL pointer dereference
+	that may occur after an illegal declaration.
+
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-21  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/89574
+	* trans-decl.c (gfc_get_extern_function_decl): Check whether a
+	symbol belongs to a different module.
+
+2020-07-23  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backported from master:
+	2020-07-19  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	PR fortran/96220
+	* dump-parse-tree.c (get_c_type_name): Always use the entries from
+	c_interop_kinds_table to find the correct C type.
+
+2020-07-23  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	PR fortran/96018
+	* frontend-passes.c (gfc_check_externals): Adjust formatting.
+	(implicit_pure_call): New function.
+	(implicit_pure_expr): New function.
+	(gfc_fix_implicit_pure): New function.
+	* gfortran.h (gfc_fix_implicit_pure): New prototype.
+	* parse.c (translate_all_program_units): Call gfc_fix_implicit_pure.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index ae34d8ee366..46a61e437ad 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,60 @@
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-10  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/95980
+	* gfortran.dg/pr95980_2.f90: New file.
+
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-06  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/95980
+	* gfortran.dg/pr95980.f90: New file.
+
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-10  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/96086
+	* gfortran.dg/pr96086.f90: New file.
+
+2020-07-23  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2020-07-21  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/89574
+	* gfortran.dg/pr89574.f90: New file.
+
+2020-07-23  Peter Bergner  <bergner@linux.ibm.com>
+
+	Backported from master:
+	2020-07-22  Peter Bergner  <bergner@linux.ibm.com>
+
+	PR target/96236
+	* gcc.target/powerpc/mma-double-test.c: Update storing results for
+	correct little-endian ordering.
+	* gcc.target/powerpc/mma-single-test.c: Likewise.
+
+2020-07-23  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	PR fortran/96018
+	* gfortran.dg/implicit_pure_5.c: New file.
+	* gfortran.dg/implicit_pure_5.f90: New file.
+
+2020-07-23  Kito Cheng  <kito.cheng@sifive.com>
+
+	Backported from master:
+	2020-07-23  Kito Cheng  <kito.cheng@sifive.com>
+
+	PR target/96260
+	* gcc.target/riscv/pr91441.c: Update warning message.
+	* gcc.target/riscv/pr96260.c: New.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.

commit 6b31ebb3fedafa7d17709f59266a4a66364c7cad
Author: Ian Lance Taylor <iant@golang.org>
Date:   Fri Jul 17 12:30:51 2020 -0700

    libgo: update to Go 1.14.6 release
    
    Reviewed-on: https://go-review.googlesource.com/c/gofrontend/+/243317

diff --git a/libgo/MERGE b/libgo/MERGE
index 07547d064a1..4f8589371d3 100644
--- a/libgo/MERGE
+++ b/libgo/MERGE
@@ -1,4 +1,4 @@
-83b181c68bf332ac7948f145f33d128377a09c42
+edfd6f28486017dcb136cd3f3ec252706d4b326e
 
 The first line of this file holds the git revision number of the
 last merge done from the master library sources.
diff --git a/libgo/VERSION b/libgo/VERSION
index d8281a2e996..398d25321fb 100644
--- a/libgo/VERSION
+++ b/libgo/VERSION
@@ -1 +1 @@
-go1.14.4
+go1.14.6
diff --git a/libgo/go/cmd/go/go_test.go b/libgo/go/cmd/go/go_test.go
index d535ea0ad34..40999f22f8d 100644
--- a/libgo/go/cmd/go/go_test.go
+++ b/libgo/go/cmd/go/go_test.go
@@ -3956,45 +3956,6 @@ func TestCgoFlagContainsSpace(t *testing.T) {
 	tg.grepStderrNot(`"-L[^"]+c flags".*"-L[^"]+c flags"`, "found too many quoted ld flags")
 }
 
-// Issue 9737: verify that GOARM and GO386 affect the computed build ID.
-func TestBuildIDContainsArchModeEnv(t *testing.T) {
-	if testing.Short() {
-		t.Skip("skipping in short mode")
-	}
-
-	var tg *testgoData
-	testWith := func(before, after func()) func(*testing.T) {
-		return func(t *testing.T) {
-			tg = testgo(t)
-			defer tg.cleanup()
-			tg.tempFile("src/mycmd/x.go", `package main
-func main() {}`)
-			tg.setenv("GOPATH", tg.path("."))
-
-			tg.cd(tg.path("src/mycmd"))
-			tg.setenv("GOOS", "linux")
-			before()
-			tg.run("install", "mycmd")
-			after()
-			tg.wantStale("mycmd", "stale dependency", "should be stale after environment variable change")
-		}
-	}
-
-	t.Run("386", testWith(func() {
-		tg.setenv("GOARCH", "386")
-		tg.setenv("GO386", "387")
-	}, func() {
-		tg.setenv("GO386", "sse2")
-	}))
-
-	t.Run("arm", testWith(func() {
-		tg.setenv("GOARCH", "arm")
-		tg.setenv("GOARM", "5")
-	}, func() {
-		tg.setenv("GOARM", "7")
-	}))
-}
-
 func TestListTests(t *testing.T) {
 	tooSlow(t)
 	var tg *testgoData
diff --git a/libgo/go/cmd/go/testdata/test_regexps.txt b/libgo/go/cmd/go/testdata/test_regexps.txt
new file mode 100644
index 00000000000..a616195caba
--- /dev/null
+++ b/libgo/go/cmd/go/testdata/test_regexps.txt
@@ -0,0 +1,75 @@
+go test -cpu=1 -run=X/Y -bench=X/Y -count=2 -v testregexp
+
+# Test the following:
+
+# TestX is run, twice
+stdout -count=2 '^=== RUN   TestX$'
+stdout -count=2 '^    x_test.go:6: LOG: X running$'
+
+# TestX/Y is run, twice
+stdout -count=2 '^=== RUN   TestX/Y$'
+stdout -count=2 '^    x_test.go:8: LOG: Y running$'
+
+# TestXX is run, twice
+stdout -count=2 '^=== RUN   TestXX$'
+stdout -count=2 '^    z_test.go:10: LOG: XX running'
+
+# TestZ is not run
+! stdout '^=== RUN   TestZ$'
+
+# BenchmarkX is run with N=1 once, only to discover what sub-benchmarks it has,
+# and should not print a final summary line.
+stdout -count=1 '^    x_test.go:13: LOG: X running N=1$'
+! stdout '^\s+BenchmarkX: x_test.go:13: LOG: X running N=\d\d+'
+! stdout 'BenchmarkX\s+\d+'
+
+# Same for BenchmarkXX.
+stdout -count=1 '^    z_test.go:18: LOG: XX running N=1$'
+! stdout  '^    z_test.go:18: LOG: XX running N=\d\d+'
+! stdout 'BenchmarkXX\s+\d+'
+
+# BenchmarkX/Y is run in full twice due to -count=2.
+# "Run in full" means that it runs for approximately the default benchtime,
+# but may cap out at N=1e9.
+# We don't actually care what the final iteration count is, but it should be
+# a large number, and the last iteration count prints right before the results.
+stdout -count=2 '^    x_test.go:15: LOG: Y running N=[1-9]\d{4,}\nBenchmarkX/Y\s+\d+'
+
+-- testregexp/x_test.go --
+package x
+
+import "testing"
+
+func TestX(t *testing.T) {
+	t.Logf("LOG: X running")
+	t.Run("Y", func(t *testing.T) {
+		t.Logf("LOG: Y running")
+	})
+}
+
+func BenchmarkX(b *testing.B) {
+	b.Logf("LOG: X running N=%d", b.N)
+	b.Run("Y", func(b *testing.B) {
+		b.Logf("LOG: Y running N=%d", b.N)
+	})
+}
+-- testregexp/z_test.go --
+package x
+
+import "testing"
+
+func TestZ(t *testing.T) {
+	t.Logf("LOG: Z running")
+}
+
+func TestXX(t *testing.T) {
+	t.Logf("LOG: XX running")
+}
+
+func BenchmarkZ(b *testing.B) {
+	b.Logf("LOG: Z running N=%d", b.N)
+}
+
+func BenchmarkXX(b *testing.B) {
+	b.Logf("LOG: XX running N=%d", b.N)
+}
diff --git a/libgo/go/crypto/x509/root_windows.go b/libgo/go/crypto/x509/root_windows.go
index 34d585318d4..1e0f3acb670 100644
--- a/libgo/go/crypto/x509/root_windows.go
+++ b/libgo/go/crypto/x509/root_windows.go
@@ -88,6 +88,9 @@ func checkChainTrustStatus(c *Certificate, chainCtx *syscall.CertChainContext) e
 		switch status {
 		case syscall.CERT_TRUST_IS_NOT_TIME_VALID:
 			return CertificateInvalidError{c, Expired, ""}
+		case syscall.CERT_TRUST_IS_NOT_VALID_FOR_USAGE:
+			return CertificateInvalidError{c, IncompatibleUsage, ""}
+		// TODO(filippo): surface more error statuses.
 		default:
 			return UnknownAuthorityError{c, nil, nil}
 		}
@@ -138,11 +141,19 @@ func checkChainSSLServerPolicy(c *Certificate, chainCtx *syscall.CertChainContex
 	return nil
 }
 
+// windowsExtKeyUsageOIDs are the C NUL-terminated string representations of the
+// OIDs for use with the Windows API.
+var windowsExtKeyUsageOIDs = make(map[ExtKeyUsage][]byte, len(extKeyUsageOIDs))
+
+func init() {
+	for _, eku := range extKeyUsageOIDs {
+		windowsExtKeyUsageOIDs[eku.extKeyUsage] = []byte(eku.oid.String() + "\x00")
+	}
+}
+
 // systemVerify is like Verify, except that it uses CryptoAPI calls
 // to build certificate chains and verify them.
 func (c *Certificate) systemVerify(opts *VerifyOptions) (chains [][]*Certificate, err error) {
-	hasDNSName := opts != nil && len(opts.DNSName) > 0
-
 	storeCtx, err := createStoreContext(c, opts)
 	if err != nil {
 		return nil, err
@@ -152,17 +163,26 @@ func (c *Certificate) systemVerify(opts *VerifyOptions) (chains [][]*Certificate
 	para := new(syscall.CertChainPara)
 	para.Size = uint32(unsafe.Sizeof(*para))
 
-	// If there's a DNSName set in opts, assume we're verifying
-	// a certificate from a TLS server.
-	if hasDNSName {
-		oids := []*byte{
-			&syscall.OID_PKIX_KP_SERVER_AUTH[0],
-			// Both IE and Chrome allow certificates with
-			// Server Gated Crypto as well. Some certificates
-			// in the wild require them.
-			&syscall.OID_SERVER_GATED_CRYPTO[0],
-			&syscall.OID_SGC_NETSCAPE[0],
+	keyUsages := opts.KeyUsages
+	if len(keyUsages) == 0 {
+		keyUsages = []ExtKeyUsage{ExtKeyUsageServerAuth}
+	}
+	oids := make([]*byte, 0, len(keyUsages))
+	for _, eku := range keyUsages {
+		if eku == ExtKeyUsageAny {
+			oids = nil
+			break
+		}
+		if oid, ok := windowsExtKeyUsageOIDs[eku]; ok {
+			oids = append(oids, &oid[0])
 		}
+		// Like the standard verifier, accept SGC EKUs as equivalent to ServerAuth.
+		if eku == ExtKeyUsageServerAuth {
+			oids = append(oids, &syscall.OID_SERVER_GATED_CRYPTO[0])
+			oids = append(oids, &syscall.OID_SGC_NETSCAPE[0])
+		}
+	}
+	if oids != nil {
 		para.RequestedUsage.Type = syscall.USAGE_MATCH_TYPE_OR
 		para.RequestedUsage.Usage.Length = uint32(len(oids))
 		para.RequestedUsage.Usage.UsageIdentifiers = &oids[0]
@@ -208,7 +228,7 @@ func (c *Certificate) systemVerify(opts *VerifyOptions) (chains [][]*Certificate
 		return nil, err
 	}
 
-	if hasDNSName {
+	if opts != nil && len(opts.DNSName) > 0 {
 		err = checkChainSSLServerPolicy(c, chainCtx, opts)
 		if err != nil {
 			return nil, err
diff --git a/libgo/go/crypto/x509/verify.go b/libgo/go/crypto/x509/verify.go
index 358fca4705b..c80b5ac825d 100644
--- a/libgo/go/crypto/x509/verify.go
+++ b/libgo/go/crypto/x509/verify.go
@@ -188,23 +188,32 @@ var errNotParsed = errors.New("x509: missing ASN.1 contents; use ParseCertificat
 // VerifyOptions contains parameters for Certificate.Verify. It's a structure
 // because other PKIX verification APIs have ended up needing many options.
 type VerifyOptions struct {
-	DNSName       string
+	// DNSName, if set, is checked against the leaf certificate with
+	// Certificate.VerifyHostname or the platform verifier.
+	DNSName string
+
+	// Intermediates is an optional pool of certificates that are not trust
+	// anchors, but can be used to form a chain from the leaf certificate to a
+	// root certificate.
 	Intermediates *CertPool
-	Roots         *CertPool // if nil, the system roots are used
-	CurrentTime   time.Time // if zero, the current time is used
-	// KeyUsage specifies which Extended Key Usage values are acceptable. A leaf
-	// certificate is accepted if it contains any of the listed values. An empty
-	// list means ExtKeyUsageServerAuth. To accept any key usage, include
-	// ExtKeyUsageAny.
-	//
-	// Certificate chains are required to nest these extended key usage values.
-	// (This matches the Windows CryptoAPI behavior, but not the spec.)
+	// Roots is the set of trusted root certificates the leaf certificate needs
+	// to chain up to. If nil, the system roots or the platform verifier are used.
+	Roots *CertPool
+
+	// CurrentTime is used to check the validity of all certificates in the
+	// chain. If zero, the current time is used.
+	CurrentTime time.Time
+
+	// KeyUsages specifies which Extended Key Usage values are acceptable. A
+	// chain is accepted if it allows any of the listed values. An empty list
+	// means ExtKeyUsageServerAuth. To accept any key usage, include ExtKeyUsageAny.
 	KeyUsages []ExtKeyUsage
+
 	// MaxConstraintComparisions is the maximum number of comparisons to
 	// perform when checking a given certificate's name constraints. If
 	// zero, a sensible default is used. This limit prevents pathological
 	// certificates from consuming excessive amounts of CPU time when
-	// validating.
+	// validating. It does not apply to the platform verifier.
 	MaxConstraintComparisions int
 }
 
@@ -717,8 +726,9 @@ func (c *Certificate) isValid(certType int, currentChain []*Certificate, opts *V
 // needed. If successful, it returns one or more chains where the first
 // element of the chain is c and the last element is from opts.Roots.
 //
-// If opts.Roots is nil and system roots are unavailable the returned error
-// will be of type SystemRootsError.
+// If opts.Roots is nil, the platform verifier might be used, and
+// verification details might differ from what is described below. If system
+// roots are unavailable the returned error will be of type SystemRootsError.
 //
 // Name constraints in the intermediates will be applied to all names claimed
 // in the chain, not just opts.DNSName. Thus it is invalid for a leaf to claim
@@ -726,9 +736,10 @@ func (c *Certificate) isValid(certType int, currentChain []*Certificate, opts *V
 // the name being validated. Note that DirectoryName constraints are not
 // supported.
 //
-// Extended Key Usage values are enforced down a chain, so an intermediate or
-// root that enumerates EKUs prevents a leaf from asserting an EKU not in that
-// list.
+// Extended Key Usage values are enforced nested down a chain, so an intermediate
+// or root that enumerates EKUs prevents a leaf from asserting an EKU not in that
+// list. (While this is not specified, it is common practice in order to limit
+// the types of certificates a CA can issue.)
 //
 // WARNING: this function doesn't do any revocation checking.
 func (c *Certificate) Verify(opts VerifyOptions) (chains [][]*Certificate, err error) {
diff --git a/libgo/go/crypto/x509/verify_test.go b/libgo/go/crypto/x509/verify_test.go
index 86fe76a57d7..bbb68db8578 100644
--- a/libgo/go/crypto/x509/verify_test.go
+++ b/libgo/go/crypto/x509/verify_test.go
@@ -21,34 +21,24 @@ import (
 )
 
 type verifyTest struct {
-	leaf                 string
-	intermediates        []string
-	roots                []string
-	currentTime          int64
-	dnsName              string
-	systemSkip           bool
-	keyUsages            []ExtKeyUsage
-	testSystemRootsError bool
-	sha2                 bool
-	ignoreCN             bool
-
-	errorCallback  func(*testing.T, int, error) bool
+	name          string
+	leaf          string
+	intermediates []string
+	roots         []string
+	currentTime   int64
+	dnsName       string
+	systemSkip    bool
+	systemLax     bool
+	keyUsages     []ExtKeyUsage
+	ignoreCN      bool
+
+	errorCallback  func(*testing.T, error)
 	expectedChains [][]string
 }
 
 var verifyTests = []verifyTest{
 	{
-		leaf:                 googleLeaf,
-		intermediates:        []string{giag2Intermediate},
-		currentTime:          1395785200,
-		dnsName:              "www.google.com",
-		testSystemRootsError: true,
-
-		// Without any roots specified we should get a system roots
-		// error.
-		errorCallback: expectSystemRootsError,
-	},
-	{
+		name:          "Valid",
 		leaf:          googleLeaf,
 		intermediates: []string{giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -60,6 +50,7 @@ var verifyTests = []verifyTest{
 		},
 	},
 	{
+		name:          "MixedCase",
 		leaf:          googleLeaf,
 		intermediates: []string{giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -71,6 +62,7 @@ var verifyTests = []verifyTest{
 		},
 	},
 	{
+		name:          "HostnameMismatch",
 		leaf:          googleLeaf,
 		intermediates: []string{giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -80,6 +72,7 @@ var verifyTests = []verifyTest{
 		errorCallback: expectHostnameError("certificate is valid for"),
 	},
 	{
+		name:          "IPMissing",
 		leaf:          googleLeaf,
 		intermediates: []string{giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -89,6 +82,7 @@ var verifyTests = []verifyTest{
 		errorCallback: expectHostnameError("doesn't contain any IP SANs"),
 	},
 	{
+		name:          "Expired",
 		leaf:          googleLeaf,
 		intermediates: []string{giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -98,6 +92,7 @@ var verifyTests = []verifyTest{
 		errorCallback: expectExpired,
 	},
 	{
+		name:        "MissingIntermediate",
 		leaf:        googleLeaf,
 		roots:       []string{geoTrustRoot},
 		currentTime: 1395785200,
@@ -109,6 +104,7 @@ var verifyTests = []verifyTest{
 		errorCallback: expectAuthorityUnknown,
 	},
 	{
+		name:          "RootInIntermediates",
 		leaf:          googleLeaf,
 		intermediates: []string{geoTrustRoot, giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -119,31 +115,50 @@ var verifyTests = []verifyTest{
 			{"Google", "Google Internet Authority", "GeoTrust"},
 		},
 		// CAPI doesn't build the chain with the duplicated GeoTrust
-		// entry so the results don't match. Thus we skip this test
-		// until that's fixed.
+		// entry so the results don't match.
+		systemLax: true,
+	},
+	{
+		name:          "dnssec-exp",
+		leaf:          dnssecExpLeaf,
+		intermediates: []string{startComIntermediate},
+		roots:         []string{startComRoot},
+		currentTime:   1302726541,
+
+		// The StartCom root is not trusted by Windows when the default
+		// ServerAuth EKU is requested.
 		systemSkip: true,
+
+		expectedChains: [][]string{
+			{"dnssec-exp", "StartCom Class 1", "StartCom Certification Authority"},
+		},
 	},
 	{
+		name:          "dnssec-exp/AnyEKU",
 		leaf:          dnssecExpLeaf,
 		intermediates: []string{startComIntermediate},
 		roots:         []string{startComRoot},
 		currentTime:   1302726541,
+		keyUsages:     []ExtKeyUsage{ExtKeyUsageAny},
 
 		expectedChains: [][]string{
 			{"dnssec-exp", "StartCom Class 1", "StartCom Certification Authority"},
 		},
 	},
 	{
+		name:          "dnssec-exp/RootInIntermediates",
 		leaf:          dnssecExpLeaf,
 		intermediates: []string{startComIntermediate, startComRoot},
 		roots:         []string{startComRoot},
 		currentTime:   1302726541,
+		systemSkip:    true, // see dnssec-exp test
 
 		expectedChains: [][]string{
 			{"dnssec-exp", "StartCom Class 1", "StartCom Certification Authority"},
 		},
 	},
 	{
+		name:          "InvalidHash",
 		leaf:          googleLeafWithInvalidHash,
 		intermediates: []string{giag2Intermediate},
 		roots:         []string{geoTrustRoot},
@@ -152,50 +167,52 @@ var verifyTests = []verifyTest{
 
 		// The specific error message may not occur when using system
 		// verification.
-		systemSkip:    true,
+		systemLax:     true,
 		errorCallback: expectHashError,
 	},
+	// EKULeaf tests use an unconstrained chain leading to a leaf certificate
+	// with an E-mail Protection EKU but not a Server Auth one, checking that
+	// the EKUs on the leaf are enforced.
 	{
-		// The default configuration should reject an S/MIME chain.
-		leaf:        smimeLeaf,
-		roots:       []string{smimeIntermediate},
-		currentTime: 1339436154,
+		name:          "EKULeaf",
+		leaf:          smimeLeaf,
+		intermediates: []string{smimeIntermediate},
+		roots:         []string{smimeRoot},
+		currentTime:   1594673418,
 
-		// Key usage not implemented for Windows yet.
-		systemSkip:    true,
 		errorCallback: expectUsageError,
 	},
 	{
-		leaf:        smimeLeaf,
-		roots:       []string{smimeIntermediate},
-		currentTime: 1339436154,
-		keyUsages:   []ExtKeyUsage{ExtKeyUsageServerAuth},
+		name:          "EKULeafExplicit",
+		leaf:          smimeLeaf,
+		intermediates: []string{smimeIntermediate},
+		roots:         []string{smimeRoot},
+		currentTime:   1594673418,
+		keyUsages:     []ExtKeyUsage{ExtKeyUsageServerAuth},
 
-		// Key usage not implemented for Windows yet.
-		systemSkip:    true,
 		errorCallback: expectUsageError,
 	},
 	{
-		leaf:        smimeLeaf,
-		roots:       []string{smimeIntermediate},
-		currentTime: 1339436154,
-		keyUsages:   []ExtKeyUsage{ExtKeyUsageEmailProtection},
+		name:          "EKULeafValid",
+		leaf:          smimeLeaf,
+		intermediates: []string{smimeIntermediate},
+		roots:         []string{smimeRoot},
+		currentTime:   1594673418,
+		keyUsages:     []ExtKeyUsage{ExtKeyUsageEmailProtection},
 
-		// Key usage not implemented for Windows yet.
-		systemSkip: true,
 		expectedChains: [][]string{
-			{"Ryan Hurst", "GlobalSign PersonalSign 2 CA - G2"},
+			{"CORPORATIVO FICTICIO ACTIVO", "EAEko Herri Administrazioen CA - CA AAPP Vascas (2)", "IZENPE S.A."},
 		},
 	},
 	{
+		name:          "SGCIntermediate",
 		leaf:          megaLeaf,
 		intermediates: []string{comodoIntermediate1},
 		roots:         []string{comodoRoot},
 		currentTime:   1360431182,
 
-		// CryptoAPI can find alternative validation paths so we don't
-		// perform this test with system validation.
-		systemSkip: true,
+		// CryptoAPI can find alternative validation paths.
+		systemLax: true,
 		expectedChains: [][]string{
 			{"mega.co.nz", "EssentialSSL CA", "COMODO Certification Authority"},
 		},
@@ -203,6 +220,7 @@ var verifyTests = []verifyTest{
 	{
 		// Check that a name constrained intermediate works even when
 		// it lists multiple constraints.
+		name:          "MultipleConstraints",
 		leaf:          nameConstraintsLeaf,
 		intermediates: []string{nameConstraintsIntermediate1, nameConstraintsIntermediate2},
 		roots:         []string{globalSignRoot},
@@ -221,17 +239,16 @@ var verifyTests = []verifyTest{
 	{
 		// Check that SHA-384 intermediates (which are popping up)
 		// work.
+		name:          "SHA-384",
 		leaf:          moipLeafCert,
 		intermediates: []string{comodoIntermediateSHA384, comodoRSAAuthority},
 		roots:         []string{addTrustRoot},
 		currentTime:   1397502195,
 		dnsName:       "api.moip.com.br",
 
-		// CryptoAPI can find alternative validation paths so we don't
-		// perform this test with system validation.
-		systemSkip: true,
+		// CryptoAPI can find alternative validation paths.
+		systemLax: true,
 
-		sha2: true,
 		expectedChains: [][]string{
 			{
 				"api.moip.com.br",
@@ -244,11 +261,12 @@ var verifyTests = []verifyTest{
 	{
 		// Putting a certificate as a root directly should work as a
 		// way of saying “exactly this”.
+		name:        "LeafInRoots",
 		leaf:        selfSigned,
 		roots:       []string{selfSigned},
 		currentTime: 1471624472,
 		dnsName:     "foo.example",
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		expectedChains: [][]string{
 			{"Acme Co"},
@@ -257,11 +275,12 @@ var verifyTests = []verifyTest{
 	{
 		// Putting a certificate as a root directly should not skip
 		// other checks however.
+		name:        "LeafInRootsInvalid",
 		leaf:        selfSigned,
 		roots:       []string{selfSigned},
 		currentTime: 1471624472,
 		dnsName:     "notfoo.example",
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		errorCallback: expectHostnameError("certificate is valid for"),
 	},
@@ -269,87 +288,95 @@ var verifyTests = []verifyTest{
 		// The issuer name in the leaf doesn't exactly match the
 		// subject name in the root. Go does not perform
 		// canonicalization and so should reject this. See issue 14955.
+		name:        "IssuerSubjectMismatch",
 		leaf:        issuerSubjectMatchLeaf,
 		roots:       []string{issuerSubjectMatchRoot},
 		currentTime: 1475787715,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		errorCallback: expectSubjectIssuerMismatcthError,
 	},
 	{
 		// An X.509 v1 certificate should not be accepted as an
 		// intermediate.
+		name:          "X509v1Intermediate",
 		leaf:          x509v1TestLeaf,
 		intermediates: []string{x509v1TestIntermediate},
 		roots:         []string{x509v1TestRoot},
 		currentTime:   1481753183,
-		systemSkip:    true,
+		systemSkip:    true, // does not chain to a system root
 
 		errorCallback: expectNotAuthorizedError,
 	},
 	{
 		// If any SAN extension is present (even one without any DNS
 		// names), the CN should be ignored.
+		name:        "IgnoreCNWithSANs",
 		leaf:        ignoreCNWithSANLeaf,
 		dnsName:     "foo.example.com",
 		roots:       []string{ignoreCNWithSANRoot},
 		currentTime: 1486684488,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		errorCallback: expectHostnameError("certificate is not valid for any names"),
 	},
 	{
 		// Test that excluded names are respected.
+		name:          "ExcludedNames",
 		leaf:          excludedNamesLeaf,
 		dnsName:       "bender.local",
 		intermediates: []string{excludedNamesIntermediate},
 		roots:         []string{excludedNamesRoot},
 		currentTime:   1486684488,
-		systemSkip:    true,
+		systemSkip:    true, // does not chain to a system root
 
 		errorCallback: expectNameConstraintsError,
 	},
 	{
 		// Test that unknown critical extensions in a leaf cause a
 		// verify error.
+		name:          "CriticalExtLeaf",
 		leaf:          criticalExtLeafWithExt,
 		dnsName:       "example.com",
 		intermediates: []string{criticalExtIntermediate},
 		roots:         []string{criticalExtRoot},
 		currentTime:   1486684488,
-		systemSkip:    true,
+		systemSkip:    true, // does not chain to a system root
 
 		errorCallback: expectUnhandledCriticalExtension,
 	},
 	{
 		// Test that unknown critical extensions in an intermediate
 		// cause a verify error.
+		name:          "CriticalExtIntermediate",
 		leaf:          criticalExtLeaf,
 		dnsName:       "example.com",
 		intermediates: []string{criticalExtIntermediateWithExt},
 		roots:         []string{criticalExtRoot},
 		currentTime:   1486684488,
-		systemSkip:    true,
+		systemSkip:    true, // does not chain to a system root
 
 		errorCallback: expectUnhandledCriticalExtension,
 	},
 	{
 		// Test that invalid CN are ignored.
+		name:        "InvalidCN",
 		leaf:        invalidCNWithoutSAN,
 		dnsName:     "foo,invalid",
 		roots:       []string{invalidCNRoot},
 		currentTime: 1540000000,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		errorCallback: expectHostnameError("Common Name is not a valid hostname"),
 	},
 	{
 		// Test that valid CN are respected.
+		name:        "ValidCN",
 		leaf:        validCNWithoutSAN,
 		dnsName:     "foo.example.com",
 		roots:       []string{invalidCNRoot},
 		currentTime: 1540000000,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		expectedChains: [][]string{
 			{"foo.example.com", "Test root"},
@@ -357,31 +384,34 @@ var verifyTests = []verifyTest{
 	},
 	// Replicate CN tests with ignoreCN = true
 	{
+		name:        "IgnoreCNWithSANs/ignoreCN",
 		leaf:        ignoreCNWithSANLeaf,
 		dnsName:     "foo.example.com",
 		roots:       []string{ignoreCNWithSANRoot},
 		currentTime: 1486684488,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 		ignoreCN:    true,
 
 		errorCallback: expectHostnameError("certificate is not valid for any names"),
 	},
 	{
+		name:        "InvalidCN/ignoreCN",
 		leaf:        invalidCNWithoutSAN,
 		dnsName:     "foo,invalid",
 		roots:       []string{invalidCNRoot},
 		currentTime: 1540000000,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 		ignoreCN:    true,
 
 		errorCallback: expectHostnameError("Common Name is not a valid hostname"),
 	},
 	{
+		name:        "ValidCN/ignoreCN",
 		leaf:        validCNWithoutSAN,
 		dnsName:     "foo.example.com",
 		roots:       []string{invalidCNRoot},
 		currentTime: 1540000000,
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 		ignoreCN:    true,
 
 		errorCallback: expectHostnameError("not valid for any names"),
@@ -389,11 +419,12 @@ var verifyTests = []verifyTest{
 	{
 		// A certificate with an AKID should still chain to a parent without SKID.
 		// See Issue 30079.
+		name:        "AKIDNoSKID",
 		leaf:        leafWithAKID,
 		roots:       []string{rootWithoutSKID},
 		currentTime: 1550000000,
 		dnsName:     "example",
-		systemSkip:  true,
+		systemSkip:  true, // does not chain to a system root
 
 		expectedChains: [][]string{
 			{"Acme LLC", "Acme Co"},
@@ -401,98 +432,70 @@ var verifyTests = []verifyTest{
 	},
 }
 
-func expectHostnameError(msg string) func(*testing.T, int, error) bool {
-	return func(t *testing.T, i int, err error) (ok bool) {
+func expectHostnameError(msg string) func(*testing.T, error) {
+	return func(t *testing.T, err error) {
 		if _, ok := err.(HostnameError); !ok {
-			t.Errorf("#%d: error was not a HostnameError: %v", i, err)
-			return false
+			t.Fatalf("error was not a HostnameError: %v", err)
 		}
 		if !strings.Contains(err.Error(), msg) {
-			t.Errorf("#%d: HostnameError did not contain %q: %v", i, msg, err)
+			t.Fatalf("HostnameError did not contain %q: %v", msg, err)
 		}
-		return true
 	}
 }
 
-func expectExpired(t *testing.T, i int, err error) (ok bool) {
+func expectExpired(t *testing.T, err error) {
 	if inval, ok := err.(CertificateInvalidError); !ok || inval.Reason != Expired {
-		t.Errorf("#%d: error was not Expired: %v", i, err)
-		return false
+		t.Fatalf("error was not Expired: %v", err)
 	}
-	return true
 }
 
-func expectUsageError(t *testing.T, i int, err error) (ok bool) {
+func expectUsageError(t *testing.T, err error) {
 	if inval, ok := err.(CertificateInvalidError); !ok || inval.Reason != IncompatibleUsage {
-		t.Errorf("#%d: error was not IncompatibleUsage: %v", i, err)
-		return false
+		t.Fatalf("error was not IncompatibleUsage: %v", err)
 	}
-	return true
 }
 
-func expectAuthorityUnknown(t *testing.T, i int, err error) (ok bool) {
+func expectAuthorityUnknown(t *testing.T, err error) {
 	e, ok := err.(UnknownAuthorityError)
 	if !ok {
-		t.Errorf("#%d: error was not UnknownAuthorityError: %v", i, err)
-		return false
+		t.Fatalf("error was not UnknownAuthorityError: %v", err)
 	}
 	if e.Cert == nil {
-		t.Errorf("#%d: error was UnknownAuthorityError, but missing Cert: %v", i, err)
-		return false
+		t.Fatalf("error was UnknownAuthorityError, but missing Cert: %v", err)
 	}
-	return true
 }
 
-func expectSystemRootsError(t *testing.T, i int, err error) bool {
-	if _, ok := err.(SystemRootsError); !ok {
-		t.Errorf("#%d: error was not SystemRootsError: %v", i, err)
-		return false
-	}
-	return true
-}
-
-func expectHashError(t *testing.T, i int, err error) bool {
+func expectHashError(t *testing.T, err error) {
 	if err == nil {
-		t.Errorf("#%d: no error resulted from invalid hash", i)
-		return false
+		t.Fatalf("no error resulted from invalid hash")
 	}
 	if expected := "algorithm unimplemented"; !strings.Contains(err.Error(), expected) {
-		t.Errorf("#%d: error resulting from invalid hash didn't contain '%s', rather it was: %v", i, expected, err)
-		return false
+		t.Fatalf("error resulting from invalid hash didn't contain '%s', rather it was: %v", expected, err)
 	}
-	return true
 }
 
-func expectSubjectIssuerMismatcthError(t *testing.T, i int, err error) (ok bool) {
+func expectSubjectIssuerMismatcthError(t *testing.T, err error) {
 	if inval, ok := err.(CertificateInvalidError); !ok || inval.Reason != NameMismatch {
-		t.Errorf("#%d: error was not a NameMismatch: %v", i, err)
-		return false
+		t.Fatalf("error was not a NameMismatch: %v", err)
 	}
-	return true
 }
 
-func expectNameConstraintsError(t *testing.T, i int, err error) (ok bool) {
+func expectNameConstraintsError(t *testing.T, err error) {
 	if inval, ok := err.(CertificateInvalidError); !ok || inval.Reason != CANotAuthorizedForThisName {
-		t.Errorf("#%d: error was not a CANotAuthorizedForThisName: %v", i, err)
-		return false
+		t.Fatalf("error was not a CANotAuthorizedForThisName: %v", err)
 	}
-	return true
 }
 
-func expectNotAuthorizedError(t *testing.T, i int, err error) (ok bool) {
+func expectNotAuthorizedError(t *testing.T, err error) {
 	if inval, ok := err.(CertificateInvalidError); !ok || inval.Reason != NotAuthorizedToSign {
-		t.Errorf("#%d: error was not a NotAuthorizedToSign: %v", i, err)
-		return false
+		t.Fatalf("error was not a NotAuthorizedToSign: %v", err)
 	}
-	return true
 }
 
-func expectUnhandledCriticalExtension(t *testing.T, i int, err error) (ok bool) {
+func expectUnhandledCriticalExtension(t *testing.T, err error) {
 	if _, ok := err.(UnhandledCriticalExtension); !ok {
-		t.Errorf("#%d: error was not an UnhandledCriticalExtension: %v", i, err)
-		return false
+		t.Fatalf("error was not an UnhandledCriticalExtension: %v", err)
 	}
-	return true
 }
 
 func certificateFromPEM(pemBytes string) (*Certificate, error) {
@@ -503,107 +506,91 @@ func certificateFromPEM(pemBytes string) (*Certificate, error) {
 	return ParseCertificate(block.Bytes)
 }
 
-func testVerify(t *testing.T, useSystemRoots bool) {
-	defer func(savedIgnoreCN bool) {
-		ignoreCN = savedIgnoreCN
-	}(ignoreCN)
-	for i, test := range verifyTests {
-		if useSystemRoots && test.systemSkip {
-			continue
-		}
-		if runtime.GOOS == "windows" && test.testSystemRootsError {
-			continue
-		}
-
-		ignoreCN = test.ignoreCN
-		opts := VerifyOptions{
-			Intermediates: NewCertPool(),
-			DNSName:       test.dnsName,
-			CurrentTime:   time.Unix(test.currentTime, 0),
-			KeyUsages:     test.keyUsages,
-		}
+func testVerify(t *testing.T, test verifyTest, useSystemRoots bool) {
+	defer func(savedIgnoreCN bool) { ignoreCN = savedIgnoreCN }(ignoreCN)
 
-		if !useSystemRoots {
-			opts.Roots = NewCertPool()
-			for j, root := range test.roots {
-				ok := opts.Roots.AppendCertsFromPEM([]byte(root))
-				if !ok {
-					t.Errorf("#%d: failed to parse root #%d", i, j)
-					return
-				}
-			}
-		}
+	ignoreCN = test.ignoreCN
+	opts := VerifyOptions{
+		Intermediates: NewCertPool(),
+		DNSName:       test.dnsName,
+		CurrentTime:   time.Unix(test.currentTime, 0),
+		KeyUsages:     test.keyUsages,
+	}
 
-		for j, intermediate := range test.intermediates {
-			ok := opts.Intermediates.AppendCertsFromPEM([]byte(intermediate))
+	if !useSystemRoots {
+		opts.Roots = NewCertPool()
+		for j, root := range test.roots {
+			ok := opts.Roots.AppendCertsFromPEM([]byte(root))
 			if !ok {
-				t.Errorf("#%d: failed to parse intermediate #%d", i, j)
-				return
+				t.Fatalf("failed to parse root #%d", j)
 			}
 		}
+	}
 
-		leaf, err := certificateFromPEM(test.leaf)
-		if err != nil {
-			t.Errorf("#%d: failed to parse leaf: %v", i, err)
-			return
-		}
-
-		var oldSystemRoots *CertPool
-		if test.testSystemRootsError {
-			oldSystemRoots = systemRootsPool()
-			systemRoots = nil
-			opts.Roots = nil
+	for j, intermediate := range test.intermediates {
+		ok := opts.Intermediates.AppendCertsFromPEM([]byte(intermediate))
+		if !ok {
+			t.Fatalf("failed to parse intermediate #%d", j)
 		}
+	}
 
-		chains, err := leaf.Verify(opts)
+	leaf, err := certificateFromPEM(test.leaf)
+	if err != nil {
+		t.Fatalf("failed to parse leaf: %v", err)
+	}
 
-		if test.testSystemRootsError {
-			systemRoots = oldSystemRoots
-		}
+	chains, err := leaf.Verify(opts)
 
-		if test.errorCallback == nil && err != nil {
-			t.Errorf("#%d: unexpected error: %v", i, err)
-		}
-		if test.errorCallback != nil {
-			if !test.errorCallback(t, i, err) {
-				return
+	if test.errorCallback == nil && err != nil {
+		t.Fatalf("unexpected error: %v", err)
+	}
+	if test.errorCallback != nil {
+		if useSystemRoots && test.systemLax {
+			if err == nil {
+				t.Fatalf("expected error")
 			}
+		} else {
+			test.errorCallback(t, err)
 		}
+	}
 
-		if len(chains) != len(test.expectedChains) {
-			t.Errorf("#%d: wanted %d chains, got %d", i, len(test.expectedChains), len(chains))
-		}
+	if len(chains) != len(test.expectedChains) {
+		t.Errorf("wanted %d chains, got %d", len(test.expectedChains), len(chains))
+	}
 
-		// We check that each returned chain matches a chain from
-		// expectedChains but an entry in expectedChains can't match
-		// two chains.
-		seenChains := make([]bool, len(chains))
-	NextOutputChain:
-		for _, chain := range chains {
-		TryNextExpected:
-			for j, expectedChain := range test.expectedChains {
-				if seenChains[j] {
-					continue
-				}
-				if len(chain) != len(expectedChain) {
-					continue
-				}
-				for k, cert := range chain {
-					if !strings.Contains(nameToKey(&cert.Subject), expectedChain[k]) {
-						continue TryNextExpected
-					}
+	// We check that each returned chain matches a chain from
+	// expectedChains but an entry in expectedChains can't match
+	// two chains.
+	seenChains := make([]bool, len(chains))
+NextOutputChain:
+	for _, chain := range chains {
+	TryNextExpected:
+		for j, expectedChain := range test.expectedChains {
+			if seenChains[j] {
+				continue
+			}
+			if len(chain) != len(expectedChain) {
+				continue
+			}
+			for k, cert := range chain {
+				if !strings.Contains(nameToKey(&cert.Subject), expectedChain[k]) {
+					continue TryNextExpected
 				}
-				// we matched
-				seenChains[j] = true
-				continue NextOutputChain
 			}
-			t.Errorf("#%d: No expected chain matched %s", i, chainToDebugString(chain))
+			// we matched
+			seenChains[j] = true
+			continue NextOutputChain
 		}
+		t.Errorf("no expected chain matched %s", chainToDebugString(chain))
 	}
 }
 
 func TestGoVerify(t *testing.T) {
-	testVerify(t, false)
+	for _, test := range verifyTests {
+		t.Run(test.name, func(t *testing.T) {
+			testVerify(t, test, false)
+		})
+	}
 }
 
 func TestSystemVerify(t *testing.T) {
@@ -611,7 +598,14 @@ func TestSystemVerify(t *testing.T) {
 		t.Skipf("skipping verify test using system APIs on %q", runtime.GOOS)
 	}
 
-	testVerify(t, true)
+	for _, test := range verifyTests {
+		t.Run(test.name, func(t *testing.T) {
+			if test.systemSkip {
+				t.SkipNow()
+			}
+			testVerify(t, test, true)
+		})
+	}
 }
 
 func chainToDebugString(chain []*Certificate) string {
@@ -648,8 +642,7 @@ tQWVYrmm3ok9Nns4d0iXrKYgjy6myQzCsplFAMfOEVEiIuCl6rYVSAlk6l5PdPcF
 PseKUgzbFbS9bZvlxrFUaKnjaZC2mqUPuLk/IH2uSrW4nOQdtqvmlKXBx4Ot2/Un
 hw4EbNX/3aBd7YdStysVAq45pmp06drE57xNNB6pXE0zX5IJL4hmXXeXxx12E6nV
 5fEWCRE11azbJHFwLJhWC9kXtNHjUStedejV0NxPNO3CBWaAocvmMw==
------END CERTIFICATE-----
-`
+-----END CERTIFICATE-----`
 
 const giag2Intermediate = `-----BEGIN CERTIFICATE-----
 MIIEBDCCAuygAwIBAgIDAjppMA0GCSqGSIb3DQEBBQUAMEIxCzAJBgNVBAYTAlVT
@@ -674,8 +667,7 @@ zG+FA1jDaFETzf3I93k9mTXwVqO94FntT0QJo544evZG0R0SnU++0ED8Vf4GXjza
 HFa9llF7b1cq26KqltyMdMKVvvBulRP/F/A8rLIQjcxz++iPAsbw+zOzlTvjwsto
 WHPbqCRiOwY1nQ2pM714A5AuTHhdUDqB1O6gyHA43LL5Z/qHQF1hwFGPa4NrzQU6
 yuGnBXj8ytqU0CwIPX4WecigUCAkVDNx
------END CERTIFICATE-----
-`
+-----END CERTIFICATE-----`
 
 const googleLeaf = `-----BEGIN CERTIFICATE-----
 MIIEdjCCA16gAwIBAgIIcR5k4dkoe04wDQYJKoZIhvcNAQEFBQAwSTELMAkGA1UE
@@ -702,8 +694,7 @@ tJAW0kYGJ+wqKm53wG/JaOADTnnq2Mt/j6F2uvjgN/ouns1nRHufIvd370N0LeH+
 orKqTuAPzXK7imQk6+OycYABbqCtC/9qmwRd8wwn7sF97DtYfK8WuNHtFalCAwyi
 8LxJJYJCLWoMhZ+V8GZm+FOex5qkQAjnZrtNlbQJ8ro4r+rpKXtmMFFhfa+7L+PA
 Kom08eUK8skxAzfDDijZPh10VtJ66uBoiDPdT+uCBehcBIcmSTrKjFGX
------END CERTIFICATE-----
-`
+-----END CERTIFICATE-----`
 
 // googleLeafWithInvalidHash is the same as googleLeaf, but the signature
 // algorithm in the certificate contains a nonsense OID.
@@ -732,8 +723,7 @@ tJAW0kYGJ+wqKm53wG/JaOADTnnq2Mt/j6F2uvjgN/ouns1nRHufIvd370N0LeH+
 orKqTuAPzXK7imQk6+OycYABbqCtC/9qmwRd8wwn7sF97DtYfK8WuNHtFalCAwyi
 8LxJJYJCLWoMhZ+V8GZm+FOex5qkQAjnZrtNlbQJ8ro4r+rpKXtmMFFhfa+7L+PA
 Kom08eUK8skxAzfDDijZPh10VtJ66uBoiDPdT+uCBehcBIcmSTrKjFGX
------END CERTIFICATE-----
-`
+-----END CERTIFICATE-----`
 
 const dnssecExpLeaf = `-----BEGIN CERTIFICATE-----
 MIIGzTCCBbWgAwIBAgIDAdD6MA0GCSqGSIb3DQEBBQUAMIGMMQswCQYDVQQGEwJJ
@@ -858,58 +848,127 @@ NOsF/5oirpt9P/FlUQqmMGqz9IgcgA38corog14=
 -----END CERTIFICATE-----`
 
 const smimeLeaf = `-----BEGIN CERTIFICATE-----
-MIIFBjCCA+6gAwIBAgISESFvrjT8XcJTEe6rBlPptILlMA0GCSqGSIb3DQEBBQUA
-MFQxCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMSowKAYD
-VQQDEyFHbG9iYWxTaWduIFBlcnNvbmFsU2lnbiAyIENBIC0gRzIwHhcNMTIwMTIz
-MTYzNjU5WhcNMTUwMTIzMTYzNjU5WjCBlDELMAkGA1UEBhMCVVMxFjAUBgNVBAgT
-DU5ldyBIYW1zcGhpcmUxEzARBgNVBAcTClBvcnRzbW91dGgxGTAXBgNVBAoTEEds
-b2JhbFNpZ24sIEluYy4xEzARBgNVBAMTClJ5YW4gSHVyc3QxKDAmBgkqhkiG9w0B
-CQEWGXJ5YW4uaHVyc3RAZ2xvYmFsc2lnbi5jb20wggEiMA0GCSqGSIb3DQEBAQUA
-A4IBDwAwggEKAoIBAQC4ASSTvavmsFQAob60ukSSwOAL9nT/s99ltNUCAf5fPH5j
-NceMKxaQse2miOmRRIXaykcq1p/TbI70Ztce38r2mbOwqDHHPVi13GxJEyUXWgaR
-BteDMu5OGyWNG1kchVsGWpbstT0Z4v0md5m1BYFnxB20ebJyOR2lXDxsFK28nnKV
-+5eMj76U8BpPQ4SCH7yTMG6y0XXsB3cCrBKr2o3TOYgEKv+oNnbaoMt3UxMt9nSf
-9jyIshjqfnT5Aew3CUNMatO55g5FXXdIukAweg1YSb1ls05qW3sW00T3d7dQs9/7
-NuxCg/A2elmVJSoy8+MLR8JSFEf/aMgjO/TyLg/jAgMBAAGjggGPMIIBizAOBgNV
-HQ8BAf8EBAMCBaAwTQYDVR0gBEYwRDBCBgorBgEEAaAyASgKMDQwMgYIKwYBBQUH
-AgEWJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkvMCQGA1Ud
-EQQdMBuBGXJ5YW4uaHVyc3RAZ2xvYmFsc2lnbi5jb20wCQYDVR0TBAIwADAdBgNV
-HSUEFjAUBggrBgEFBQcDAgYIKwYBBQUHAwQwQwYDVR0fBDwwOjA4oDagNIYyaHR0
-cDovL2NybC5nbG9iYWxzaWduLmNvbS9ncy9nc3BlcnNvbmFsc2lnbjJnMi5jcmww
-VQYIKwYBBQUHAQEESTBHMEUGCCsGAQUFBzAChjlodHRwOi8vc2VjdXJlLmdsb2Jh
-bHNpZ24uY29tL2NhY2VydC9nc3BlcnNvbmFsc2lnbjJnMi5jcnQwHQYDVR0OBBYE
-FFWiECe0/L72eVYqcWYnLV6SSjzhMB8GA1UdIwQYMBaAFD8V0m18L+cxnkMKBqiU
-bCw7xe5lMA0GCSqGSIb3DQEBBQUAA4IBAQAhQi6hLPeudmf3IBF4IDzCvRI0FaYd
-BKfprSk/H0PDea4vpsLbWpA0t0SaijiJYtxKjlM4bPd+2chb7ejatDdyrZIzmDVy
-q4c30/xMninGKokpYA11/Ve+i2dvjulu65qasrtQRGybAuuZ67lrp/K3OMFgjV5N
-C3AHYLzvNU4Dwc4QQ1BaMOg6KzYSrKbABRZajfrpC9uiePsv7mDIXLx/toBPxWNl
-a5vJm5DrZdn7uHdvBCE6kMykbOLN5pmEK0UIlwKh6Qi5XD0pzlVkEZliFkBMJgub
-d/eF7xeg7TKPWC5xyOFp9SdMolJM7LTC3wnSO3frBAev+q/nGs9Xxyvs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 -----END CERTIFICATE-----`
 
 const smimeIntermediate = `-----BEGIN CERTIFICATE-----
-MIIEFjCCAv6gAwIBAgILBAAAAAABL07hL1IwDQYJKoZIhvcNAQEFBQAwVzELMAkG
-A1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNVBAsTB1Jv
-b3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0MTMxMDAw
-MDBaFw0xOTA0MTMxMDAwMDBaMFQxCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
-YWxTaWduIG52LXNhMSowKAYDVQQDEyFHbG9iYWxTaWduIFBlcnNvbmFsU2lnbiAy
-IENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDBa0H5Nez4
-En3dIlFpX7e5E0YndxQ74xOBbz7kdBd+DLX0LOQMjVPU3DAgKL9ujhH+ZhHkURbH
-3X/94TQSUL/z2JjsaQvS0NqyZXHhM5eeuquzOJRzEQ8+odETzHg2G0Erv7yjSeww
-gkwDWDJnYUDlOjYTDUEG6+i+8Mn425reo4I0E277wD542kmVWeW7+oHv5dZo9e1Q
-yWwiKTEP6BEQVVSBgThXMG4traSSDRUt3T1eQTZx5EObpiBEBO4OTqiBTJfg4vEI
-YgkXzKLpnfszTB6YMDpR9/QS6p3ANB3kfAb+t6udSO3WCst0DGrwHDLBFGDR4UeY
-T5KGGnI7cWL7AgMBAAGjgeUwgeIwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB/wQI
-MAYBAf8CAQAwHQYDVR0OBBYEFD8V0m18L+cxnkMKBqiUbCw7xe5lMEcGA1UdIARA
-MD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxzaWdu
-LmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3JsLmds
-b2JhbHNpZ24ubmV0L3Jvb3QuY3JsMB8GA1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTN
-NKj//P1LMA0GCSqGSIb3DQEBBQUAA4IBAQBDc3nMpMxJMQMcYUCB3+C73UpvwDE8
-eCOr7t2F/uaQKKcyqqstqLZc6vPwI/rcE9oDHugY5QEjQzIBIEaTnN6P0vege2IX
-eCOr7t2F/uaQKKcyqqstqLZc6vPwI/rcE9oDHugY5QEjQzIBIEaTnN6P0vege2IX
-YEvTWbWwGdPytDFPYIl3/6OqNSXSnZ7DxPcdLJq2uyiga8PB/TTIIHYkdM2+1DE0
-7y3rH/7TjwDVD7SLu5/SdOfKskuMPTjOEvz3K161mymW06klVhubCIWOro/Gx1Q2
-2FQOZ7/2k4uYoOdBTSlb8kTAuzZNgIE0rB2BIYCTz/P6zZIKW0ogbRSH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+-----END CERTIFICATE-----`
+
+const smimeRoot = `-----BEGIN CERTIFICATE-----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 -----END CERTIFICATE-----`
 
 var megaLeaf = `-----BEGIN CERTIFICATE-----
@@ -1315,50 +1374,7 @@ vRAvOtNiKtPzFeQVdbRPOskC4rcHyPeiDAMAMixeLi63+CFty4da3r5lRezeedCE
 cw3ESZzThBwWqvPOtJdpXdm+r57pDW8qD+/0lY8wfImMNkQAyCUCLg/1Lxt/hrBj
 -----END CERTIFICATE-----`
 
-const issuerSubjectMatchRoot = `
-Certificate:
-    Data:
-        Version: 3 (0x2)
-        Serial Number: 161640039802297062 (0x23e42c281e55ae6)
-    Signature Algorithm: sha256WithRSAEncryption
-        Issuer: O=Golang, CN=Root ca
-        Validity
-            Not Before: Jan  1 00:00:00 2015 GMT
-            Not After : Jan  1 00:00:00 2025 GMT
-        Subject: O=Golang, CN=Root ca
-        Subject Public Key Info:
-            Public Key Algorithm: rsaEncryption
-                Public-Key: (1024 bit)
-                Modulus:
-                    00:e9:0e:7f:11:0c:e6:5a:e6:86:83:70:f6:51:07:
-                    2e:02:78:11:f5:b2:24:92:38:ee:26:62:02:c7:94:
-                    f1:3e:a1:77:6a:c0:8f:d5:22:68:b6:5d:e2:4c:da:
-                    e0:85:11:35:c2:92:72:49:8d:81:b4:88:97:6b:b7:
-                    fc:b2:44:5b:d9:4d:06:70:f9:0c:c6:8f:e9:b3:df:
-                    a3:6a:84:6c:43:59:be:9d:b2:d0:76:9b:c3:d7:fa:
-                    99:59:c3:b8:e5:f3:53:03:bd:49:d6:b3:cc:a2:43:
-                    fe:ad:c2:0b:b9:01:b8:56:29:94:03:24:a7:0d:28:
-                    21:29:a9:ae:94:5b:4a:f9:9f
-                Exponent: 65537 (0x10001)
-        X509v3 extensions:
-            X509v3 Key Usage: critical
-                Certificate Sign
-            X509v3 Extended Key Usage:
-                TLS Web Server Authentication, TLS Web Client Authentication
-            X509v3 Basic Constraints: critical
-                CA:TRUE
-            X509v3 Subject Key Identifier:
-                40:37:D7:01:FB:40:2F:B8:1C:7E:54:04:27:8C:59:01
-    Signature Algorithm: sha256WithRSAEncryption
-         6f:84:df:49:e0:99:d4:71:66:1d:32:86:56:cb:ea:5a:6b:0e:
-         00:6a:d1:5a:6e:1f:06:23:07:ff:cb:d1:1a:74:e4:24:43:0b:
-         aa:2a:a0:73:75:25:82:bc:bf:3f:a9:f8:48:88:ac:ed:3a:94:
-         3b:0d:d3:88:c8:67:44:61:33:df:71:6c:c5:af:ed:16:8c:bf:
-         82:f9:49:bb:e3:2a:07:53:36:37:25:77:de:91:a4:77:09:7f:
-         6f:b2:91:58:c4:05:89:ea:8e:fa:e1:3b:19:ef:f8:f6:94:b7:
-         7b:27:e6:e4:84:dd:2b:f5:93:f5:3c:d8:86:c5:38:01:56:5c:
-         9f:6d
------BEGIN CERTIFICATE-----
+const issuerSubjectMatchRoot = `-----BEGIN CERTIFICATE-----
 MIICIDCCAYmgAwIBAgIIAj5CwoHlWuYwDQYJKoZIhvcNAQELBQAwIzEPMA0GA1UE
 ChMGR29sYW5nMRAwDgYDVQQDEwdSb290IGNhMB4XDTE1MDEwMTAwMDAwMFoXDTI1
 MDEwMTAwMDAwMFowIzEPMA0GA1UEChMGR29sYW5nMRAwDgYDVQQDEwdSb290IGNh
@@ -1373,53 +1389,7 @@ RGEz33Fsxa/tFoy/gvlJu+MqB1M2NyV33pGkdwl/b7KRWMQFieqO+uE7Ge/49pS3
 eyfm5ITdK/WT9TzYhsU4AVZcn20=
 -----END CERTIFICATE-----`
 
-const issuerSubjectMatchLeaf = `
-Certificate:
-    Data:
-        Version: 3 (0x2)
-        Serial Number: 16785088708916013734 (0xe8f09d3fe25beaa6)
-    Signature Algorithm: sha256WithRSAEncryption
-        Issuer: O=Golang, CN=Root CA
-        Validity
-            Not Before: Jan  1 00:00:00 2015 GMT
-            Not After : Jan  1 00:00:00 2025 GMT
-        Subject: O=Golang, CN=Leaf
-        Subject Public Key Info:
-            Public Key Algorithm: rsaEncryption
-                Public-Key: (1024 bit)
-                Modulus:
-                    00:db:46:7d:93:2e:12:27:06:48:bc:06:28:21:ab:
-                    7e:c4:b6:a2:5d:fe:1e:52:45:88:7a:36:47:a5:08:
-                    0d:92:42:5b:c2:81:c0:be:97:79:98:40:fb:4f:6d:
-                    14:fd:2b:13:8b:c2:a5:2e:67:d8:d4:09:9e:d6:22:
-                    38:b7:4a:0b:74:73:2b:c2:34:f1:d1:93:e5:96:d9:
-                    74:7b:f3:58:9f:6c:61:3c:c0:b0:41:d4:d9:2b:2b:
-                    24:23:77:5b:1c:3b:bd:75:5d:ce:20:54:cf:a1:63:
-                    87:1d:1e:24:c4:f3:1d:1a:50:8b:aa:b6:14:43:ed:
-                    97:a7:75:62:f4:14:c8:52:d7
-                Exponent: 65537 (0x10001)
-        X509v3 extensions:
-            X509v3 Key Usage: critical
-                Digital Signature, Key Encipherment
-            X509v3 Extended Key Usage:
-                TLS Web Server Authentication, TLS Web Client Authentication
-            X509v3 Basic Constraints: critical
-                CA:FALSE
-            X509v3 Subject Key Identifier:
-                9F:91:16:1F:43:43:3E:49:A6:DE:6D:B6:80:D7:9F:60
-            X509v3 Authority Key Identifier:
-                keyid:40:37:D7:01:FB:40:2F:B8:1C:7E:54:04:27:8C:59:01
-
-    Signature Algorithm: sha256WithRSAEncryption
-         8d:86:05:da:89:f5:1d:c5:16:14:41:b9:34:87:2b:5c:38:99:
-         e3:d9:5a:5b:7a:5b:de:0b:5c:08:45:09:6f:1c:9d:31:5f:08:
-         ca:7a:a3:99:da:83:0b:22:be:4f:02:35:91:4e:5d:5c:37:bf:
-         89:22:58:7d:30:76:d2:2f:d0:a0:ee:77:9e:77:c0:d6:19:eb:
-         ec:a0:63:35:6a:80:9b:80:1a:80:de:64:bc:40:38:3c:22:69:
-         ad:46:26:a2:3d:ea:f4:c2:92:49:16:03:96:ae:64:21:b9:7c:
-         ee:64:91:47:81:aa:b4:0c:09:2b:12:1a:b2:f3:af:50:b3:b1:
-         ce:24
------BEGIN CERTIFICATE-----
+const issuerSubjectMatchLeaf = `-----BEGIN CERTIFICATE-----
 MIICODCCAaGgAwIBAgIJAOjwnT/iW+qmMA0GCSqGSIb3DQEBCwUAMCMxDzANBgNV
 BAoTBkdvbGFuZzEQMA4GA1UEAxMHUm9vdCBDQTAeFw0xNTAxMDEwMDAwMDBaFw0y
 NTAxMDEwMDAwMDBaMCAxDzANBgNVBAoTBkdvbGFuZzENMAsGA1UEAxMETGVhZjCB
@@ -1432,11 +1402,9 @@ Q0M+SabebbaA159gMBsGA1UdIwQUMBKAEEA31wH7QC+4HH5UBCeMWQEwDQYJKoZI
 hvcNAQELBQADgYEAjYYF2on1HcUWFEG5NIcrXDiZ49laW3pb3gtcCEUJbxydMV8I
 ynqjmdqDCyK+TwI1kU5dXDe/iSJYfTB20i/QoO53nnfA1hnr7KBjNWqAm4AagN5k
 vEA4PCJprUYmoj3q9MKSSRYDlq5kIbl87mSRR4GqtAwJKxIasvOvULOxziQ=
------END CERTIFICATE-----
-`
+-----END CERTIFICATE-----`
 
-const x509v1TestRoot = `
------BEGIN CERTIFICATE-----
+const x509v1TestRoot = `-----BEGIN CERTIFICATE-----
 MIICIDCCAYmgAwIBAgIIAj5CwoHlWuYwDQYJKoZIhvcNAQELBQAwIzEPMA0GA1UE
 ChMGR29sYW5nMRAwDgYDVQQDEwdSb290IENBMB4XDTE1MDEwMTAwMDAwMFoXDTI1
 MDEwMTAwMDAwMFowIzEPMA0GA1UEChMGR29sYW5nMRAwDgYDVQQDEwdSb290IENB
@@ -1451,8 +1419,7 @@ h2NtN34ard0hEfHc8qW8mkXdsysVmq6cPvFYaHz+dBtkHuHDoy8YQnC0zdN/WyYB
 /1JmacUUofl+HusHuLkDxmadogI=
 -----END CERTIFICATE-----`
 
-const x509v1TestIntermediate = `
------BEGIN CERTIFICATE-----
+const x509v1TestIntermediate = `-----BEGIN CERTIFICATE-----
 MIIByjCCATMCCQCCdEMsT8ykqTANBgkqhkiG9w0BAQsFADAjMQ8wDQYDVQQKEwZH
 b2xhbmcxEDAOBgNVBAMTB1Jvb3QgQ0EwHhcNMTUwMTAxMDAwMDAwWhcNMjUwMTAx
 MDAwMDAwWjAwMQ8wDQYDVQQKEwZHb2xhbmcxHTAbBgNVBAMTFFguNTA5djEgaW50
@@ -1465,8 +1432,7 @@ zWE77kJDibzd141u21ZbLsKvEdUJXjla43bdyMmEqf5VGpC3D4sFt3QVH7lGeRur
 x5Wlq1u3YDL/j6s1nU2dQ3ySB/oP7J+vQ9V4QeM+
 -----END CERTIFICATE-----`
 
-const x509v1TestLeaf = `
------BEGIN CERTIFICATE-----
+const x509v1TestLeaf = `-----BEGIN CERTIFICATE-----
 MIICMzCCAZygAwIBAgIJAPo99mqJJrpJMA0GCSqGSIb3DQEBCwUAMDAxDzANBgNV
 BAoTBkdvbGFuZzEdMBsGA1UEAxMUWC41MDl2MSBpbnRlcm1lZGlhdGUwHhcNMTUw
 MTAxMDAwMDAwWhcNMjUwMTAxMDAwMDAwWjArMQ8wDQYDVQQKEwZHb2xhbmcxGDAW
@@ -1481,8 +1447,7 @@ CwUAA4GBADYzYUvaToO/ucBskPdqXV16AaakIhhSENswYVSl97/sODaxsjishKq9
 /jt8qszOXCv2vYdUTPNuPqufXLWMoirpuXrr1liJDmedCcAHepY/
 -----END CERTIFICATE-----`
 
-const ignoreCNWithSANRoot = `
------BEGIN CERTIFICATE-----
+const ignoreCNWithSANRoot = `-----BEGIN CERTIFICATE-----
 MIIDPzCCAiegAwIBAgIIJkzCwkNrPHMwDQYJKoZIhvcNAQELBQAwMDEQMA4GA1UE
 ChMHVEVTVElORzEcMBoGA1UEAxMTKipUZXN0aW5nKiogUm9vdCBDQTAeFw0xNTAx
 MDEwMDAwMDBaFw0yNTAxMDEwMDAwMDBaMDAxEDAOBgNVBAoTB1RFU1RJTkcxHDAa
@@ -1503,8 +1468,7 @@ aSLjI/Ya0zwUARMmyZ3RRGCyhIarPb20mKSaMf1/Nb23pS3k1QgmZhk5pAnXYsWu
 BJ6bvwEAasFiLGP6Zbdmxb2hIA==
 -----END CERTIFICATE-----`
 
-const ignoreCNWithSANLeaf = `
------BEGIN CERTIFICATE-----
+const ignoreCNWithSANLeaf = `-----BEGIN CERTIFICATE-----
 MIIDaTCCAlGgAwIBAgIJAONakvRTxgJhMA0GCSqGSIb3DQEBCwUAMDAxEDAOBgNV
 BAoTB1RFU1RJTkcxHDAaBgNVBAMTEyoqVGVzdGluZyoqIFJvb3QgQ0EwHhcNMTUw
 MTAxMDAwMDAwWhcNMjUwMTAxMDAwMDAwWjAsMRAwDgYDVQQKEwdURVNUSU5HMRgw
@@ -1526,8 +1490,7 @@ j2kBQyvnyKsXHLAKUoUOpd6t/1PHrfXnGj+HmzZNloJ/BZ1kiWb4eLvMljoLGkZn
 xZbqP3Krgjj4XNaXjg==
 -----END CERTIFICATE-----`
 
-const excludedNamesLeaf = `
------BEGIN CERTIFICATE-----
+const excludedNamesLeaf = `-----BEGIN CERTIFICATE-----
 MIID4DCCAsigAwIBAgIHDUSFtJknhzANBgkqhkiG9w0BAQsFADCBnjELMAkGA1UE
 BhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEjAQBgNVBAcMCUxvcyBHYXRvczEU
 MBIGA1UECgwLTmV0ZmxpeCBJbmMxLTArBgNVBAsMJFBsYXRmb3JtIFNlY3VyaXR5
@@ -1549,11 +1512,9 @@ hDt8MCFJ8eSjCyKdtZh1MPMLrLVymmJV+Rc9JUUYM9TIeERkpl0rskcO1YGewkYt
 qKlWE+0S16+pzsWvKn831uylqwIb8ANBPsCX4aM4muFBHavSWAHgRO+P+yXVw8Q+
 VQDnMHUe5PbZd1/+1KKVs1K/CkBCtoHNHp1d/JT+2zUQJphwja9CcgfFdVhSnHL4
 oEEOFtqVMIuQfR2isi08qW/JGOHc4sFoLYB8hvdaxKWSE19A
------END CERTIFICATE-----
-`
+-----END CERTIFICATE-----`
 
-const excludedNamesIntermediate = `
------BEGIN CERTIFICATE-----
+const excludedNamesIntermediate = `-----BEGIN CERTIFICATE-----
 MIIDzTCCArWgAwIBAgIHDUSFqYeczDANBgkqhkiG9w0BAQsFADCBmTELMAkGA1UE
 BhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEjAQBgNVBAcMCUxvcyBHYXRvczEU
 MBIGA1UECgwLTmV0ZmxpeCBJbmMxLTArBgNVBAsMJFBsYXRmb3JtIFNlY3VyaXR5
@@ -1577,8 +1538,7 @@ LbIjZCSfgZnk/LK1KU1j91FI2bc2ULYZvAC1PAg8/zvIgxn6YM2Q7ZsdEgWw0FpS
 zMBX1/lk4wkFckeUIlkD55Y=
 -----END CERTIFICATE-----`
 
-const excludedNamesRoot = `
------BEGIN CERTIFICATE-----
+const excludedNamesRoot = `-----BEGIN CERTIFICATE-----
 MIIEGTCCAwGgAwIBAgIHDUSFpInn/zANBgkqhkiG9w0BAQsFADCBozELMAkGA1UE
 BhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEjAQBgNVBAcMCUxvcyBHYXRvczEU
 MBIGA1UECgwLTmV0ZmxpeCBJbmMxLTArBgNVBAsMJFBsYXRmb3JtIFNlY3VyaXR5
@@ -1603,46 +1563,16 @@ yU1yRHUqUYpN0DWFpsPbBqgM6uUAVO2ayBFhPgWUaqkmSbZ/Nq7isGvknaTmcIwT
 +NQCZDd5eFeU8PpNX7rgaYE4GPq+EEmLVCBYmdctr8QVdqJ//8Xu3+1phjDy
 -----END CERTIFICATE-----`
 
-const invalidCNRoot = `
------BEGIN CERTIFICATE-----
+const invalidCNRoot = `-----BEGIN CERTIFICATE-----
 MIIBFjCBvgIJAIsu4r+jb70UMAoGCCqGSM49BAMCMBQxEjAQBgNVBAsMCVRlc3Qg
 cm9vdDAeFw0xODA3MTExODMyMzVaFw0yODA3MDgxODMyMzVaMBQxEjAQBgNVBAsM
 CVRlc3Qgcm9vdDBZMBMGByqGSM49AgEGCCqGSM49AwEHA0IABF6oDgMg0LV6YhPj
 QXaPXYCc2cIyCdqp0ROUksRz0pOLTc5iY2nraUheRUD1vRRneq7GeXOVNn7uXONg
 oCGMjNwwCgYIKoZIzj0EAwIDRwAwRAIgDSiwgIn8g1lpruYH0QD1GYeoWVunfmrI
 XzZZl0eW/ugCICgOfXeZ2GGy3wIC0352BaC3a8r5AAb2XSGNe+e9wNN6
------END CERTIFICATE-----
-`
-
-const invalidCNWithoutSAN = `
-Certificate:
-    Data:
-        Version: 1 (0x0)
-        Serial Number:
-            07:ba:bc:b7:d9:ab:0c:02:fe:50:1d:4e:15:a3:0d:e4:11:16:14:a2
-        Signature Algorithm: ecdsa-with-SHA256
-        Issuer: OU = Test root
-        Validity
-            Not Before: Jul 11 18:35:21 2018 GMT
-            Not After : Jul  8 18:35:21 2028 GMT
-        Subject: CN = "foo,invalid"
-        Subject Public Key Info:
-            Public Key Algorithm: id-ecPublicKey
-                Public-Key: (256 bit)
-                pub:
-                    04:a7:a6:7c:22:33:a7:47:7f:08:93:2d:5f:61:35:
-                    2e:da:45:67:76:f2:97:73:18:b0:01:12:4a:1a:d5:
-                    b7:6f:41:3c:bb:05:69:f4:06:5d:ff:eb:2b:a7:85:
-                    0b:4c:f7:45:4e:81:40:7a:a9:c6:1d:bb:ba:d9:b9:
-                    26:b3:ca:50:90
-                ASN1 OID: prime256v1
-                NIST CURVE: P-256
-    Signature Algorithm: ecdsa-with-SHA256
-         30:45:02:21:00:85:96:75:b6:72:3c:67:12:a0:7f:86:04:81:
-         d2:dd:c8:67:50:d7:5f:85:c0:54:54:fc:e6:6b:45:08:93:d3:
-         2a:02:20:60:86:3e:d6:28:a6:4e:da:dd:6e:95:89:cc:00:76:
-         78:1c:03:80:85:a6:5a:0b:eb:c5:f3:9c:2e:df:ef:6e:fa
------BEGIN CERTIFICATE-----
+-----END CERTIFICATE-----`
+
+const invalidCNWithoutSAN = `-----BEGIN CERTIFICATE-----
 MIIBJDCBywIUB7q8t9mrDAL+UB1OFaMN5BEWFKIwCgYIKoZIzj0EAwIwFDESMBAG
 A1UECwwJVGVzdCByb290MB4XDTE4MDcxMTE4MzUyMVoXDTI4MDcwODE4MzUyMVow
 FjEUMBIGA1UEAwwLZm9vLGludmFsaWQwWTATBgcqhkjOPQIBBggqhkjOPQMBBwNC
@@ -1650,38 +1580,9 @@ AASnpnwiM6dHfwiTLV9hNS7aRWd28pdzGLABEkoa1bdvQTy7BWn0Bl3/6yunhQtM
 90VOgUB6qcYdu7rZuSazylCQMAoGCCqGSM49BAMCA0gAMEUCIQCFlnW2cjxnEqB/
 hgSB0t3IZ1DXX4XAVFT85mtFCJPTKgIgYIY+1iimTtrdbpWJzAB2eBwDgIWmWgvr
 xfOcLt/vbvo=
------END CERTIFICATE-----
-`
-
-const validCNWithoutSAN = `
-Certificate:
-    Data:
-        Version: 1 (0x0)
-        Serial Number:
-            07:ba:bc:b7:d9:ab:0c:02:fe:50:1d:4e:15:a3:0d:e4:11:16:14:a4
-        Signature Algorithm: ecdsa-with-SHA256
-        Issuer: OU = Test root
-        Validity
-            Not Before: Jul 11 18:47:24 2018 GMT
-            Not After : Jul  8 18:47:24 2028 GMT
-        Subject: CN = foo.example.com
-        Subject Public Key Info:
-            Public Key Algorithm: id-ecPublicKey
-                Public-Key: (256 bit)
-                pub:
-                    04:a7:a6:7c:22:33:a7:47:7f:08:93:2d:5f:61:35:
-                    2e:da:45:67:76:f2:97:73:18:b0:01:12:4a:1a:d5:
-                    b7:6f:41:3c:bb:05:69:f4:06:5d:ff:eb:2b:a7:85:
-                    0b:4c:f7:45:4e:81:40:7a:a9:c6:1d:bb:ba:d9:b9:
-                    26:b3:ca:50:90
-                ASN1 OID: prime256v1
-                NIST CURVE: P-256
-    Signature Algorithm: ecdsa-with-SHA256
-         30:44:02:20:53:6c:d7:b7:59:61:51:72:a5:18:a3:4b:0d:52:
-         ea:15:fa:d0:93:30:32:54:4b:ed:0f:58:85:b8:a8:1a:82:3b:
-         02:20:14:77:4b:0e:7e:4f:0a:4f:64:26:97:dc:d0:ed:aa:67:
-         1d:37:85:da:b4:87:ba:25:1c:2a:58:f7:23:11:8b:3d
------BEGIN CERTIFICATE-----
+-----END CERTIFICATE-----`
+
+const validCNWithoutSAN = `-----BEGIN CERTIFICATE-----
 MIIBJzCBzwIUB7q8t9mrDAL+UB1OFaMN5BEWFKQwCgYIKoZIzj0EAwIwFDESMBAG
 A1UECwwJVGVzdCByb290MB4XDTE4MDcxMTE4NDcyNFoXDTI4MDcwODE4NDcyNFow
 GjEYMBYGA1UEAwwPZm9vLmV4YW1wbGUuY29tMFkwEwYHKoZIzj0CAQYIKoZIzj0D
@@ -1689,48 +1590,9 @@ AQcDQgAEp6Z8IjOnR38Iky1fYTUu2kVndvKXcxiwARJKGtW3b0E8uwVp9AZd/+sr
 p4ULTPdFToFAeqnGHbu62bkms8pQkDAKBggqhkjOPQQDAgNHADBEAiBTbNe3WWFR
 cqUYo0sNUuoV+tCTMDJUS+0PWIW4qBqCOwIgFHdLDn5PCk9kJpfc0O2qZx03hdq0
 h7olHCpY9yMRiz0=
------END CERTIFICATE-----
-`
-
-const (
-	rootWithoutSKID = `
-Certificate:
-    Data:
-        Version: 3 (0x2)
-        Serial Number:
-            78:29:2a:dc:2f:12:39:7f:c9:33:93:ea:61:39:7d:70
-        Signature Algorithm: ecdsa-with-SHA256
-        Issuer: O = Acme Co
-        Validity
-            Not Before: Feb  4 22:56:34 2019 GMT
-            Not After : Feb  1 22:56:34 2029 GMT
-        Subject: O = Acme Co
-        Subject Public Key Info:
-            Public Key Algorithm: id-ecPublicKey
-                Public-Key: (256 bit)
-                pub:
-                    04:84:a6:8c:69:53:af:87:4b:39:64:fe:04:24:e6:
-                    d8:fc:d6:46:39:35:0e:92:dc:48:08:7e:02:5f:1e:
-                    07:53:5c:d9:e0:56:c5:82:07:f6:a3:e2:ad:f6:ad:
-                    be:a0:4e:03:87:39:67:0c:9c:46:91:68:6b:0e:8e:
-                    f8:49:97:9d:5b
-                ASN1 OID: prime256v1
-                NIST CURVE: P-256
-        X509v3 extensions:
-            X509v3 Key Usage: critical
-                Digital Signature, Key Encipherment, Certificate Sign
-            X509v3 Extended Key Usage:
-                TLS Web Server Authentication
-            X509v3 Basic Constraints: critical
-                CA:TRUE
-            X509v3 Subject Alternative Name:
-                DNS:example
-    Signature Algorithm: ecdsa-with-SHA256
-         30:46:02:21:00:c6:81:61:61:42:8d:37:e7:d0:c3:72:43:44:
-         17:bd:84:ff:88:81:68:9a:99:08:ab:3c:3a:c0:1e:ea:8c:ba:
-         c0:02:21:00:de:c9:fa:e5:5e:c6:e2:db:23:64:43:a9:37:42:
-         72:92:7f:6e:89:38:ea:9e:2a:a7:fd:2f:ea:9a:ff:20:21:e7
------BEGIN CERTIFICATE-----
+-----END CERTIFICATE-----`
+
+const rootWithoutSKID = `-----BEGIN CERTIFICATE-----
 MIIBbzCCARSgAwIBAgIQeCkq3C8SOX/JM5PqYTl9cDAKBggqhkjOPQQDAjASMRAw
 DgYDVQQKEwdBY21lIENvMB4XDTE5MDIwNDIyNTYzNFoXDTI5MDIwMTIyNTYzNFow
 EjEQMA4GA1UEChMHQWNtZSBDbzBZMBMGByqGSM49AgEGCCqGSM49AwEHA0IABISm
@@ -1739,49 +1601,9 @@ ZwycRpFoaw6O+EmXnVujTDBKMA4GA1UdDwEB/wQEAwICpDATBgNVHSUEDDAKBggr
 BgEFBQcDATAPBgNVHRMBAf8EBTADAQH/MBIGA1UdEQQLMAmCB2V4YW1wbGUwCgYI
 KoZIzj0EAwIDSQAwRgIhAMaBYWFCjTfn0MNyQ0QXvYT/iIFompkIqzw6wB7qjLrA
 AiEA3sn65V7G4tsjZEOpN0Jykn9uiTjqniqn/S/qmv8gIec=
------END CERTIFICATE-----
-`
-	leafWithAKID = `
-	Certificate:
-    Data:
-        Version: 3 (0x2)
-        Serial Number:
-            f0:8a:62:f0:03:84:a2:cf:69:63:ad:71:3b:b6:5d:8c
-        Signature Algorithm: ecdsa-with-SHA256
-        Issuer: O = Acme Co
-        Validity
-            Not Before: Feb  4 23:06:52 2019 GMT
-            Not After : Feb  1 23:06:52 2029 GMT
-        Subject: O = Acme LLC
-        Subject Public Key Info:
-            Public Key Algorithm: id-ecPublicKey
-                Public-Key: (256 bit)
-                pub:
-                    04:5a:4e:4d:fb:ff:17:f7:b6:13:e8:29:45:34:81:
-                    39:ff:8c:9c:d9:8c:0a:9f:dd:b5:97:4c:2b:20:91:
-                    1c:4f:6b:be:53:27:66:ec:4a:ad:08:93:6d:66:36:
-                    0c:02:70:5d:01:ca:7f:c3:29:e9:4f:00:ba:b4:14:
-                    ec:c5:c3:34:b3
-                ASN1 OID: prime256v1
-                NIST CURVE: P-256
-        X509v3 extensions:
-            X509v3 Key Usage: critical
-                Digital Signature, Key Encipherment
-            X509v3 Extended Key Usage:
-                TLS Web Server Authentication
-            X509v3 Basic Constraints: critical
-                CA:FALSE
-            X509v3 Authority Key Identifier:
-                keyid:C2:2B:5F:91:78:34:26:09:42:8D:6F:51:B2:C5:AF:4C:0B:DE:6A:42
-
-            X509v3 Subject Alternative Name:
-                DNS:example
-    Signature Algorithm: ecdsa-with-SHA256
-         30:44:02:20:64:e0:ba:56:89:63:ce:22:5e:4f:22:15:fd:3c:
-         35:64:9a:3a:6b:7b:9a:32:a0:7f:f7:69:8c:06:f0:00:58:b8:
-         02:20:09:e4:9f:6d:8b:9e:38:e1:b6:01:d5:ee:32:a4:94:65:
-         93:2a:78:94:bb:26:57:4b:c7:dd:6c:3d:40:2b:63:90
------BEGIN CERTIFICATE-----
+-----END CERTIFICATE-----`
+
+const leafWithAKID = `-----BEGIN CERTIFICATE-----
 MIIBjTCCATSgAwIBAgIRAPCKYvADhKLPaWOtcTu2XYwwCgYIKoZIzj0EAwIwEjEQ
 MA4GA1UEChMHQWNtZSBDbzAeFw0xOTAyMDQyMzA2NTJaFw0yOTAyMDEyMzA2NTJa
 MBMxETAPBgNVBAoTCEFjbWUgTExDMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAE
@@ -1791,9 +1613,7 @@ CCsGAQUFBwMBMAwGA1UdEwEB/wQCMAAwHwYDVR0jBBgwFoAUwitfkXg0JglCjW9R
 ssWvTAveakIwEgYDVR0RBAswCYIHZXhhbXBsZTAKBggqhkjOPQQDAgNHADBEAiBk
 4LpWiWPOIl5PIhX9PDVkmjpre5oyoH/3aYwG8ABYuAIgCeSfbYueOOG2AdXuMqSU
 ZZMqeJS7JldLx91sPUArY5A=
------END CERTIFICATE-----
-`
-)
+-----END CERTIFICATE-----`
 
 var unknownAuthorityErrorTests = []struct {
 	cert     string
@@ -2124,3 +1944,33 @@ func TestLongChain(t *testing.T) {
 	}
 	t.Logf("verification took %v", time.Since(start))
 }
+
+func TestSystemRootsError(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		t.Skip("Windows does not use (or support) systemRoots")
+	}
+
+	defer func(oldSystemRoots *CertPool) { systemRoots = oldSystemRoots }(systemRootsPool())
+
+	opts := VerifyOptions{
+		Intermediates: NewCertPool(),
+		DNSName:       "www.google.com",
+		CurrentTime:   time.Unix(1395785200, 0),
+	}
+
+	if ok := opts.Intermediates.AppendCertsFromPEM([]byte(giag2Intermediate)); !ok {
+		t.Fatalf("failed to parse intermediate")
+	}
+
+	leaf, err := certificateFromPEM(googleLeaf)
+	if err != nil {
+		t.Fatalf("failed to parse leaf: %v", err)
+	}
+
+	systemRoots = nil
+
+	_, err = leaf.Verify(opts)
+	if _, ok := err.(SystemRootsError); !ok {
+		t.Errorf("error was not SystemRootsError: %v", err)
+	}
+}
diff --git a/libgo/go/database/sql/driver/driver.go b/libgo/go/database/sql/driver/driver.go
index 316e7cea375..a0ba7ecf694 100644
--- a/libgo/go/database/sql/driver/driver.go
+++ b/libgo/go/database/sql/driver/driver.go
@@ -255,12 +255,9 @@ type ConnBeginTx interface {
 // SessionResetter may be implemented by Conn to allow drivers to reset the
 // session state associated with the connection and to signal a bad connection.
 type SessionResetter interface {
-	// ResetSession is called while a connection is in the connection
-	// pool. No queries will run on this connection until this method returns.
-	//
-	// If the connection is bad this should return driver.ErrBadConn to prevent
-	// the connection from being returned to the connection pool. Any other
-	// error will be discarded.
+	// ResetSession is called prior to executing a query on the connection
+	// if the connection has been used before. If the driver returns ErrBadConn
+	// the connection is discarded.
 	ResetSession(ctx context.Context) error
 }
 
diff --git a/libgo/go/database/sql/fakedb_test.go b/libgo/go/database/sql/fakedb_test.go
index a0028be0e57..0ec72d409d3 100644
--- a/libgo/go/database/sql/fakedb_test.go
+++ b/libgo/go/database/sql/fakedb_test.go
@@ -390,12 +390,19 @@ func setStrictFakeConnClose(t *testing.T) {
 
 func (c *fakeConn) ResetSession(ctx context.Context) error {
 	c.dirtySession = false
+	c.currTx = nil
 	if c.isBad() {
 		return driver.ErrBadConn
 	}
 	return nil
 }
 
+var _ validator = (*fakeConn)(nil)
+
+func (c *fakeConn) IsValid() bool {
+	return !c.isBad()
+}
+
 func (c *fakeConn) Close() (err error) {
 	drv := fdriver.(*fakeDriver)
 	defer func() {
@@ -728,6 +735,9 @@ var hookExecBadConn func() bool
 func (s *fakeStmt) Exec(args []driver.Value) (driver.Result, error) {
 	panic("Using ExecContext")
 }
+
+var errFakeConnSessionDirty = errors.New("fakedb: session is dirty")
+
 func (s *fakeStmt) ExecContext(ctx context.Context, args []driver.NamedValue) (driver.Result, error) {
 	if s.panic == "Exec" {
 		panic(s.panic)
@@ -740,7 +750,7 @@ func (s *fakeStmt) ExecContext(ctx context.Context, args []driver.NamedValue) (d
 		return nil, driver.ErrBadConn
 	}
 	if s.c.isDirtyAndMark() {
-		return nil, errors.New("fakedb: session is dirty")
+		return nil, errFakeConnSessionDirty
 	}
 
 	err := checkSubsetTypes(s.c.db.allowAny, args)
@@ -854,7 +864,7 @@ func (s *fakeStmt) QueryContext(ctx context.Context, args []driver.NamedValue) (
 		return nil, driver.ErrBadConn
 	}
 	if s.c.isDirtyAndMark() {
-		return nil, errors.New("fakedb: session is dirty")
+		return nil, errFakeConnSessionDirty
 	}
 
 	err := checkSubsetTypes(s.c.db.allowAny, args)
@@ -887,6 +897,37 @@ func (s *fakeStmt) QueryContext(ctx context.Context, args []driver.NamedValue) (
 				}
 			}
 		}
+		if s.table == "tx_status" && s.colName[0] == "tx_status" {
+			txStatus := "autocommit"
+			if s.c.currTx != nil {
+				txStatus = "transaction"
+			}
+			cursor := &rowsCursor{
+				parentMem: s.c,
+				posRow:    -1,
+				rows: [][]*row{
+					[]*row{
+						{
+							cols: []interface{}{
+								txStatus,
+							},
+						},
+					},
+				},
+				cols: [][]string{
+					[]string{
+						"tx_status",
+					},
+				},
+				colType: [][]string{
+					[]string{
+						"string",
+					},
+				},
+				errPos: -1,
+			}
+			return cursor, nil
+		}
 
 		t.mu.Lock()
 
diff --git a/libgo/go/database/sql/sql.go b/libgo/go/database/sql/sql.go
index 0f5bbc01c9e..a0b7ca8f087 100644
--- a/libgo/go/database/sql/sql.go
+++ b/libgo/go/database/sql/sql.go
@@ -421,7 +421,6 @@ type DB struct {
 	// It is closed during db.Close(). The close tells the connectionOpener
 	// goroutine to exit.
 	openerCh          chan struct{}
-	resetterCh        chan *driverConn
 	closed            bool
 	dep               map[finalCloser]depSet
 	lastPut           map[*driverConn]string // stacktrace of last conn's put; debug only
@@ -458,10 +457,10 @@ type driverConn struct {
 
 	sync.Mutex  // guards following
 	ci          driver.Conn
+	needReset   bool // The connection session should be reset before use if true.
 	closed      bool
 	finalClosed bool // ci.Close has been called
 	openStmt    map[*driverStmt]bool
-	lastErr     error // lastError captures the result of the session resetter.
 
 	// guarded by db.mu
 	inUse      bool
@@ -486,6 +485,41 @@ func (dc *driverConn) expired(timeout time.Duration) bool {
 	return dc.createdAt.Add(timeout).Before(nowFunc())
 }
 
+// resetSession checks if the driver connection needs the
+// session to be reset and if required, resets it.
+func (dc *driverConn) resetSession(ctx context.Context) error {
+	dc.Lock()
+	defer dc.Unlock()
+
+	if !dc.needReset {
+		return nil
+	}
+	if cr, ok := dc.ci.(driver.SessionResetter); ok {
+		return cr.ResetSession(ctx)
+	}
+	return nil
+}
+
+// validator was introduced for Go1.15, but backported to Go1.14.
+type validator interface {
+	IsValid() bool
+}
+
+// validateConnection checks if the connection is valid and can
+// still be used. It also marks the session for reset if required.
+func (dc *driverConn) validateConnection(needsReset bool) bool {
+	dc.Lock()
+	defer dc.Unlock()
+
+	if needsReset {
+		dc.needReset = true
+	}
+	if cv, ok := dc.ci.(validator); ok {
+		return cv.IsValid()
+	}
+	return true
+}
+
 // prepareLocked prepares the query on dc. When cg == nil the dc must keep track of
 // the prepared statements in a pool.
 func (dc *driverConn) prepareLocked(ctx context.Context, cg stmtConnGrabber, query string) (*driverStmt, error) {
@@ -511,19 +545,6 @@ func (dc *driverConn) prepareLocked(ctx context.Context, cg stmtConnGrabber, que
 	return ds, nil
 }
 
-// resetSession resets the connection session and sets the lastErr
-// that is checked before returning the connection to another query.
-//
-// resetSession assumes that the embedded mutex is locked when the connection
-// was returned to the pool. This unlocks the mutex.
-func (dc *driverConn) resetSession(ctx context.Context) {
-	defer dc.Unlock() // In case of panic.
-	if dc.closed {    // Check if the database has been closed.
-		return
-	}
-	dc.lastErr = dc.ci.(driver.SessionResetter).ResetSession(ctx)
-}
-
 // the dc.db's Mutex is held.
 func (dc *driverConn) closeDBLocked() func() error {
 	dc.Lock()
@@ -713,14 +734,12 @@ func OpenDB(c driver.Connector) *DB {
 	db := &DB{
 		connector:    c,
 		openerCh:     make(chan struct{}, connectionRequestQueueSize),
-		resetterCh:   make(chan *driverConn, 50),
 		lastPut:      make(map[*driverConn]string),
 		connRequests: make(map[uint64]chan connRequest),
 		stop:         cancel,
 	}
 
 	go db.connectionOpener(ctx)
-	go db.connectionResetter(ctx)
 
 	return db
 }
@@ -1058,23 +1077,6 @@ func (db *DB) connectionOpener(ctx context.Context) {
 	}
 }
 
-// connectionResetter runs in a separate goroutine to reset connections async
-// to exported API.
-func (db *DB) connectionResetter(ctx context.Context) {
-	for {
-		select {
-		case <-ctx.Done():
-			close(db.resetterCh)
-			for dc := range db.resetterCh {
-				dc.Unlock()
-			}
-			return
-		case dc := <-db.resetterCh:
-			dc.resetSession(ctx)
-		}
-	}
-}
-
 // Open one new connection
 func (db *DB) openNewConnection(ctx context.Context) {
 	// maybeOpenNewConnctions has already executed db.numOpen++ before it sent
@@ -1155,14 +1157,13 @@ func (db *DB) conn(ctx context.Context, strategy connReuseStrategy) (*driverConn
 			conn.Close()
 			return nil, driver.ErrBadConn
 		}
-		// Lock around reading lastErr to ensure the session resetter finished.
-		conn.Lock()
-		err := conn.lastErr
-		conn.Unlock()
-		if err == driver.ErrBadConn {
+
+		// Reset the session if required.
+		if err := conn.resetSession(ctx); err == driver.ErrBadConn {
 			conn.Close()
 			return nil, driver.ErrBadConn
 		}
+
 		return conn, nil
 	}
 
@@ -1204,18 +1205,22 @@ func (db *DB) conn(ctx context.Context, strategy connReuseStrategy) (*driverConn
 			if !ok {
 				return nil, errDBClosed
 			}
-			if ret.err == nil && ret.conn.expired(lifetime) {
+			// Only check if the connection is expired if the strategy is cachedOrNewConns.
+			// If we require a new connection, just re-use the connection without looking
+			// at the expiry time. If it is expired, it will be checked when it is placed
+			// back into the connection pool.
+			// This prioritizes giving a valid connection to a client over the exact connection
+			// lifetime, which could expire exactly after this point anyway.
+			if strategy == cachedOrNewConn && ret.err == nil && ret.conn.expired(lifetime) {
 				ret.conn.Close()
 				return nil, driver.ErrBadConn
 			}
 			if ret.conn == nil {
 				return nil, ret.err
 			}
-			// Lock around reading lastErr to ensure the session resetter finished.
-			ret.conn.Lock()
-			err := ret.conn.lastErr
-			ret.conn.Unlock()
-			if err == driver.ErrBadConn {
+
+			// Reset the session if required.
+			if err := ret.conn.resetSession(ctx); err == driver.ErrBadConn {
 				ret.conn.Close()
 				return nil, driver.ErrBadConn
 			}
@@ -1275,13 +1280,23 @@ const debugGetPut = false
 // putConn adds a connection to the db's free pool.
 // err is optionally the last error that occurred on this connection.
 func (db *DB) putConn(dc *driverConn, err error, resetSession bool) {
+	if err != driver.ErrBadConn {
+		if !dc.validateConnection(resetSession) {
+			err = driver.ErrBadConn
+		}
+	}
 	db.mu.Lock()
 	if !dc.inUse {
+		db.mu.Unlock()
 		if debugGetPut {
 			fmt.Printf("putConn(%v) DUPLICATE was: %s\n\nPREVIOUS was: %s", dc, stack(), db.lastPut[dc])
 		}
 		panic("sql: connection returned that was never out")
 	}
+
+	if err != driver.ErrBadConn && dc.expired(db.maxLifetime) {
+		err = driver.ErrBadConn
+	}
 	if debugGetPut {
 		db.lastPut[dc] = stack()
 	}
@@ -1305,41 +1320,13 @@ func (db *DB) putConn(dc *driverConn, err error, resetSession bool) {
 	if putConnHook != nil {
 		putConnHook(db, dc)
 	}
-	if db.closed {
-		// Connections do not need to be reset if they will be closed.
-		// Prevents writing to resetterCh after the DB has closed.
-		resetSession = false
-	}
-	if resetSession {
-		if _, resetSession = dc.ci.(driver.SessionResetter); resetSession {
-			// Lock the driverConn here so it isn't released until
-			// the connection is reset.
-			// The lock must be taken before the connection is put into
-			// the pool to prevent it from being taken out before it is reset.
-			dc.Lock()
-		}
-	}
 	added := db.putConnDBLocked(dc, nil)
 	db.mu.Unlock()
 
 	if !added {
-		if resetSession {
-			dc.Unlock()
-		}
 		dc.Close()
 		return
 	}
-	if !resetSession {
-		return
-	}
-	select {
-	default:
-		// If the resetterCh is blocking then mark the connection
-		// as bad and continue on.
-		dc.lastErr = driver.ErrBadConn
-		dc.Unlock()
-	case db.resetterCh <- dc:
-	}
 }
 
 // Satisfy a connRequest or put the driverConn in the idle pool and return true
@@ -1701,7 +1688,11 @@ func (db *DB) begin(ctx context.Context, opts *TxOptions, strategy connReuseStra
 // beginDC starts a transaction. The provided dc must be valid and ready to use.
 func (db *DB) beginDC(ctx context.Context, dc *driverConn, release func(error), opts *TxOptions) (tx *Tx, err error) {
 	var txi driver.Tx
+	keepConnOnRollback := false
 	withLock(dc, func() {
+		_, hasSessionResetter := dc.ci.(driver.SessionResetter)
+		_, hasConnectionValidator := dc.ci.(validator)
+		keepConnOnRollback = hasSessionResetter && hasConnectionValidator
 		txi, err = ctxDriverBegin(ctx, opts, dc.ci)
 	})
 	if err != nil {
@@ -1713,12 +1704,13 @@ func (db *DB) beginDC(ctx context.Context, dc *driverConn, release func(error),
 	// The cancel function in Tx will be called after done is set to true.
 	ctx, cancel := context.WithCancel(ctx)
 	tx = &Tx{
-		db:          db,
-		dc:          dc,
-		releaseConn: release,
-		txi:         txi,
-		cancel:      cancel,
-		ctx:         ctx,
+		db:                 db,
+		dc:                 dc,
+		releaseConn:        release,
+		txi:                txi,
+		cancel:             cancel,
+		keepConnOnRollback: keepConnOnRollback,
+		ctx:                ctx,
 	}
 	go tx.awaitDone()
 	return tx, nil
@@ -1980,6 +1972,11 @@ type Tx struct {
 	// Use atomic operations on value when checking value.
 	done int32
 
+	// keepConnOnRollback is true if the driver knows
+	// how to reset the connection's session and if need be discard
+	// the connection.
+	keepConnOnRollback bool
+
 	// All Stmts prepared for this transaction. These will be closed after the
 	// transaction has been committed or rolled back.
 	stmts struct {
@@ -2005,7 +2002,10 @@ func (tx *Tx) awaitDone() {
 	// transaction is closed and the resources are released.  This
 	// rollback does nothing if the transaction has already been
 	// committed or rolled back.
-	tx.rollback(true)
+	// Do not discard the connection if the connection knows
+	// how to reset the session.
+	discardConnection := !tx.keepConnOnRollback
+	tx.rollback(discardConnection)
 }
 
 func (tx *Tx) isDone() bool {
@@ -2016,14 +2016,10 @@ func (tx *Tx) isDone() bool {
 // that has already been committed or rolled back.
 var ErrTxDone = errors.New("sql: transaction has already been committed or rolled back")
 
-// close returns the connection to the pool and
-// must only be called by Tx.rollback or Tx.Commit.
-func (tx *Tx) close(err error) {
-	tx.cancel()
-
-	tx.closemu.Lock()
-	defer tx.closemu.Unlock()
-
+// closeLocked returns the connection to the pool and
+// must only be called by Tx.rollback or Tx.Commit while
+// closemu is Locked and tx already canceled.
+func (tx *Tx) closeLocked(err error) {
 	tx.releaseConn(err)
 	tx.dc = nil
 	tx.txi = nil
@@ -2090,6 +2086,15 @@ func (tx *Tx) Commit() error {
 	if !atomic.CompareAndSwapInt32(&tx.done, 0, 1) {
 		return ErrTxDone
 	}
+
+	// Cancel the Tx to release any active R-closemu locks.
+	// This is safe to do because tx.done has already transitioned
+	// from 0 to 1. Hold the W-closemu lock prior to rollback
+	// to ensure no other connection has an active query.
+	tx.cancel()
+	tx.closemu.Lock()
+	defer tx.closemu.Unlock()
+
 	var err error
 	withLock(tx.dc, func() {
 		err = tx.txi.Commit()
@@ -2097,16 +2102,31 @@ func (tx *Tx) Commit() error {
 	if err != driver.ErrBadConn {
 		tx.closePrepared()
 	}
-	tx.close(err)
+	tx.closeLocked(err)
 	return err
 }
 
+var rollbackHook func()
+
 // rollback aborts the transaction and optionally forces the pool to discard
 // the connection.
 func (tx *Tx) rollback(discardConn bool) error {
 	if !atomic.CompareAndSwapInt32(&tx.done, 0, 1) {
 		return ErrTxDone
 	}
+
+	if rollbackHook != nil {
+		rollbackHook()
+	}
+
+	// Cancel the Tx to release any active R-closemu locks.
+	// This is safe to do because tx.done has already transitioned
+	// from 0 to 1. Hold the W-closemu lock prior to rollback
+	// to ensure no other connection has an active query.
+	tx.cancel()
+	tx.closemu.Lock()
+	defer tx.closemu.Unlock()
+
 	var err error
 	withLock(tx.dc, func() {
 		err = tx.txi.Rollback()
@@ -2117,7 +2137,7 @@ func (tx *Tx) rollback(discardConn bool) error {
 	if discardConn {
 		err = driver.ErrBadConn
 	}
-	tx.close(err)
+	tx.closeLocked(err)
 	return err
 }
 
diff --git a/libgo/go/database/sql/sql_test.go b/libgo/go/database/sql/sql_test.go
index 6f59260cdab..a9e18004fb4 100644
--- a/libgo/go/database/sql/sql_test.go
+++ b/libgo/go/database/sql/sql_test.go
@@ -80,6 +80,11 @@ func newTestDBConnector(t testing.TB, fc *fakeConnector, name string) *DB {
 		exec(t, db, "CREATE|magicquery|op=string,millis=int32")
 		exec(t, db, "INSERT|magicquery|op=sleep,millis=10")
 	}
+	if name == "tx_status" {
+		// Magic table name and column, known by fakedb_test.go.
+		exec(t, db, "CREATE|tx_status|tx_status=string")
+		exec(t, db, "INSERT|tx_status|tx_status=invalid")
+	}
 	return db
 }
 
@@ -437,6 +442,7 @@ func TestTxContextWait(t *testing.T) {
 		}
 		t.Fatal(err)
 	}
+	tx.keepConnOnRollback = false
 
 	// This will trigger the *fakeConn.Prepare method which will take time
 	// performing the query. The ctxDriverPrepare func will check the context
@@ -449,6 +455,35 @@ func TestTxContextWait(t *testing.T) {
 	waitForFree(t, db, 5*time.Second, 0)
 }
 
+// TestTxContextWaitNoDiscard is the same as TestTxContextWait, but should not discard
+// the final connection.
+func TestTxContextWaitNoDiscard(t *testing.T) {
+	db := newTestDB(t, "people")
+	defer closeDB(t, db)
+
+	ctx, cancel := context.WithTimeout(context.Background(), 15*time.Millisecond)
+	defer cancel()
+
+	tx, err := db.BeginTx(ctx, nil)
+	if err != nil {
+		// Guard against the context being canceled before BeginTx completes.
+		if err == context.DeadlineExceeded {
+			t.Skip("tx context canceled prior to first use")
+		}
+		t.Fatal(err)
+	}
+
+	// This will trigger the *fakeConn.Prepare method which will take time
+	// performing the query. The ctxDriverPrepare func will check the context
+	// after this and close the rows and return an error.
+	_, err = tx.QueryContext(ctx, "WAIT|1s|SELECT|people|age,name|")
+	if err != context.DeadlineExceeded {
+		t.Fatalf("expected QueryContext to error with context deadline exceeded but returned %v", err)
+	}
+
+	waitForFree(t, db, 5*time.Second, 1)
+}
+
 // TestUnsupportedOptions checks that the database fails when a driver that
 // doesn't implement ConnBeginTx is used with non-default options and an
 // un-cancellable context.
@@ -1525,6 +1560,37 @@ func TestConnTx(t *testing.T) {
 	}
 }
 
+// TestConnIsValid verifies that a database connection that should be discarded,
+// is actually discarded and does not re-enter the connection pool.
+// If the IsValid method from *fakeConn is removed, this test will fail.
+func TestConnIsValid(t *testing.T) {
+	db := newTestDB(t, "people")
+	defer closeDB(t, db)
+
+	db.SetMaxOpenConns(1)
+
+	ctx := context.Background()
+
+	c, err := db.Conn(ctx)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	err = c.Raw(func(raw interface{}) error {
+		dc := raw.(*fakeConn)
+		dc.stickyBad = true
+		return nil
+	})
+	if err != nil {
+		t.Fatal(err)
+	}
+	c.Close()
+
+	if len(db.freeConn) > 0 && db.freeConn[0].ci.(*fakeConn).stickyBad {
+		t.Fatal("bad connection returned to pool; expected bad connection to be discarded")
+	}
+}
+
 // Tests fix for issue 2542, that we release a lock when querying on
 // a closed connection.
 func TestIssue2542Deadlock(t *testing.T) {
@@ -2658,6 +2724,159 @@ func TestManyErrBadConn(t *testing.T) {
 	}
 }
 
+// Issue 34755: Ensure that a Tx cannot commit after a rollback.
+func TestTxCannotCommitAfterRollback(t *testing.T) {
+	db := newTestDB(t, "tx_status")
+	defer closeDB(t, db)
+
+	// First check query reporting is correct.
+	var txStatus string
+	err := db.QueryRow("SELECT|tx_status|tx_status|").Scan(&txStatus)
+	if err != nil {
+		t.Fatal(err)
+	}
+	if g, w := txStatus, "autocommit"; g != w {
+		t.Fatalf("tx_status=%q, wanted %q", g, w)
+	}
+
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	tx, err := db.BeginTx(ctx, nil)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	// Ignore dirty session for this test.
+	// A failing test should trigger the dirty session flag as well,
+	// but that isn't exactly what this should test for.
+	tx.txi.(*fakeTx).c.skipDirtySession = true
+
+	defer tx.Rollback()
+
+	err = tx.QueryRow("SELECT|tx_status|tx_status|").Scan(&txStatus)
+	if err != nil {
+		t.Fatal(err)
+	}
+	if g, w := txStatus, "transaction"; g != w {
+		t.Fatalf("tx_status=%q, wanted %q", g, w)
+	}
+
+	// 1. Begin a transaction.
+	// 2. (A) Start a query, (B) begin Tx rollback through a ctx cancel.
+	// 3. Check if 2.A has committed in Tx (pass) or outside of Tx (fail).
+	sendQuery := make(chan struct{})
+	hookTxGrabConn = func() {
+		cancel()
+		<-sendQuery
+	}
+	rollbackHook = func() {
+		close(sendQuery)
+	}
+	defer func() {
+		hookTxGrabConn = nil
+		rollbackHook = nil
+	}()
+
+	err = tx.QueryRow("SELECT|tx_status|tx_status|").Scan(&txStatus)
+	if err != nil {
+		// A failure here would be expected if skipDirtySession was not set to true above.
+		t.Fatal(err)
+	}
+	if g, w := txStatus, "transaction"; g != w {
+		t.Fatalf("tx_status=%q, wanted %q", g, w)
+	}
+}
+
+// Issue32530 encounters an issue where a connection may
+// expire right after it comes out of a used connection pool
+// even when a new connection is requested.
+func TestConnExpiresFreshOutOfPool(t *testing.T) {
+	execCases := []struct {
+		expired  bool
+		badReset bool
+	}{
+		{false, false},
+		{true, false},
+		{false, true},
+	}
+
+	t0 := time.Unix(1000000, 0)
+	offset := time.Duration(0)
+	offsetMu := sync.RWMutex{}
+
+	nowFunc = func() time.Time {
+		offsetMu.RLock()
+		defer offsetMu.RUnlock()
+		return t0.Add(offset)
+	}
+	defer func() { nowFunc = time.Now }()
+
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	db := newTestDB(t, "magicquery")
+	defer closeDB(t, db)
+
+	db.SetMaxOpenConns(1)
+
+	for _, ec := range execCases {
+		ec := ec
+		name := fmt.Sprintf("expired=%t,badReset=%t", ec.expired, ec.badReset)
+		t.Run(name, func(t *testing.T) {
+			db.clearAllConns(t)
+
+			db.SetMaxIdleConns(1)
+			db.SetConnMaxLifetime(10 * time.Second)
+
+			conn, err := db.conn(ctx, alwaysNewConn)
+			if err != nil {
+				t.Fatal(err)
+			}
+
+			afterPutConn := make(chan struct{})
+			waitingForConn := make(chan struct{})
+
+			go func() {
+				conn, err := db.conn(ctx, alwaysNewConn)
+				if err != nil {
+					t.Fatal(err)
+				}
+				db.putConn(conn, err, false)
+				close(afterPutConn)
+			}()
+			go func() {
+				for {
+					db.mu.Lock()
+					ct := len(db.connRequests)
+					db.mu.Unlock()
+					if ct > 0 {
+						close(waitingForConn)
+						return
+					}
+					time.Sleep(10 * time.Millisecond)
+				}
+			}()
+
+			<-waitingForConn
+
+			offsetMu.Lock()
+			if ec.expired {
+				offset = 11 * time.Second
+			} else {
+				offset = time.Duration(0)
+			}
+			offsetMu.Unlock()
+
+			conn.ci.(*fakeConn).stickyBad = ec.badReset
+
+			db.putConn(conn, err, true)
+
+			<-afterPutConn
+		})
+	}
+}
+
 // TestIssue20575 ensures the Rows from query does not block
 // closing a transaction. Ensure Rows is closed while closing a trasaction.
 func TestIssue20575(t *testing.T) {
diff --git a/libgo/go/encoding/json/decode.go b/libgo/go/encoding/json/decode.go
index b60e2bb0b2c..86d8a69db7e 100644
--- a/libgo/go/encoding/json/decode.go
+++ b/libgo/go/encoding/json/decode.go
@@ -213,9 +213,6 @@ type decodeState struct {
 	savedError            error
 	useNumber             bool
 	disallowUnknownFields bool
-	// safeUnquote is the number of current string literal bytes that don't
-	// need to be unquoted. When negative, no bytes need unquoting.
-	safeUnquote int
 }
 
 // readIndex returns the position of the last byte read.
@@ -317,27 +314,13 @@ func (d *decodeState) rescanLiteral() {
 Switch:
 	switch data[i-1] {
 	case '"': // string
-		// safeUnquote is initialized at -1, which means that all bytes
-		// checked so far can be unquoted at a later time with no work
-		// at all. When reaching the closing '"', if safeUnquote is
-		// still -1, all bytes can be unquoted with no work. Otherwise,
-		// only those bytes up until the first '\\' or non-ascii rune
-		// can be safely unquoted.
-		safeUnquote := -1
 		for ; i < len(data); i++ {
-			if c := data[i]; c == '\\' {
-				if safeUnquote < 0 { // first unsafe byte
-					safeUnquote = int(i - d.off)
-				}
+			switch data[i] {
+			case '\\':
 				i++ // escaped char
-			} else if c == '"' {
-				d.safeUnquote = safeUnquote
+			case '"':
 				i++ // tokenize the closing quote too
 				break Switch
-			} else if c >= utf8.RuneSelf {
-				if safeUnquote < 0 { // first unsafe byte
-					safeUnquote = int(i - d.off)
-				}
 			}
 		}
 	case '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '-': // number
@@ -691,7 +674,7 @@ func (d *decodeState) object(v reflect.Value) error {
 		start := d.readIndex()
 		d.rescanLiteral()
 		item := d.data[start:d.readIndex()]
-		key, ok := d.unquoteBytes(item)
+		key, ok := unquoteBytes(item)
 		if !ok {
 			panic(phasePanicMsg)
 		}
@@ -892,7 +875,7 @@ func (d *decodeState) literalStore(item []byte, v reflect.Value, fromQuoted bool
 			d.saveError(&UnmarshalTypeError{Value: val, Type: v.Type(), Offset: int64(d.readIndex())})
 			return nil
 		}
-		s, ok := d.unquoteBytes(item)
+		s, ok := unquoteBytes(item)
 		if !ok {
 			if fromQuoted {
 				return fmt.Errorf("json: invalid use of ,string struct tag, trying to unmarshal %q into %v", item, v.Type())
@@ -943,7 +926,7 @@ func (d *decodeState) literalStore(item []byte, v reflect.Value, fromQuoted bool
 		}
 
 	case '"': // string
-		s, ok := d.unquoteBytes(item)
+		s, ok := unquoteBytes(item)
 		if !ok {
 			if fromQuoted {
 				return fmt.Errorf("json: invalid use of ,string struct tag, trying to unmarshal %q into %v", item, v.Type())
@@ -1103,7 +1086,7 @@ func (d *decodeState) objectInterface() map[string]interface{} {
 		start := d.readIndex()
 		d.rescanLiteral()
 		item := d.data[start:d.readIndex()]
-		key, ok := d.unquote(item)
+		key, ok := unquote(item)
 		if !ok {
 			panic(phasePanicMsg)
 		}
@@ -1152,7 +1135,7 @@ func (d *decodeState) literalInterface() interface{} {
 		return c == 't'
 
 	case '"': // string
-		s, ok := d.unquote(item)
+		s, ok := unquote(item)
 		if !ok {
 			panic(phasePanicMsg)
 		}
@@ -1195,33 +1178,40 @@ func getu4(s []byte) rune {
 
 // unquote converts a quoted JSON string literal s into an actual string t.
 // The rules are different than for Go, so cannot use strconv.Unquote.
-// The first byte in s must be '"'.
-func (d *decodeState) unquote(s []byte) (t string, ok bool) {
-	s, ok = d.unquoteBytes(s)
+func unquote(s []byte) (t string, ok bool) {
+	s, ok = unquoteBytes(s)
 	t = string(s)
 	return
 }
 
-func (d *decodeState) unquoteBytes(s []byte) (t []byte, ok bool) {
-	// We already know that s[0] == '"'. However, we don't know that the
-	// closing quote exists in all cases, such as when the string is nested
-	// via the ",string" option.
-	if len(s) < 2 || s[len(s)-1] != '"' {
+func unquoteBytes(s []byte) (t []byte, ok bool) {
+	if len(s) < 2 || s[0] != '"' || s[len(s)-1] != '"' {
 		return
 	}
 	s = s[1 : len(s)-1]
 
-	// If there are no unusual characters, no unquoting is needed, so return
-	// a slice of the original bytes.
-	r := d.safeUnquote
-	if r == -1 {
+	// Check for unusual characters. If there are none,
+	// then no unquoting is needed, so return a slice of the
+	// original bytes.
+	r := 0
+	for r < len(s) {
+		c := s[r]
+		if c == '\\' || c == '"' || c < ' ' {
+			break
+		}
+		if c < utf8.RuneSelf {
+			r++
+			continue
+		}
+		rr, size := utf8.DecodeRune(s[r:])
+		if rr == utf8.RuneError && size == 1 {
+			break
+		}
+		r += size
+	}
+	if r == len(s) {
 		return s, true
 	}
-	// Only perform up to one safe unquote for each re-scanned string
-	// literal. In some edge cases, the decoder unquotes a literal a second
-	// time, even after another literal has been re-scanned. Thus, only the
-	// first unquote can safely use safeUnquote.
-	d.safeUnquote = 0
 
 	b := make([]byte, len(s)+2*utf8.UTFMax)
 	w := copy(b, s[0:r])
diff --git a/libgo/go/encoding/json/decode_test.go b/libgo/go/encoding/json/decode_test.go
index a49181e9823..689cc34c243 100644
--- a/libgo/go/encoding/json/decode_test.go
+++ b/libgo/go/encoding/json/decode_test.go
@@ -2459,4 +2459,20 @@ func TestUnmarshalRescanLiteralMangledUnquote(t *testing.T) {
 	if t1 != t2 {
 		t.Errorf("Marshal and Unmarshal roundtrip mismatch: want %q got %q", t1, t2)
 	}
+
+	// See golang.org/issues/39555.
+	input := map[textUnmarshalerString]string{"FOO": "", `"`: ""}
+
+	encoded, err := Marshal(input)
+	if err != nil {
+		t.Fatalf("Marshal unexpected error: %v", err)
+	}
+	var got map[textUnmarshalerString]string
+	if err := Unmarshal(encoded, &got); err != nil {
+		t.Fatalf("Unmarshal unexpected error: %v", err)
+	}
+	want := map[textUnmarshalerString]string{"foo": "", `"`: ""}
+	if !reflect.DeepEqual(want, got) {
+		t.Fatalf("Unexpected roundtrip result:\nwant: %q\ngot:  %q", want, got)
+	}
 }
diff --git a/libgo/go/golang.org/x/tools/go/analysis/passes/printf/printf.go b/libgo/go/golang.org/x/tools/go/analysis/passes/printf/printf.go
index a81dba91251..e6177f2ea9b 100644
--- a/libgo/go/golang.org/x/tools/go/analysis/passes/printf/printf.go
+++ b/libgo/go/golang.org/x/tools/go/analysis/passes/printf/printf.go
@@ -801,6 +801,7 @@ var printVerbs = []printVerb{
 	{'g', sharpNumFlag, argFloat | argComplex},
 	{'G', sharpNumFlag, argFloat | argComplex},
 	{'o', sharpNumFlag, argInt | argPointer},
+	{'O', sharpNumFlag, argInt | argPointer},
 	{'p', "-#", argPointer},
 	{'q', " -+.0#", argRune | argInt | argString},
 	{'s', " -+.0", argString},
diff --git a/libgo/go/net/http/fs.go b/libgo/go/net/http/fs.go
index d2144857e84..b8a68cc460f 100644
--- a/libgo/go/net/http/fs.go
+++ b/libgo/go/net/http/fs.go
@@ -411,6 +411,7 @@ func checkIfNoneMatch(w ResponseWriter, r *Request) condResult {
 		}
 		if buf[0] == ',' {
 			buf = buf[1:]
+			continue
 		}
 		if buf[0] == '*' {
 			return condFalse
diff --git a/libgo/go/net/http/fs_test.go b/libgo/go/net/http/fs_test.go
index 435e34be3af..c082ceee71b 100644
--- a/libgo/go/net/http/fs_test.go
+++ b/libgo/go/net/http/fs_test.go
@@ -849,6 +849,15 @@ func TestServeContent(t *testing.T) {
 			wantStatus:      200,
 			wantContentType: "text/css; charset=utf-8",
 		},
+		"if_none_match_malformed": {
+			file:      "testdata/style.css",
+			serveETag: `"foo"`,
+			reqHeader: map[string]string{
+				"If-None-Match": `,`,
+			},
+			wantStatus:      200,
+			wantContentType: "text/css; charset=utf-8",
+		},
 		"range_good": {
 			file:      "testdata/style.css",
 			serveETag: `"A"`,
diff --git a/libgo/go/net/http/server.go b/libgo/go/net/http/server.go
index 77329b2708a..6e6514dbddb 100644
--- a/libgo/go/net/http/server.go
+++ b/libgo/go/net/http/server.go
@@ -425,6 +425,16 @@ type response struct {
 	wants10KeepAlive bool               // HTTP/1.0 w/ Connection "keep-alive"
 	wantsClose       bool               // HTTP request has Connection "close"
 
+	// canWriteContinue is a boolean value accessed as an atomic int32
+	// that says whether or not a 100 Continue header can be written
+	// to the connection.
+	// writeContinueMu must be held while writing the header.
+	// These two fields together synchronize the body reader
+	// (the expectContinueReader, which wants to write 100 Continue)
+	// against the main writer.
+	canWriteContinue atomicBool
+	writeContinueMu  sync.Mutex
+
 	w  *bufio.Writer // buffers output in chunks to chunkWriter
 	cw chunkWriter
 
@@ -515,6 +525,7 @@ type atomicBool int32
 
 func (b *atomicBool) isSet() bool { return atomic.LoadInt32((*int32)(b)) != 0 }
 func (b *atomicBool) setTrue()    { atomic.StoreInt32((*int32)(b), 1) }
+func (b *atomicBool) setFalse()   { atomic.StoreInt32((*int32)(b), 0) }
 
 // declareTrailer is called for each Trailer header when the
 // response header is written. It notes that a header will need to be
@@ -877,21 +888,27 @@ type expectContinueReader struct {
 	resp       *response
 	readCloser io.ReadCloser
 	closed     bool
-	sawEOF     bool
+	sawEOF     atomicBool
 }
 
 func (ecr *expectContinueReader) Read(p []byte) (n int, err error) {
 	if ecr.closed {
 		return 0, ErrBodyReadAfterClose
 	}
-	if !ecr.resp.wroteContinue && !ecr.resp.conn.hijacked() {
-		ecr.resp.wroteContinue = true
-		ecr.resp.conn.bufw.WriteString("HTTP/1.1 100 Continue\r\n\r\n")
-		ecr.resp.conn.bufw.Flush()
+	w := ecr.resp
+	if !w.wroteContinue && w.canWriteContinue.isSet() && !w.conn.hijacked() {
+		w.wroteContinue = true
+		w.writeContinueMu.Lock()
+		if w.canWriteContinue.isSet() {
+			w.conn.bufw.WriteString("HTTP/1.1 100 Continue\r\n\r\n")
+			w.conn.bufw.Flush()
+			w.canWriteContinue.setFalse()
+		}
+		w.writeContinueMu.Unlock()
 	}
 	n, err = ecr.readCloser.Read(p)
 	if err == io.EOF {
-		ecr.sawEOF = true
+		ecr.sawEOF.setTrue()
 	}
 	return
 }
@@ -1315,7 +1332,7 @@ func (cw *chunkWriter) writeHeader(p []byte) {
 	// because we don't know if the next bytes on the wire will be
 	// the body-following-the-timer or the subsequent request.
 	// See Issue 11549.
-	if ecr, ok := w.req.Body.(*expectContinueReader); ok && !ecr.sawEOF {
+	if ecr, ok := w.req.Body.(*expectContinueReader); ok && !ecr.sawEOF.isSet() {
 		w.closeAfterReply = true
 	}
 
@@ -1565,6 +1582,17 @@ func (w *response) write(lenData int, dataB []byte, dataS string) (n int, err er
 		}
 		return 0, ErrHijacked
 	}
+
+	if w.canWriteContinue.isSet() {
+		// Body reader wants to write 100 Continue but hasn't yet.
+		// Tell it not to. The store must be done while holding the lock
+		// because the lock makes sure that there is not an active write
+		// this very moment.
+		w.writeContinueMu.Lock()
+		w.canWriteContinue.setFalse()
+		w.writeContinueMu.Unlock()
+	}
+
 	if !w.wroteHeader {
 		w.WriteHeader(StatusOK)
 	}
@@ -1876,6 +1904,7 @@ func (c *conn) serve(ctx context.Context) {
 			if req.ProtoAtLeast(1, 1) && req.ContentLength != 0 {
 				// Wrap the Body reader with one that replies on the connection
 				req.Body = &expectContinueReader{readCloser: req.Body, resp: w}
+				w.canWriteContinue.setTrue()
 			}
 		} else if req.Header.get("Expect") != "" {
 			w.sendExpectationFailed()
diff --git a/libgo/go/reflect/all_test.go b/libgo/go/reflect/all_test.go
index 33d02aea849..e5ec052f7de 100644
--- a/libgo/go/reflect/all_test.go
+++ b/libgo/go/reflect/all_test.go
@@ -789,6 +789,11 @@ var loop1, loop2 Loop
 var loopy1, loopy2 Loopy
 var cycleMap1, cycleMap2, cycleMap3 map[string]interface{}
 
+type structWithSelfPtr struct {
+	p *structWithSelfPtr
+	s string
+}
+
 func init() {
 	loop1 = &loop2
 	loop2 = &loop1
@@ -845,6 +850,7 @@ var deepEqualTests = []DeepEqualTest{
 	{[]float64{math.NaN()}, self{}, true},
 	{map[float64]float64{math.NaN(): 1}, map[float64]float64{1: 2}, false},
 	{map[float64]float64{math.NaN(): 1}, self{}, true},
+	{&structWithSelfPtr{p: &structWithSelfPtr{s: "a"}}, &structWithSelfPtr{p: &structWithSelfPtr{s: "b"}}, false},
 
 	// Nil vs empty: not the same.
 	{[]int{}, []int(nil), false},
diff --git a/libgo/go/reflect/deepequal.go b/libgo/go/reflect/deepequal.go
index f2d46165b50..8a2bf8b09e2 100644
--- a/libgo/go/reflect/deepequal.go
+++ b/libgo/go/reflect/deepequal.go
@@ -45,8 +45,20 @@ func deepValueEqual(v1, v2 Value, visited map[visit]bool, depth int) bool {
 	}
 
 	if hard(v1, v2) {
-		addr1 := v1.ptr
-		addr2 := v2.ptr
+		// For a Ptr or Map value, we need to check flagIndir,
+		// which we do by calling the pointer method.
+		// For Slice or Interface, flagIndir is always set,
+		// and using v.ptr suffices.
+		ptrval := func(v Value) unsafe.Pointer {
+			switch v.Kind() {
+			case Ptr, Map:
+				return v.pointer()
+			default:
+				return v.ptr
+			}
+		}
+		addr1 := ptrval(v1)
+		addr2 := ptrval(v2)
 		if uintptr(addr1) > uintptr(addr2) {
 			// Canonicalize order to reduce number of entries in visited.
 			// Assumes non-moving garbage collector.
diff --git a/libgo/go/reflect/type.go b/libgo/go/reflect/type.go
index 9c003a43dd9..2ce1901f556 100644
--- a/libgo/go/reflect/type.go
+++ b/libgo/go/reflect/type.go
@@ -2477,6 +2477,7 @@ func ifaceIndir(t *rtype) bool {
 	return t.kind&kindDirectIface == 0
 }
 
+// Note: this type must agree with runtime.bitvector.
 type bitVector struct {
 	n    uint32 // number of bits
 	data []byte
diff --git a/libgo/go/reflect/value.go b/libgo/go/reflect/value.go
index 147a9c47298..7c6a3e8a935 100644
--- a/libgo/go/reflect/value.go
+++ b/libgo/go/reflect/value.go
@@ -2175,6 +2175,7 @@ func NewAt(typ Type, p unsafe.Pointer) Value {
 // assignTo returns a value v that can be assigned directly to typ.
 // It panics if v is not assignable to typ.
 // For a conversion to an interface type, target is a suggested scratch space to use.
+// target must be initialized memory (or nil).
 func (v Value) assignTo(context string, dst *rtype, target unsafe.Pointer) Value {
 	if v.flag&flagMethod != 0 {
 		v = makeMethodValue(context, v)
diff --git a/libgo/go/testing/benchmark.go b/libgo/go/testing/benchmark.go
index 88ba0f02420..52766005bf6 100644
--- a/libgo/go/testing/benchmark.go
+++ b/libgo/go/testing/benchmark.go
@@ -526,6 +526,7 @@ func runBenchmarks(importPath string, matchString func(pat, str string) (bool, e
 			name:   "Main",
 			w:      os.Stdout,
 			chatty: *chatty,
+			bench:  true,
 		},
 		importPath: importPath,
 		benchFunc: func(b *B) {
@@ -559,6 +560,7 @@ func (ctx *benchContext) processBench(b *B) {
 						name:   b.name,
 						w:      b.w,
 						chatty: b.chatty,
+						bench:  true,
 					},
 					benchFunc: b.benchFunc,
 					benchTime: b.benchTime,
@@ -624,6 +626,7 @@ func (b *B) Run(name string, f func(b *B)) bool {
 			creator: pc[:n],
 			w:       b.w,
 			chatty:  b.chatty,
+			bench:   true,
 		},
 		importPath: b.importPath,
 		benchFunc:  f,
diff --git a/libgo/go/testing/sub_test.go b/libgo/go/testing/sub_test.go
index 95f8220f815..8eb0084b1c8 100644
--- a/libgo/go/testing/sub_test.go
+++ b/libgo/go/testing/sub_test.go
@@ -438,8 +438,6 @@ func TestTRun(t *T) {
 	}, {
 		// A chatty test should always log with fmt.Print, even if the
 		// parent test has completed.
-		// TODO(deklerk) Capture the log of fmt.Print and assert that the
-		// subtest message is not lost.
 		desc:   "log in finished sub test with chatty",
 		ok:     false,
 		chatty: true,
@@ -477,35 +475,37 @@ func TestTRun(t *T) {
 		},
 	}}
 	for _, tc := range testCases {
-		ctx := newTestContext(tc.maxPar, newMatcher(regexp.MatchString, "", ""))
-		buf := &bytes.Buffer{}
-		root := &T{
-			common: common{
-				signal: make(chan bool),
-				name:   "Test",
-				w:      buf,
-				chatty: tc.chatty,
-			},
-			context: ctx,
-		}
-		ok := root.Run(tc.desc, tc.f)
-		ctx.release()
+		t.Run(tc.desc, func(t *T) {
+			ctx := newTestContext(tc.maxPar, newMatcher(regexp.MatchString, "", ""))
+			buf := &bytes.Buffer{}
+			root := &T{
+				common: common{
+					signal: make(chan bool),
+					name:   "Test",
+					w:      buf,
+					chatty: tc.chatty,
+				},
+				context: ctx,
+			}
+			ok := root.Run(tc.desc, tc.f)
+			ctx.release()
 
-		if ok != tc.ok {
-			t.Errorf("%s:ok: got %v; want %v", tc.desc, ok, tc.ok)
-		}
-		if ok != !root.Failed() {
-			t.Errorf("%s:root failed: got %v; want %v", tc.desc, !ok, root.Failed())
-		}
-		if ctx.running != 0 || ctx.numWaiting != 0 {
-			t.Errorf("%s:running and waiting non-zero: got %d and %d", tc.desc, ctx.running, ctx.numWaiting)
-		}
-		got := strings.TrimSpace(buf.String())
-		want := strings.TrimSpace(tc.output)
-		re := makeRegexp(want)
-		if ok, err := regexp.MatchString(re, got); !ok || err != nil {
-			t.Errorf("%s:output:\ngot:\n%s\nwant:\n%s", tc.desc, got, want)
-		}
+			if ok != tc.ok {
+				t.Errorf("%s:ok: got %v; want %v", tc.desc, ok, tc.ok)
+			}
+			if ok != !root.Failed() {
+				t.Errorf("%s:root failed: got %v; want %v", tc.desc, !ok, root.Failed())
+			}
+			if ctx.running != 0 || ctx.numWaiting != 0 {
+				t.Errorf("%s:running and waiting non-zero: got %d and %d", tc.desc, ctx.running, ctx.numWaiting)
+			}
+			got := strings.TrimSpace(buf.String())
+			want := strings.TrimSpace(tc.output)
+			re := makeRegexp(want)
+			if ok, err := regexp.MatchString(re, got); !ok || err != nil {
+				t.Errorf("%s:output:\ngot:\n%s\nwant:\n%s", tc.desc, got, want)
+			}
+		})
 	}
 }
 
@@ -655,43 +655,45 @@ func TestBRun(t *T) {
 		},
 	}}
 	for _, tc := range testCases {
-		var ok bool
-		buf := &bytes.Buffer{}
-		// This is almost like the Benchmark function, except that we override
-		// the benchtime and catch the failure result of the subbenchmark.
-		root := &B{
-			common: common{
-				signal: make(chan bool),
-				name:   "root",
-				w:      buf,
-				chatty: tc.chatty,
-			},
-			benchFunc: func(b *B) { ok = b.Run("test", tc.f) }, // Use Run to catch failure.
-			benchTime: benchTimeFlag{d: 1 * time.Microsecond},
-		}
-		root.runN(1)
-		if ok != !tc.failed {
-			t.Errorf("%s:ok: got %v; want %v", tc.desc, ok, !tc.failed)
-		}
-		if !ok != root.Failed() {
-			t.Errorf("%s:root failed: got %v; want %v", tc.desc, !ok, root.Failed())
-		}
-		// All tests are run as subtests
-		if root.result.N != 1 {
-			t.Errorf("%s: N for parent benchmark was %d; want 1", tc.desc, root.result.N)
-		}
-		got := strings.TrimSpace(buf.String())
-		want := strings.TrimSpace(tc.output)
-		re := makeRegexp(want)
-		if ok, err := regexp.MatchString(re, got); !ok || err != nil {
-			t.Errorf("%s:output:\ngot:\n%s\nwant:\n%s", tc.desc, got, want)
-		}
+		t.Run(tc.desc, func(t *T) {
+			var ok bool
+			buf := &bytes.Buffer{}
+			// This is almost like the Benchmark function, except that we override
+			// the benchtime and catch the failure result of the subbenchmark.
+			root := &B{
+				common: common{
+					signal: make(chan bool),
+					name:   "root",
+					w:      buf,
+					chatty: tc.chatty,
+				},
+				benchFunc: func(b *B) { ok = b.Run("test", tc.f) }, // Use Run to catch failure.
+				benchTime: benchTimeFlag{d: 1 * time.Microsecond},
+			}
+			root.runN(1)
+			if ok != !tc.failed {
+				t.Errorf("%s:ok: got %v; want %v", tc.desc, ok, !tc.failed)
+			}
+			if !ok != root.Failed() {
+				t.Errorf("%s:root failed: got %v; want %v", tc.desc, !ok, root.Failed())
+			}
+			// All tests are run as subtests
+			if root.result.N != 1 {
+				t.Errorf("%s: N for parent benchmark was %d; want 1", tc.desc, root.result.N)
+			}
+			got := strings.TrimSpace(buf.String())
+			want := strings.TrimSpace(tc.output)
+			re := makeRegexp(want)
+			if ok, err := regexp.MatchString(re, got); !ok || err != nil {
+				t.Errorf("%s:output:\ngot:\n%s\nwant:\n%s", tc.desc, got, want)
+			}
+		})
 	}
 }
 
 func makeRegexp(s string) string {
 	s = regexp.QuoteMeta(s)
-	s = strings.ReplaceAll(s, ":NNN:", `:\d\d\d:`)
+	s = strings.ReplaceAll(s, ":NNN:", `:\d\d\d\d?:`)
 	s = strings.ReplaceAll(s, "N\\.NNs", `\d*\.\d*s`)
 	return s
 }
diff --git a/libgo/go/testing/testing.go b/libgo/go/testing/testing.go
index 758af7487c7..9f47eb8584f 100644
--- a/libgo/go/testing/testing.go
+++ b/libgo/go/testing/testing.go
@@ -320,6 +320,7 @@ var (
 	cpuListStr           *string
 	parallel             *int
 	testlog              *string
+	printer              *testPrinter
 
 	haveExamples bool // are there examples?
 
@@ -329,6 +330,48 @@ var (
 	numFailed uint32 // number of test failures
 )
 
+type testPrinter struct {
+	chatty bool
+
+	lastNameMu sync.Mutex // guards lastName
+	lastName   string     // last printed test name in chatty mode
+}
+
+func newTestPrinter(chatty bool) *testPrinter {
+	return &testPrinter{
+		chatty: chatty,
+	}
+}
+
+func (p *testPrinter) Print(testName, out string) {
+	p.Fprint(os.Stdout, testName, out)
+}
+
+func (p *testPrinter) Fprint(w io.Writer, testName, out string) {
+	p.lastNameMu.Lock()
+	defer p.lastNameMu.Unlock()
+
+	if !p.chatty ||
+		strings.HasPrefix(out, "--- PASS") ||
+		strings.HasPrefix(out, "--- FAIL") ||
+		strings.HasPrefix(out, "=== CONT") ||
+		strings.HasPrefix(out, "=== RUN") {
+		p.lastName = testName
+		fmt.Fprint(w, out)
+		return
+	}
+
+	if p.lastName == "" {
+		p.lastName = testName
+	} else if p.lastName != testName {
+		// Always printed as-is, with 0 decoration or indentation. So, we skip
+		// printing to w.
+		fmt.Printf("=== CONT  %s\n", testName)
+		p.lastName = testName
+	}
+	fmt.Fprint(w, out)
+}
+
 // The maximum number of stack frames to go through when skipping helper functions for
 // the purpose of decorating log messages.
 const maxStackLen = 50
@@ -347,10 +390,11 @@ type common struct {
 	cleanup func()              // optional function to be called at the end of the test
 
 	chatty     bool   // A copy of the chatty flag.
+	bench      bool   // Whether the current test is a benchmark.
 	finished   bool   // Test function has completed.
-	hasSub     int32  // written atomically
-	raceErrors int    // number of races detected during test
-	runner     string // function name of tRunner running the test
+	hasSub     int32  // Written atomically.
+	raceErrors int    // Number of races detected during test.
+	runner     string // Function name of tRunner running the test.
 
 	parent   *common
 	level    int       // Nesting depth of test or benchmark.
@@ -480,9 +524,6 @@ func (c *common) decorate(s string, skip int) string {
 	buf := new(strings.Builder)
 	// Every line is indented at least 4 spaces.
 	buf.WriteString("    ")
-	if c.chatty {
-		fmt.Fprintf(buf, "%s: ", c.name)
-	}
 	fmt.Fprintf(buf, "%s:%d: ", file, line)
 	lines := strings.Split(s, "\n")
 	if l := len(lines); l > 1 && lines[l-1] == "" {
@@ -501,12 +542,12 @@ func (c *common) decorate(s string, skip int) string {
 
 // flushToParent writes c.output to the parent after first writing the header
 // with the given format and arguments.
-func (c *common) flushToParent(format string, args ...interface{}) {
+func (c *common) flushToParent(testName, format string, args ...interface{}) {
 	p := c.parent
 	p.mu.Lock()
 	defer p.mu.Unlock()
 
-	fmt.Fprintf(p.w, format, args...)
+	printer.Fprint(p.w, testName, fmt.Sprintf(format, args...))
 
 	c.mu.Lock()
 	defer c.mu.Unlock()
@@ -680,7 +721,14 @@ func (c *common) logDepth(s string, depth int) {
 		panic("Log in goroutine after " + c.name + " has completed")
 	} else {
 		if c.chatty {
-			fmt.Print(c.decorate(s, depth+1))
+			if c.bench {
+				// Benchmarks don't print === CONT, so we should skip the test
+				// printer and just print straight to stdout.
+				fmt.Print(c.decorate(s, depth+1))
+			} else {
+				printer.Print(c.name, c.decorate(s, depth+1))
+			}
+
 			return
 		}
 		c.output = append(c.output, c.decorate(s, depth+1)...)
@@ -909,7 +957,7 @@ func (t *T) Parallel() {
 		for ; root.parent != nil; root = root.parent {
 		}
 		root.mu.Lock()
-		fmt.Fprintf(root.w, "=== CONT  %s\n", t.name)
+		printer.Fprint(root.w, t.name, fmt.Sprintf("=== CONT  %s\n", t.name))
 		root.mu.Unlock()
 	}
 
@@ -968,7 +1016,7 @@ func tRunner(t *T, fn func(t *T)) {
 				root.duration += time.Since(root.start)
 				d := root.duration
 				root.mu.Unlock()
-				root.flushToParent("--- FAIL: %s (%s)\n", root.name, fmtDuration(d))
+				root.flushToParent(root.name, "--- FAIL: %s (%s)\n", root.name, fmtDuration(d))
 				if r := root.parent.runCleanup(recoverAndReturnPanic); r != nil {
 					fmt.Fprintf(root.parent.w, "cleanup panicked with %v", r)
 				}
@@ -1067,7 +1115,7 @@ func (t *T) Run(name string, f func(t *T)) bool {
 		for ; root.parent != nil; root = root.parent {
 		}
 		root.mu.Lock()
-		fmt.Fprintf(root.w, "=== RUN   %s\n", t.name)
+		printer.Fprint(root.w, t.name, fmt.Sprintf("=== RUN   %s\n", t.name))
 		root.mu.Unlock()
 	}
 	// Instead of reducing the running count of this test before calling the
@@ -1215,6 +1263,8 @@ func (m *M) Run() int {
 		flag.Parse()
 	}
 
+	printer = newTestPrinter(Verbose())
+
 	if *parallel < 1 {
 		fmt.Fprintln(os.Stderr, "testing: -parallel can only be given a positive integer")
 		flag.Usage()
@@ -1254,12 +1304,12 @@ func (t *T) report() {
 	dstr := fmtDuration(t.duration)
 	format := "--- %s: %s (%s)\n"
 	if t.Failed() {
-		t.flushToParent(format, "FAIL", t.name, dstr)
+		t.flushToParent(t.name, format, "FAIL", t.name, dstr)
 	} else if t.chatty {
 		if t.Skipped() {
-			t.flushToParent(format, "SKIP", t.name, dstr)
+			t.flushToParent(t.name, format, "SKIP", t.name, dstr)
 		} else {
-			t.flushToParent(format, "PASS", t.name, dstr)
+			t.flushToParent(t.name, format, "PASS", t.name, dstr)
 		}
 	}
 }

commit 8dafc134683a1aa5538b99d1677dec72779cd45c
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Jul 25 00:16:54 2020 +0000

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 09a13ab3781..ca1a68b03b7 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200724
+20200725

commit b45f51d467c6c192c70f57e517bec3a3c0c9d1f4
Author: Dominique d'Humieres <dhumieres.dominique@free.fr>
Date:   Fri Jul 24 20:07:12 2020 +0200

    PR 93592 - Invalid UP/DOWN rounding with EN descriptor.
    
    The fix is obvious (I have added a comment). The tests are probably
    an overkill, but it does not hurt.
    
    libgfortran/ChangeLog:
    
            PR fortran/93592
            * io/write_float.def (build_float_string): Do not reset
              nbefore for FMT_F and FMT_EN.
    
    gcc/testsuite/ChangeLog:
    
            PR fortran/93592
            * gfortran.dg/fmt_en.f90: Adjust test.
            * gfortran.dg/fmt_en_rd.f90: New test.
            * gfortran.dg/fmt_en_rn.f90: New test.
            * gfortran.dg/fmt_en_ru.f90: New test.
            * gfortran.dg/fmt_en_rz.f90: New test.
    
    (cherry picked from commit 05e0971bcf94a481cbfa2731484f024a67dbd4a5)

diff --git a/gcc/testsuite/gfortran.dg/fmt_en.f90 b/gcc/testsuite/gfortran.dg/fmt_en.f90
index 89011b32368..d7e51b3fa21 100644
--- a/gcc/testsuite/gfortran.dg/fmt_en.f90
+++ b/gcc/testsuite/gfortran.dg/fmt_en.f90
@@ -10,7 +10,6 @@ use ISO_FORTRAN_ENV
     integer :: n_tst = 0, n_cnt = 0, n_skip = 0
     character(len=20) :: s, s1
 
-    open (unit = 10, file = 'fmt_en.res')
 !   Check that the default rounding mode is to nearest and to even on tie.
     do i=1,size(real_kinds)
       if (i == 1) then
@@ -149,8 +148,7 @@ use ISO_FORTRAN_ENV
 
     ! print *, n_tst, n_cnt, n_skip
     if (n_cnt /= 0) STOP 1
-    if (all(.not. l_skip)) write (10, *) "All kinds rounded to nearest"
-    close (10)
+    if (all(.not. l_skip)) print *, "All kinds rounded to nearest"
 
 contains
     subroutine checkfmt(fmt, x, cmp)
@@ -182,4 +180,4 @@ contains
         
     end subroutine
 end program
-! { dg-final { scan-file fmt_en.res "All kinds rounded to nearest" { xfail hppa*-*-hpux* } } }
+! { dg-output "All kinds rounded to nearest" { xfail { i?86-*-solaris2.9* hppa*-*-hpux* } } }
diff --git a/gcc/testsuite/gfortran.dg/fmt_en_rd.f90 b/gcc/testsuite/gfortran.dg/fmt_en_rd.f90
new file mode 100644
index 00000000000..ea914e0901c
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/fmt_en_rd.f90
@@ -0,0 +1,185 @@
+! { dg-do run }
+! PR60128 Invalid outputs with EN descriptors
+! Test case provided by Walt Brainerd.
+program pr60128
+use ISO_FORTRAN_ENV
+    implicit none
+    integer, parameter :: j(size(real_kinds)+4)=[REAL_KINDS, [4, 4, 4, 4]]
+    logical :: l_skip(4) = .false.
+    integer :: i
+    integer :: n_tst = 0, n_cnt = 0, n_skip = 0
+    character(len=20,kind=4) :: s, s1
+
+!   Check that the default rounding mode is to nearest and to even on tie.
+    do i=1,size(real_kinds)
+      if (i == 1) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(1)), &
+                                  real(9.49999905,kind=j(1)),  &
+                                  real(9.5,kind=j(1)), real(8.5,kind=j(1))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(1)), &
+                                       real(98765.0,kind=j(1))
+      else if (i == 2) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(2)), &
+                                  real(9.49999905,kind=j(2)),  &
+                                  real(9.5,kind=j(2)), real(8.5,kind=j(2))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(2)), &
+                                       real(98765.0,kind=j(2))
+      else if (i == 3) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(3)), &
+                                  real(9.49999905,kind=j(3)),  &
+                                  real(9.5,kind=j(3)), real(8.5,kind=j(3))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(3)), &
+                                       real(98765.0,kind=j(3))
+      else if (i == 4) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(4)), &
+                                  real(9.49999905,kind=j(4)),  &
+                                  real(9.5,kind=j(4)), real(8.5,kind=j(4))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(4)), &
+                                       real(98765.0,kind=j(4))
+      end if
+      if (s /= 4_'-9.5 9.5 10.  8.' .or. s1 /= 4_' 987.4E+03 98.76E+03') then
+        l_skip(i) = .true.
+        print "('Unsupported rounding for real(',i0,')')", j(i)
+      end if
+    end do
+        
+
+! Original test.
+    call checkfmt("(en15.2)", -.44444,    4_"    -444.44E-03")
+
+! Test for the bug in comment 6.
+    call checkfmt("(rd,en15.0)", 1.0,        4_"         1.E+00")
+    call checkfmt("(rd,en15.0)", 1.00000012, 4_"         1.E+00")
+    call checkfmt("(rd,en15.0)", 0.99999994, 4_"       999.E-03")
+    call checkfmt("(rd,en15.0)", 10.0,       4_"        10.E+00")
+    call checkfmt("(rd,en15.0)", 10.0000010, 4_"        10.E+00")
+    call checkfmt("(rd,en15.0)", 9.99999905, 4_"         9.E+00")
+    call checkfmt("(ru,en15.0)", 100.0,      4_"       100.E+00")
+    call checkfmt("(rd,en15.0)", 100.000008, 4_"       100.E+00")
+    call checkfmt("(rd,en15.0)", 99.9999924, 4_"        99.E+00")
+    call checkfmt("(rd,en15.0)", 1000.0,     4_"         1.E+03")
+    call checkfmt("(rd,en15.0)", 1000.00006, 4_"         1.E+03")
+    call checkfmt("(rd,en15.0)", 999.999939, 4_"       999.E+00")
+    call checkfmt("(rd,en15.0)", 9.5,        4_"         9.E+00")
+    call checkfmt("(rd,en15.0)", 9.50000095, 4_"         9.E+00")
+    call checkfmt("(rd,en15.0)", 9.49999905, 4_"         9.E+00")
+    call checkfmt("(rd,en15.0)", 99.5,       4_"        99.E+00")
+    call checkfmt("(rd,en15.0)", 99.5000076, 4_"        99.E+00")
+    call checkfmt("(rd,en15.0)", 99.4999924, 4_"        99.E+00")
+    call checkfmt("(rd,en15.0)", 999.5,      4_"       999.E+00")
+    call checkfmt("(rd,en15.0)", 999.500061, 4_"       999.E+00")
+    call checkfmt("(rd,en15.0)", 999.499939, 4_"       999.E+00")
+    call checkfmt("(rd,en15.0)", 9500.0,     4_"         9.E+03")
+    call checkfmt("(rd,en15.0)", 9500.00098, 4_"         9.E+03")
+    call checkfmt("(rd,en15.0)", 9499.99902, 4_"         9.E+03")
+    call checkfmt("(rd,en15.1)", 9950.0,     4_"        9.9E+03")
+    call checkfmt("(rd,en15.2)", 9995.0,     4_"       9.99E+03")
+    call checkfmt("(rd,en15.3)", 9999.5,     4_"      9.999E+03")
+    call checkfmt("(rd,en15.1)", 9.5,        4_"        9.5E+00")
+    call checkfmt("(rd,en15.1)", 9.50000095, 4_"        9.5E+00")
+    call checkfmt("(rd,en15.1)", 9.49999905, 4_"        9.4E+00")
+    call checkfmt("(rd,en15.1)", 0.099951,   4_"       99.9E-03")
+    call checkfmt("(rd,en15.1)", 0.009951,   4_"        9.9E-03")
+    call checkfmt("(rd,en15.1)", 0.000999951,4_"      999.9E-06")
+
+    call checkfmt("(rd,en15.0)", -1.0,        4_"        -1.E+00")
+    call checkfmt("(rd,en15.0)", -1.00000012, 4_"        -2.E+00")
+    call checkfmt("(rd,en15.0)", -0.99999994, 4_"        -1.E+00")
+    call checkfmt("(rd,en15.0)", -10.0,       4_"       -10.E+00")
+    call checkfmt("(rd,en15.0)", -10.0000010, 4_"       -11.E+00")
+    call checkfmt("(rd,en15.0)", -9.99999905, 4_"       -10.E+00")
+    call checkfmt("(rd,en15.0)", -100.0,      4_"      -100.E+00")
+    call checkfmt("(rd,en15.0)", -100.000008, 4_"      -101.E+00")
+    call checkfmt("(rd,en15.0)", -99.9999924, 4_"      -100.E+00")
+    call checkfmt("(rd,en15.0)", -1000.0,     4_"        -1.E+03")
+    call checkfmt("(rd,en15.0)", -1000.00006, 4_"        -2.E+03")
+    call checkfmt("(rd,en15.0)", -999.999939, 4_"        -1.E+03")
+    call checkfmt("(rd,en15.0)", -9.5,        4_"       -10.E+00")
+    call checkfmt("(rd,en15.0)", -9.50000095, 4_"       -10.E+00")
+    call checkfmt("(rd,en15.0)", -9.49999905, 4_"       -10.E+00")
+    call checkfmt("(rd,en15.0)", -99.5,       4_"      -100.E+00")
+    call checkfmt("(rd,en15.0)", -99.5000076, 4_"      -100.E+00")
+    call checkfmt("(rd,en15.0)", -99.4999924, 4_"      -100.E+00")
+    call checkfmt("(rd,en15.0)", -999.5,      4_"        -1.E+03")
+    call checkfmt("(rd,en15.0)", -999.500061, 4_"        -1.E+03")
+    call checkfmt("(rd,en15.0)", -999.499939, 4_"        -1.E+03")
+    call checkfmt("(rd,en15.0)", -9500.0,     4_"       -10.E+03")
+    call checkfmt("(rd,en15.0)", -9500.00098, 4_"       -10.E+03")
+    call checkfmt("(rd,en15.0)", -9499.99902, 4_"       -10.E+03")
+    call checkfmt("(rd,en15.1)", -9950.0,     4_"      -10.0E+03")
+    call checkfmt("(rd,en15.2)", -9995.0,     4_"     -10.00E+03")
+    call checkfmt("(rd,en15.3)", -9999.5,     4_"    -10.000E+03")
+    call checkfmt("(rd,en15.1)", -9.5,        4_"       -9.5E+00")
+    call checkfmt("(rd,en15.1)", -9.50000095, 4_"       -9.6E+00")
+    call checkfmt("(rd,en15.1)", -9.49999905, 4_"       -9.5E+00")
+    call checkfmt("(rd,en15.1)", -0.099951,   4_"     -100.0E-03")
+    call checkfmt("(rd,en15.1)", -0.009951,   4_"      -10.0E-03")
+    call checkfmt("(rd,en15.1)", -0.000999951,4_"       -1.0E-03")
+
+    call checkfmt("(rd,en15.1)", 987350.,     4_"      987.3E+03")
+    call checkfmt("(rd,en15.2)", 98735.,      4_"      98.73E+03")
+    call checkfmt("(rd,en15.3)", 9873.5,      4_"      9.873E+03")
+    call checkfmt("(rd,en15.1)", 987650.,     4_"      987.6E+03")
+    call checkfmt("(rd,en15.2)", 98765.,      4_"      98.76E+03")
+    call checkfmt("(rd,en15.3)", 9876.5,      4_"      9.876E+03")
+    call checkfmt("(rd,en15.1)", 3.125E-02,   4_"       31.2E-03")
+    call checkfmt("(rd,en15.1)", 9.375E-02,   4_"       93.7E-03")
+    call checkfmt("(rd,en15.2)", 1.5625E-02,  4_"      15.62E-03")
+    call checkfmt("(rd,en15.2)", 4.6875E-02,  4_"      46.87E-03")
+    call checkfmt("(rd,en15.3)", 7.8125E-03,  4_"      7.812E-03")
+    call checkfmt("(rd,en15.3)", 2.34375E-02, 4_"     23.437E-03")
+    call checkfmt("(rd,en15.3)", 9.765625E-04,4_"    976.562E-06")
+    call checkfmt("(rd,en15.6)", 2.9296875E-03,4_"   2.929687E-03")
+
+    call checkfmt("(rd,en15.1)", -987350.,     4_"     -987.4E+03")
+    call checkfmt("(rd,en15.2)", -98735.,      4_"     -98.74E+03")
+    call checkfmt("(rd,en15.3)", -9873.5,      4_"     -9.874E+03")
+    call checkfmt("(rd,en15.1)", -987650.,     4_"     -987.7E+03")
+    call checkfmt("(rd,en15.2)", -98765.,      4_"     -98.77E+03")
+    call checkfmt("(rd,en15.3)", -9876.5,      4_"     -9.877E+03")
+    call checkfmt("(rd,en15.1)", -3.125E-02,   4_"      -31.3E-03")
+    call checkfmt("(rd,en15.1)", -9.375E-02,   4_"      -93.8E-03")
+    call checkfmt("(rd,en15.2)", -1.5625E-02,  4_"     -15.63E-03")
+    call checkfmt("(rd,en15.2)", -4.6875E-02,  4_"     -46.88E-03")
+    call checkfmt("(rd,en15.3)", -7.8125E-03,  4_"     -7.813E-03")
+    call checkfmt("(rd,en15.3)", -2.34375E-02, 4_"    -23.438E-03")
+    call checkfmt("(rd,en15.3)", -9.765625E-04,4_"   -976.563E-06")
+    call checkfmt("(rd,en15.6)", -2.9296875E-03,4_"  -2.929688E-03")
+
+    print *, n_tst, n_cnt, n_skip
+    if (n_cnt /= 0) stop n_cnt
+    if (all(.not. l_skip)) print *, "All kinds rounded down"
+
+contains
+    subroutine checkfmt(fmt, x, cmp)
+        implicit none
+        integer :: i
+        character(len=*), intent(in) :: fmt
+        real, intent(in) :: x
+        character(len=*, kind=4), intent(in) :: cmp
+        do i=1,size(real_kinds)
+          if (l_skip(i)) cycle
+          if (i == 1) then
+            write(s, fmt) real(x,kind=j(1))
+          else if (i == 2) then
+            write(s, fmt) real(x,kind=j(2))
+          else if (i == 3) then
+            write(s, fmt) real(x,kind=j(3))
+          else if (i == 4) then
+            write(s, fmt) real(x,kind=j(4))
+          end if
+          n_tst = n_tst + 1
+          if (s /= cmp) then
+            if (l_skip(i)) then
+              n_skip = n_skip + 1
+            else
+              print "(a,1x,a,' expected: ',1x,a)", fmt, s, cmp
+              n_cnt = n_cnt + 1
+            end if
+          end if
+        end do
+        
+    end subroutine
+end program
+! { dg-output "All kinds rounded down" { xfail { i?86-*-solaris2.9* hppa*-*-hpux* } } }
+! { dg-final { cleanup-saved-temps } }
diff --git a/gcc/testsuite/gfortran.dg/fmt_en_rn.f90 b/gcc/testsuite/gfortran.dg/fmt_en_rn.f90
new file mode 100644
index 00000000000..b0ada5c672d
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/fmt_en_rn.f90
@@ -0,0 +1,185 @@
+! { dg-do run }
+! PR60128 Invalid outputs with EN descriptors
+! Test case provided by Walt Brainerd.
+program pr60128
+use ISO_FORTRAN_ENV
+    implicit none
+    integer, parameter :: j(size(real_kinds)+4)=[REAL_KINDS, [4, 4, 4, 4]]
+    logical :: l_skip(4) = .false.
+    integer :: i
+    integer :: n_tst = 0, n_cnt = 0, n_skip = 0
+    character(len=20,kind=4) :: s, s1
+
+!   Check that the default rounding mode is to nearest and to even on tie.
+    do i=1,size(real_kinds)
+      if (i == 1) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(1)), &
+                                  real(9.49999905,kind=j(1)),  &
+                                  real(9.5,kind=j(1)), real(8.5,kind=j(1))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(1)), &
+                                       real(98765.0,kind=j(1))
+      else if (i == 2) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(2)), &
+                                  real(9.49999905,kind=j(2)),  &
+                                  real(9.5,kind=j(2)), real(8.5,kind=j(2))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(2)), &
+                                       real(98765.0,kind=j(2))
+      else if (i == 3) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(3)), &
+                                  real(9.49999905,kind=j(3)),  &
+                                  real(9.5,kind=j(3)), real(8.5,kind=j(3))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(3)), &
+                                       real(98765.0,kind=j(3))
+      else if (i == 4) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(4)), &
+                                  real(9.49999905,kind=j(4)),  &
+                                  real(9.5,kind=j(4)), real(8.5,kind=j(4))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(4)), &
+                                       real(98765.0,kind=j(4))
+      end if
+      if (s /= 4_'-9.5 9.5 10.  8.' .or. s1 /= 4_' 987.4E+03 98.76E+03') then
+        l_skip(i) = .true.
+        print "('Unsupported rounding for real(',i0,')')", j(i)
+      end if
+    end do
+        
+
+! Original test.
+    call checkfmt("(en15.2)", -.44444,    4_"    -444.44E-03")
+
+! Test for the bug in comment 6.
+    call checkfmt("(rn,en15.0)", 1.0,        4_"         1.E+00")
+    call checkfmt("(rn,en15.0)", 1.00000012, 4_"         1.E+00")
+    call checkfmt("(rn,en15.0)", 0.99999994, 4_"         1.E+00")
+    call checkfmt("(rn,en15.0)", 10.0,       4_"        10.E+00")
+    call checkfmt("(rn,en15.0)", 10.0000010, 4_"        10.E+00")
+    call checkfmt("(rn,en15.0)", 9.99999905, 4_"        10.E+00")
+    call checkfmt("(rn,en15.0)", 100.0,      4_"       100.E+00")
+    call checkfmt("(rn,en15.0)", 100.000008, 4_"       100.E+00")
+    call checkfmt("(rn,en15.0)", 99.9999924, 4_"       100.E+00")
+    call checkfmt("(rn,en15.0)", 1000.0,     4_"         1.E+03")
+    call checkfmt("(rn,en15.0)", 1000.00006, 4_"         1.E+03")
+    call checkfmt("(rn,en15.0)", 999.999939, 4_"         1.E+03")
+    call checkfmt("(rn,en15.0)", 9.5,        4_"        10.E+00")
+    call checkfmt("(rn,en15.0)", 9.50000095, 4_"        10.E+00")
+    call checkfmt("(rn,en15.0)", 9.49999905, 4_"         9.E+00")
+    call checkfmt("(rn,en15.0)", 99.5,       4_"       100.E+00")
+    call checkfmt("(rn,en15.0)", 99.5000076, 4_"       100.E+00")
+    call checkfmt("(rn,en15.0)", 99.4999924, 4_"        99.E+00")
+    call checkfmt("(rn,en15.0)", 999.5,      4_"         1.E+03")
+    call checkfmt("(rn,en15.0)", 999.500061, 4_"         1.E+03")
+    call checkfmt("(rn,en15.0)", 999.499939, 4_"       999.E+00")
+    call checkfmt("(rn,en15.0)", 9500.0,     4_"        10.E+03")
+    call checkfmt("(rn,en15.0)", 9500.00098, 4_"        10.E+03")
+    call checkfmt("(rn,en15.0)", 9499.99902, 4_"         9.E+03")
+    call checkfmt("(rn,en15.1)", 9950.0,     4_"       10.0E+03")
+    call checkfmt("(rn,en15.2)", 9995.0,     4_"      10.00E+03")
+    call checkfmt("(rn,en15.3)", 9999.5,     4_"     10.000E+03")
+    call checkfmt("(rn,en15.1)", 9.5,        4_"        9.5E+00")
+    call checkfmt("(rn,en15.1)", 9.50000095, 4_"        9.5E+00")
+    call checkfmt("(rn,en15.1)", 9.49999905, 4_"        9.5E+00")
+    call checkfmt("(rn,en15.1)", 0.099951,   4_"      100.0E-03")
+    call checkfmt("(rn,en15.1)", 0.009951,   4_"       10.0E-03")
+    call checkfmt("(rn,en15.1)", 0.000999951,4_"        1.0E-03")
+
+    call checkfmt("(rn,en15.0)", -1.0,        4_"        -1.E+00")
+    call checkfmt("(rn,en15.0)", -1.00000012, 4_"        -1.E+00")
+    call checkfmt("(rn,en15.0)", -0.99999994, 4_"        -1.E+00")
+    call checkfmt("(rn,en15.0)", -10.0,       4_"       -10.E+00")
+    call checkfmt("(rn,en15.0)", -10.0000010, 4_"       -10.E+00")
+    call checkfmt("(rn,en15.0)", -9.99999905, 4_"       -10.E+00")
+    call checkfmt("(rn,en15.0)", -100.0,      4_"      -100.E+00")
+    call checkfmt("(rn,en15.0)", -100.000008, 4_"      -100.E+00")
+    call checkfmt("(rn,en15.0)", -99.9999924, 4_"      -100.E+00")
+    call checkfmt("(rn,en15.0)", -1000.0,     4_"        -1.E+03")
+    call checkfmt("(rn,en15.0)", -1000.00006, 4_"        -1.E+03")
+    call checkfmt("(rn,en15.0)", -999.999939, 4_"        -1.E+03")
+    call checkfmt("(rn,en15.0)", -9.5,        4_"       -10.E+00")
+    call checkfmt("(rn,en15.0)", -9.50000095, 4_"       -10.E+00")
+    call checkfmt("(rn,en15.0)", -9.49999905, 4_"        -9.E+00")
+    call checkfmt("(rn,en15.0)", -99.5,       4_"      -100.E+00")
+    call checkfmt("(rn,en15.0)", -99.5000076, 4_"      -100.E+00")
+    call checkfmt("(rn,en15.0)", -99.4999924, 4_"       -99.E+00")
+    call checkfmt("(rn,en15.0)", -999.5,      4_"        -1.E+03")
+    call checkfmt("(rn,en15.0)", -999.500061, 4_"        -1.E+03")
+    call checkfmt("(rn,en15.0)", -999.499939, 4_"      -999.E+00")
+    call checkfmt("(rn,en15.0)", -9500.0,     4_"       -10.E+03")
+    call checkfmt("(rn,en15.0)", -9500.00098, 4_"       -10.E+03")
+    call checkfmt("(rn,en15.0)", -9499.99902, 4_"        -9.E+03")
+    call checkfmt("(rn,en15.1)", -9950.0,     4_"      -10.0E+03")
+    call checkfmt("(rn,en15.2)", -9995.0,     4_"     -10.00E+03")
+    call checkfmt("(rn,en15.3)", -9999.5,     4_"    -10.000E+03")
+    call checkfmt("(rn,en15.1)", -9.5,        4_"       -9.5E+00")
+    call checkfmt("(rn,en15.1)", -9.50000095, 4_"       -9.5E+00")
+    call checkfmt("(rn,en15.1)", -9.49999905, 4_"       -9.5E+00")
+    call checkfmt("(rn,en15.1)", -0.099951,   4_"     -100.0E-03")
+    call checkfmt("(rn,en15.1)", -0.009951,   4_"      -10.0E-03")
+    call checkfmt("(rn,en15.1)", -0.000999951,4_"       -1.0E-03")
+
+    call checkfmt("(rn,en15.1)", 987350.,     4_"      987.4E+03")
+    call checkfmt("(rn,en15.2)", 98735.,      4_"      98.74E+03")
+    call checkfmt("(rn,en15.3)", 9873.5,      4_"      9.874E+03")
+    call checkfmt("(rn,en15.1)", 987650.,     4_"      987.6E+03")
+    call checkfmt("(rn,en15.2)", 98765.,      4_"      98.76E+03")
+    call checkfmt("(rn,en15.3)", 9876.5,      4_"      9.876E+03")
+    call checkfmt("(rn,en15.1)", 3.125E-02,   4_"       31.2E-03")
+    call checkfmt("(rn,en15.1)", 9.375E-02,   4_"       93.8E-03")
+    call checkfmt("(rn,en15.2)", 1.5625E-02,  4_"      15.62E-03")
+    call checkfmt("(rn,en15.2)", 4.6875E-02,  4_"      46.88E-03")
+    call checkfmt("(rn,en15.3)", 7.8125E-03,  4_"      7.812E-03")
+    call checkfmt("(rn,en15.3)", 2.34375E-02, 4_"     23.438E-03")
+    call checkfmt("(rn,en15.3)", 9.765625E-04,4_"    976.562E-06")
+    call checkfmt("(rn,en15.6)", 2.9296875E-03,4_"   2.929688E-03")
+
+    call checkfmt("(rn,en15.1)", -987350.,     4_"     -987.4E+03")
+    call checkfmt("(rn,en15.2)", -98735.,      4_"     -98.74E+03")
+    call checkfmt("(rn,en15.3)", -9873.5,      4_"     -9.874E+03")
+    call checkfmt("(rn,en15.1)", -987650.,     4_"     -987.6E+03")
+    call checkfmt("(rn,en15.2)", -98765.,      4_"     -98.76E+03")
+    call checkfmt("(rn,en15.3)", -9876.5,      4_"     -9.876E+03")
+    call checkfmt("(rn,en15.1)", -3.125E-02,   4_"      -31.2E-03")
+    call checkfmt("(rn,en15.1)", -9.375E-02,   4_"      -93.8E-03")
+    call checkfmt("(rn,en15.2)", -1.5625E-02,  4_"     -15.62E-03")
+    call checkfmt("(rn,en15.2)", -4.6875E-02,  4_"     -46.88E-03")
+    call checkfmt("(rn,en15.3)", -7.8125E-03,  4_"     -7.812E-03")
+    call checkfmt("(rn,en15.3)", -2.34375E-02, 4_"    -23.438E-03")
+    call checkfmt("(rn,en15.3)", -9.765625E-04,4_"   -976.562E-06")
+    call checkfmt("(rn,en15.6)", -2.9296875E-03,4_"  -2.929688E-03")
+
+    print *, n_tst, n_cnt, n_skip
+    if (n_cnt /= 0) stop n_cnt
+    if (all(.not. l_skip)) print *, "All kinds rounded to nearest"
+
+contains
+    subroutine checkfmt(fmt, x, cmp)
+        implicit none
+        integer :: i
+        character(len=*), intent(in) :: fmt
+        real, intent(in) :: x
+        character(len=*, kind=4), intent(in) :: cmp
+        do i=1,size(real_kinds)
+          if (l_skip(i)) cycle
+          if (i == 1) then
+            write(s, fmt) real(x,kind=j(1))
+          else if (i == 2) then
+            write(s, fmt) real(x,kind=j(2))
+          else if (i == 3) then
+            write(s, fmt) real(x,kind=j(3))
+          else if (i == 4) then
+            write(s, fmt) real(x,kind=j(4))
+          end if
+          n_tst = n_tst + 1
+          if (s /= cmp) then
+            if (l_skip(i)) then
+              n_skip = n_skip + 1
+            else
+              print "(a,1x,a,' expected: ',1x,a)", fmt, s, cmp
+              n_cnt = n_cnt + 1
+            end if
+          end if
+        end do
+        
+    end subroutine
+end program
+! { dg-output "All kinds rounded to nearest" { xfail { i?86-*-solaris2.9* hppa*-*-hpux* } } }
+! { dg-final { cleanup-saved-temps } }
diff --git a/gcc/testsuite/gfortran.dg/fmt_en_ru.f90 b/gcc/testsuite/gfortran.dg/fmt_en_ru.f90
new file mode 100644
index 00000000000..7834e2880bd
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/fmt_en_ru.f90
@@ -0,0 +1,185 @@
+! { dg-do run }
+! PR60128 Invalid outputs with EN descriptors
+! Test case provided by Walt Brainerd.
+program pr60128
+use ISO_FORTRAN_ENV
+    implicit none
+    integer, parameter :: j(size(real_kinds)+4)=[REAL_KINDS, [4, 4, 4, 4]]
+    logical :: l_skip(4) = .false.
+    integer :: i
+    integer :: n_tst = 0, n_cnt = 0, n_skip = 0
+    character(len=20,kind=4) :: s, s1
+
+!   Check that the default rounding mode is to nearest and to even on tie.
+    do i=1,size(real_kinds)
+      if (i == 1) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(1)), &
+                                  real(9.49999905,kind=j(1)),  &
+                                  real(9.5,kind=j(1)), real(8.5,kind=j(1))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(1)), &
+                                       real(98765.0,kind=j(1))
+      else if (i == 2) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(2)), &
+                                  real(9.49999905,kind=j(2)),  &
+                                  real(9.5,kind=j(2)), real(8.5,kind=j(2))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(2)), &
+                                       real(98765.0,kind=j(2))
+      else if (i == 3) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(3)), &
+                                  real(9.49999905,kind=j(3)),  &
+                                  real(9.5,kind=j(3)), real(8.5,kind=j(3))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(3)), &
+                                       real(98765.0,kind=j(3))
+      else if (i == 4) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(4)), &
+                                  real(9.49999905,kind=j(4)),  &
+                                  real(9.5,kind=j(4)), real(8.5,kind=j(4))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(4)), &
+                                       real(98765.0,kind=j(4))
+      end if
+      if (s /= 4_'-9.5 9.5 10.  8.' .or. s1 /= 4_' 987.4E+03 98.76E+03') then
+        l_skip(i) = .true.
+        print "('Unsupported rounding for real(',i0,')')", j(i)
+      end if
+    end do
+        
+
+! Original test.
+    call checkfmt("(en15.2)", -.44444,    4_"    -444.44E-03")
+
+! Test for the bug in comment 6.
+    call checkfmt("(ru,en15.0)", 1.0,        4_"         1.E+00")
+    call checkfmt("(ru,en15.0)", 1.00000012, 4_"         2.E+00")
+    call checkfmt("(ru,en15.0)", 0.99999994, 4_"         1.E+00")
+    call checkfmt("(ru,en15.0)", 10.0,       4_"        10.E+00")
+    call checkfmt("(ru,en15.0)", 10.0000010, 4_"        11.E+00")
+    call checkfmt("(ru,en15.0)", 9.99999905, 4_"        10.E+00")
+    call checkfmt("(ru,en15.0)", 100.0,      4_"       100.E+00")
+    call checkfmt("(ru,en15.0)", 100.000008, 4_"       101.E+00")
+    call checkfmt("(ru,en15.0)", 99.9999924, 4_"       100.E+00")
+    call checkfmt("(ru,en15.0)", 1000.0,     4_"         1.E+03")
+    call checkfmt("(ru,en15.0)", 1000.00006, 4_"         2.E+03")
+    call checkfmt("(ru,en15.0)", 999.999939, 4_"         1.E+03")
+    call checkfmt("(ru,en15.0)", 9.5,        4_"        10.E+00")
+    call checkfmt("(ru,en15.0)", 9.50000095, 4_"        10.E+00")
+    call checkfmt("(ru,en15.0)", 9.49999905, 4_"        10.E+00")
+    call checkfmt("(ru,en15.0)", 99.5,       4_"       100.E+00")
+    call checkfmt("(ru,en15.0)", 99.5000076, 4_"       100.E+00")
+    call checkfmt("(ru,en15.0)", 99.4999924, 4_"       100.E+00")
+    call checkfmt("(ru,en15.0)", 999.5,      4_"         1.E+03")
+    call checkfmt("(ru,en15.0)", 999.500061, 4_"         1.E+03")
+    call checkfmt("(ru,en15.0)", 999.499939, 4_"         1.E+03")
+    call checkfmt("(ru,en15.0)", 9500.0,     4_"        10.E+03")
+    call checkfmt("(ru,en15.0)", 9500.00098, 4_"        10.E+03")
+    call checkfmt("(ru,en15.0)", 9499.99902, 4_"        10.E+03")
+    call checkfmt("(ru,en15.1)", 9950.0,     4_"       10.0E+03")
+    call checkfmt("(ru,en15.2)", 9995.0,     4_"      10.00E+03")
+    call checkfmt("(ru,en15.3)", 9999.5,     4_"     10.000E+03")
+    call checkfmt("(ru,en15.1)", 9.5,        4_"        9.5E+00")
+    call checkfmt("(ru,en15.1)", 9.50000095, 4_"        9.6E+00")
+    call checkfmt("(ru,en15.1)", 9.49999905, 4_"        9.5E+00")
+    call checkfmt("(ru,en15.1)", 0.099951,   4_"      100.0E-03")
+    call checkfmt("(ru,en15.1)", 0.009951,   4_"       10.0E-03")
+    call checkfmt("(ru,en15.1)", 0.000999951,4_"        1.0E-03")
+
+    call checkfmt("(ru,en15.0)", -1.0,        4_"        -1.E+00")
+    call checkfmt("(ru,en15.0)", -1.00000012, 4_"        -1.E+00")
+    call checkfmt("(ru,en15.0)", -0.99999994, 4_"      -999.E-03")
+    call checkfmt("(ru,en15.0)", -10.0,       4_"       -10.E+00")
+    call checkfmt("(ru,en15.0)", -10.0000010, 4_"       -10.E+00")
+    call checkfmt("(ru,en15.0)", -9.99999905, 4_"        -9.E+00")
+    call checkfmt("(ru,en15.0)", -100.0,      4_"      -100.E+00")
+    call checkfmt("(ru,en15.0)", -100.000008, 4_"      -100.E+00")
+    call checkfmt("(ru,en15.0)", -99.9999924, 4_"       -99.E+00")
+    call checkfmt("(ru,en15.0)", -1000.0,     4_"        -1.E+03")
+    call checkfmt("(ru,en15.0)", -1000.00006, 4_"        -1.E+03")
+    call checkfmt("(ru,en15.0)", -999.999939, 4_"      -999.E+00")
+    call checkfmt("(ru,en15.0)", -9.5,        4_"        -9.E+00")
+    call checkfmt("(ru,en15.0)", -9.50000095, 4_"        -9.E+00")
+    call checkfmt("(ru,en15.0)", -9.49999905, 4_"        -9.E+00")
+    call checkfmt("(ru,en15.0)", -99.5,       4_"       -99.E+00")
+    call checkfmt("(ru,en15.0)", -99.5000076, 4_"       -99.E+00")
+    call checkfmt("(ru,en15.0)", -99.4999924, 4_"       -99.E+00")
+    call checkfmt("(ru,en15.0)", -999.5,      4_"      -999.E+00")
+    call checkfmt("(ru,en15.0)", -999.500061, 4_"      -999.E+00")
+    call checkfmt("(ru,en15.0)", -999.499939, 4_"      -999.E+00")
+    call checkfmt("(ru,en15.0)", -9500.0,     4_"        -9.E+03")
+    call checkfmt("(ru,en15.0)", -9500.00098, 4_"        -9.E+03")
+    call checkfmt("(ru,en15.0)", -9499.99902, 4_"        -9.E+03")
+    call checkfmt("(ru,en15.1)", -9950.0,     4_"       -9.9E+03")
+    call checkfmt("(ru,en15.2)", -9995.0,     4_"      -9.99E+03")
+    call checkfmt("(ru,en15.3)", -9999.5,     4_"     -9.999E+03")
+    call checkfmt("(ru,en15.1)", -9.5,        4_"       -9.5E+00")
+    call checkfmt("(ru,en15.1)", -9.50000095, 4_"       -9.5E+00")
+    call checkfmt("(ru,en15.1)", -9.49999905, 4_"       -9.4E+00")
+    call checkfmt("(ru,en15.1)", -0.099951,   4_"      -99.9E-03")
+    call checkfmt("(ru,en15.1)", -0.009951,   4_"       -9.9E-03")
+    call checkfmt("(ru,en15.1)", -0.000999951,4_"     -999.9E-06")
+
+    call checkfmt("(ru,en15.1)", 987350.,     4_"      987.4E+03")
+    call checkfmt("(ru,en15.2)", 98735.,      4_"      98.74E+03")
+    call checkfmt("(ru,en15.3)", 9873.5,      4_"      9.874E+03")
+    call checkfmt("(ru,en15.1)", 987650.,     4_"      987.7E+03")
+    call checkfmt("(ru,en15.2)", 98765.,      4_"      98.77E+03")
+    call checkfmt("(ru,en15.3)", 9876.5,      4_"      9.877E+03")
+    call checkfmt("(ru,en15.1)", 3.125E-02,   4_"       31.3E-03")
+    call checkfmt("(ru,en15.1)", 9.375E-02,   4_"       93.8E-03")
+    call checkfmt("(ru,en15.2)", 1.5625E-02,  4_"      15.63E-03")
+    call checkfmt("(ru,en15.2)", 4.6875E-02,  4_"      46.88E-03")
+    call checkfmt("(ru,en15.3)", 7.8125E-03,  4_"      7.813E-03")
+    call checkfmt("(ru,en15.3)", 2.34375E-02, 4_"     23.438E-03")
+    call checkfmt("(ru,en15.3)", 9.765625E-04,4_"    976.563E-06")
+    call checkfmt("(ru,en15.6)", 2.9296875E-03,4_"   2.929688E-03")
+
+    call checkfmt("(ru,en15.1)", -987350.,     4_"     -987.3E+03")
+    call checkfmt("(ru,en15.2)", -98735.,      4_"     -98.73E+03")
+    call checkfmt("(ru,en15.3)", -9873.5,      4_"     -9.873E+03")
+    call checkfmt("(ru,en15.1)", -987650.,     4_"     -987.6E+03")
+    call checkfmt("(ru,en15.2)", -98765.,      4_"     -98.76E+03")
+    call checkfmt("(ru,en15.3)", -9876.5,      4_"     -9.876E+03")
+    call checkfmt("(ru,en15.1)", -3.125E-02,   4_"      -31.2E-03")
+    call checkfmt("(ru,en15.1)", -9.375E-02,   4_"      -93.7E-03")
+    call checkfmt("(ru,en15.2)", -1.5625E-02,  4_"     -15.62E-03")
+    call checkfmt("(ru,en15.2)", -4.6875E-02,  4_"     -46.87E-03")
+    call checkfmt("(ru,en15.3)", -7.8125E-03,  4_"     -7.812E-03")
+    call checkfmt("(ru,en15.3)", -2.34375E-02, 4_"    -23.437E-03")
+    call checkfmt("(ru,en15.3)", -9.765625E-04,4_"   -976.562E-06")
+    call checkfmt("(ru,en15.6)", -2.9296875E-03,4_"  -2.929687E-03")
+
+    print *, n_tst, n_cnt, n_skip
+    if (n_cnt /= 0) stop n_cnt
+    if (all(.not. l_skip)) print *, "All kinds rounded up"
+
+contains
+    subroutine checkfmt(fmt, x, cmp)
+        implicit none
+        integer :: i
+        character(len=*), intent(in) :: fmt
+        real, intent(in) :: x
+        character(len=*, kind=4), intent(in) :: cmp
+        do i=1,size(real_kinds)
+          if (l_skip(i)) cycle
+          if (i == 1) then
+            write(s, fmt) real(x,kind=j(1))
+          else if (i == 2) then
+            write(s, fmt) real(x,kind=j(2))
+          else if (i == 3) then
+            write(s, fmt) real(x,kind=j(3))
+          else if (i == 4) then
+            write(s, fmt) real(x,kind=j(4))
+          end if
+          n_tst = n_tst + 1
+          if (s /= cmp) then
+            if (l_skip(i)) then
+              n_skip = n_skip + 1
+            else
+              print "(a,1x,a,' expected: ',1x,a)", fmt, s, cmp
+              n_cnt = n_cnt + 1
+            end if
+          end if
+        end do
+        
+    end subroutine
+end program
+! { dg-output "All kinds rounded up" { xfail { i?86-*-solaris2.9* hppa*-*-hpux* } } }
+! { dg-final { cleanup-saved-temps } }
diff --git a/gcc/testsuite/gfortran.dg/fmt_en_rz.f90 b/gcc/testsuite/gfortran.dg/fmt_en_rz.f90
new file mode 100644
index 00000000000..c07847cad6d
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/fmt_en_rz.f90
@@ -0,0 +1,185 @@
+! { dg-do run }
+! PR60128 Invalid outputs with EN descriptors
+! Test case provided by Walt Brainerd.
+program pr60128
+use ISO_FORTRAN_ENV
+    implicit none
+    integer, parameter :: j(size(real_kinds)+4)=[REAL_KINDS, [4, 4, 4, 4]]
+    logical :: l_skip(4) = .false.
+    integer :: i
+    integer :: n_tst = 0, n_cnt = 0, n_skip = 0
+    character(len=20,kind=4) :: s, s1
+
+!   Check that the default rounding mode is to nearest and to even on tie.
+    do i=1,size(real_kinds)
+      if (i == 1) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(1)), &
+                                  real(9.49999905,kind=j(1)),  &
+                                  real(9.5,kind=j(1)), real(8.5,kind=j(1))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(1)), &
+                                       real(98765.0,kind=j(1))
+      else if (i == 2) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(2)), &
+                                  real(9.49999905,kind=j(2)),  &
+                                  real(9.5,kind=j(2)), real(8.5,kind=j(2))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(2)), &
+                                       real(98765.0,kind=j(2))
+      else if (i == 3) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(3)), &
+                                  real(9.49999905,kind=j(3)),  &
+                                  real(9.5,kind=j(3)), real(8.5,kind=j(3))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(3)), &
+                                       real(98765.0,kind=j(3))
+      else if (i == 4) then
+        write(s, '(2F4.1,2F4.0)') real(-9.49999905,kind=j(4)), &
+                                  real(9.49999905,kind=j(4)),  &
+                                  real(9.5,kind=j(4)), real(8.5,kind=j(4))
+        write(s1, '(3PE10.3,2PE10.3)') real(987350.,kind=j(4)), &
+                                       real(98765.0,kind=j(4))
+      end if
+      if (s /= 4_'-9.5 9.5 10.  8.' .or. s1 /= 4_' 987.4E+03 98.76E+03') then
+        l_skip(i) = .true.
+        print "('Unsupported rounding for real(',i0,')')", j(i)
+      end if
+    end do
+        
+
+! Original test.
+    call checkfmt("(en15.2)", -.44444,    4_"    -444.44E-03")
+
+! Test for the bug in comment 6.
+    call checkfmt("(rz,en15.0)", 1.0,        4_"         1.E+00")
+    call checkfmt("(rz,en15.0)", 1.00000012, 4_"         1.E+00")
+    call checkfmt("(rz,en15.0)", 0.99999994, 4_"       999.E-03")
+    call checkfmt("(rz,en15.0)", 10.0,       4_"        10.E+00")
+    call checkfmt("(rz,en15.0)", 10.0000010, 4_"        10.E+00")
+    call checkfmt("(rz,en15.0)", 9.99999905, 4_"         9.E+00")
+    call checkfmt("(rz,en15.0)", 100.0,      4_"       100.E+00")
+    call checkfmt("(rz,en15.0)", 100.000008, 4_"       100.E+00")
+    call checkfmt("(rz,en15.0)", 99.9999924, 4_"        99.E+00")
+    call checkfmt("(rz,en15.0)", 1000.0,     4_"         1.E+03")
+    call checkfmt("(rz,en15.0)", 1000.00006, 4_"         1.E+03")
+    call checkfmt("(rz,en15.0)", 999.999939, 4_"       999.E+00")
+    call checkfmt("(rz,en15.0)", 9.5,        4_"         9.E+00")
+    call checkfmt("(rz,en15.0)", 9.50000095, 4_"         9.E+00")
+    call checkfmt("(rz,en15.0)", 9.49999905, 4_"         9.E+00")
+    call checkfmt("(rz,en15.0)", 99.5,       4_"        99.E+00")
+    call checkfmt("(rz,en15.0)", 99.5000076, 4_"        99.E+00")
+    call checkfmt("(rz,en15.0)", 99.4999924, 4_"        99.E+00")
+    call checkfmt("(rz,en15.0)", 999.5,      4_"       999.E+00")
+    call checkfmt("(rz,en15.0)", 999.500061, 4_"       999.E+00")
+    call checkfmt("(rz,en15.0)", 999.499939, 4_"       999.E+00")
+    call checkfmt("(rz,en15.0)", 9500.0,     4_"         9.E+03")
+    call checkfmt("(rz,en15.0)", 9500.00098, 4_"         9.E+03")
+    call checkfmt("(rz,en15.0)", 9499.99902, 4_"         9.E+03")
+    call checkfmt("(rz,en15.1)", 9950.0,     4_"        9.9E+03")
+    call checkfmt("(rz,en15.2)", 9995.0,     4_"       9.99E+03")
+    call checkfmt("(rz,en15.3)", 9999.5,     4_"      9.999E+03")
+    call checkfmt("(rz,en15.1)", 9.5,        4_"        9.5E+00")
+    call checkfmt("(rz,en15.1)", 9.50000095, 4_"        9.5E+00")
+    call checkfmt("(rz,en15.1)", 9.49999905, 4_"        9.4E+00")
+    call checkfmt("(rz,en15.1)", 0.099951,   4_"       99.9E-03")
+    call checkfmt("(rz,en15.1)", 0.009951,   4_"        9.9E-03")
+    call checkfmt("(rz,en15.1)", 0.000999951,4_"      999.9E-06")
+
+    call checkfmt("(rz,en15.0)", -1.0,        4_"        -1.E+00")
+    call checkfmt("(rz,en15.0)", -1.00000012, 4_"        -1.E+00")
+    call checkfmt("(rz,en15.0)", -0.99999994, 4_"      -999.E-03")
+    call checkfmt("(rz,en15.0)", -10.0,       4_"       -10.E+00")
+    call checkfmt("(rz,en15.0)", -10.0000010, 4_"       -10.E+00")
+    call checkfmt("(rz,en15.0)", -9.99999905, 4_"        -9.E+00")
+    call checkfmt("(rz,en15.0)", -100.0,      4_"      -100.E+00")
+    call checkfmt("(rz,en15.0)", -100.000008, 4_"      -100.E+00")
+    call checkfmt("(rz,en15.0)", -99.9999924, 4_"       -99.E+00")
+    call checkfmt("(rz,en15.0)", -1000.0,     4_"        -1.E+03")
+    call checkfmt("(rz,en15.0)", -1000.00006, 4_"        -1.E+03")
+    call checkfmt("(rz,en15.0)", -999.999939, 4_"      -999.E+00")
+    call checkfmt("(rz,en15.0)", -9.5,        4_"        -9.E+00")
+    call checkfmt("(rz,en15.0)", -9.50000095, 4_"        -9.E+00")
+    call checkfmt("(rz,en15.0)", -9.49999905, 4_"        -9.E+00")
+    call checkfmt("(rz,en15.0)", -99.5,       4_"       -99.E+00")
+    call checkfmt("(rz,en15.0)", -99.5000076, 4_"       -99.E+00")
+    call checkfmt("(rz,en15.0)", -99.4999924, 4_"       -99.E+00")
+    call checkfmt("(rz,en15.0)", -999.5,      4_"      -999.E+00")
+    call checkfmt("(rz,en15.0)", -999.500061, 4_"      -999.E+00")
+    call checkfmt("(rz,en15.0)", -999.499939, 4_"      -999.E+00")
+    call checkfmt("(rz,en15.0)", -9500.0,     4_"        -9.E+03")
+    call checkfmt("(rz,en15.0)", -9500.00098, 4_"        -9.E+03")
+    call checkfmt("(rz,en15.0)", -9499.99902, 4_"        -9.E+03")
+    call checkfmt("(rz,en15.1)", -9950.0,     4_"       -9.9E+03")
+    call checkfmt("(rz,en15.2)", -9995.0,     4_"      -9.99E+03")
+    call checkfmt("(rz,en15.3)", -9999.5,     4_"     -9.999E+03")
+    call checkfmt("(rz,en15.1)", -9.5,        4_"       -9.5E+00")
+    call checkfmt("(rz,en15.1)", -9.50000095, 4_"       -9.5E+00")
+    call checkfmt("(rz,en15.1)", -9.49999905, 4_"       -9.4E+00")
+    call checkfmt("(rz,en15.1)", -0.099951,   4_"      -99.9E-03")
+    call checkfmt("(rz,en15.1)", -0.009951,   4_"       -9.9E-03")
+    call checkfmt("(rz,en15.1)", -0.000999951,4_"     -999.9E-06")
+
+    call checkfmt("(rz,en15.1)", 987350.,     4_"      987.3E+03")
+    call checkfmt("(rz,en15.2)", 98735.,      4_"      98.73E+03")
+    call checkfmt("(rz,en15.3)", 9873.5,      4_"      9.873E+03")
+    call checkfmt("(rz,en15.1)", 987650.,     4_"      987.6E+03")
+    call checkfmt("(rz,en15.2)", 98765.,      4_"      98.76E+03")
+    call checkfmt("(rz,en15.3)", 9876.5,      4_"      9.876E+03")
+    call checkfmt("(rz,en15.1)", 3.125E-02,   4_"       31.2E-03")
+    call checkfmt("(rz,en15.1)", 9.375E-02,   4_"       93.7E-03")
+    call checkfmt("(rz,en15.2)", 1.5625E-02,  4_"      15.62E-03")
+    call checkfmt("(rz,en15.2)", 4.6875E-02,  4_"      46.87E-03")
+    call checkfmt("(rz,en15.3)", 7.8125E-03,  4_"      7.812E-03")
+    call checkfmt("(rz,en15.3)", 2.34375E-02, 4_"     23.437E-03")
+    call checkfmt("(rz,en15.3)", 9.765625E-04,4_"    976.562E-06")
+    call checkfmt("(rz,en15.6)", 2.9296875E-03,4_"   2.929687E-03")
+
+    call checkfmt("(rz,en15.1)", -987350.,     4_"     -987.3E+03")
+    call checkfmt("(rz,en15.2)", -98735.,      4_"     -98.73E+03")
+    call checkfmt("(rz,en15.3)", -9873.5,      4_"     -9.873E+03")
+    call checkfmt("(rz,en15.1)", -987650.,     4_"     -987.6E+03")
+    call checkfmt("(rz,en15.2)", -98765.,      4_"     -98.76E+03")
+    call checkfmt("(rz,en15.3)", -9876.5,      4_"     -9.876E+03")
+    call checkfmt("(rz,en15.1)", -3.125E-02,   4_"      -31.2E-03")
+    call checkfmt("(rz,en15.1)", -9.375E-02,   4_"      -93.7E-03")
+    call checkfmt("(rz,en15.2)", -1.5625E-02,  4_"     -15.62E-03")
+    call checkfmt("(rz,en15.2)", -4.6875E-02,  4_"     -46.87E-03")
+    call checkfmt("(rz,en15.3)", -7.8125E-03,  4_"     -7.812E-03")
+    call checkfmt("(rz,en15.3)", -2.34375E-02, 4_"    -23.437E-03")
+    call checkfmt("(rz,en15.3)", -9.765625E-04,4_"   -976.562E-06")
+    call checkfmt("(rz,en15.6)", -2.9296875E-03,4_"  -2.929687E-03")
+
+    print *, n_tst, n_cnt, n_skip
+    if (n_cnt /= 0) stop n_cnt
+    if (all(.not. l_skip)) print *, "All kinds rounded to zero"
+
+contains
+    subroutine checkfmt(fmt, x, cmp)
+        implicit none
+        integer :: i
+        character(len=*), intent(in) :: fmt
+        real, intent(in) :: x
+        character(len=*, kind=4), intent(in) :: cmp
+        do i=1,size(real_kinds)
+          if (l_skip(i)) cycle
+          if (i == 1) then
+            write(s, fmt) real(x,kind=j(1))
+          else if (i == 2) then
+            write(s, fmt) real(x,kind=j(2))
+          else if (i == 3) then
+            write(s, fmt) real(x,kind=j(3))
+          else if (i == 4) then
+            write(s, fmt) real(x,kind=j(4))
+          end if
+          n_tst = n_tst + 1
+          if (s /= cmp) then
+            if (l_skip(i)) then
+              n_skip = n_skip + 1
+            else
+              print "(a,1x,a,' expected: ',1x,a)", fmt, s, cmp
+              n_cnt = n_cnt + 1
+            end if
+          end if
+        end do
+        
+    end subroutine
+end program
+! { dg-output "All kinds rounded to zero" { xfail { i?86-*-solaris2.9* hppa*-*-hpux* } } }
+! { dg-final { cleanup-saved-temps } }
diff --git a/libgfortran/io/write_float.def b/libgfortran/io/write_float.def
index 8a1be054371..3311db31209 100644
--- a/libgfortran/io/write_float.def
+++ b/libgfortran/io/write_float.def
@@ -399,7 +399,8 @@ build_float_string (st_parameter_dt *dtp, const fnode *f, char *buffer,
   updown:
 
   rchar = '0';
-  if (ft != FMT_F && w > 0 && d == 0 && p == 0)
+  /* Do not reset nbefore for FMT_F and FMT_EN.  */
+  if (ft != FMT_F && ft !=FMT_EN && w > 0 && d == 0 && p == 0)
     nbefore = 1;
   /* Scan for trailing zeros to see if we really need to round it.  */
   for(i = nbefore + nafter; i < ndigits; i++)

commit d0dbe7695cf1e7a7163952797c4590cfda137541
Author: Dominique d'Humieres <dhumieres.dominique@free.fr>
Date:   Fri Jul 24 20:27:53 2020 +0200

    PR 93567, G edit descriptor uses E instead of F editing in rounding mode UP.
    
    The switch between FMT_E and FMT_F is based on the absolute value.
    Set r=0 for rounding toward zero and r = 1 otherwise.
    If (exp_d - m) == 1 there is no rounding needed.
    
    libgfortran/ChangeLog:
    
            PR fortran/93567
            * io/write_float.def (determine_en_precision): Fix switch between
            FMT_E and FMT_F.
    
    gcc/testsuite/ChangeLog:
    
            PR fortran/93567
            * gfortran.dg/round_3.f08: Add test cases.
    
    (cherry picked from commit aa7e7eff5ec165dc8463a0e74309801b15d1feda)

diff --git a/gcc/testsuite/gfortran.dg/round_3.f08 b/gcc/testsuite/gfortran.dg/round_3.f08
index 57d83395531..4a0a692fa7b 100644
--- a/gcc/testsuite/gfortran.dg/round_3.f08
+++ b/gcc/testsuite/gfortran.dg/round_3.f08
@@ -110,6 +110,30 @@ program pr48615
     call checkfmt("(RU,E17.1)", nearest(2.0, 1.0),     "          0.3E+01")
     call checkfmt("(RD,E17.1)", nearest(3.0, -1.0),    "          0.2E+01")
 
+    call checkfmt("(G12.2)", 99.0,       "     99.    ")
+    call checkfmt("(G12.2)", 99.5,       "    0.10E+03")
+    call checkfmt("(G12.2)", 100.0,      "    0.10E+03")
+    call checkfmt("(G12.2)", -99.0,      "    -99.    ")
+    call checkfmt("(G12.2)", -99.5,      "   -0.10E+03")
+    call checkfmt("(G12.2)", -100.0,     "   -0.10E+03")
+    call checkfmt("(RU,G12.2)", 99.0,    "     99.    ")    ! pr93567
+    call checkfmt("(RU,G12.2)", 99.01,   "    0.10E+03")
+    call checkfmt("(RU,G12.2)", -99.0,   "    -99.    ")
+    call checkfmt("(RU,G12.2)", -99.01,  "    -99.    ")
+    call checkfmt("(RU,G12.2)", -100.01, "   -0.10E+03")
+    call checkfmt("(RU,G12.4)", 99.0 ,   "   99.00    ")
+    call checkfmt("(RU,G12.4)", 99.01,   "   99.02    ")
+    call checkfmt("(RD,G12.2)", 99.0,    "     99.    ")
+    call checkfmt("(RD,G12.2)", 99.01,   "     99.    ")
+    call checkfmt("(RD,G12.2)", 100.01,  "    0.10E+03")
+    call checkfmt("(RD,G12.2)", -99.0,   "    -99.    ")
+    call checkfmt("(RD,G12.2)", -99.01,  "   -0.10E+03")
+    call checkfmt("(RD,G12.2)", -100.00, "   -0.10E+03")
+    call checkfmt("(Rz,G12.2)", 99.01,   "     99.    ")
+    call checkfmt("(Rz,G12.2)", 100.01,  "    0.10E+03")
+    call checkfmt("(Rz,G12.2)", -99.01,  "    -99.    ")
+    call checkfmt("(Rz,G12.2)", -100.01, "   -0.10E+03")
+
 contains
     subroutine checkfmt(fmt, x, cmp)
         character(len=*), intent(in) :: fmt
@@ -119,6 +143,6 @@ contains
         
         write(s, fmt) x
         if (s /= cmp) STOP 1
-        !if (s /= cmp) print "(a,1x,a,' expected: ',1x)", fmt, s, cmp
+        !if (s /= cmp) print "(a,1x,a,' expected: ',1x,a)", fmt, s, cmp
     end subroutine
 end program
diff --git a/libgfortran/io/write_float.def b/libgfortran/io/write_float.def
index 3311db31209..9a4462c1117 100644
--- a/libgfortran/io/write_float.def
+++ b/libgfortran/io/write_float.def
@@ -988,16 +988,19 @@ determine_en_precision (st_parameter_dt *dtp, const fnode *f,
 	  w = default_width;\
 	  d = precision;\
 	}\
+      /* The switch between FMT_E and FMT_F is based on the absolute value.  \
+         Set r=0 for rounding toward zero and r = 1 otherwise.  \
+	 If (exp_d - m) == 1 there is no rounding needed.  */\
       switch (dtp->u.p.current_unit->round_status)\
 	{\
 	  case ROUND_ZERO:\
-	    r = sign_bit ? 1.0 : 0.0;\
+	    r = 0.0;\
 	    break;\
 	  case ROUND_UP:\
-	    r = 1.0;\
+	    r = sign_bit ? 0.0 : 1.0;\
 	    break;\
 	  case ROUND_DOWN:\
-	    r = 0.0;\
+	    r = sign_bit ? 1.0 : 0.0;\
 	    break;\
 	  default:\
 	    break;\
@@ -1005,7 +1008,8 @@ determine_en_precision (st_parameter_dt *dtp, const fnode *f,
       exp_d = calculate_exp_ ## x (d);\
       r_sc = (1 - r / exp_d);\
       temp = 0.1 * r_sc;\
-      if ((m > 0.0 && ((m < temp) || (r >= (exp_d - m))))\
+      if ((m > 0.0 && ((m < temp) || (r < 1 && r >= (exp_d - m))\
+				  || (r == 1 && 1 > (exp_d - m))))\
 	  || ((m == 0.0) && !(compile_options.allow_std\
 			      & (GFC_STD_F2003 | GFC_STD_F2008)))\
 	  ||  d == 0)\

commit cf1ea3fdca1320b647ed706e94a2d4fa764d81d4
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Jul 26 00:16:51 2020 +0000

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index ca1a68b03b7..22878d584d2 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200725
+20200726
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 46a61e437ad..7dfac6c50fa 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,23 @@
+2020-07-25  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	Backported from master:
+	2020-07-24  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	PR fortran/93567
+	* gfortran.dg/round_3.f08: Add test cases.
+
+2020-07-25  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	Backported from master:
+	2020-07-24  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	PR fortran/93592
+	* gfortran.dg/fmt_en.f90: Adjust test.
+	* gfortran.dg/fmt_en_rd.f90: New test.
+	* gfortran.dg/fmt_en_rn.f90: New test.
+	* gfortran.dg/fmt_en_ru.f90: New test.
+	* gfortran.dg/fmt_en_rz.f90: New test.
+
 2020-07-23  Harald Anlauf  <anlauf@gmx.de>
 
 	Backported from master:
diff --git a/libgfortran/ChangeLog b/libgfortran/ChangeLog
index b47ae6b62a0..2aa54095648 100644
--- a/libgfortran/ChangeLog
+++ b/libgfortran/ChangeLog
@@ -1,3 +1,21 @@
+2020-07-25  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	Backported from master:
+	2020-07-24  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	PR fortran/93567
+	* io/write_float.def (determine_en_precision): Fix switch between
+	FMT_E and FMT_F.
+
+2020-07-25  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	Backported from master:
+	2020-07-24  Dominique d'Humieres  <dhumieres.dominique@free.fr>
+
+	PR fortran/93592
+	* io/write_float.def (build_float_string): Do not reset
+	  nbefore for FMT_F and FMT_EN.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.

commit 7dcd5b38fa91326e120a7ebb6f521330d83ff757
Author: Mark Eggleston <markeggleston@gcc.gnu.org>
Date:   Thu Jun 11 06:42:36 2020 +0100

    Fortran  : ICE in gfc_check_reshape PR95585
    
    Issue an error where an array is used before its definition
    instead of an ICE.
    
    2020-07-26  Steven G. Kargl  <kargl@gcc.gnu.org>
    
    gcc/fortran/
    
            PR fortran/95585
            * check.c (gfc_check_reshape): Add check for a value when
            the symbol has an attribute flavor FL_PARAMETER.
    
    2020-07-26  Mark Eggleston  <markeggleston@gcc.gnu.org>
    
    gcc/testsuite/
    
            PR fortran/95585
            * gfortran.dg/pr95585.f90: New test.
    
    (cherry picked from commit d9aed5f1ccffc019ddf980e349caa3d092755cb4)

diff --git a/gcc/fortran/check.c b/gcc/fortran/check.c
index 148a3269815..4d50906a3f3 100644
--- a/gcc/fortran/check.c
+++ b/gcc/fortran/check.c
@@ -4742,7 +4742,8 @@ gfc_check_reshape (gfc_expr *source, gfc_expr *shape,
 	   && shape->ref->u.ar.as->lower[0]->ts.type == BT_INTEGER
 	   && shape->ref->u.ar.as->upper[0]->expr_type == EXPR_CONSTANT
 	   && shape->ref->u.ar.as->upper[0]->ts.type == BT_INTEGER
-	   && shape->symtree->n.sym->attr.flavor == FL_PARAMETER)
+	   && shape->symtree->n.sym->attr.flavor == FL_PARAMETER
+	   && shape->symtree->n.sym->value)
     {
       int i, extent;
       gfc_expr *e, *v;
diff --git a/gcc/testsuite/gfortran.dg/pr95585.f90 b/gcc/testsuite/gfortran.dg/pr95585.f90
new file mode 100644
index 00000000000..b0e6cdc5bea
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr95585.f90
@@ -0,0 +1,6 @@
+! { dg-do compile }
+
+program test
+  integer, parameter :: a(2) = reshape([1, 2], a) ! { dg-error "before its definition" }
+end program
+

commit 1d9f93de8c3bb1517db75f7c1e561dc4504a2ddb
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Jul 27 00:16:54 2020 +0000

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 22878d584d2..244a45a8404 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200726
+20200727
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 9cfa0c10c11..b0e1a540213 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,13 @@
+2020-07-26  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	Backported from master:
+	2020-06-22  Steven G. Kargl  <kargl@gcc.gnu.org>
+		    Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	PR fortran/95585
+	* check.c (gfc_check_reshape): Add check for a value when
+	the symbol has an attribute flavor FL_PARAMETER.
+
 2020-07-23  Harald Anlauf  <anlauf@gmx.de>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 7dfac6c50fa..a1a18d8f7b1 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2020-07-26  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	Backported from master:
+	2020-06-22  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/95585
+	* gfortran.dg/pr95585.f90: New test.
+
 2020-07-25  Dominique d'Humieres  <dhumieres.dominique@free.fr>
 
 	Backported from master:

commit 3eb264bd241598b27b765e198690a7cf4a2d91f8
Author: Mark Eggleston <markeggleston@gcc.gnu.org>
Date:   Thu Jun 11 11:05:40 2020 +0100

    Fortran  : ICE in gfc_check_pointer_assign PR95612
    
    Output an error if the right hand value is a zero sized array or
    does not have a symbol tree otherwise continue checking.
    
    2020-07-27  Steven G. Kargl  <kargl@gcc.gnu.org>
    
    gcc/fortran/
    
            PR fortran/95612
            * expr.c (gfc_check_pointer_assigb): Output an error if
            rvalue is a zero sized array or output an error if rvalue
            doesn't have a symbol tree.
    
    2020-07-27  Mark Eggleston  <markeggleston@gcc.gnu.org>
    
    gcc/testsuite/
    
            PR fortran/95612
            * gfortran.dg/pr95612.f90: New test.
    
    (cherry picked from commit 81072bab8d1e48ee83d9711dcb559ea1e019b351)

diff --git a/gcc/fortran/expr.c b/gcc/fortran/expr.c
index 8daa7bb8d06..569f4d9bf06 100644
--- a/gcc/fortran/expr.c
+++ b/gcc/fortran/expr.c
@@ -4271,7 +4271,20 @@ gfc_check_pointer_assign (gfc_expr *lvalue, gfc_expr *rvalue,
       gfc_symbol *sym;
       bool target;
 
-      gcc_assert (rvalue->symtree);
+      if (gfc_is_size_zero_array (rvalue))
+	{
+	  gfc_error ("Zero-sized array detected at %L where an entity with "
+		     "the TARGET attribute is expected", &rvalue->where);
+	  return false;
+	}
+      else if (!rvalue->symtree)
+	{
+	  gfc_error ("Pointer assignment target in initialization expression "
+		     "does not have the TARGET attribute at %L",
+		     &rvalue->where);
+	  return false;
+	}
+
       sym = rvalue->symtree->n.sym;
 
       if (sym->ts.type == BT_CLASS && sym->attr.class_ok)
diff --git a/gcc/testsuite/gfortran.dg/pr95612.f90 b/gcc/testsuite/gfortran.dg/pr95612.f90
new file mode 100644
index 00000000000..b3cac8c1d81
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr95612.f90
@@ -0,0 +1,7 @@
+! { dg-do compile }
+
+program p
+   integer, pointer :: y(:) => shape(1)   ! { dg-error "Zero-sized array detected at .1. where an entity with the TARGET attribute is expected" }
+   integer, pointer :: z(:) => shape([1]) ! { dg-error "Pointer assignment target in initialization expression does not have the TARGET attribute at .1." }
+end
+

commit f93ce9ea23e1806ccf9d8cd1640fc14596f54be8
Author: Martin Liska <mliska@suse.cz>
Date:   Fri Jul 24 14:33:27 2020 +0200

    Use vec::reserve before vec_safe_grow_cleared is called
    
    gcc/ChangeLog:
    
            PR lto/45375
            * symbol-summary.h: Call vec_safe_reserve before grow is called
            in order to grow to a reasonable size.
            * vec.h (vec_safe_reserve): Add missing function for vl_ptr
            type.
    
    (cherry picked from commit 7f5c0f328eced560a204bb8e3eae0d45795dd235)

diff --git a/gcc/symbol-summary.h b/gcc/symbol-summary.h
index a38eb1db778..fa1df5c8015 100644
--- a/gcc/symbol-summary.h
+++ b/gcc/symbol-summary.h
@@ -354,8 +354,11 @@ public:
       id = this->m_symtab->assign_summary_id (node);
 
     if ((unsigned int)id >= m_vector->length ())
-      vec_safe_grow_cleared (m_vector,
-			     this->m_symtab->cgraph_max_summary_id);
+      {
+	int newlen = this->m_symtab->cgraph_max_summary_id;
+	vec_safe_reserve (m_vector, newlen - m_vector->length ());
+	m_vector->quick_grow_cleared (newlen);
+      }
 
     if ((*m_vector)[id] == NULL)
       (*m_vector)[id] = this->allocate_new ();
@@ -812,7 +815,11 @@ public:
       id = this->m_symtab->assign_summary_id (edge);
 
     if ((unsigned)id >= m_vector->length ())
-      vec_safe_grow_cleared (m_vector, this->m_symtab->edges_max_summary_id);
+      {
+	int newlen = this->m_symtab->edges_max_summary_id;
+	m_vector->reserve (newlen - m_vector->length ());
+	m_vector->quick_grow_cleared (newlen);
+      }
 
     if ((*m_vector)[id] == NULL)
       (*m_vector)[id] = this->allocate_new ();
diff --git a/gcc/vec.h b/gcc/vec.h
index bd7c7351dcd..3ad99b83690 100644
--- a/gcc/vec.h
+++ b/gcc/vec.h
@@ -753,6 +753,17 @@ vec_safe_grow_cleared (vec<T, va_heap, vl_ptr> *&v,
   v->safe_grow_cleared (len PASS_MEM_STAT);
 }
 
+/* If V does not have space for NELEMS elements, call
+   V->reserve(NELEMS, EXACT).  */
+
+template<typename T>
+inline bool
+vec_safe_reserve (vec<T, va_heap, vl_ptr> *&v, unsigned nelems, bool exact = false
+		  CXX_MEM_STAT_INFO)
+{
+  return v->reserve (nelems, exact);
+}
+
 
 /* If V is NULL return false, otherwise return V->iterate(IX, PTR).  */
 template<typename T, typename A>

commit 7cdb3704d973da174829a5641b4433bfab4d4193
Author: Aaron Sawdey <acsawdey@linux.ibm.com>
Date:   Tue Jun 23 13:12:52 2020 -0500

    Allow --with-cpu=power10
    
    Update config.gcc so that we can use --with-cpu=power10.
    Also remove "future" from the 64-bit check as Segher suggests.
    
            * config.gcc: Identify power10 as a 64-bit processor and as valid
            for --with-cpu and --with-tune.
    
    (cherry picked from commit 71237df0a0b7f0f10cebedcd114fae7ad2aaebcb)

diff --git a/gcc/config.gcc b/gcc/config.gcc
index 6a349965c0a..ed9697b9d4c 100644
--- a/gcc/config.gcc
+++ b/gcc/config.gcc
@@ -513,7 +513,7 @@ powerpc*-*-*)
 	extra_headers="${extra_headers} ppu_intrinsics.h spu2vmx.h vec_types.h si2vmx.h"
 	extra_headers="${extra_headers} amo.h"
 	case x$with_cpu in
-	    xpowerpc64|xdefault64|x6[23]0|x970|xG5|xpower[3456789]|xpower6x|xrs64a|xcell|xa2|xe500mc64|xe5500|xe6500|xfuture)
+	    xpowerpc64|xdefault64|x6[23]0|x970|xG5|xpower[3456789]|xpower10|xpower6x|xrs64a|xcell|xa2|xe500mc64|xe5500|xe6500)
 		cpu_is_64bit=yes
 		;;
 	esac
@@ -4928,7 +4928,7 @@ case "${target}" in
 				eval "with_$which=405"
 				;;
 			"" | common | native \
-			| power[3456789] | power5+ | power6x \
+			| power[3456789] | power10 | power5+ | power6x \
 			| powerpc | powerpc64 | powerpc64le \
 			| rs64 \
 			| 401 | 403 | 405 | 405fp | 440 | 440fp | 464 | 464fp \

commit f5b673ce61628188ca00b5fd33eefa89136b9b24
Author: Joseph Myers <joseph@codesourcery.com>
Date:   Mon Jul 27 22:53:40 2020 +0000

    Update gcc .po files.
    
            * be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
            ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
            zh_TW.po: Update.

diff --git a/gcc/po/be.po b/gcc/po/be.po
index 044cfc4092b..8239973a928 100644
--- a/gcc/po/be.po
+++ b/gcc/po/be.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -1941,87 +1941,87 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid vector constant"
 msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid register name for `%s'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "прапушчан ініцыялізатар"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "нерэчаісны %%d аперанд"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "нерэчаісны адрас"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2037,18 +2037,18 @@ msgid "invalid %%r value"
 msgstr "нерэчаіснае значэньне %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "нерэчаіснае значэньне %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
@@ -2078,7 +2078,7 @@ msgstr "нерэчаіснае значэньне %%M"
 msgid "invalid %%U value"
 msgstr "нерэчаіснае значэньне %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
@@ -2088,7 +2088,7 @@ msgstr "нерэчаіснае значэньне %%v"
 msgid "invalid %%C value"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
@@ -2098,10 +2098,10 @@ msgstr "нерэчаіснае значэньне %%E"
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "нерэчаіснае значэньне %%xn"
@@ -2185,36 +2185,36 @@ msgstr "нерэчаісны %%-код"
 msgid "unrecognized supposed constant"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2222,13 +2222,13 @@ msgstr "Нерэчаісны выбар \"%s\""
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2361,7 +2361,7 @@ msgstr "непадтрымліваемая версія"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2580,25 +2580,25 @@ msgstr ""
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 msgid "invalid operand %%xn code"
 msgstr "нерэчаісны %%-код"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr ""
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid fp constant"
@@ -2752,7 +2752,7 @@ msgstr "нерэчаісны %%-код"
 msgid "invalid %%P operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -2808,7 +2808,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -2864,8 +2864,8 @@ msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, fuzzy, c-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of '%%%c'"
@@ -3006,173 +3006,211 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%Q value"
+msgid "invalid %%A value"
+msgstr "дрэннае %%Q значэнне"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%t value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "нерэчаіснае значэньне %%V"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26742
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26744
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26746
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26754
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26757
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26760
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26763
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr ""
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3183,90 +3221,90 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "vector argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3534,8 +3572,8 @@ msgstr ""
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
@@ -3555,7 +3593,7 @@ msgstr ""
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -3563,7 +3601,7 @@ msgstr ""
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -3581,21 +3619,21 @@ msgstr ""
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -3606,12 +3644,12 @@ msgstr ""
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -3620,7 +3658,7 @@ msgstr ""
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -3629,18 +3667,18 @@ msgstr ""
 msgid "expected %<.%>"
 msgstr ""
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -3648,19 +3686,19 @@ msgstr ""
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
@@ -3669,7 +3707,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -3680,34 +3718,34 @@ msgstr ""
 msgid "expected label"
 msgstr ""
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr ""
 
@@ -3805,7 +3843,7 @@ msgstr "невыкарыстаемы параметр \"%s\""
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -3986,50 +4024,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "in argument to unary !"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4071,17 +4109,17 @@ msgstr "пустая сімвальная канстанта"
 msgid "elemental binary operation"
 msgstr "прапушчан ініцыялізатар"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr ""
@@ -4155,7 +4193,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "увага:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4170,7 +4208,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4284,11 +4322,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr ""
 
@@ -4296,219 +4334,219 @@ msgstr ""
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 #| msgid "no arguments"
 msgid "value argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "няма аргументаў"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4521,27 +4559,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4616,7 +4654,7 @@ msgstr ""
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5070,7 +5108,7 @@ msgstr "немагчыма стварыць часовы файл"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5653,8 +5691,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -8109,105 +8147,100 @@ msgstr ""
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr ""
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12740,7 +12773,7 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
+msgid "Use instructions added in ISA 3.1."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:576
@@ -12754,6 +12787,12 @@ msgstr "Не генерыраваць сімвальныя інструкцыі"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Do not generate char instructions"
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Не генерыраваць сімвальныя інструкцыі"
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17775,7 +17814,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18428,371 +18467,371 @@ msgstr ""
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop vectorization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Стварыць код для DLL"
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Стварыць код для DLL"
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <файл>                Памясціць вывад у <файл>\n"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable exception handling"
 msgid "Enable function profiling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr ""
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19942,8 +19981,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -19971,7 +20010,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr ""
@@ -20040,7 +20079,7 @@ msgstr "няма аргументаў"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments"
@@ -20426,7 +20465,7 @@ msgstr ""
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -20512,12 +20551,12 @@ msgstr ""
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20536,8 +20575,8 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %qD"
@@ -20659,7 +20698,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -20952,7 +20991,7 @@ msgstr "аргумент для \"%s\" прапушчан"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -21252,12 +21291,12 @@ msgstr ""
 msgid "%<asm%> clobber conflict with input operand"
 msgstr ""
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21786,303 +21825,303 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr ""
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "local symbols must be defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -22169,13 +22208,13 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%q+F used but never defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -22333,7 +22372,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr ""
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s"
 msgid "cannot open %s: %m"
@@ -22670,22 +22709,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, fuzzy, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "Нерэчаісны выбар %s"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr ""
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, fuzzy, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "унутраная памылка"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22747,7 +22786,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -22777,12 +22816,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -22798,7 +22837,7 @@ msgstr "нявернае выкарыстанне \"restict\""
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "не магу знайсці крыніцу %s\n"
@@ -22818,37 +22857,37 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23491,13 +23530,13 @@ msgstr ""
 msgid "function returns address of local variable"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared here"
@@ -24066,10 +24105,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -24234,7 +24273,7 @@ msgstr ""
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
@@ -24284,13 +24323,13 @@ msgstr ""
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -24300,147 +24339,147 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -24517,7 +24556,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -24789,54 +24828,54 @@ msgstr ""
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24866,37 +24905,37 @@ msgstr ""
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr ""
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24946,59 +24985,59 @@ msgstr ""
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "немагчыма знайсьці кляс `%s'"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find source %s"
 msgid "cannot find LTO section refs in %s"
 msgstr "не магу знайсці крыніцу %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Нерэчаісны выбар %s"
@@ -25252,52 +25291,52 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr ""
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr ""
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25521,52 +25560,52 @@ msgstr "нявернае выкарыстанне \"restict\""
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -26920,136 +26959,136 @@ msgstr "атрыбуты секцыі не падтрымліваюцца для
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr ""
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr ""
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "can't close input file %s"
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "немагчыма зачыніць уваходзячы файл %s"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr ""
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr ""
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "section attributes are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, fuzzy, gcc-internal-format
 #| msgid "error writing to %s"
 msgid "error writing to %s: %m"
 msgstr "памылка запісу ў %s"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, fuzzy, gcc-internal-format
 #| msgid "error writing to %s"
 msgid "error closing %s: %m"
 msgstr "памылка запісу ў %s"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr ""
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -27144,176 +27183,176 @@ msgstr ""
 msgid "ignoring loop annotation"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%m value"
 msgid "invalid expression for min lvalue"
 msgstr "нерэчаіснае значэньне %%m"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr ""
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr ""
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr ""
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%f operand"
 msgid "invalid %qs offset operator"
 msgstr "нерэчаісны %%f аперанд"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr ""
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid address operand in %qs"
 msgstr "нерэчаісны %%d аперанд"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%f operand"
 msgid "invalid offset operand in %qs"
 msgstr "нерэчаісны %%f аперанд"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -27324,512 +27363,512 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr ""
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr ""
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr ""
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, fuzzy, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr ""
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr ""
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr ""
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr ""
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr ""
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "прапушчан ініцыялізатар"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr ""
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr ""
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr ""
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr ""
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr ""
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "нерэчаісны %%-код"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%Q value"
 msgid "invalid %<PHI%> result"
 msgstr "дрэннае %%Q значэнне"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%Q value"
 msgid "invalid %<PHI%> argument"
 msgstr "дрэннае %%Q значэнне"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr ""
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "case labels not sorted: "
 msgstr "-pipe не падтрымліваецца"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing field '%s' in '%s'"
 msgid "missing edge %i->%i"
 msgstr "прапушчана поле '%s' у '%s'"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -27844,47 +27883,47 @@ msgstr "перанакіраванне stdout: %s"
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -28395,12 +28434,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr ""
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -28465,7 +28504,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28475,27 +28514,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr ""
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -28570,32 +28609,32 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -28620,233 +28659,233 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:14387
+#: tree.c:14398
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr ""
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -28973,82 +29012,82 @@ msgstr ""
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
@@ -29640,7 +29679,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -29661,7 +29700,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -30034,12 +30073,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -30197,13 +30236,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %qE"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
@@ -30310,7 +30349,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
@@ -30320,127 +30359,127 @@ msgstr ""
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr ""
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of arguments to function %qE"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "адмоўны памер масіва "
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "адмоўны памер масіва "
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30497,509 +30536,509 @@ msgstr ""
 msgid "format string argument follows the arguments to be formatted"
 msgstr ""
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr ""
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr ""
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr ""
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr ""
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr ""
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr ""
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr ""
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr ""
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr ""
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr ""
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr ""
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr ""
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr ""
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr ""
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s не падтрымлівае %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s не падтрымлівае %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr ""
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr ""
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s не падтрымлівае %s"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s не падтрымлівае %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr ""
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr ""
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr ""
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr ""
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s не падтрымлівае %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr ""
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr ""
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "unquoted attribute in format"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr ""
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr ""
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr ""
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated comment"
 msgid "unterminated quoting directive"
 msgstr "незавершаныя каментарыі"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr ""
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, fuzzy, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr ""
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated comment"
 msgid "unterminated color directive"
 msgstr "незавершаныя каментарыі"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr ""
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -31163,7 +31202,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -31179,17 +31218,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -31199,7 +31238,7 @@ msgstr "аргумент для \"%s\" прапушчан"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -31805,7 +31844,7 @@ msgid "wrong type argument to %s"
 msgstr "не хапае аргументаў у функцыі"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -32491,7 +32530,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -32570,7 +32609,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -32590,7 +32629,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
@@ -32610,7 +32649,7 @@ msgstr ""
 msgid "too many input files"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -32642,14 +32681,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -33173,395 +33212,402 @@ msgstr "-pipe не падтрымліваецца"
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid format for sve_width"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "нерэчаіснае значэньне %%h"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s не падтрымлівае %s"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "непадтрымліваемая версія"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr ""
@@ -33744,17 +33790,17 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33906,12 +33952,12 @@ msgstr ""
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -33919,198 +33965,198 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 7"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 3"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 1"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of mask should be in 0 to 255"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -34120,283 +34166,283 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr ""
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -34404,23 +34450,23 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "-pipe не падтрымліваецца"
@@ -34503,18 +34549,18 @@ msgstr "-pipe не падтрымліваецца"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%qs function cannot have arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qs function cannot return a value"
@@ -34781,7 +34827,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument to built-in function"
@@ -35118,52 +35164,52 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr ""
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr ""
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr ""
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -35302,132 +35348,132 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "parameter to builtin not valid: %s"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr ""
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
@@ -35810,145 +35856,145 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -36399,7 +36445,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -37487,52 +37533,52 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -37651,325 +37697,326 @@ msgstr ""
 msgid "junk at end of %<#pragma longcall%>"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of `%s' should be `char **'"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "другім аргументам \"%s\" павінен быць \"char **\""
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -37991,223 +38038,228 @@ msgstr "Не выкарыстоўваць рэгістра sb"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s не падтрымлівае %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "%qs is not a valid base register in %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "%s=%s is too large"
 msgid "%s%qs%s is not allowed"
 msgstr "%s=%s вельмі вялікі"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
@@ -38529,141 +38581,141 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "памер \"%s\" - %d байт"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -39085,8 +39137,8 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "could not read the BRIG file"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -39369,7 +39421,7 @@ msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэк
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -39442,7 +39494,7 @@ msgstr "\"%s\" не абвешчан (першае выкарыстанне ў 
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Аб кожным неабвешчаным ідэнтыфікатары паведамляецца"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -39474,7 +39526,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "паўтарэнне \"%s\""
@@ -39689,7 +39741,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -40041,7 +40093,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -40354,7 +40406,7 @@ msgstr "перанакіраванне stdout: %s"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -40406,7 +40458,7 @@ msgstr ""
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -40444,7 +40496,7 @@ msgstr "перанакіраванне stdout: %s"
 msgid "redeclaration of %<enum %E%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -40474,7 +40526,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
@@ -40506,7 +40558,7 @@ msgstr "няма папярэдняга прататыпа для \"%s\""
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
@@ -40626,12 +40678,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -40640,272 +40692,272 @@ msgstr "адмеціна `%D' вызначана, але не выкарысто
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C89 не падтрымлівае \"long long\""
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "`long long long' - вельмі доўга для GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "паўтарэньне `%s'"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C90 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -40925,7 +40977,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -40973,7 +41025,7 @@ msgid "unknown type name %qE"
 msgstr "невядомая назва рэгістра: %s"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -40995,7 +41047,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -41011,8 +41063,8 @@ msgstr "атрыбуты секцыі не падтрымліваюцца для
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -41050,7 +41102,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -41080,7 +41132,7 @@ msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -41111,7 +41163,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -41158,14 +41210,14 @@ msgstr "параметр \"%s\" ініцыялізаваны"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -41252,7 +41304,7 @@ msgstr ""
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr ""
@@ -41262,7 +41314,7 @@ msgstr ""
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C89 не падтрымлівае \"long long\""
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -41323,7 +41375,7 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -41338,7 +41390,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
@@ -41363,19 +41415,19 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr ""
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -41395,12 +41447,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -41415,8 +41467,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "паўтарэнне \"volatile\""
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -41443,12 +41495,12 @@ msgstr "ISO C не дазваляе пусты ізыходны файл"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -41847,61 +41899,61 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -41911,18 +41963,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -41943,54 +41995,54 @@ msgstr ""
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr ""
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -42012,12 +42064,12 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
@@ -42027,22 +42079,22 @@ msgstr ""
 msgid "expected constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr ""
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -42057,54 +42109,54 @@ msgstr ""
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many %<static%> arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "unexpected argument"
 msgstr "няма аргументаў"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr ""
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr ""
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -42114,7 +42166,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -42150,24 +42202,24 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -42182,78 +42234,78 @@ msgstr "Нерэчаісны выбар %s"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr ""
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -42268,7 +42320,7 @@ msgstr ""
 msgid "expected function name"
 msgstr ""
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD does not refer to a function"
@@ -42279,68 +42331,68 @@ msgstr "`%D' - гэта ня функцыя,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -42350,57 +42402,57 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr ""
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr ""
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr ""
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr ""
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr ""
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -42410,72 +42462,72 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -42490,57 +42542,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr ""
@@ -42551,12 +42603,12 @@ msgstr ""
 msgid "variant %qD is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -42566,32 +42618,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr ""
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -42646,42 +42698,42 @@ msgstr ""
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr ""
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr ""
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -42696,27 +42748,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -42726,7 +42778,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -42742,7 +42794,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -42863,7 +42915,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -42888,7 +42940,7 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -43004,17 +43056,17 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -43039,7 +43091,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -43289,7 +43341,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -43458,7 +43510,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -43618,7 +43670,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -43649,7 +43701,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -43795,7 +43847,7 @@ msgstr ""
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C не падтрымлівае \"goto *expr;\""
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -43836,7 +43888,7 @@ msgstr ""
 msgid "case label is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -43846,17 +43898,17 @@ msgstr ""
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -43871,7 +43923,7 @@ msgstr ""
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
@@ -43881,22 +43933,22 @@ msgstr ""
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -43947,7 +43999,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -43977,51 +44029,51 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -44031,8 +44083,8 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
@@ -44200,12 +44252,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -44230,8 +44282,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -44246,19 +44298,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -44328,116 +44380,116 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr ""
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -44625,789 +44677,789 @@ msgid "expected case label"
 msgstr ""
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "  no known conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr ""
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr ""
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "Унутраная памылка: %s"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr ""
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %qs"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "немагчымы апэратар '%s'"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared protected here"
 msgstr "выклікана адсюль"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "  declared here"
 msgstr " адсюль"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -45436,524 +45488,524 @@ msgstr ""
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr ""
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is larger than %d bytes"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "language %s not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "мова %s не распазнана"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr ""
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr ""
@@ -46033,7 +46085,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "call to internal function %qE"
@@ -46090,7 +46142,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
@@ -46145,373 +46197,372 @@ msgstr ""
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "выклікана адсюль"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "%qD used in its own initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr ""
@@ -46553,7 +46604,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -46592,292 +46643,292 @@ msgstr ""
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr ""
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -46946,7 +46997,7 @@ msgstr "папярэдняе абвяшчэньне `%D'"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -47133,12 +47184,12 @@ msgstr "няма папярэдняга аб'яўлення для \"%s\""
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "deleted definition of %qD"
@@ -47152,46 +47203,46 @@ msgstr "папярэдняе вызначэньне `%#T'"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -47199,849 +47250,849 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr " адсюль"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr ""
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
@@ -48315,7 +48366,7 @@ msgstr ""
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
@@ -48482,7 +48533,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -48694,819 +48745,819 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "%qD cannot be %qs"
 msgstr "[нельга знайсці %s]"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "%qD must have no arguments"
 msgstr "няма аргументаў"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qT has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -49518,96 +49569,96 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -49616,73 +49667,73 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -49722,7 +49773,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "метка \"%s\" ужываецца, але не вызначана"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "пустое абвяшчэнне"
@@ -49732,7 +49783,7 @@ msgstr "пустое абвяшчэнне"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -50061,148 +50112,148 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "няма аргументаў"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -50383,340 +50434,340 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "  when initialized here"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr ""
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "поле \"%s\" не знойдзена ў класе"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -50877,12 +50928,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr ""
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr ""
@@ -50907,157 +50958,162 @@ msgstr ""
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
+#: cp/method.c:1115
 #, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1111
+#: cp/method.c:1123
 #, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must be %<const%>"
 msgstr ""
 
-#: cp/method.c:1126
+#: cp/method.c:1128
 #, gcc-internal-format
-msgid "defaulted %qD must return %<bool%>"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1155
 #, gcc-internal-format
-msgid "defaulted %qD must be %<const%>"
+msgid "defaulted %qD is not a friend of %qT"
 msgstr ""
 
-#: cp/method.c:1158
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr ""
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr ""
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr ""
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -51099,213 +51155,213 @@ msgstr "тып параметра \"%s\" не аб'яўлены"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "does not match previous declaration %q#D"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr ""
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr ""
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "using-declaration may not name namespace %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qD attribute directive ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -51330,7 +51386,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -51355,7 +51411,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -51435,7 +51491,7 @@ msgstr "Нерэчаісны выбар %s"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -51557,7 +51613,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -51677,7 +51733,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -51779,12 +51835,12 @@ msgstr ""
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "\"%s\" мае незавершаны тып"
@@ -51819,7 +51875,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -51835,7 +51891,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -51851,7 +51907,7 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
@@ -51877,924 +51933,929 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr ""
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "default argument specified for lambda parameter"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr ""
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "condition declares a function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "expected initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "неаднолькавае абвяшчэньне `%T' і `%T'"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected operator"
 msgstr "нераспазнаны аператар %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr ""
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qE does not constrain a type"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a namespace-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr ""
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -52803,437 +52864,437 @@ msgstr "\"%s\" мае незавершаны тып"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "нерэчаісны абвяшчальнік"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate cv-qualifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate virt-specifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "нерэчаіснае выкарыстаньне `%T'"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr ""
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -53242,551 +53303,551 @@ msgstr "невыкарыстаемы параметр \"%s\""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr ""
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr ""
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr ""
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr ""
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -54062,7 +54123,7 @@ msgstr ""
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
@@ -54088,85 +54149,85 @@ msgstr "абвяшчэньне шаблёну `%#D'"
 msgid "template parameter %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "too many arguments for partial specialization %qT"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -54174,47 +54235,47 @@ msgstr "нехапае аргументаў у функцыі \"%s\""
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -54224,497 +54285,497 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "нявернае выкарыстанне \"restict\""
 msgstr[1] "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "original definition appeared here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "in template argument for type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -54732,296 +54793,296 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -55033,133 +55094,133 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -55366,7 +55427,7 @@ msgstr "нявернае выкарыстанне \"restict\""
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -55416,7 +55477,7 @@ msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -55515,7 +55576,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -55555,7 +55616,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
@@ -55680,117 +55741,117 @@ msgstr ""
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -56033,806 +56094,806 @@ msgstr ""
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a member template function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -57098,108 +57159,108 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr ""
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -57424,10 +57485,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -57594,7 +57655,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -57711,7 +57772,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -57752,7 +57813,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr ""
@@ -57767,7 +57828,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
@@ -57888,167 +57949,167 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr ""
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr ""
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr ""
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr ""
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr ""
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr ""
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr ""
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr ""
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr ""
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -58056,698 +58117,698 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr ""
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr ""
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr ""
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr ""
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr ""
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr ""
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr ""
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr ""
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr ""
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr ""
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr ""
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr ""
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr ""
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr ""
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr ""
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr ""
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr ""
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr ""
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr ""
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr ""
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr ""
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr ""
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -58944,1759 +59005,1759 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "пустая сімвальная канстанта"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing initializer"
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "прапушчан ініцыялізатар"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization"
 msgid "Old-style initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr ""
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Прапушчана назва"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr ""
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr ""
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr ""
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "невядомая назва рэгістра: %s"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr ""
@@ -60823,12 +60884,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr ""
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr ""
@@ -60903,7 +60964,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -61169,7 +61230,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -61227,167 +61288,167 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -61414,7 +61475,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -61606,12 +61667,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -61681,583 +61742,583 @@ msgstr ""
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "не знойдзен клас \"%s\""
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -62362,73 +62423,73 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr ""
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr ""
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "Conversion from %s to %s at %L"
@@ -62437,22 +62498,22 @@ msgstr "пераўтварэньне з `%T' у `%T'"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -62800,12 +62861,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62815,7 +62876,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62860,7 +62921,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -62955,7 +63016,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -63025,7 +63086,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -63040,83 +63101,83 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr ""
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr ""
@@ -63361,505 +63422,505 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr ""
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr ""
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr ""
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr ""
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr ""
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr ""
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "пустая сімвальная канстанта"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -63867,217 +63928,217 @@ msgstr ""
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "метка \"%s\" вызначана, але не выкарыстоўваецца"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "метка \"%s\" вызначана, але не выкарыстоўваецца"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr ""
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr ""
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -64118,12 +64179,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -64812,8 +64873,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -66223,172 +66284,172 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr ""
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr ""
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr ""
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr ""
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "метка \"%s\" вызначана, але не выкарыстоўваецца"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr ""
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr ""
@@ -66715,495 +66776,495 @@ msgstr "памер \"%s\" - %d байт"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "метка \"%s\" вызначана, але не выкарыстоўваецца"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "Substring end index at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -67212,12 +67273,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -67226,283 +67287,283 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67511,284 +67572,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67796,187 +67857,187 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67984,957 +68045,957 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -69627,153 +69688,153 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -69810,84 +69871,84 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "empty character constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "пустая сімвальная канстанта"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr ""
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -69907,73 +69968,73 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "unused variable `%s'"
 msgid "Unused variable %qs declared at %L"
 msgstr "невыкарыстоўваемая пераменная \"%s\""
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -69988,28 +70049,28 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -70045,22 +70106,22 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 msgid "optional class parameter"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -70172,84 +70233,84 @@ msgstr ""
 msgid "unable to open file"
 msgstr "немагу адчыніць файл \"%s\""
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr ""
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't open %s"
 msgid "Cannot open %s"
 msgstr "немагчыма адчыніць %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "не магу зачыніць %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "не магу прачытаць з %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 #| msgid "Could not open data file %s.\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "Немагчыма адчыніць файл з дадзенымі %s.\n"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -71405,7 +71466,7 @@ msgstr "аргумент для \"%s\" прапушчан"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, fuzzy, gcc-internal-format
 #| msgid "missing white space after number '%.*s'"
 msgid "missing filename after %qs"
@@ -71618,19 +71679,19 @@ msgstr ""
 msgid "unknown TLS model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized section name \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "нераспазнаная назва сэкцыі \"%s\""
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/da.po b/gcc/po/da.po
index 72cf3779fda..5fa573be0fa 100644
--- a/gcc/po/da.po
+++ b/gcc/po/da.po
@@ -137,7 +137,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc-9.1-b20190203\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2019-02-14 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -2038,93 +2038,93 @@ msgstr "længdemodifikation i strfmon-formatering"
 msgid "<command-line>"
 msgstr "<kommandolinje>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "manglende operand"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "ugyldig operand"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ugyldig operandpræfiks »%%%c«"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ugyldig adresseringstilstand"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands to binary %s"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ugyldige operander til binær %s"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« brugt uden nogle lokale dynamiske TLS-referencer"
@@ -2140,18 +2140,18 @@ msgid "invalid %%r value"
 msgstr "ugyldig %%r-værdi"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "ugyldig %%R-værdi"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
@@ -2181,7 +2181,7 @@ msgstr "ugyldig %%M-værdi"
 msgid "invalid %%U value"
 msgstr "ugyldig %%U-værdi"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
@@ -2191,7 +2191,7 @@ msgstr "ugyldig %%s-værdi"
 msgid "invalid %%C value"
 msgstr "ugyldig %%C-værdi"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
@@ -2201,10 +2201,10 @@ msgstr "ugyldig %%E-værdi"
 msgid "unknown relocation unspec"
 msgstr "ukendt relokaliserings-unspec"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ugyldig %%xn-kode"
@@ -2287,37 +2287,37 @@ msgstr "ugyldig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "ukendt formodet konstant"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "ugyldig skift-operand"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, fuzzy, c-format
 #| msgid "Generate char instructions"
 msgid "predicated Thumb instruction"
 msgstr "Generér char-instruktioner"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, fuzzy, c-format
 #| msgid "ret instruction not implemented"
 msgid "predicated instruction in conditional sequence"
 msgstr "ret-instruktion ikke implementeret"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2325,13 +2325,13 @@ msgstr "Ikke understøttet operand for koden »%c«"
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktion aldrig udført"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "forældet Maverick-formatkode »%c«"
@@ -2465,7 +2465,7 @@ msgstr "uventet operand"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2682,27 +2682,27 @@ msgstr "ugyldig output_move_double-operand"
 msgid "bad output_condmove_single operand"
 msgstr "ugyldig output_condmove_single-operand"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operand %%xn code"
 msgstr "ugyldig operand til %%Z-koden"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "c4x_operand_subword: invalid mode"
 msgid "operand %%xn code invalid for QImode"
 msgstr "c4x_operand_subword: ugyldig tilstand"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid fp constant"
@@ -2852,7 +2852,7 @@ msgstr "ugyldig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ugyldig %%P-operand"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -2906,7 +2906,7 @@ msgid "post-increment address is not a register"
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -2959,8 +2959,8 @@ msgstr "»%%%c« er ikke et gyldigt operandpræfiks"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ugyldig brug af »%%%c«"
@@ -3101,183 +3101,237 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx kræver udstyrskommatal"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx kræver indekseret adressering"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx og -mno-altivec er indbyrdes uforenelige"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec deaktiverer vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "-mquad-memory kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 #, fuzzy
 #| msgid "-mquad-memory-atomic requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "-mquad-memory-atomic kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 #| msgid "-mquad-memory is not available in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "ugyldig %%J-værdi"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "ugyldig %%D-værdi"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "ugyldig %%z-værdi"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 og __ibm128 kan ikke bruges i det samme udtryk"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 og lang dobbelt kan ikke bruges i det samme udtryk"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 og lang dobbelt kan ikke bruges i det samme udtryk"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "Kunne ikke generere addis-værdi for fusion"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kunne ikke generere indlæsning/lagring af forskydning for fusion"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Ugyldig GPR-fusion"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "ugyldig konvertering fra %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "ugyldig konvertering til %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "ugyldig konvertering fra %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "ugyldig konvertering til %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "ugyldig konvertering fra %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "ugyldig konvertering til %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "ugyldig konvertering fra %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "ugyldig konvertering til %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3288,88 +3342,88 @@ msgstr "symbolske hukommelsesreferencer er kun understøttet på z10 eller sener
 msgid "cannot decompose address"
 msgstr "Kan ikke nedbryde adresse"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ugyldig sammenligningsoperator til »E«-ændring"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ugyldig reference til »J«-uddataændring"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ugyldig adresse til »O«-uddataændring"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ugyldig adresse til »R«-uddataændring"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "hukommelsesreference forventet til »S«-uddataændring"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ugyldig adresse for »S«-uddatamodifikation"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »N«-uddataændring"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »M«-uddataændring"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ugyldig konstant til uddataændringen »%c«"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ugyldig konstant - prøv at bruge en uddataændring"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ugyldig konstantvektor for uddataændringen »%c«"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ugyldigt udtryk - prøv at brug en uddataændring"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ugyldig udtryk til uddataændringen »%c«"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorparameter sendt til funktion uden prototype"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "typer er forskellige i signedness"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr "binær operator understøtter ikke tovektor bool-operand"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr "binær operator understøtter ikke vektor bool-operand"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binær operator understøtter ikke at blande vektor bool med kommatals vektor-operand"
 
@@ -3632,8 +3686,8 @@ msgstr "({anonym})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> forventet"
@@ -3653,7 +3707,7 @@ msgstr "%<;%> forventet"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> forventet"
@@ -3661,7 +3715,7 @@ msgstr "%<)%> forventet"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> forventet"
@@ -3679,21 +3733,21 @@ msgstr "%<;%>, %<,%> eller %<)%> forventet"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> forventet"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> forventet"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> forventet"
@@ -3704,12 +3758,12 @@ msgstr "%<{%> forventet"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> forventet"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> forventet"
@@ -3718,7 +3772,7 @@ msgstr "%<while%> forventet"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> forventet"
@@ -3727,18 +3781,18 @@ msgstr "%<,%> forventet"
 msgid "expected %<.%>"
 msgstr "%<.%> forventet"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> forventet"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> forventet"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> forventet"
@@ -3746,19 +3800,19 @@ msgstr "%<,%> eller %<)%> forventet"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> forventet"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> forventet"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
@@ -3767,7 +3821,7 @@ msgstr "%<#pragma omp section%> eller %<}%> forventet"
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> forventet"
@@ -3778,38 +3832,38 @@ msgstr "%<<%> forventet"
 msgid "expected label"
 msgstr "forventet etiket"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable use of DB instruction"
 msgid "  after user-defined conversion:"
 msgstr "Aktivér brug af DB-instruktioner"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidate%s: %+#D"
 msgstr[1] "candidate%s: %+#D"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "spring til etiketten %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "spring til case-etiket"
 
@@ -3909,7 +3963,7 @@ msgstr "skabelonsparameter '%#D'"
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4109,50 +4163,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "forkert parametertype til unært minus"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "forkert parametertype til abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "forkert parametertype til konjugation"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4198,17 +4252,17 @@ msgstr "Nul-længde tegnkonstant ved %0"
 msgid "elemental binary operation"
 msgstr "manglende binær operator"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr ""
@@ -4286,7 +4340,7 @@ msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 msgid "Driving:"
 msgstr "advarsel: "
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4301,7 +4355,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4435,11 +4489,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
@@ -4449,233 +4503,233 @@ msgstr "tildeling"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "ingen parametre"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "ugyldig typeparameter"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 #, fuzzy
 #| msgid "Do not allocate BK register"
 msgid "pointer or allocatable result"
 msgstr "Allokér ikke BK-registeret"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 #, fuzzy
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4688,27 +4742,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4788,7 +4842,7 @@ msgstr "Mystisk tal i FORMAT-sætning ved %0"
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5268,7 +5322,7 @@ msgstr "Advar om beregninger på funktionshenvisninger"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5876,8 +5930,8 @@ msgstr "Tilføj aldrig en anden understreg til eksterne variable"
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -8440,107 +8494,101 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "Advar når en inline funktion ikke kan indbygges"
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about uninitialized automatic variables"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Advar om ikke-klargjorte automatiske variabler"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13375,9 +13423,9 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "generation of Branch Likely instructions enabled, but not supported by architecture"
-msgid "Use instructions for a future architecture."
-msgstr "generering af Branch Likely-instruktioner er aktiveret, men ikke understøttet af arkitekturen"
+#| msgid "Use vector/scalar (VSX) instructions"
+msgid "Use instructions added in ISA 3.1."
+msgstr "Benyt vektor/skalar-instruktioner (VSX)"
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13391,6 +13439,12 @@ msgstr "Generér char-instruktioner"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Tillad ikke ikke-justeret adgang"
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate char instructions"
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Generér char-instruktioner"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -18897,7 +18951,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -19598,397 +19652,397 @@ msgstr "Udfør løkkeudrulning når iterationsantallet er kendt"
 msgid "Perform loop unrolling for all loops."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, fuzzy, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Tillad matematikoptimeringer der kan overtræde IEEE- eller ANSI-standarderne"
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Generér blot afvindingstabeller for undtagelseshåndtering"
 
-#: common.opt:2896
+#: common.opt:2900
 #, fuzzy, no-c-format
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the gold linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform tail call optimization"
 msgid "Perform variable tracking."
 msgstr "Udfør halekaldsoptimering"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, fuzzy, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable loop vectorization on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 #| msgid "Enable linker optimizations"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2959
+#: common.opt:2963
 #, fuzzy, no-c-format
 #| msgid "Specify alternate name for bss section"
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Angiv alternativt navn til bss-sektionen"
 
-#: common.opt:2963
+#: common.opt:2967
 #, fuzzy, no-c-format
 #| msgid "Specify alternate name for bss section"
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "Angiv alternativt navn til bss-sektionen"
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Tilføj ekstra kommentarer til menneskeligt læsbar maskinkodeuddata"
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Set Windows defines"
 msgid "Assume pointer overflow wraps around."
 msgstr "Angiv Windows-definitioner"
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Anbring nul-klargjorte data i bss-sektionen"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Generér fejlfindingsinfo i udvidet standardformat"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Generér et enkelt afslutningspunkt for hver funktion"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, fuzzy, no-c-format
 #| msgid "Don't generate fused multiply/add instructions"
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generér ikke sammensatte gang/addér-instruktioner"
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Opret sektioner for DWARF-pubnavne og pubtyper."
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Opret sektioner for DWARF-pubnavne og pubtyper med GNU-udvidelser."
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in separate .dwo files"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Opret fejlsøgningsinformation i separate .dwo-filer"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Opret fejlsøgningsinformation i STABS-format"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Opret fejlsøgningsinformation i udvidet STABS-format"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Opret fejlsøgningsinformation i VMS-format"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Opret fejlsøgningsinformation i XCOFF-format"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Opret fejlsøgningsinformation i udvidet XCOFF-format"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 #| msgid "Generate compressed debug sections"
 msgid "Generate compressed debug sections."
 msgstr "Opret komprimeret fejlsøgningssektioner"
 
-#: common.opt:3209
+#: common.opt:3213
 #, fuzzy, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <fil>                Anbring uddata i <fil>\n"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "MIPS16-funktionsprofilering"
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Vis ikke funktioner der oversættes eller forløbet tid"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Aktiver uddybende uddata"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Vis oversætterens version"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Undertryk advarsler"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "Opret et delt bibliotek"
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21168,8 +21222,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "beregnet værdi benyttes ikke"
@@ -21197,7 +21251,7 @@ msgid "expected boolean type"
 msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "uventet operand"
@@ -21271,7 +21325,7 @@ msgstr "ikke nok parametre"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "for mange parametre"
@@ -21674,7 +21728,7 @@ msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
@@ -21765,12 +21819,12 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -21790,8 +21844,8 @@ msgstr "egenskaben '%s' ignoreret"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidligere erklæring af %qD"
@@ -21917,7 +21971,7 @@ msgstr "  '%#D' erklæret her"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "forskydning udenfor grænserne af konstant streng"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qE declared here"
@@ -22238,7 +22292,7 @@ msgstr "ugyldig typeparameter"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -22564,12 +22618,12 @@ msgstr "asm-overskrivelse er i modstrid med uddataoperander"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "asm-overskrivelse er i modstrid med inddataoperander"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -23130,317 +23184,317 @@ msgstr "basisblokkene er ikke nummeret i rækkefølge"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antallet af basisbloknoter i instruktionskæden (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count invalid"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing counts for called function %s/%i"
 msgid "missing direct call for speculation %i"
 msgstr "Manglende antal for kaldt funktion %s/%i"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "manglende barriere efter blok %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "startværdielement er ikke en konstant"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "tp_first_run must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "local symbols must be defined"
 msgstr "ingen symboltabel fundet"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with no value, in function returning non-void"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "edge count is not compatible with function count"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "section pointer missing"
 msgid "inlined_to pointer is wrong"
 msgstr "sektionshenvisning mangler"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple inline callers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count does not match BB count"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "inlined_to pointer refers to itself"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' used prior to declaration"
 msgid "edge points to wrong declaration:"
 msgstr "'%s' benyttes før erklæringen"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "origin points to a different parent"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_cgraph_node failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "string section missing"
 msgid "%s: section %s.%d is missing"
@@ -23537,12 +23591,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F brugt, men aldrig defineret"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F erklæret %<static%>, men aldrig defineret"
@@ -23710,7 +23764,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
@@ -24062,23 +24116,23 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, fuzzy, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "ugyldig operand i instruktionen"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr ""
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "internal consistency failure"
 msgstr "intern GCC-afbrydelse"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn brugt hvor emit_jump_insn behøves:\n"
@@ -24143,7 +24197,7 @@ msgstr "typeomtvingelse passer ikke til funktionstype"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "options enabled: "
 msgid "%qs failed"
@@ -24175,12 +24229,12 @@ msgstr "Generér kode til en C400"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: expr.c:11123
+#: expr.c:11128
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
@@ -24197,7 +24251,7 @@ msgstr "ugyldig typeparameter"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "%Jstørrelsen af '%D' er større end %d byte"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not open final insn dump file %qs: %m"
@@ -24220,40 +24274,40 @@ msgstr "stort heltal forkortes underforstået til type uden fortegn"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "sammenligning er altid %d"
 
 # RETMIG: det giver ikke mening
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, fuzzy, gcc-internal-format
 #| msgid "`or' of unmatched not-equal tests is always 1"
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "'or' af uafbalancerede sammenligninger med forskellig fra er altid 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "`and' of mutually exclusive equal-tests is always 0"
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "'and' af udtryk der hver for sig udelukker hinanden, er altid 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -24918,13 +24972,13 @@ msgstr "funktion kan returnere adressen på en lokal variabel"
 msgid "function returns address of local variable"
 msgstr "funktion returnerer adressen på en lokal variabel"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared here"
@@ -25538,10 +25592,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -25730,7 +25784,7 @@ msgstr "'%D' ikke erklæret"
 msgid "enclosing %<target%>"
 msgstr "fejl ved lukning af %s: %m"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variablen '%s' er erklæret 'inline'"
@@ -25786,13 +25840,13 @@ msgstr "instansvariablen '%s' er erklæret privat"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
@@ -25803,153 +25857,153 @@ msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid private reduction on %qE"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "antallet af resultater matcher ikke antallet af værdier"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is promoted to `%s' when passed through `...'"
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "'%s' forfremmes til '%s' ved overbringelse gennem '...'"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, fuzzy, gcc-internal-format
 #| msgid "(so you should pass `%s' not `%s' to `va_arg')"
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(så du skal overbring '%s' ikke '%s' til 'va_arg')"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -26029,7 +26083,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -26324,54 +26378,54 @@ msgstr "typen af startværdien for feltet passer ikke"
 msgid "the extra base is defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "Ugyldig erklæring"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -26404,39 +26458,39 @@ msgstr "funktion er muligvis en kandidat til egenskaben %<%s%>, hvis den vides a
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, fuzzy, gcc-internal-format
 #| msgid "using `typename' outside of template"
 msgid "Access terminates outside of its parent"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "IPA-SRA access verification failed"
 msgstr "verifikationsfejl ved PC=%d"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -26490,58 +26544,58 @@ msgstr "inkonsistente operandbegræsninger i 'asm'"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "kan ikke finde klassen '%s'"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "kan ikke finde kilden %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -26817,54 +26871,54 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "... to the previous %qs clause here"
 msgstr "%Jtidligere benyttet her"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "... with %qs clause here"
 msgstr "  '%#D' erklæret her"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -27093,53 +27147,53 @@ msgstr "ugyldig parameter til egenskaben '%s'"
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "routine %qD declared here"
 msgstr "  '%#D' erklæret her"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -28571,142 +28625,142 @@ msgstr "-fcheck-pointer-bounds er ikke understøttet for denne målarkitektur"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> understøttes ikke længere"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "instruktionsplanlægning understøttes ikke på målarkitekturen"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "målarkitekturen har ikke forsinkede forgreninger"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore understøttes ikke på målarkitekturen"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "kunne ikke lukke nulstillet insn-dumpningsfilen %qs: %m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "målarkitektursystem understøtter ikke %qs-fejlsøgningsformatet"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "der blev anmodt om variabelsporing, men den er nytteløs uden fejlsøgningsinformation"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "der blev anmodt om variabelsporing, men den er ikke understøttet af dette fejlsøgningsformat"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments ændrer selektiv planlægning"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections understøttes ikke på målarkitekturen"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen (prøv '-march'-tilvalgene)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays understøttes ikke med -Os"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math deaktiveret; andre tilvalg har forrang"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector understøttes ikke på denne målarkitektur"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fsanitize=address og -fsanitize=kernel-address understøttes ikke på denne målarkitektur"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "fejl ved skrivning til %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "fejl ved lukning af %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -28806,196 +28860,196 @@ msgstr "%Kasm er ikke tilladt i %<transaction_safe%> funktion"
 msgid "ignoring loop annotation"
 msgstr "ignorerer løkkeannotation"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "konstant blev ikke genberegnet da ADDR_EXPR ændrede sig"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "sideeffekter blev ikke genberegnet da ADDR_EXPR ændrede sig"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "DECL_GIMPLE_REG_P set on a variable with address taken"
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "DECL_GIMPLE_REG_P sat på en variabel med optaget adresse"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "adresse optaget, men ADDRESSABLE-bit er ikke angivet"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression for min lvalue"
 msgstr "ugyldigt udtryk som operand"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in indirect reference"
 msgstr "ugyldig operand i instruktionen"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "In construct"
 msgid "non-scalar %qs"
 msgstr "I konstruktionen"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "ugyldig position eller størrelsesoperant for BIT_FIELD_REF"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "non-lvalue in %s"
 msgid "non-top-level %qs"
 msgstr "ikke-venstreværdi i %s"
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "ugyldig operand til %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in %qs"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offset operand of MEM_REF"
 msgid "invalid %qs offset operator"
 msgstr "ugyldig forskydningsoperand for MEM_REF"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "konvertering fra '%T' til '%T' er tvetydigt"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s operand"
 msgid "invalid address operand in %qs"
 msgstr "ugyldig %%s-operand"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%f operand"
 msgid "invalid offset operand in %qs"
 msgstr "ugyldig %%f-operand"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid clique in %qs"
 msgstr "ugyldig brug af '%D"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "INDIRECT_REF in gimple IL"
 msgid "%qs in gimple IL"
 msgstr "INDIRECT_REF i gimple IL"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, fuzzy, gcc-internal-format
 #| msgid "-split has no argument."
 msgid "gimple call has no target"
 msgstr "-split uden parametre"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "Ugyldig erklæring"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "funktion kan ikke indbygges"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "invalid pure const state for function"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PC in line number table"
 msgid "invalid LHS in gimple call"
 msgstr "ugyldig PC i linjetalstabel"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number format"
 msgid "invalid conversion in gimple call"
 msgstr "ugyldigt versionsnummerformat"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PC in line number table"
 msgid "invalid static chain in gimple call"
 msgstr "ugyldig PC i linjetalstabel"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -29006,573 +29060,573 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid argument to gimple call"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operands in gimple comparison"
 msgstr "ugyldig operand i instruktionen"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "invalid vector comparison resulting type"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in unary operation"
 msgstr "ugyldig operand i instruktionen"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid token in expression"
 msgid "invalid vector types in nop conversion"
 msgstr "ugyldigt symbol udtryk"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "invalid token in expression"
 msgid "invalid types in nop conversion"
 msgstr "ugyldigt symbol udtryk"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 #| msgid "invalid token in expression"
 msgid "invalid types in address space conversion"
 msgstr "ugyldigt symbol udtryk"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, fuzzy, gcc-internal-format
 #| msgid "invalid token in expression"
 msgid "invalid types in fixed-point conversion"
 msgstr "ugyldigt symbol udtryk"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid suffix \"%.*s\" on floating constant"
 msgid "invalid types in conversion to floating-point"
 msgstr "ugyldig endelse \"%.*s\" i kommatalskonstant"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `void' for new"
 msgid "invalid types in conversion to integer"
 msgstr "ugyldig type 'void' til new"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in %qs expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid prototype for '%s'"
 msgid "invalid types for %qs"
 msgstr "ugyldig prototype for »%s«"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number format"
 msgid "non-trivial conversion in unary operation"
 msgstr "ugyldigt versionsnummerformat"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid operands in binary operation"
 msgstr "ugyldige operander til binær %s"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid non-vector operands to %qs"
 msgstr "ugyldig operand til %%R"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode `%s'"
 msgid "invalid (pointer) operands %qs"
 msgstr "ugyldig henvisningstilstand '%s'"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "vector type expected in %qs"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in binary expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operands in ternary operation"
 msgstr "ugyldig operand i instruktionen"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "vector types expected in %qs"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "vectors with different element number found in %qs"
 msgstr "operander til ?: har forskellige typer"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "ugyldig roteringsinstruktion"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "ikke-understøttet kombination: %s"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size in %qs"
 msgstr "ugyldig position eller størrelsesoperant for BIT_FIELD_REF"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 #| msgid "`sigof' applied to non-aggregate expression"
 msgid "%qs into non-mode-precision operand"
 msgstr "'sigof' benyttet på et udtryk der ikke er af en sammensat type"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "insertion out of range in %qs"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a directory"
 msgid "%qs not at element boundary"
 msgstr "%qs er ikke en mappe"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "%qs LHS in clobber statement"
 msgstr "Ugyldig klargøringssætning"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "ugyldig operand til %%R"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid indirect memory address"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ugyldig indirekte hukommelsesadresse"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of vector %qs elements"
 msgstr "for få parametre til funktionen '%s'"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "non-vector %qs with elements"
 msgstr "operander til ?: har forskellige typer"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR med en altid-falsk betingelse"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in return statement"
 msgstr "ugyldig operand i instruktionen"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "invalid conversion in return statement"
 msgstr "Ugyldig klargøringssætning"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "goto destination is neither a label nor a pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to switch statement"
 msgstr "ugyldig operand til %%s-koden"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code for huge switch statements"
 msgid "non-integral type switch statement"
 msgstr "Generér kode til store switch-sætninger"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "invalid case label in switch statement"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid case range in switch statement"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "formateringsstrengen har et ugyldigt operandtal"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid comparison code in gimple cond"
 msgstr "ugyldig operand til %%p-koden"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in increment"
 msgid "invalid labels in gimple cond"
 msgstr "ugyldig venstreværdi i forøgelse"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address"
 msgid "invalid %<PHI%> result"
 msgstr "ugyldig adresse"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "missing %<PHI%> def"
 msgstr "manglende tal"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid %<PHI%> argument"
 msgstr "ugyldig typeparameter"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in %s"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "uforenelige typer i %s"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "local declaration from a different function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_gimple failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "flow control insn inside a basic block"
 msgid "control flow in the middle of basic block %d"
 msgstr "strømkontrolinstruktion inden i en basisblok"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fallthru edge after unconditional jump %i"
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "Fald gennem-kant efter ubetinget spring %i"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit goto at end of bb %d"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "case labels not sorted: "
 msgstr "trampoliner understøttes ikke"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing field '%s' in '%s'"
 msgid "missing edge %i->%i"
 msgstr "manglende felt '%s' i '%s'"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "`noreturn' function does return"
 msgid "%<noreturn%> function does return"
 msgstr "funktion med egenskaben 'noreturn' returnerer"
 
 # RETMIG: dette må kunne gøres bedre
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "kontrol når til slutningen af ikke-void funktion"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -29590,50 +29644,50 @@ msgstr "omdefinering af 'union %s'"
 msgid "in expansion of macro %qs"
 msgstr "ingen parametre givet til makroen '%s'"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`B' operand has multiple bits set"
 msgid "BB %i has multiple EH edges"
 msgstr "'B'-operanden har flere bit sat"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "forkert instruktion i fald-gennem-kant"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -30163,13 +30217,13 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "hex escape sequence out of range"
 msgid "machine independent builtin code out of range"
 msgstr "den hexadecimale undvigesekvens er uden for det gyldige interval"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -30240,7 +30294,7 @@ msgstr "tabelindeks er ikke et heltal"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -30251,31 +30305,31 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "'%s' tidligere defineret her"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -30355,32 +30409,32 @@ msgstr "trækontrol: tilgik operand %d af %s med %d operander i %s, ved %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af omp_clause %s med %d operander i %s, ved %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD er forældet: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD  er forældet"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE er forældet: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE er forældet"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "type er forældet: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "type er forældet"
@@ -30405,251 +30459,251 @@ msgstr "type er forældet"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr "og felt"
 
-#: tree.c:14064
+#: tree.c:14075
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, fuzzy, gcc-internal-format
 #| msgid "type's TREE_TYPE"
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "types TREE_TYPE"
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "type er ikke forenelig med dens variant"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "Main variant is not defined"
 msgid "main variant is not defined"
 msgstr "Hovedvariant er ikke defineret"
 
-#: tree.c:14392
+#: tree.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_BINFO type er ikke TYPE_MAIN_VARIANT"
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL er ikke kompatibel"
 
-#: tree.c:14431
+#: tree.c:14442
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL er ikke kompatibel"
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "TYPE_VFIELD er ikke FIELD_DECL eller TREE_LIST"
 
-#: tree.c:14463
+#: tree.c:14474
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "TYPE_NEXT_PTR_TO er ikke POINTER_TYPE"
 
-#: tree.c:14473
+#: tree.c:14484
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "TYPE_NEXT_REF_TO er ikke REFERENCE_TYPE"
 
-#: tree.c:14494
+#: tree.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO is not TREE_BINFO"
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "TYPE_BINFO er ikke TREE_BINFO"
 
-#: tree.c:14500
+#: tree.c:14511
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_BINFO type er ikke TYPE_MAIN_VARIANT"
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "Array TYPE_DOMAIN is not integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Tabellen TYPE_DOMAIN er ikke af en heltalstype"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_FIELDS defined in incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "TYPE_FIELDS er defineret i en ufuldstændig type"
 
-#: tree.c:14627
+#: tree.c:14638
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Forkert træ i TYPE_FIELDS-liste"
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, fuzzy, gcc-internal-format
 #| msgid "wrong TYPE_CACHED_VALUES entry"
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "forkert TYPE_CACHED_VALUES-element"
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Forkert træ i TYPE_FIELDS-liste"
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -30779,91 +30833,91 @@ msgstr "%Jforespurgt justering for '%D' er større end den implementerede juster
 msgid "storage size of %q+D isn%'t known"
 msgstr "lagringsstørrelsen af '%D' er ikke kendt"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for integer value is too complicated"
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "startværdien for heltallet er for kompliceret"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "startværdien for kommatal er ikke en kommatalskonstant"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member `%s'"
 msgid "invalid initial value for member %qE"
 msgstr "ugyldig startværdi for medlemmet '%s'"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "'%s' er erklæret inline efter at være blevet kaldt"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' must be public"
 msgid "weak declaration of %q+D must be public"
 msgstr "%Jsvag erklæring af '%D' skal være public"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "weak declaration of %q+D not supported"
 msgstr "%Jsvag erklæring af '%D' ikke understøttet"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "kun svage aliaser understøttes i denne konfiguration"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%qs is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 #| msgid "alias definitions not supported in this configuration; ignored"
 msgid "alias definitions not supported in this configuration"
 msgstr "aliasdefinitioner er ikke understøttet i denne konfiguration; ignoreret"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "synlighedsegenskab er ikke understøttet i denne konfiguration; ignoreret"
@@ -31509,7 +31563,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -31531,7 +31585,7 @@ msgstr "-march=%s er ikke forenelig med den valgte ABI"
 msgid "%qE argument is not a function"
 msgstr "ingen parametre til specifikationsfunktion"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 #| msgid "second token after #line is not a string"
 msgid "deprecated message is not a string"
@@ -31942,12 +31996,12 @@ msgstr "heltalskonstanten er for stor for dens type"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "foreslår paranteser omkring tildeling der er benyttet som boolsk værdi"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -32125,13 +32179,13 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %qE"
 msgstr "for få parametre til funktionen"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
@@ -32246,7 +32300,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -32258,143 +32312,143 @@ msgstr "typen af den %d. parameter i '%s' passer ikke"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "venstre parameter skal være en skive"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of arguments to function %qE"
 msgstr "for få parametre til funktionen '%s'"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "size mismatch in argument %d of %qE"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid memory model argument %d of %qE"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator number is out of bounds"
 msgid "index value is out of bound"
 msgstr "akkumulatortal er uden for det gyldig interval"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size of array exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -32453,559 +32507,559 @@ msgstr "'%s' er en ukendt formateringsfunktionstype"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "formateringsstrengsparameter efterfølger parametrene der skal formateres"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "manglende $-operandnummer i formatering"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s understøtter ikke %%n$-operandnummerformateringer"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "operandnummer uden for det gyldige interval"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "formateringsparameter %d brugt mere end en gang i %s-formatering"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "operand number specified for format taking no argument"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "operandnummer angiver for formatering der ikke tager mod parametre"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "formateringsparameter %d ubenyttet før den brugte parameter %d i formatering med $"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "formatering er ikke en strengkonstant, formateringsstrengen er ikke kontrolleret"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "formatering er ikke en strengkonstant og der er ingen formateringsparametre"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "formatering er ikke en strengkonstant, parametertyper er ikke kontrolleret"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "for mange parametre til formatering"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "formateringsstreng %s med længden nul"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "formatering er en bredtegnsstreng"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string arg not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "formateringsstrengsparameter er ikke af en strengtype"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "uafsluttet formateringsstreng"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s understøtter ikke %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s with the `%%%c' %s format"
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s understøtter ikke %s med '%%%c' %s-formateringen"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "gentaget %s i formatering"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "mangler fyldtegn i slutningen af strfmon-formatering"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "bredde på nul i %s-formatering"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "tom venstrepræcision i %s-formatering"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "tom præcision i %s-formatering"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support the `%s' %s length modifier"
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s understøtter ikke '%s' %s-længdemodifikationen"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unknown conversion type character %qc in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support the `%%%s%c' %s format"
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s understøtter ikke '%%%s%c' %s-formateringen"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, fuzzy, gcc-internal-format
 #| msgid "%s ignored with %s and `%%%c' %s format"
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s ignoreret med %s og '%%%c' %s-formatering"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s ignoreret med %s i %s-formatering"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s and %s together with `%%%c' %s format"
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "brug af %s og %s sammen med '%%%c' %s-formatering"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "brug af %s og %s sammen i %s-formatering"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, fuzzy, gcc-internal-format
 #| msgid "`%%%c' yields only last 2 digits of year in some locales"
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "'%%%c' giver kun de to sidste cifre af året under nogle regionalindstillinger"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, fuzzy, gcc-internal-format
 #| msgid "`%%%c' yields only last 2 digits of year"
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "'%%%c' giver kun de to sidste cifre af året"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "no closing `]' for `%%[' format"
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "ingen afsluttende '[' til '%%['-formatering"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' length modifier with `%c' type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "brug af '%s'-længdemodifikation med '%c'-typetegn"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support the `%%%s%c' %s format"
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s understøtter ikke '%%%s%c' %s-formateringen"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "operandnummer angivet med undertrykt tildeling"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "operandnummer angiver for formatering der ikke tager mod parametre"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "gentaget %s i formatering"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "gentaget %s i formatering"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded `\\0' in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "indlejret '\\0' i formatering"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use %qs instead"
 msgstr "brug af '%s' i skabelon"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "unquoted attribute in format"
 msgstr "forskellige funktionsattributter"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing `%%' in format"
 msgid "spurious trailing space in format"
 msgstr "mystisk afsluttende '%%' i formatering"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "inconsistent capitalization in format"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unquoted control characters in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unquoted control character %qc in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing `%%' in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "mystisk afsluttende '%%' i formatering"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, fuzzy, gcc-internal-format
 #| msgid "form feed in preprocessing directive"
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr "sideskift i præprocessordirektiv"
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "gentaget %s i formatering"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "gentaget %s i formatering"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "gentaget %s i formatering"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing `%%' in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "mystisk afsluttende '%%' i formatering"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing `%%' in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "mystisk afsluttende '%%' i formatering"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "unquoted non-graph characters in format"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "undefined or invalid # directive"
 msgid "unterminated quoting directive"
 msgstr "ugyldigt eller ikke-defineret #-direktiv"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character `%c' in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "ukendt konverteringstypetegn '%c' i formatering"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing `%%' in format"
 msgid "spurious trailing %<%%%> in format"
 msgstr "mystisk afsluttende '%%' i formatering"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "konvertering mangler type i slutningen af formatering"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "undefined or invalid # directive"
 msgid "nested quoting directive"
 msgstr "ugyldigt eller ikke-defineret #-direktiv"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #ident directive"
 msgid "unmatched quoting directive"
 msgstr "ugyldigt #ident-direktiv"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, fuzzy, gcc-internal-format
 #| msgid "embedded `\\0' in format"
 msgid "embedded %<\\0%> in format"
 msgstr "indlejret '\\0' i formatering"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated comment"
 msgid "unterminated color directive"
 msgstr "uafsluttet kommentar"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "writing through null pointer (arg %d)"
 msgid "writing through null pointer (argument %d)"
 msgstr "skrivning gennem nulhenvisning (parameter %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reading through null pointer (arg %d)"
 msgid "reading through null pointer (argument %d)"
 msgstr "læsning gennem nulhenvisning (parameter %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "writing into constant object (arg %d)"
 msgid "writing into constant object (argument %d)"
 msgstr "skrivning til konstant objekt (parameter %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra type qualifiers in format argument (arg %d)"
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "ekstra typemodifikationer i formateringsparameter (parameter %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "'%s' forventer en konstant parameter"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "'%s' forventer en konstant parameter"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%<locus%> is not defined as a type"
 msgstr "\"%s\" er ikke defineret"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%qs is not defined as a type"
 msgstr "\"%s\" er ikke defineret"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%<tree%> is not defined as a type"
 msgstr "\"%s\" er ikke defineret"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not '...'"
 msgid "argument to be formatted is not %<...%>"
 msgstr "parametrene der skal formateres, er ikke '...'"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-formater kan ikke formatere parametre"
@@ -33181,7 +33235,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -33199,19 +33253,19 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
@@ -33222,7 +33276,7 @@ msgstr "manglende ')' i udtryk"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -33887,7 +33941,7 @@ msgid "wrong type argument to %s"
 msgstr "forkert parametertype til %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overløb i konstant udtryk"
@@ -34650,7 +34704,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "comparison between types %qT and %qT"
@@ -34735,7 +34789,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 msgstr[1] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, fuzzy, gcc-internal-format
 #| msgid "the conditional began here"
 msgid "this condition has identical branches"
@@ -34756,7 +34810,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "defined here"
@@ -34777,7 +34831,7 @@ msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 msgid "too many input files"
 msgstr "for mange inddatafiler"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -34812,15 +34866,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s"
@@ -35390,446 +35444,453 @@ msgstr "aliasdefinitioner er ikke understøttet i denne konfiguration; ignoreret
 msgid "profiler support for VxWorks"
 msgstr "function_profiler-understøttelse for MMIX"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "uventede bivirkninger i adresse"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "uventede bivirkninger i adresse"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<,%> eller %<)%> forventet"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa NSA option"
 msgid "this operation requires the SVE ISA extension"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa NSA option"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "invalid format for sve_width"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %h value"
 msgid "invalid sve_width value: %d"
 msgstr "ugyldig %h-værdi"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "tuning string missing in option (%s)"
 msgstr "ugyldigt interval %s i tilvalg %s"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function `%s'"
 msgid "unknown tuning option (%s)"
 msgstr "ukendt specifikationsfunktion '%s'"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Angiv registerallokeringsordnen"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s;"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "ukendt maskintilstand '%s'"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing arch name in %<-march=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "unknown value %qs for %<-march%>"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "et filnavn mangler efter '-%s'"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "tilvalget -mcpu=%s er i konflikt med tilvalget -march="
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed spec function name"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "forkert udformet specifikationsfunktionsnavn"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the %qs debug format"
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "målarkitektursystem understøtter ikke %qs-fejlsøgningsformatet"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "lane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "versionen er ikke understøttet"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "The -shared option is not currently supported for VAX ELF."
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -36029,17 +36090,17 @@ msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -36215,13 +36276,13 @@ msgstr "ukendt registernavn: %s"
 msgid "invalid type for %<asm%> flag output"
 msgstr "ugyldig type for make-funktion"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "options enabled: "
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "tilvalg slået til: "
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -36229,197 +36290,197 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "this builtin is not supported for this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "vælger skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -36429,308 +36490,308 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 #| msgid "-msystem-v and -p are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-msystem-v og -p er indbyrdes uforenelige"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "target CPU does not support ARM mode"
 msgstr "målprocessoren understøtter ikke APCS-32"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "aktivering af tilbagesporingsunderstøttelse giver kun mening ved oversættelse for en Thumb"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "aktivering af interarbejdeunderstøttelse for kaldte objekter giver kun mening ved oversættelse for en Thumb"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g med -mno-apcs-frame giver måske ikke fornuftig fejlanalysering"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use typeid with -fno-rtti"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "kan ikke bruge typeid med -fno-rtti"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-G is incompatible with PIC code which is the default"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-G er uforenelig med PIC-kode som genereres som standard"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic og -mapcs-reent er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS-genindtrædelig kode er ikke understøttet - ignoreret"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to 8 or 32"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= er ubrugelig uden -fpic"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "kan ikke bruge '%s' til PIC-register"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable og -msdata=%s er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan ikke beregne virkelig placering af stakkede parametre"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "ingen lave registre er tilgængelige til at modtage værdier fra høje registre"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -36739,24 +36800,24 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -36848,19 +36909,19 @@ msgstr "-pipe understøttes ikke"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional and -ansi are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-traditional og -ansi er indbyrdes uforenelige"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have arguments"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%qs function cannot return a value"
@@ -37148,7 +37209,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument to built-in function"
@@ -37506,57 +37567,57 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "Overbring parametre i registre"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "wrong type of argument %s"
 msgstr "forkert parametertype til %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "nested function trampolines not supported on this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "indlejrede funktionstrampoliner er ikke understøttet på denne målarkitektur"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented\n"
 msgid "TLS is not implemented for GCN."
 msgstr "DW_LOC_OP %s understøttes ikke\n"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented\n"
 msgid "Builtin not implemented"
 msgstr "DW_LOC_OP %s understøttes ikke\n"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "operandtal er uden for det gyldige interval"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "virtual memory exhausted"
 msgid "local data-share memory exhausted"
@@ -37708,154 +37769,154 @@ msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 msgid "parameter to builtin not valid: %s"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "skifteværdi skal være en umiddelbar værdi"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -38274,156 +38335,156 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -38903,7 +38964,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -40067,56 +40128,56 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "--resource påkræver -o"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have different interrupt type"
@@ -40243,372 +40304,373 @@ msgstr "tal skal enten være 0 eller 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "ragelse i slutningen af #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin %qs requires builtin %qs"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ugyldigt register i instruktionen"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs already processed"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs understøttes ikke af denne målarkitektur"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "Argument must be a value between 0 and 3."
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "Argument must be a value between 0 and 7."
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qs must be a constant"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s accepterer kun 1 parameter"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "#%s med ugyldig parameter"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "#%s med ugyldig parameter"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "this media function is only available on the fr400"
 msgid "%qs is only valid for the cell processor"
 msgstr "denne mediafunktion er kun tilgængelig på fr400"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "%qs requires the %qs option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "%qs requires the %qs and %qs options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "%qs is not supported with the current options"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
@@ -40632,237 +40694,242 @@ msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC-målarkitektur er ikke understøttet på denne maskine"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid reference type"
 msgid "%qs requires %qs or %qs"
 msgstr "Ugyldig referencetype"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 kræver at PowerPC64-arkitekturen forbliver aktiveret"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring er ikke understøttet på lilleendede systemer"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "Udsend kode der er kompatibel med TI-værktøjer"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qs requires %qs"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "ukendt registernavn: %s"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t use %qs as a call-used register"
 msgid "%qs needs a valid base register"
 msgstr "kan ikke bruge %qs som et kald-brugt register"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%s har ingen %s"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ugyldig parametertype '%T'"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s%qs%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
@@ -41217,147 +41284,147 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, fuzzy, gcc-internal-format
 #| msgid "Total size of local variables exceeds architecture limit."
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Total størrelse af lokale variable overstiger arkitekturgrænsen."
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "%Jstørrelsen af '%D' er %d byte"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "-f%s er ikke understøttet: ignoreret"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -41823,8 +41890,8 @@ msgstr "egenskaben '%s' kan kun anvendes på variabler"
 msgid "could not read the BRIG file"
 msgstr "kunne ikke finde specifikationsfilen %s\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tom værdi er ikke ignoreret som den burde være"
@@ -42119,7 +42186,7 @@ msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 msgid "declaration of %qD shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "declaration of %qD shadows a global declaration"
@@ -42204,7 +42271,7 @@ msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(et kaldenavn der ikke er erklæret, rapporteres kun én gang per funktion)"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, fuzzy, gcc-internal-format
 #| msgid "label %s referenced outside of any function"
 msgid "label %qE referenced outside of any function"
@@ -42239,7 +42306,7 @@ msgstr "overløb i konstant udtryk"
 msgid "duplicate label declaration %qE"
 msgstr "etiketten '%s' er blevet erklæret mere end én gang"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "duplicate label %qD"
@@ -42459,7 +42526,7 @@ msgstr "kan ikke anbringe et objekt med et volatile-felt i et register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "konstant '%D' uden startværdi"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -42848,7 +42915,7 @@ msgstr "typenavn er erklæret som en funktion, der returnerer en array"
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
@@ -43189,7 +43256,7 @@ msgstr "indlejret omdefinering af '%s'"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
@@ -43245,7 +43312,7 @@ msgstr "navngivne medlemmer"
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
@@ -43284,7 +43351,7 @@ msgstr "indlejret omdefinering af '%s'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "omerklæring af 'enum %s'"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -43317,7 +43384,7 @@ msgstr "enum-værdier for store"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline funktion '%s' givet egenskaben noinline"
@@ -43349,7 +43416,7 @@ msgstr "ingen tidligere prototype for '%s'"
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
@@ -43469,12 +43536,12 @@ msgstr "parameteren '%s' passer ikke til prototypen"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -43483,283 +43550,283 @@ msgstr "etiketten '%D' er defineret, men ikke benyttet"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "'struct %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "'union %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "'enum %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der ikke er en variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "gentaget erklæring af enheden '%s'"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "'long long long' er for langt for GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "'%s' optræder mere end én gang"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<__int%d%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' fails to be a typedef or built in type"
 msgid "%qE fails to be a typedef or built in type"
 msgstr "'%s' er hverken en typedef eller en indbygget type"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `extern'"
 msgid "%<__thread%> before %<extern%>"
 msgstr "'__thread' før 'extern'"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `static'"
 msgid "%<__thread%> before %<static%>"
 msgstr "'__thread' før 'static'"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %qE"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "højreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -43781,7 +43848,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "  anden type her"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -43832,7 +43899,7 @@ msgid "unknown type name %qE"
 msgstr "ukendt registernavn: %s"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -43854,7 +43921,7 @@ msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -43871,8 +43938,8 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 msgid "unexpected attribute"
 msgstr "uventet operand"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
@@ -43910,7 +43977,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -43940,7 +44007,7 @@ msgstr "ISO C90 understøtter ikke komplekse typer"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected string literal"
@@ -43975,7 +44042,7 @@ msgstr "startværdien for den statiske variabel er ikke en konstant"
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed"
@@ -44025,14 +44092,14 @@ msgstr "skabelonsparameter %d er ugyldig"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutningen af enum-liste"
@@ -44122,7 +44189,7 @@ msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute does not take any arguments"
@@ -44134,7 +44201,7 @@ msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -44200,7 +44267,7 @@ msgstr "ISO C89 forbyder blandede erklæringer og kode"
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -44215,7 +44282,7 @@ msgstr "forældet brug af etiket i slutningen af sammensat sætning"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "uventet operand"
@@ -44241,18 +44308,18 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr ""
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous `else'"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -44275,12 +44342,12 @@ msgstr "flere erklærerer i skabelonserklæring"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ugyldigt register i instruktionen"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44296,8 +44363,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "case-værdi optræder mere end én gang"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
 msgid "first seen here"
 msgstr "  første type her"
@@ -44328,12 +44395,12 @@ msgstr "ISO C forbyder udeladelse af den midterste del af et '?:'-udtryk"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -44763,62 +44830,62 @@ msgstr "Klasse- eller grænsefladeerklæring forventet"
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "en dataområdeegenskab kan ikke angives for lokale variable"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -44829,18 +44896,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -44864,60 +44931,60 @@ msgstr "%<,%> eller %<)%> forventet"
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -44940,12 +45007,12 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<priority%> value must be non-negative"
@@ -44957,25 +45024,25 @@ msgstr "%s-roteringsantal er negativt"
 msgid "expected constant integer expression"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<defaultmap%> clauses with unspecified category"
@@ -44993,58 +45060,58 @@ msgstr "udsagn skal være et kaldenavn"
 msgid "%qs value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "for mange parametre"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected argument"
 msgstr "uventet operand"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "forventede %<new%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -45055,7 +45122,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -45090,25 +45157,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -45125,79 +45192,79 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -45214,7 +45281,7 @@ msgstr "'%#D' kan ikke erklæres"
 msgid "expected function name"
 msgstr "forventet funktion"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a function"
@@ -45225,73 +45292,73 @@ msgstr "'%D' er ikke en medlemsskabelonfunktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many memory order clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -45301,63 +45368,63 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
@@ -45368,73 +45435,73 @@ msgstr "gentaget erklæring af automaten '%s'"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -45449,65 +45516,65 @@ msgstr "en global registervariabel følger en funktionsdefinition"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected trait selector name"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifier `%s' not allowed after struct or class"
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "typemodifikationen '%s' er ikke tilladt efter struct eller class"
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "selector %qs does not accept any properties"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "score argument must be constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "score argument must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected identifier or string literal"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "property must be constant integer expression"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -45519,13 +45586,13 @@ msgstr "forventede %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s og -msdata=%s er indbyrdes uforenelige"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -45535,32 +45602,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -45616,45 +45683,45 @@ msgstr "uventet operand"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "code model `large' not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "kodemodellen 'large' er ikke understøttet endnu"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -45671,27 +45738,27 @@ msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -45702,7 +45769,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> funktionskald er ikke inden for ydre transaktion eller %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -45719,7 +45786,7 @@ msgstr "fejl ved lukning af %s: %m"
 msgid "%qD has an incomplete type %qT"
 msgstr "'%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ugyldig brug af void-udtryk"
@@ -45850,7 +45917,7 @@ msgstr "forsøg på at følge en 'void *'-henvisning"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "tabelindeks er ikke et heltal"
@@ -45877,7 +45944,7 @@ msgstr "ISO C90 forbyder opslag i tabel der ikke er venstreværdi"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -46008,19 +46075,19 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "for få parametre til funktionen"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%Jsvag erklæring af '%D' efter første brug resulterer i ikke-defineret opførsel"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "sammenligning mellem henvisningsvariabel og heltal"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -46048,7 +46115,7 @@ msgstr "henvisning til en funktion benyttet i subtraktion"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -46327,7 +46394,7 @@ msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typeomtvingelse fra heltal til henvisning af en anden størrelse"
@@ -46522,7 +46589,7 @@ msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
@@ -46713,7 +46780,7 @@ msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
@@ -46745,7 +46812,7 @@ msgstr "startværdielement kan ikke beregnes ved indlæsningstidspunktet"
 msgid "invalid initializer"
 msgstr "ugyldig startværdi"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
@@ -46898,7 +46965,7 @@ msgstr "for mange elementer i skalarstartværdi"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C forbyder 'goto *udtryk;'"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -46945,7 +47012,7 @@ msgstr "'long'-udtryk i switch konverteres ikke til 'int' i ISO C"
 msgid "case label is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
@@ -46956,17 +47023,17 @@ msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 msgid "%<default%> label not within a switch statement"
 msgstr "'default'-etiket befinder sig ikke inden i en switch-sætning"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
@@ -46984,7 +47051,7 @@ msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement with no effect"
@@ -46995,24 +47062,24 @@ msgstr "%Hsætning uden nogen virkning"
 msgid "expression statement has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "operandbegrænsninger til 'asm' har forskellige antal alternativer"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -47067,7 +47134,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
@@ -47101,57 +47168,57 @@ msgstr "værdi af union-type angivet hvor skalar er påkrævet"
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -47163,8 +47230,8 @@ msgstr "'%s' er et ugyldigt klassenavn"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
@@ -47351,12 +47418,12 @@ msgstr "brug af '%D' er tvetydigt"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -47382,8 +47449,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
@@ -47399,19 +47466,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -47488,120 +47555,120 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE er hverken en variabel eller et funktionsnavn i klausul %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `va_arg' not of type `va_list'"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "den første parameter til 'va_arg' er ikke af typen 'va_list'"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -47809,157 +47876,157 @@ msgid "expected case label"
 msgstr "forventet etiket"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T, %T) <indbygget>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T) <indbygget>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s %D(%T) <indbygget>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s %T <konvertering>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 msgid "  inherited here"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "konvertering fra '%T' til '%T' er tvetydigt"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, fuzzy, gcc-internal-format
 #| msgid "call of overloaded `%D(%A)' is ambiguous"
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
@@ -47967,713 +48034,713 @@ msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "henvisning til medlemsfunktionen %E kan ikke kaldes uden et objekt; overvej at benytte .* eller ->*"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to `(%T) (%A)'"
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen passende fundet for kald til '(%T) (%A)'"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "tvetydig konvertering af tabelindeks"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "operanden er r0"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: %s"
 msgid "ternary %<operator?:%>"
 msgstr "intern fejl: %s"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ forbyder udeladelse af den mellemste del af et ?:-udtryk"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: `%T' vs `%T'"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "enum-typer passer ikke sammen i betinget udtryk: '%T' og '%T'"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %q#T and %q#T"
 msgstr "sammenligning mellem '%#T' og '%#T'"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passende 'operator delete' for '%T'"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared private here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared protected here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "'%+#D' er ikke tilgængelig"
 
 # %s bliver til returnering eller tildeling eller noget i den retning
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, fuzzy, gcc-internal-format
 #| msgid "passing NULL used for non-pointer %s %P of `%D'"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "overbringelse af NULL benyttet for ikke-henvisnings%s %P af '%D'"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "  declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, fuzzy, gcc-internal-format
 #| msgid "%s to non-pointer type `%T' from NULL"
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s til ikke-henvisningstypen '%T' fra NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %qD"
 msgstr "  ved klargøring af parameteren %P til '%D'"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around initializer for %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "kan ikke erklære feltet '%D' til at være af typen '%T'"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type `%#T' through `...'"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan ikke modtage objekter af en ikke-POD type '%#T' gennem '...'"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr "  i kald af '%D'"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "; use value-initialization instead"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use copy-assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "; use copy-initialization instead"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%#qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan ikke kalde destruktionsfunktion '%T::~%T' uden objekt"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "kan ikke kalde medlemsfunktionen '%D' uden et objekt"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "videregivelse af '%T' vælger '%T' frem for '%T'"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "vælger '%D' frem for '%D'"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  fordi konverteringssekvensen for parameteren er bedre"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
@@ -48707,595 +48774,595 @@ msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "strider mod tidligere erklæring '%#D'"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "version inherited from %qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' and `%#D' cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
 # hænger sammen med næste tekst
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting access specifications for method `%D', ignored"
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "modstridende tilgangsanvisninger til metoden '%D', ignoreret"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting access specifications for field `%s', ignored"
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "modstridende tilgangsanvisninger til feltet '%s', ignoreret"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method `%#D' with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  på grund af den lokale metode '%#D' med det samme navn"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "local method %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member `%#D' with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  på grund af det lokale medlem '%#D' med det samme navn"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "local member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base `%T' to derived type `%T' via virtual base `%T'"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, fuzzy, gcc-internal-format
 #| msgid "all member functions in class `%T' are private"
 msgid "all member functions in class %qT are private"
 msgstr "alle medlemsfunktioner i klassen '%T' er private"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines a private destructor and has no friends"
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "'%#T' definerer kun en privat destruktionsfunktion og har ingen venner"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines private constructors and has no friends"
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "'%#T' definerer kun private konstruktionsfunktioner og har ingen venner"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
 # %D er en funktion
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, fuzzy, gcc-internal-format
 #| msgid "no unique final overrider for `%D' in `%T'"
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik endelig overskrivning af '%D' i '%T'"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' and `%#D' cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was hidden"
 msgid "%qD was hidden"
 msgstr "'%D' var skjult"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "  by `%D'"
 msgid "  by %qD"
 msgstr "  af '%D'"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
 msgstr "-traditional er forældet og kan blive fjernet"
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%D' width not an integer constant"
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredden af bitfeltet '%D' er ikke en heltalskonstant"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%D'"
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredde i bitfeltet '%D'"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%D'"
 msgid "zero width for bit-field %q+D"
 msgstr "en bredde på nul for bitfeltet '%D'"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%D' exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "bredden af '%D' overstiger typen"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is too small to hold all values of `%#T'"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "'%D' er for lille til at indeholde alle værdierne af '%#T'"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with constructor not allowed in union"
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlemmet '%#D' med en konstruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with destructor not allowed in union"
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlemmet '%#D' med en destruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with copy assignment operator not allowed in union"
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlemmet '%#D' med en kopitildelingsoperator er ikke tilladt i en union"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "feltet '%D' er på ugyldig vis erklæret som en funktionstype"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, fuzzy, gcc-internal-format
 #| msgid "multiple fields in union `%T' initialized"
 msgid "multiple fields in union %qT initialized"
 msgstr "flere felter i union '%T' tildeles startværdi"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field `%#D' with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "felt '%#D' med samme navn som klassen"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has pointer data members"
 msgid "%q#T has pointer data members"
 msgstr "'%#T' har henvisningsdatamedlemmer"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `%T(const %T&)'"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  men overskriver ikke '%T(const %T&)'"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, fuzzy, gcc-internal-format
 #| msgid "  or `operator=(const %T&)'"
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller 'operator=(const %T&)'"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `operator=(const %T&)'"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  men overskriver ikke 'operator=(const %T&)'"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method `%D'"
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "startværdi angivet for ikke-virtuel medlemsfunktion '%D'"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%q+T is not literal because:"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "  non-static data member %qD has volatile type"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference `%#D' in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "ikke-statisk reference '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D' in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "ikke-statisk konstant medlem '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, fuzzy, gcc-internal-format
 #| msgid "direct base `%T' inaccessible in `%T' due to ambiguity"
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, fuzzy, gcc-internal-format
 #| msgid "virtual base `%T' inaccessible in `%T' due to ambiguity"
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuel stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of `%D' is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "afsættet for '%D' følger ikke ABI'en og kan ændre sig i en fremtidig version af GCC"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ugyldig brug af %<...%> med ikke-skive"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "array member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "'%#T' har virtuelle funktioner, men ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "type transparent %q#T does not have any fields"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "  eftersom typen '%T' har abstrakte virtuelle funktioner"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "forsøgte at afslutte struct, men blev stoppet af tidligere fortolkningsfejl"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "language string `\"%s\"' not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "sprogstrengen '\"%s\"' ikke genkendt"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, fuzzy, gcc-internal-format
 #| msgid "cannot resolve overloaded function `%D' based on conversion to type `%T'"
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "kan ikke benytte den flertydiggjorte funktion '%D' baseret på konvertering til typen '%T'"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, fuzzy, gcc-internal-format
 #| msgid "no matches converting function `%D' to type `%#T'"
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen passende ved konvertering af funktionen '%D' til typen '%#T'"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, fuzzy, gcc-internal-format
 #| msgid "converting overloaded function `%D' to type `%#T' is ambiguous"
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering af den flertydiggjorte funktion '%D' til typen '%T' er tvetydig"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "assuming pointer to member `%D'"
 msgid "assuming pointer to member %qD"
 msgstr "antager henvisning til medlemmet '%D'"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan ikke konvertere '%E' fra typen '%T' til typen '%T'"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "%qD declared here as %q#D"
@@ -49382,7 +49449,7 @@ msgstr "tom erklæring"
 msgid "%q+E is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to internal function %qE"
@@ -49443,7 +49510,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-%<constexpr%> function %qD"
@@ -49505,414 +49572,413 @@ msgstr ""
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized array element"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "allocated here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "'%s' er ikke en funktion,"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "'%+#D' er privat"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline assembly is not a constant expression"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "uventet operand"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
 msgstr "uventet type for 'id' (%s)"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qD is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -49962,7 +50028,7 @@ msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "casting %qT to %qT does not dereference pointer"
@@ -50009,327 +50075,327 @@ msgstr "'%#T' benyttet hvor der forventedes en kommatalsværdi"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "konvertering fra '%T' til en ikke-skalartype '%T' udbedt"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "in call to %qD, declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konvertering til en ufuldstændig type"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of type `%T'"
 msgid "conversion to void will not access object of type %qT"
 msgstr "kan ikke allokere et objekt af typen '%T'"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement has no effect"
 msgstr "%Hsætning uden nogen virkning"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous default type conversion from `%T'"
 msgid "ambiguous default type conversion from %qT"
 msgstr "tvetydig standardtypekonvertering fra '%T'"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, fuzzy, gcc-internal-format
 #| msgid "  candidate conversions include `%D' and `%D'"
 msgid "  candidate conversions include %qD and %qD"
@@ -50404,7 +50470,7 @@ msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "erklæring af '%D' som %s"
 
 # hænger sammen med næste tekst
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -50615,13 +50681,13 @@ msgstr "tidligere erklæring af '%#D' her"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%D' in same scope"
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overflødig omerklæring af '%D' i samme virkefelt"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "deleted definition of %qD"
@@ -50635,48 +50701,48 @@ msgstr "indlejret omdefinering af '%s'"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD after first use"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#D"
 msgstr "omdefinering af '%#T'"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' conflicts with previous using declaration `%#D'"
 msgid "%qD conflicts with used function"
 msgstr "'%#D' strider mod tidligere using-erklæring '%#D'"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%q#D not declared in class"
 msgstr "'%D' ikke erklæret"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -50684,736 +50750,736 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal erklæring af '%s' følger ikke-trådlokal erklæring"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ikke-trådlokal erklæring af '%s' følger trådlokal erklæring"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overflødig omerklæring af '%s' i samme virkefelt"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "en tidligere lokal variabel"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  herfra"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of `%#D'"
 msgid "  crosses initialization of %q#D"
 msgstr "  krydser klargøring af '%#D'"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  går ind i catch-blok"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "uventet operand"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of `%#D'"
 msgid "  skips initialization of %q#D"
 msgstr "  springer over klargøring af '%#D'"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "'%D' benyttet uden skabelonsparametre"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a template"
 msgid "%q#T is not a class"
 msgstr "'%#T' er ikke en skabelon"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named `%#T' in `%#T'"
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klasseskabelon ved navn '%#T' i '%#T'"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 #| msgid "no type named `%#T' in `%#T'"
 msgid "no type named %q#T in %q#T"
 msgstr "ingen type ved navn '%#T' i '%#T'"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameters do not match template %qD"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d understøttes ikke"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med konstruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med destruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med kopitildelingsoperator er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flere typer i én erklæring"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omerklæring af indbygget type i C++ '%T'"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "manglende typenavn i typedef-erklæring"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ forbyder anonyme strukturer"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "'%D' kan kun angives for konstruktionsfunktioner"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "tom erklæring"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
 # init dækker over værditildeling her - samme for de næste mange
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef '%D' bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillader ikke '%T::%D' at blive defineret som '%T::%D'"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variablen '%#D' bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "den sammensatte type '%#D' er af en ufuldstændig type og kan ikke defineres"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ikke-trivielle udpegede startværdier er ikke understøttet"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "startværdien giver ikke størrelsen af %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "tabelstørrelsen mangler i %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nulstørrelsestabel %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstørrelsen af %qD er ikke kendt"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  du kan arbejde dig rundt om dette ved at fjerne startværdien"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized %<const %D%>"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "typen '%T' har ingen destruktionsfunktion"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "startværdi for '%T' skal være indesluttet i krøllede paranteser"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "ugyldig startværdi"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C89 forbyder sammensatte konstanter"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "'%D' skal klargøres af en konstruktionsfunktion, ikke af '{...}'"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktionsfunktion"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en klargøring uden for klassens erklæring er nødvendig)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "medlem '%D' med konstante felter uden startværdi"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "could not find variant declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillader ikke %<register%>-lagerklasseangivelse"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "%<register%> storage class specifier used"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skygger for tidligere typeerklæring af '%#D'"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%u name provided for structured binding"
@@ -51421,222 +51487,222 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "lagringsklasse angivet for strukturfelt '%s'"
 msgstr[1] "lagringsklasse angivet for strukturfelt '%s'"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "in initialization of structured binding variable %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose union type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "'%D' erklæret som 'virtual' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method '%D' has non-Java return type `%T'"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -51946,7 +52012,7 @@ msgstr "tabeldimension for stor"
 msgid "%qD declared as array of %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
@@ -52137,7 +52203,7 @@ msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
@@ -52369,933 +52435,933 @@ msgstr "egenskaben '%s' ignoreret"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "requires-clause on return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ugyldig brug af '%D"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "constructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referencen %qs kan ikke erklæres %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type %qD med samme navn som den omgivende klasse"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet for friend class-erklæring"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen %qT til ven af det globale virkningsfelt"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter `%D' to be of type `%T'"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "kan ikke erklære parameteren '%D' til at være af typen '%T'"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %qs"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a constructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "kan ikke åbne %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a nonstatic member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -53307,104 +53373,104 @@ msgstr "'%#D' omerklæret som %C"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in the class %T"
 msgid "%qT defined with multiple direct bases"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "%qT defined with direct virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -53414,81 +53480,81 @@ msgstr "parameter til '%s' skal være en 2 bit-konstant"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -53533,7 +53599,7 @@ msgstr "kan ikke udføre delete på en funktion; kun henvisninger til objekter e
 msgid "deleting %qT is undefined"
 msgstr "benyttelse af delete på '%T' er ikke defineret"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -53545,7 +53611,7 @@ msgstr "skabelonserklæring af '%#D'"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
@@ -53912,169 +53978,169 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "use of template qualifier outside template"
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "brug af skabelonsmodifikation uden for skabelon"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "ingen parametre"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, fuzzy, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "%qD is not a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -54281,369 +54347,369 @@ msgstr "standardklargøring af '%#D' som er af en referencetype"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "'%D' bør blive klargjort i medlemsklargøringslisten"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "klassen '%T' er underforstået ven med sig selv"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid initializer for array member %q#D"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %q#T"
 msgstr "konstant medlem '%D' uden startværdi"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, fuzzy, gcc-internal-format
 #| msgid "base `%T' will be initialized after"
 msgid "base %qT will be initialized after"
 msgstr "stamklasse '%T' vil blive klargjort efter"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, fuzzy, gcc-internal-format
 #| msgid "  base `%T'"
 msgid "  base %qT"
 msgstr "  stamklasse '%T'"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for `%D'"
 msgid "multiple initializations given for %qD"
 msgstr "flere startværdier angivet for '%D'"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for base `%T'"
 msgid "multiple initializations given for base %qT"
 msgstr "flere startværdier angivet for stamklassen '%T'"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 #| msgid "initializations for multiple members of `%T'"
 msgid "initializations for multiple members of %qT"
 msgstr "startværdier for flere medlemmer af '%T'"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "stamklassen '%#T' bør eksplicit blive klargjort i kopikonstruktionsfunktionen"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "class %qT does not have any field named %qD"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "feltet '%#D' er statisk; det eneste sted det kan klargøres er ved dets definition"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which has no base classes"
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which uses multiple inheritance"
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unavngiven klargøring af '%T' som benytter multipel nedarvning"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, fuzzy, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qT is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "heltalsoverløb i udtryk"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "strenge med dobbelte anførselstegn er ikke tilladte i #if-udtryk"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `void' for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "ugyldig type 'void' til new"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "feltet '%s' blev ikke fundet i klassen"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous"
 msgid "request for member %qD is ambiguous"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "startværdien slutter for tidligt"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukendt tabelstørrelse i delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
@@ -54816,13 +54882,13 @@ msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D', can't use default assignment operator"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "ikke-statisk konstant medlem '%#D' kan ikke bruge standardtildelingsoperatoren"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member `%#D', can't use default assignment operator"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -54850,170 +54916,176 @@ msgstr "forkert parametertype til %s"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take `void'"
 msgid "defaulted %qD must be %<const%>"
 msgstr "'%D' skal tage mod 'void'"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+#| msgid "%smember function `%D' cannot have `%T' method qualifier"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "'%T' er allerede en ven af '%T'"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot default compare union %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot default compare reference member %qD"
 msgstr "kan ikke oprette henvisning til reference medlemmet '%D'"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 #| msgid "Only constructors can invoke constructors"
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "Kun konstruktionsfunktioner kan kalde konstruktionsfunktioner"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 #| msgid "Only constructors can invoke constructors"
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "Kun konstruktionsfunktioner kan kalde konstruktionsfunktioner"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "startværdi for %q#D er ugyldig"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "(use `=' to initialize static data members)"
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "(brug '=' for at klargøre statiske datamedlemmer)"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, fuzzy, gcc-internal-format
 #| msgid "(use `=' to initialize static data members)"
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "(brug '=' for at klargøre statiske datamedlemmer)"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "expected signature: %qD"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
@@ -55057,232 +55129,232 @@ msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktions
 msgid "declaration of %q#D shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration `%#D'"
 msgid "local external declaration %q#D"
 msgstr "global erklæring '%#D'"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "does not match previous declaration %q#D"
 msgstr "strider mod tidligere erklæring '%#D'"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T::%D%> names destructor"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate type qualifiers in %s declaration"
 msgid "explicit qualification in declaration of %qD"
 msgstr "dobbelte typemodifikationer i %s-erklæring"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should have been declared inside `%D'"
 msgid "%qD should have been declared inside %qD"
 msgstr "'%D' skulle have været erklæret inden i '%D'"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "it was later defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, fuzzy, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, fuzzy, gcc-internal-format
 #| msgid "namespace alias `%D' not allowed here, assuming `%D'"
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "navnerumsalias '%D' er ikke tilladt her, antager '%D'"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "cannot nest more than %d namespaces"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -55308,7 +55380,7 @@ msgstr "kaldenavnet '%s' er i modstrid med den interne navngivningsstrategi i GN
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
@@ -55335,7 +55407,7 @@ msgstr "'%#D' kan ikke erklæres"
 msgid "request for member %qE in non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -55427,7 +55499,7 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -55556,7 +55628,7 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
@@ -55683,7 +55755,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -55794,12 +55866,12 @@ msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a template"
@@ -55836,7 +55908,7 @@ msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 msgid "expected nested-name-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "new kan ikke bruges på en referencetype"
@@ -55852,7 +55924,7 @@ msgstr "new kan ikke bruges på en referencetype"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -55868,7 +55940,7 @@ msgstr "ISO C++ forbyder sammensatte konstanter"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
@@ -55895,998 +55967,1003 @@ msgstr "ISO C++ tillader ikke %<alignof%> med en ikke-type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
 msgstr "typer kan ikke defineres i et nyt udtryk"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer kan ikke defineres i et nyt udtryk"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, fuzzy, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected expression-list or type-id"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "brug af ældre type typeomtvingning"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "foreslår paranteser omkring && inden i ||"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ tillader ikke ?: med udeladt midter operand"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, fuzzy, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "ISO C forbyder brug af typeomtvingningsudtryk som venstreværdier"
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to references"
 msgid "%<this%> cannot be captured by reference"
 msgstr "kan ikke erklære %s til referencer"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only variable `%s'"
 msgid "capture of non-variable %qE"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<...%> in lambda capture"
 msgstr "for mange inddatafiler"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "default argument specified for lambda parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<mutable%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, fuzzy, gcc-internal-format
 #| msgid "case label `%E' not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "case-etiket '%E' befinder sig ikke inden i en switch-sætning"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 #| msgid "In statement function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "I sætningsfunktion"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "condition declares an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "condition declares a function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "new kan ikke bruges på en referencetype"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 #| msgid "empty scalar initializer"
 msgid "expected initializer"
 msgstr "tom skalarstartværdi"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flere erklæringer '%T' og '%T'"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "tom erklæring"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "ugyldig startværdi til bitstreng"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' invalid in `%#T'"
 msgid "%qD invalid in lambda"
 msgstr "'%D' ugyldig i '%#T'"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "type-specifier invalid in lambda"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "cannot expand initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "forældet stamklasseklargøring"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expected suffix identifier"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type modifier within pointer declarator"
 msgid "invalid encoding prefix in literal operator"
 msgstr "ugyldig typemodifikation i erklæring af henvisning"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "uventet operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `export' not implemented, and will be ignored"
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "uventet operand"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "uventet operand"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "uventet operand"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "uventet operand"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 #| msgid "sigof type specifier"
 msgid "expected type specifier"
 msgstr "sigof-typeangivelse"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "forventet skabelon-id for typen"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "forventet type-navn"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "concept defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "uventet operand"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ekstra kvalifikation er ikke tilladt"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ forbyder tomme unavngivet enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD er ikke et navnerum-navn"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "forventet navnerum-navn"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "uventet operand"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "navnerumnavn krævet"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "function with nested functions cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "funktion med indlejrede funktioner kan ikke indbygges"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace %qD entered"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%D' is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%J'%D' er ikke defineret uden for funktionsvirkefelt"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "'%T' er ikke et navnerum"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition er ikke tilladt her"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array bound is not an integer constant"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<%T::%E%> is not a type"
@@ -56896,461 +56973,461 @@ msgstr "'%D::%D' er ikke en skabelon"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ugyldig erklærer"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "tom erklæring"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is a namespace"
 msgid "%qD is a namespace"
 msgstr "'%D' er et navnerum"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate cv-qualifier"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource påkræver -o"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "ugyldig brug af '%T'"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "forventede %<,%> eller %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillader ikke GNU-udpegede startværdier"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillader ikke C99-udpegede startværdier"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> er ikke tilladt i udpegede startværdiliste"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "forventet klasse-navn"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "forventede %<{%> eller %<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "kan ikke finde filen for klassen %s"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "tidligere definition af '%#T'"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ugyldig brug af %<auto%> i undtagelsesspecifikation"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected attribute before %<...%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expression must be enclosed in parentheses"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "asm template is not a string constant"
 msgid "result type is not a plain type-constraint"
 msgstr "asm-sætning er ikke en strengkonstant"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "angivet justering er ikke en konstant"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -57359,573 +57436,573 @@ msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching concept for template-introduction"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> forventet"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T var tidligere erklæret her"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "'%D' ikke erklæret"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "uventet operand"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qT defined as %qs here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as `%#D' here"
 msgid "%qT first declared as %qs here"
 msgstr "  først erklæret som '%#D' her"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omerklæret med anden adgang"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected integer expression list"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -58233,7 +58310,7 @@ msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
@@ -58263,77 +58340,77 @@ msgstr "erklæring af '%#D' skygger for en parameter"
 msgid "template parameter %qD declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments for partial specialization %qT"
 msgstr "for mange parametre til funktionen"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "primary template %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "template argument %qE involves template parameter(s)"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
 # flertalsform unødvendig
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -58341,19 +58418,19 @@ msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 msgstr[1] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -58362,53 +58439,53 @@ msgstr "ingen standardparameter til '%D'"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "template %qD declared"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "skabelonsklasse uden et navn"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -58418,66 +58495,66 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "skabelonsdefinition af ikke-skabelon '%#D'"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "forvented %d niveauer af skabelonsparametre for '%#D', modtog %d"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "modtog %d skabelonsparametre for '%#T'"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d påkrævet"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -58485,7 +58562,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "'%D' benyttet uden skabelonsparametre"
 msgstr[1] "'%D' benyttet uden skabelonsparametre"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %qD used %d template parameter"
@@ -58493,485 +58570,485 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "tidligere erklæring af '%#D' her"
 msgstr[1] "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "skabelonsparameter '%#D'"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
 msgstr "omerklæret her som '%#D'"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "den skal være en henvisning til medlem på formen '&X::Y'"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "because it is a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qE"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attributes in template argument %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected %qD but got %qD"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %qD"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure for %qD"
 msgstr "intern GCC-afbrydelse"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
@@ -58990,334 +59067,334 @@ msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en kla
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to __builtin_choose_expr not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "første parameter til '__builtin_choose_expr' skal være en konstant"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "'%#T' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "exception specification of %qD depends on itself"
@@ -59330,149 +59407,149 @@ msgstr "eksplicit specialisering af %D efter første brug"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "'%T' er ikke et navnerum"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ugyldig standardparameter i skabelon"
@@ -59706,7 +59783,7 @@ msgstr "ugyldig brug af 'this' ved øverste niveau"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualified type %qT does not match destructor name ~%qT"
@@ -59762,7 +59839,7 @@ msgstr "ugyldig stamklasseangivelse"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
@@ -59870,7 +59947,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -59912,7 +59989,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
@@ -60051,129 +60128,129 @@ msgstr "%qD fremgår mere end en gang i map-klausuller"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "for mange inddatafiler"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<grainsize%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<priority%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<hint%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<tile%> argument needs integral type"
 msgstr "skive-slutning skal være heltal"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -60452,905 +60529,905 @@ msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvi
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of `%s' to a member function"
 msgid "invalid application of %qs to a member function"
 msgstr "ugyldig brug af '%s' på en medlemsfunktion"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-aggregate type `%T'"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-sammensat type '%T'"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-class type `%T'"
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member `%D' of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ugyldig tilgang til ikke-statisk datamedlem '%D' af NULL-objekt"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a member template function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qT is not a pointer-to-object type"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared `register'"
 msgid "subscripting array declared %<register%>"
 msgstr "indeksering af tabel som er erklæret 'register'"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "object missing in use of `%E'"
 msgid "object missing in use of %qE"
 msgstr "objekt mangler i brug af '%E'"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids calling `::main' from within program"
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ forbyder kald af '::main' inde fra programmet"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "must use .* or ->* to call pointer-to-member function in `%E (...)'"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "brug .* eller ->* i kald af henvisning til medlemsfunktion i '%E (...)'"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qE cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to constructor %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to constructor %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to method %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to method %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, fuzzy, gcc-internal-format
 #| msgid "assuming cast to type `%T' from overloaded function"
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antager typeomtvingning til typen '%T' fra flertydig funktion"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL benyttet i udregning"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ forbyder sammenligning mellem henvisningsvariabel og heltal"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "uordnet sammenligning af ikke-kommatalsparameter"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types `%T' and `%T' to binary `%O'"
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ugyldige operander af typerne '%T' og '%T' til binær '%O'"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer of type `void *' in subtraction"
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning af typen 'void *' i fratrækning"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til funktion i fratrækning"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til medlemsfunktion i fratrækning"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ugyldig brug af en henvisning til en ufuldstændig type i henvisningsberegning"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of constructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of destructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' to form a pointer-to-member-function.  Use a qualified-id."
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ugyldig brug af '%E' til at danne en henvisning til medlemsfunktion; benyt et kaldenavn med klassepræfiks"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around '%E' cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "paranteser omkring '%E' kan ikke bruges til at danne en henvisning til medlemsfunktion"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en ikke-modificeret, ikke-statisk medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en bundet medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking address of function `::main'"
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ forbyder at tage adressen på funktionen '::main'"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan ikke oprette henvisning til reference medlemmet '%D'"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "attempt to take address of bit-field"
 msgstr "kan ikke finde adressen af bitfeltet '%s'"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of an immediate function %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, fuzzy, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "ISO C forbyder brug af typeomtvingningsudtryk som venstreværdier"
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of explicit register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, fuzzy, gcc-internal-format
 #| msgid "address requested for `%D', which is declared `register'"
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse forespurgt for '%D' som er erklæret 'register'"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' casts away const (or volatile)"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast fra '%T' til '%T' fjerner const (eller volatile)"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "skabelonsparameter '%T' benytter lokal type '%T'"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type `%T' to type `%T'"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ugyldig static_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "konvertering fra '%T' til '%T'"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "reinterpret_cast from `%T' to `%T' loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "reinterpret_cast fra '%T' til '%T' mister præcision"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from `%T' to `%T' increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typeomtvingning fra '%T' til '%T' forøger den påkrævede justering af målets type"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ forbyder sammenligninger mellem henvisning til funktion og henvisning til objekt"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ugyldig brug af const_cast med typen '%T' som ikke er en henvisnings-, reference- eller en henvisning til datamedlem-type"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ugyldig brug af const_cast med typen '%T' som er en henvisning eller reference til funktion"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type `%T' to type `%T'"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type `%T'"
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ forbyder omtvingelse af typen til en tabeltype '%T'"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "invalid cast to function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, fuzzy, gcc-internal-format
 #| msgid "  in evaluation of `%Q(%#T, %#T)'"
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i evaluering af '%Q(%#T, %#T)'"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "ugyldig tildeling af startværdi til tabel"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i henvisning til medlemsfunktion-omdannelse"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "henvisning til medlem-omdannelse via den virtuelle stamklasse '%T' af '%T'"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i henvisning til medlem-omdannelse"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %qD"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %qD returned"
 msgstr "reference til den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "too many 'l' suffixes in integer constant"
 msgid "redundant move in return statement"
 msgstr "for mange 'l'-endelser i heltalskonstant"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "kan ikke returnere fra en håndtering af en funktions-try-blok i en konstruktionsfunktion"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "manglende startværdi"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "'operator new' må ikke returnere NULL medmindre den er erklæret 'throw()' (eller -fcheck-new er benyttet)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -61653,124 +61730,124 @@ msgstr "krøllede paranteser omkring skalarstartværdi"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -62006,10 +62083,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -62185,7 +62262,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -62309,7 +62386,7 @@ msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -62356,7 +62433,7 @@ msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr ""
@@ -62371,7 +62448,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -62498,175 +62575,175 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "different type"
 msgid "Different type kinds at %L"
 msgstr "anden type"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr ""
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr ""
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "STAT= argument to %s at %L"
 msgstr "for få parametre til %s '%+#D'"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Negative argument N at %L"
 msgstr "forkert parametertype til %s"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr ""
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr ""
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -62674,715 +62751,715 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr ""
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr ""
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr ""
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to `%s' option"
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "der mangler en parameter til tilvalget '%s'"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "different type"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "anden type"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Argument of %s at %L must be of length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr ""
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr ""
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid filename"
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "\"%s\" er ikke et ugyldigt filnavn"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to `%s' option"
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "der mangler en parameter til tilvalget '%s'"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "for få parametre til funktionen '%s'"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr ""
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr ""
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr ""
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr ""
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr ""
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr ""
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr ""
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too many arguments to %s at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -63590,790 +63667,790 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero-length character constant at %0"
 msgid "Old-style character length at %C"
 msgstr "Nul-længde tegnkonstant ved %0"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in character length specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing initializer"
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "manglende startværdi"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "kan ikke klargøre multidimensional tabel med startværdi"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "kan ikke klargøre multidimensional tabel med startværdi"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Component %qs at %C already declared at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can't match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "en parameterliste med '...' passer ikke til en erklæring med en tom parameterliste"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization designators may not nest"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "klargøringstegn må ikke indlejres"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in pointer initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "non-NULL pointer initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, fuzzy, gcc-internal-format
 #| msgid "INTENT is not allowed inside of BLOCK at %C"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "INTENT er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "invalid character '%c' in #if"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "ugyldigt tegn '%c' i #if"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero-size array at %0"
 msgid "Implied-shape array at %L"
 msgstr "Nulstørrelsestabel ved %0"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot read function profile from %s."
 msgid "Cannot set pointee array spec."
 msgstr "kan ikke læse funktionsprofil fra %s."
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Old-style initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected an initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%Jsvag erklæring af '%D' ikke understøttet"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nested extern declaration of `%s'"
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "indlejret extern-erklæring af '%s'"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing right parenthesis at %C"
 msgstr "Manglende formel parameterterm"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected scalar initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "ugyldig typeparameter"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Malformed type-spec at %C"
 msgstr "ugyldig typeparameter"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "IMPORT statement at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Missing codimension specification at %C"
 msgstr "Modstridende I/O-kontrolangivelser ved %0 og %1"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing dimension specification at %C"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
@@ -64381,1063 +64458,1063 @@ msgstr "Returnér værdier fra funktioner i fpu-registre"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "Missing term"
 msgid "Missing symbol"
 msgstr "Manglende term"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Alternate-return argument at %C"
 msgstr "forkert parametertype til %s"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Planlæg ikke begyndelsen og slutningen af proceduren"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't specify array dimension in a declaration"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Kan ikke angive tabeldimension i en erklæring"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicts with function declaration `%#D'"
 msgid "Unexpected junk after function declaration at %C"
 msgstr "strider mod funktionserklæring '%#D'"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-sætning ved %C kan ikke fremgå i en STRUCTURE-blok"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing first operand for binary operator at %0"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Manglende første operand for binær operator ved %0"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected END statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "END statement instead of %s statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-udtryk forventet ved %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting %s statement at %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "Cray pointer at %C must be an integer"
 msgstr "udsagn skal være et kaldenavn"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "kan ikke konverteres til en henvisningstype"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksfejl i PROTECTED-udtryk ved %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Mystisk fortegn i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializing array with parameter list"
 msgid "Initializing already initialized variable at %C"
 msgstr "klargør tabel med en parameterliste"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VALUE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VOLATILE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "forhåndserklæring af '%#T'"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after MAP statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after UNION statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing structure name for outer structure definition at %0"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Manglende strukturnavn for ydre strukturdefinition ved %0"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "empty declaration"
 msgid "Mangled derived type definition at %C"
 msgstr "tom erklæring"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type name expected before `*'"
 msgid "ENUM definition statement expected before %C"
 msgstr "der forventedes et typenavn før '*'"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Duplicate access-specifier at %C"
 msgstr "mere end én tilgangsangivelse"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Forventede tilgangsangivere ved %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Forventede bindingattribut ved %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE og DEFERRED kan ikke begge vises ved %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> forventet ved %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-liste ved %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> er ugyldig for DEFERRED-binding ved %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Forventede %<::%> ved %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Forventede generisk navn elelr operatordeskriptor ved %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Forkert udformet GENERIC-udtryk ved %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Forventede %<=>%> ved %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
@@ -65565,13 +65642,13 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "LEN part_ref at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter `%s'"
 msgid "KIND part_ref at %C"
@@ -65650,7 +65727,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -65926,7 +66003,7 @@ msgstr "ugyldig venstreværdi i tildeling"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -65984,170 +66061,170 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer/integer type mismatch in conditional expression"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "henvisnings- og heltalstype i betingelsesudtrykket passer ikke sammen"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -66176,7 +66253,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of `%T'"
@@ -66375,12 +66452,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -66453,604 +66530,604 @@ msgstr "konvertering fra NaN til int"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "reference '%s' er tvetydig: den optræder i grænsefladen '%s' og grænsefladen '%s'"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "Invalid procedure argument at %L"
 msgstr "ugyldig typeparameter '%s'"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return specifier at %0 invalid within a function"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returangivelse ved %0 er ugyldig inden i en funktion"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return specifier at %0 invalid within a function"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returangivelse ved %0 er ugyldig inden i en funktion"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Missing value at %1 for real-number exponent at %0"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Manglende værdi ved %1 for reel eksponent ved %0"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid option argument `%s'"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "ugyldig tilvalgsparameter '%s'"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "Unable to find symbol %qs"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "intern fejl - for mange grænsefladetyper"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator number is out of bounds"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "akkumulatortal er uden for det gyldig interval"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "complex arguments must have identical types"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "komplekse parametre skal have identiske typer"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -67160,79 +67237,79 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "init_arglist(): too many arguments"
 msgstr "ugyldig typeparameter"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Function %qs as initialization expression at %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conversion from NaN to int"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "konvertering fra NaN til int"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conversion from NaN to int"
 msgid "Conversion from %s to %s at %L"
@@ -67241,22 +67318,22 @@ msgstr "konvertering fra NaN til int"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -67639,12 +67716,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -67654,7 +67731,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -67701,7 +67778,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -67802,7 +67879,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -67875,7 +67952,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Ugyldig udtrykssætning"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at '%s' token"
 msgid "Syntax error in %s statement at %C"
@@ -67892,87 +67969,87 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "asm not allowed in atomic transaction"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "asm er ikke tilladt i atomar transaktion"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected comma in I/O list at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "integer overflow in expression"
 msgid "identifier overflow: %d"
@@ -68237,528 +68314,528 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "ugyldig typeparameter"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "%s statement at %C is not within a construct"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 follows ELSE block for IF construct at %1"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Sætning ved %0 følger ELSE-blok for IF-konstruktion ved %1"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  enters try block"
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "  går ind i try-blok"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "STOP code at %C cannot be negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "PAUSE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "EVENT POST statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "EVENT WAIT statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "FAIL IMAGE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "FORM TEAM statement at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "CHANGE TEAM statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "END TEAM statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "SYNC TEAM statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "UNLOCK statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "ASSIGN statement at %C"
 msgstr "I sætningsfunktion"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Assigned GOTO statement at %C"
 msgstr "Mystisk fortegn i FORMAT-sætning ved %0"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected constant at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "STAT tag at %L cannot be a constant"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "objekt mangler i brug af '%E'"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
@@ -68766,237 +68843,237 @@ msgstr "\"%s\" må ikke optræde i makroparameterliste"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "BLOCK DATA construct at %L"
 msgstr "I konstruktionen"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attempt to extend COMMON area beyond its starting point via EQUIVALENCE of `%A'"
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Forsøg på at udvide COMMON-område over dets begyndelsespunkt vha. EQUIVALENCE '%A'"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "EQUIVALENCE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function at %L is recursive"
 msgstr "Sætningsfunktion '%A' defineret ved %0, men er ikke brugt"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Sætningsfunktion '%A' defineret ved %0, men er ikke brugt"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "Statement function at %C"
 msgstr "I sætningsfunktion"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression in CASE at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "SELECT RANK statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected CASE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CASE specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected RANK statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in RANK specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -69041,12 +69118,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -69759,8 +69836,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -71208,182 +71285,182 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr ""
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument missing after %s"
 msgid "Expected argument list at %C"
 msgstr "en parameter mangler efter %s"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "danner %s til referencetypen '%T'"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too many components in structure constructor at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "kommatalsoverløb i udtryk"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Sætningsfunktion '%A' defineret ved %0, men er ikke brugt"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%s: option `%s' requires an argument\n"
 msgid "Function %qs requires an argument list at %C"
 msgstr "%s: tilvalget '%s' skal have en parameter\n"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" cannot be used as a macro name as it is an operator in C++"
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "\"%s\" kan ikke bruges som et makronavn da det er en operator i C++"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid filename"
 msgid "%qs at %C is not a variable"
@@ -71721,512 +71798,512 @@ msgstr "brug af '%D' er tvetydigt"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function `%A' defined at %0 is not used"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Sætningsfunktion '%A' defineret ved %0, men er ikke brugt"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "resolve_function(): bad function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "resolve_subroutine(): bad function type"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "shared and mdll are not compatible"
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared og mdll er indbyrdes uforenelige"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Advar når en inline funktion ikke kan indbygges"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Argument dim at %L must be scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array `%A' at %0 is too large to handle"
 msgid "Array index at %L is an array of rank %d"
 msgstr "Tabellen '%A' ved %0 er for stor til at håndtere"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring begin/end point at %0 out of defined range"
 msgid "Substring end index at %L must be scalar"
 msgstr "Understrengs begyndelses-/slutpunkt ved %0 er uden for det definerede interval"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "Substring end index at %L is too large"
 msgstr "angivet justering er for stor"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -72235,12 +72312,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -72249,290 +72326,290 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in typebound call at %L"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -72541,291 +72618,291 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" cannot be used as a macro name as it is an operator in C++"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" kan ikke bruges som et makronavn da det er en operator i C++"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Selector at %L cannot be NULL()"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "Selector at %L has no type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -72833,192 +72910,192 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "FORALL construct at %L"
 msgstr "I konstruktionen"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Pointer procedure assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid NULL at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -73026,969 +73103,969 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fejl ved egenskabsundersøgelse af filen %s"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "'%#D' kan ikke erklæres"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting definable entity near %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in method specification"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -74700,158 +74777,158 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Labeled DO statement at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -74891,85 +74968,85 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Null element at %0 for array reference at %1"
 msgid "Bad array reference at %L"
 msgstr "Nulelement ved %0 for tabelreference ved %1"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -74990,77 +75067,77 @@ msgstr "tildeling af startværdi til new-udtryk med '='"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared %s"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "instansvariablen '%s' er erklæret '%s'"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared %s"
 msgid "Unused variable %qs declared at %L"
 msgstr "instansvariablen '%s' er erklæret '%s'"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' declared void"
 msgid "Unused parameter %qs declared at %L"
 msgstr "parameteren '%s' erklæret void"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Returnér værdier fra funktioner i fpu-registre"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -75076,29 +75153,29 @@ msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, fuzzy, gcc-internal-format
 #| msgid "unknown insn mode"
 msgid "Unknown intrinsic op"
 msgstr "ukendt instruktionstilstand"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "for få parametre til funktionen '%s'"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -75135,25 +75212,25 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "implicit mapping of assumed size array %qD"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "optional class parameter"
 msgstr "ingen parametre"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "unhandled derived-type component"
 msgstr "ugyldig typeparameter"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -75264,84 +75341,84 @@ msgstr "uens antal parenteser"
 msgid "unable to open file"
 msgstr "kunne ikke åbne filen"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "kunne ikke fortolke hex-tal"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "kunne ikke fortolke filforskydning"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "uventet forskydning"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ugyldig linje i løsningsfilen"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ugyldig løsning i løsningsfilen"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "cannot read LTO mode table from %s"
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "kan ikke læse LTO-tilstandstabel fra %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Kan ikke åbne %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Kan ikke oversætte %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Kan ikke læse %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "kunne ikke åbne symbolløsningsfilen: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing resolution data for %s"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -76547,7 +76624,7 @@ msgstr "et makronavn mangler efter %s"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, fuzzy, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "et filnavn mangler efter '-%s'"
@@ -76759,18 +76836,18 @@ msgstr "ukendt registernavn: %s"
 msgid "unknown TLS model %qs"
 msgstr "ukendt tls-model %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "ikke genkendt synlighedsværdi %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for `%s')"
 msgid "unknown vtable verify initialization priority %qs"
diff --git a/gcc/po/de.po b/gcc/po/de.po
index 1e09e45ba71..c452de75f94 100644
--- a/gcc/po/de.po
+++ b/gcc/po/de.po
@@ -8,10 +8,10 @@
 # Roland Illig <roland.illig@gmx.de>, 2015, 2017-2020.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 10.1.0\n"
+"Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
-"PO-Revision-Date: 2020-05-10 20:21+0200\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
+"PO-Revision-Date: 2020-07-23 20:00+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
 "Language: de\n"
@@ -1908,83 +1908,83 @@ msgstr "Längenmodifizierer im strfmon-Format"
 msgid "<command-line>"
 msgstr "<Kommandozeile>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ungültiger Operand für »%%%c«"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr "ungültige Vektorkonstante"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "unverträglicher Gleitkomma- / Vektorregisteroperand für »%%%c«"
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "unverträglicher Registeroperand für »%%%c«"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "fehlender Operand"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "ungültige Konstante"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "ungültiger Operand"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ungültiger Operandenpräfix »%%%c«"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr "ungültiger Adressierungsmodus"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung von Typ %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung in Typ %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "Operation nicht erlaubt auf Typ %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "GNU- und SVE-Vektoren können nicht in einer binären Operation kombiniert werden"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
@@ -2000,18 +2000,18 @@ msgid "invalid %%r value"
 msgstr "ungültiger %%r-Wert"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "ungültiger %%R-Wert"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
@@ -2041,7 +2041,7 @@ msgstr "ungültiger %%M-Wert"
 msgid "invalid %%U value"
 msgstr "ungültiger %%U-Wert"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
@@ -2051,7 +2051,7 @@ msgstr "ungültiger %%s-Wert"
 msgid "invalid %%C value"
 msgstr "ungültiger %%C-Wert"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
@@ -2061,10 +2061,10 @@ msgstr "ungültiger %%E-Wert"
 msgid "unknown relocation unspec"
 msgstr "unbekannte Adressverschiebungs-Unspec"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ungültiger %%xn-Code"
@@ -2146,35 +2146,35 @@ msgstr "ungültiges UNSPEC als Operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "unerkannte vermutete Konstante"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "ungültiger Schiebeoperand"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "bedingter Thumb-Befehl"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "bedingter Befehl in bedingter Sequenz"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2182,13 +2182,13 @@ msgstr "Operand für Code »%c« nicht unterstützt"
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "Befehl wird niemals ausgeführt"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "veralteter Maverick-Formatcode »%c«"
@@ -2310,7 +2310,7 @@ msgstr "nicht unterstützter Operand"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2527,25 +2527,25 @@ msgstr "Falscher Operand für output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "Falscher Operand für output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr "falsche ADDR_SPACE_GLOBAL-Adresse"
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, c-format
 msgid "invalid operand %%xn code"
 msgstr "ungültiger Code für Operand %%xn"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr "Operandencode %%xn ist für QImode ungültig"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, c-format
 msgid "invalid fp constant"
 msgstr "ungültige Gleitkomma-Konstante"
@@ -2689,7 +2689,7 @@ msgstr "ungültige Operation auf %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ungültiger %%P-Operand"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -2743,7 +2743,7 @@ msgid "post-increment address is not a register"
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -2795,8 +2795,8 @@ msgstr "»%%%c« ist kein gültiger Operandenpräfix"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ungültige Verwendung von »%%%c«"
@@ -2927,165 +2927,202 @@ msgstr "Stapelspeicher aufgebraucht.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "»%s« in der Shell könnte diese Beschränkung erhöhen.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> benötigt Hardware-Gleitkommabefehle"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> benötigt indizierte Adressierung"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> und %<-mno-altivec%> sind unverträglich"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> schaltet vsx aus"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> benötigt 64-Bit-Modus"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> benötigt 64-Bit-Modus"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> ist im Little-Endian-Modus nicht verfügbar"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, c-format
+msgid "invalid %%A value"
+msgstr "ungültiger %%A-Wert"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "ungültiger %%D-Wert"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, c-format
 msgid "invalid %%t value"
 msgstr "ungültiger %%t-Wert"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "ungültiger %%V-Wert"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "ungültiger %%z-Wert"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 und __ibm128 können nicht im selben Ausdruck verwendet werden"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 und long double können nicht im gleichen Ausdruck verwendet werden"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 und long double können nicht im selben Ausdruck verwendet werden"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "Addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
+#: config/rs6000/rs6000.c:26740
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "ungültige Umwandlung von Typ %<__vector_quad%>"
+
+#: config/rs6000/rs6000.c:26742
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "ungültige Umwandlung in Typ %<__vector_quad%>"
+
+#: config/rs6000/rs6000.c:26744
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "ungültige Umwandlung von %<__vector_pair%>"
+
+#: config/rs6000/rs6000.c:26746
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "ungültige Umwandlung in %<__vector_pair%>"
+
+#: config/rs6000/rs6000.c:26754
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "ungültige Umwandlung von Typ %<* __vector_quad%>"
+
+#: config/rs6000/rs6000.c:26757
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "ungültige Umwandlung in Typ %<* __vector_quad%>"
+
+#: config/rs6000/rs6000.c:26760
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "ungültige Umwandlung von %<* __vector_pair%>"
+
+#: config/rs6000/rs6000.c:26763
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "ungültige Umwandlung in %<* __vector_pair%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3096,88 +3133,88 @@ msgstr "symbolische Speicherreferenzen werden nur auf z10 oder neuer unterstütz
 msgid "cannot decompose address"
 msgstr "Adresse kann nicht zerlegt werden"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ungültiger Vergleichsoperator für Ausgabemodifizierer »E«"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ungültige Referenz für Ausgabemodifizierer »J«"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »O«"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »R«"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "Speicherreferenz für Ausgabemodifizierer »S« erwartet"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »S«"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »N« erwartet"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »M« erwartet"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ungültige Konstante für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Ungültige Konstante – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ungültiger konstanter Vektor für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ungültiger Ausdruck – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ungültiger Ausdruck für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr "Vektor-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "Typen unterscheiden sich im Vorzeichenbesitz"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr "binärer Operator unterstützt keine zwei bool-Vektor-Operanden"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr "Binärer Operator unterstützt Boolean-Vektor-Argument nicht"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binärer Operator unterstützt nicht, dass bool-Vektor mit Gleitkommavektor vermischt wird"
 
@@ -3440,8 +3477,8 @@ msgstr "({anonym})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
@@ -3461,7 +3498,7 @@ msgstr "%<;%> erwartet"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -3469,7 +3506,7 @@ msgstr "%<)%> erwartet"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -3487,21 +3524,21 @@ msgstr "%<;%>, %<,%> oder %<)%> erwartet"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -3512,12 +3549,12 @@ msgstr "%<{%> erwartet"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
@@ -3526,7 +3563,7 @@ msgstr "%<while%> erwartet"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -3535,18 +3572,18 @@ msgstr "%<,%> erwartet"
 msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
@@ -3554,19 +3591,19 @@ msgstr "%<,%> oder %<)%> erwartet"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
@@ -3575,7 +3612,7 @@ msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> erwartet"
@@ -3586,33 +3623,33 @@ msgstr "%<<%> erwartet"
 msgid "expected label"
 msgstr "Sprungmarke erwartet"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr "Kandidat:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 msgid "  after user-defined conversion:"
 msgstr "  nach benutzerdefinierter Umwandlung:"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
 msgstr[1] "Kandidaten sind:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "Kandidat 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "Kandidat 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "Sprung zur Marke %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "Sprung zur case-Marke"
 
@@ -3701,7 +3738,7 @@ msgstr "<Template-Parameter-Fehler>"
 msgid "<statement>"
 msgstr "<Anweisung>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<unbekannt>"
@@ -3867,48 +3904,48 @@ msgstr "Umformung verwirft Konstantheit"
 msgid "source type is not polymorphic"
 msgstr "Quellentyp ist nicht polymorph"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "Argument falschen Typs für unäres Minus"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "Argument falschen Typs für unäres Plus"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "Argument falschen Typs für Bit-Komplement"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "Argument falschen Typs für abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "Argument falschen Typs für Konjugation"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "in Argument für unäres !"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "kein Präinkrementoperator für Typ"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "kein Postinkrementoperator für Typ"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "kein Prädekrementoperator für Typ"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "kein Postdekrementoperator für Typ"
 
@@ -3948,17 +3985,17 @@ msgstr "Unzulässiger Typ in Zeichenverkettung bei %L"
 msgid "elemental binary operation"
 msgstr "Elementare Binäroperation"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "Argumente »a%d« und »a%d« für intrinsisches »%s«"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "Argumente »%s« und »%s« für intrinsisches %s"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "Argumente »%s« und »%s« für intrinsisches »%s«"
@@ -4040,7 +4077,7 @@ msgstr "Unstimmige Arraygrenzen für Dimension 2 des Arrays (%ld/%ld)"
 msgid "Driving:"
 msgstr "Angesteuert:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "effektives Argument für INTENT = OUT/INOUT"
 
@@ -4055,7 +4092,7 @@ msgstr "interne Einheit in WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s-Symbol mit INQUIRE"
@@ -4161,11 +4198,11 @@ msgstr "Block-IF"
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
@@ -4173,199 +4210,199 @@ msgstr "Zeigerzuweisung"
 msgid "simple IF"
 msgstr "einfaches IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "Elementares Unterprogramm"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr "allozierbares Argument"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr "asynchrones Argument"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "optionales Argument"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "Zeigerargument"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "Zielargument"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "Wertargument"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr "flüchtiges Argument"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr "Argument mit angenommener Form"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr "Argument mit angenommenem Rang"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr "Coarray-Argument"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr "parametrisiertes abgeleitetes Typargument"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr "polymorphes Argument"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "NO_ARG_CHECK-Attribut"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr "Argument von angenommenem Typ"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "Arrayergebnis"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr "Zeiger oder allozierbares Resultat"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr "Resultat mit nicht konstanter Zeichenlänge"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr "bind(c)-Prozedur"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand des unären numerischen Operators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Unerwartete Entitäten mit abgeleitetem Typ im binären intrinsischen numerischen Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des binären numerischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanden des Zeichenkettenverkettungsoperators bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des logischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand des Operators .not. bei %%L ist %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-Größen können nicht bei %L verglichen werden"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logische Werte bei %%L müssen mit %s statt mit %s verglichen werden"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Vergleichsoperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L; meinten Sie »%s«?"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operand des Benutzeroperators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Benutzeroperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Ränge für Operator bei %%L und %%L stimmen nicht überein"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
@@ -4378,27 +4415,27 @@ msgstr "Unterschiedliche CHARACTER-Längen (%ld/%ld) in Feldkonstruktor"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Ganzzahlüberlauf bei der Berechnung des zu reservierenden Speichers"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Der Wert des Parameters PDT LEN »%s« stimmt nicht mit dem in der Dummy-Deklaration überein"
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge passt nicht zur deklarierten für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge ist kürzer als die deklarierte für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ziel für neue Rangabbildung ist zu klein (%ld < %ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr "Zuweisung von Skalar zu unalloziertem Array"
 
@@ -4473,7 +4510,7 @@ msgstr "Einheitszahl in E/A-Anweisung zu groß"
 msgid "Assigned label is not a target label"
 msgstr "Zugewiesene Marke ist keine Zielmarke"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Ungültige Bildanzahl %d in SYNC IMAGES"
@@ -4896,7 +4933,7 @@ msgstr "Bei Erzeugung temporärer Felder warnen."
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
@@ -5478,8 +5515,8 @@ msgstr "Unterstriche an extern sichtbare Namen anhängen."
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
@@ -7920,105 +7957,100 @@ msgstr "Bei Codepfaden warnen, in denen ein Zeiger auf einen bereits verschwunde
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Bei Codepfaden warnen, in denen ein uninitialisierter Wert verwendet wird."
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr "Warnen, wenn der Code so kompliziert ist, dass er nicht vollständig analysiert werden kann."
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr "Die Analyse auf die Prüfung mit dem angegebenen Namen einschränken."
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr "Vermeiden, dass mehrere Anweisungen zu einer expandierten Kante zusammengefasst werden."
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr "Einen Hinweis ausgeben, wenn doppelte Diagnosemeldungen zusammengefasst werden."
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr "Ungenutze Zustände während der Analyse verwerfen."
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr "Zustände, die ähnlich genug sind, während der Analyse zusammenfassen."
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr "Transitivität von Beschränkungen während der Analyse berücksichtigen."
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr "Die Auswirkungen von Funktionsaufrufen abschätzen, um die Analyse zu vereinfachen."
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr "Ausführlichere Beschreibungen des Steuerablaufs in den Diagnosemeldungen ausgeben."
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr "Ausführlichere Beschreibungen der Zustandsänderungen in den Diagnosemeldungen ausgeben."
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr "Steuern, welche Ereignisse in den Diagnosepfaden angegeben werden."
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "Diverse Interna des Analysierers nach SRCFILE.analyzer.txt wegschreiben."
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr "Diverse Interna des Analysierers auf die Standardfehlerausgabe wegschreiben."
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr "Aufrufgraphen des Analysierers nach SRCFILE.callgraph.dot wegschreiben."
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr "Expandierten Graphen des Analysierers nach SRCFILE.eg.dot wegschreiben."
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr "Diagnoseinformationen zur Position der Knoten im expandierten Graphen ausgeben."
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr "Textdarstellung des expandierten Graphen nach SRCFILE.eg.txt wegschreiben."
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr "Textdarstellung des expandierten Graphen nach SRCFILE.eg-ID.txt wegschreiben."
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr "Informationen über das Wegwerfen von Zuständen nach SRCFILE.state-purge.dot wegschreiben."
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr "Gesamtgraphen des Analysierers nach SRCFILE.supergraph.dot wegschreiben."
@@ -12449,8 +12481,8 @@ msgstr "Standardumwandlungen zwischen »__float128« und »long double« einscha
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
-msgstr "Befehle für eine zukünftige Architektur verwenden."
+msgid "Use instructions added in ISA 3.1."
+msgstr "Vektor-Befehle verwenden, die in ISA 3.1 hinzugefügt wurden."
 
 #: config/rs6000/rs6000.opt:576
 #, no-c-format
@@ -12462,6 +12494,11 @@ msgstr "Speicherzugriffsbefehle mit (oder ohne) Präfix erzeugen."
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Speicheradressierung relativ zu PC (oder absolut) erzeugen."
 
+#: config/rs6000/rs6000.opt:584
+#, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "MMA-Befehle erzeugen (oder auch nicht)."
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17401,10 +17438,9 @@ msgstr "Funktionen nur aus Dateien instrumentieren, deren Namen nicht zu allen d
 msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
 msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tStufe für die Reproduzierbarkeit des mit »-fprofile-generate« generierten Profils festlegen."
 
-# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=95040
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr "Präfix von absolutem Pfad abschneiden, bevor dieser Name für »-fprofile-generate=« und »-fprofile-use=« gemangelt wird."
 
 #: common.opt:2217
@@ -18047,367 +18083,367 @@ msgstr "Schleifenabwicklung durchführen, wenn Anzahl der Wiederholungen bekannt
 msgid "Perform loop unrolling for all loops."
 msgstr "Schleifenabwicklung für alle Schleifen durchführen."
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Optimierung für Gleitkommaarithmetik erlauben, auch wenn durch Runden ein anderes Ergebnis herauskommen kann."
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Das gleiche wie -fassociative-math für Ausdrücke, die Division enthalten."
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Mathematische Optimierungen erlauben, die IEEE- oder ISO-Standards verletzen könnten."
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Schleifenausschaltung durchführen."
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Schleifen-Aufteilung durchführen."
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr "Schleifen versionieren, je nachdem, ob sie eine Schrittweite von eins haben."
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Einfach Abwicklungstabellen für Ausnahmebehandlung erzeugen."
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "BFD-Linker statt Standardlinker verwenden."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Gold-Linker statt Standardlinker verwenden."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Den LLVM-lld-Linker statt des Standardlinkers verwenden."
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Variablenverfolgung durchführen."
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Variablenverfolgung durch Zuweisungsanmerkungen durchführen."
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "-fvar-tracking-assignments umschalten."
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Variablenverfolgung durchführen und auch Variablen markieren, die uninitialisiert sind."
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Vektorisierung auf Bäumen einschalten."
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Schleifenvektorisierung auf Bäumen einschalten."
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Vektorisierung von Basisblöcken (SLP) auf Bäumen einschalten."
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "-fvect-cost-model=[unlimited|dynamic|cheap]\tKostenmodell für Vektorisierung angeben."
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tVektorisierungs-Kostenmodell angeben, das für mit einer SIMD-Direktive markierten Code verwendet wird."
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Schaltet das dynamische Vektorisierer-Kostenmodell ein. Für Rückwärtskompatibilität erhalten."
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Kopieweitergabe von Informationen über Skalar-Evolution einschalten."
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Zusätzliche Anmerkungen an Assemblerausgabe anfügen."
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tStandard-Symbolsichtbarkeit festlegen."
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "VTable-Zeiger validieren, bevor sie verwendet werden."
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Verifikationszähler für VTables ausgeben."
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Informationen über Zeigermengen der VTable-Verifikation ausgeben."
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Profile von Ausdruckswerten in Optimierungen verwenden."
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Netze konstruieren und nicht zusammenhängende Verwendungen einzelner Variablen aufteilen."
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Beseitigung von bedingt totem Code für Aufrufe eingebauter Funktionen einschalten."
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Gesamtprogrammoptimierung durchführen."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Annehmen, dass Zeigerüberläufe überschlagen (Wraparound)."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Annehmen, dass vorzeichenbehaftete arithmetische Überläufe regulär überschlagen (Wraparound)."
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Null-initialisierte Daten in den bss-Abschnitt legen."
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Fehlersuchinformationen im Standardformat erzeugen."
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Assembler-Unterstützung für (DWARF2+-).loc-Direktiven annehmen."
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Assembler-Unterstützung für Ansicht in (DWARF2+-).loc-Direktiven annehmen."
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "DW_AT_decl_column und DW_AT_call_column in DWARF aufzeichnen."
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Fehlersuchinformationen im Standardversion des DWARF-Formats erzeugen."
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Fehlersuchinformationen im DWARF-v2-Format (oder neuer) erzeugen."
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Fehlersuchinformationen im erweiterten Standardformat erzeugen."
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Erweiterte Informationen für Einsprungpunkt für inline-Funktionen erzeugen."
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr "Locview-Rücksetzpunkte auf Basis der geschätzten Befehlslängen berechnen."
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Keine DWARF-Abschnitte für Pubnames und Pubtypes erzeugen."
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes erzeugen."
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes mit GNU-Erweiterungen erzeugen."
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "GCC-Kommandozeilenschalter in DWARF DW_AT_producer aufzeichnen."
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Fehlersuchinformationen in separaten .dwo-Dateien erzeugen."
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Fehlersuchinformationen im STABS-Format erzeugen."
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Fehlersuchinformationen im erweiterten STABS-Format erzeugen."
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Progressive empfohlene Breakpoint-Stellen ausgeben."
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Keine DWARF-Ergänzungen über gewählte Version hinaus erzeugen."
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr "Beschreibungsattribute zu einigen DWARF-DIEs hinzufügen, die kein Namensattribut haben."
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Erzeugung von Fehlersuchinformationen umschalten."
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr "Adresslisten der Variablen mit progressiven Sichten anreichern."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Fehlersuchinformationen im VMS-Format erzeugen."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Fehlersuchinformationen im XCOFF-Format erzeugen."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Fehlersuchinformationen im erweiterten XCOFF-Format erzeugen."
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Komprimierte Fehlersuchinformationen erzeugen."
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<Format>\tKomprimierte Debugabschnitte im Format <Format> erzeugen."
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<Verz>\t<Verz> als Standard-Plugin-Verzeichnis festlegen."
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <Verzeichnis>\t<Verzeichnis> als Multiarch-include-Verzeichnis festlegen."
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <Datei>\tAusgabe in <Datei> schreiben."
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Funktionsprofilierung einschalten."
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Wie -pedantic, aber als Fehler ausgeben."
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Übersetzte Funktionen oder verstrichene Zeit nicht ausgeben."
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Wortreiche Ausgabe einschalten."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Compiler-Version anzeigen."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Warnungen unterdrücken."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Shared Library erzeugen."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Keine dynamisch gebundene, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Dynamisch gebundene, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Statische, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Vom Aufrufer zu sichernde Register über Aufrufe hinweg verwenden, wenn möglich."
@@ -19558,8 +19594,8 @@ msgstr "Schranke für Anzahl der Laufzeitprüfungen, die von Schleifenversionier
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Schranke für Anzahl der Laufzeitprüfungen, die von Schleifenversionierung des Vektorisierers für Ausrichtungsprüfung eingefügt werden."
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "berechneter Wert ist unbenutzt"
@@ -19585,7 +19621,7 @@ msgid "expected boolean type"
 msgstr "boolescher Typ erwartet"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Ganzzahl erwartet"
@@ -19649,7 +19685,7 @@ msgstr "Nicht genug Argumente"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "zu viele Argumente"
@@ -20003,7 +20039,7 @@ msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20087,12 +20123,12 @@ msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20110,8 +20146,8 @@ msgstr "Attribut %qE wird ignoriert"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "Attribut %<target%> fehlt für multiversioniertes %qD"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "vorherige Deklaration von %qD"
@@ -20230,7 +20266,7 @@ msgstr "das referenzierte Argument wird hier deklariert"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "Adressabstand %wi ist außerhalb der Grenzen der konstanten Zeichenkette"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE ist hier deklariert"
@@ -20517,7 +20553,7 @@ msgstr "ungültiges Argument 0 für %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack ()%>"
@@ -20808,12 +20844,12 @@ msgstr "%<asm%>-Konflikt mit Ausgabeoperand"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "%<asm%>-Konflikt mit Eingabeoperand"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "Stapelschutz schützt nicht lokale Variablen: Puffer variabler Größe"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "Stapelschutz schützt nicht Funktion: Alle lokalen Arrays sind kleiner als %d Bytes"
@@ -21323,302 +21359,302 @@ msgstr "Interner Fehler: basic blocks not laid down consecutively"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "Interner Fehler: number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "Interner Fehler: caller edge count invalid"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr "fehlender indirekter Aufruf in der Folge der spekulativen Aufrufe"
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr "indirekter Aufruf in der Folge der spekulativen Aufrufe hat kein Spekulationsflag"
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr "spekulative Kanten sind nicht benachbart"
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr "der direkte Aufruf von %s in der Folge der spekulativen Aufrufe hat kein Spekulationsflag"
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr "der direkte Aufruf von %s in der Folge der spekulativen Aufrufe hat speculative_id %i außerhalb des Bereichs"
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr "doppelter direkter Aufruf von %s in der Folge der spekulativen Aufrufe mit speculative_id %i"
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr "der Hash der Aufrufanweisung zeigt nicht auf die erste direkte Kante der Folge von spekulativen Aufrufen"
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr "doppelter Verweis %s in der Folge der spekulativen Aufrufe mit speculative_id %i"
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "missing direct call for speculation %i"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "missing ref for speculation %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr "Anzahl der spekulativen Ziele %i stimmt nicht mit num_speculative_call_targets %i überein"
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "Interner Fehler: aux field set for edge %s->%s"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "Interner Fehler: cgraph count invalid"
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "Interner Fehler: inline clone in same comdat group list"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "inline clone count is not compatible"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "tp_first_run must be non-negative"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "Interner Fehler: local symbols must be defined"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "Interner Fehler: externally visible inline clone"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "Interner Fehler: inline clone with address taken"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "Interner Fehler: inline clone is forced to output"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr "calls_comdat_local wird außerhalb einer comdat-Gruppe gesetzt"
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr "ungültiger Schalter »calls_comdat_local«"
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "Attribut %<malloc%> ist nur an Funktionen sinnvoll, die einen Zeiger zurückgeben"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "Interner Fehler: aux field set for indirect edge from %s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "edge count is not compatible with function count"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Interner Fehler: An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr "Kante hat sowohl call_stmt als auch lto_stmt_uid gesetzt"
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "Interner Fehler: comdat-local function called by %s outside its comdat"
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "Interner Fehler: inlined_to pointer is wrong"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "Interner Fehler: multiple inline callers"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Interner Fehler: inlined_to pointer set for noninline callers"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "Interner Fehler: caller edge count does not match BB count"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "Interner Fehler: indirect call count does not match BB count"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr "Verweis hat sowohl stmt als auch lto_stmt_uid gesetzt"
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "Interner Fehler: inlined_to pointer is set but no predecessors found"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Interner Fehler: inlined_to pointer refers to itself"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "Interner Fehler: cgraph_node has wrong clone_of"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "Interner Fehler: cgraph_node has wrong clone list"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "Interner Fehler: cgraph_node is in clone list but it is not clone"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "Interner Fehler: cgraph_node has wrong prev_clone pointer"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "Interner Fehler: double linked list of clones corrupted"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Interner Fehler: Alias has call edges"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Interner Fehler: Alias has non-alias reference"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Interner Fehler: Alias has more than one alias reference"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Interner Fehler: Analyzed alias has no reference"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Interner Fehler: No edge out of thunk node"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Interner Fehler: More than one edge out of thunk node"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Interner Fehler: Thunk is not supposed to have body"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Interner Fehler: shared call_stmt:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "Interner Fehler: edge points to wrong declaration:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "Interner Fehler: an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "Interner Fehler: missing callgraph edge for call stmt:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "Interner Fehler: reference to dead statement"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "Interner Fehler: edge %s->%s has no corresponding call_stmt"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "Interner Fehler: an indirect edge from %s has no corresponding call_stmt"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr "fehlender Ursprung für einen Knoten in einer verschachtelten Liste"
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "origin points to a different parent"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "Interner Fehler: verify_cgraph_node failed"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: section %s.%d is missing"
@@ -21704,12 +21740,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "Attribut %<weakref%> ignoriert, da Variable bereits initialisiert ist"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F verwendet, aber nirgendwo definiert"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F als %<static%> deklariert, aber nirgendwo definiert"
@@ -21861,7 +21897,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO-Unterstützung wurde in dieser Konfiguration nicht eingeschaltet"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "%s kann nicht geöffnet werden: %m"
@@ -22188,22 +22224,22 @@ msgstr "%<-gdwarf-6%> wird als Version 5 ausgegeben, mit Inkompatibilitäten"
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "Nicht-Delegitimiertes UNSPEC %s (%d) am Variablenort gefunden"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "ungültige gemeinsame rtl-Verwendung in Befehl gefunden"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "Gemeinsames rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "internes Konsistenzproblem"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn verwendet, wo emit_jump_insn erforderlich:\n"
@@ -22263,7 +22299,7 @@ msgstr "%<region_array%> passt nicht zum %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> passt nicht zum %<region_tree%>"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs fehlgeschlagen"
@@ -22294,12 +22330,12 @@ msgstr "umgekehrte Speicherreihenfolge für »%smode«"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "Schreiben von %wu Bit Daten außerhalb der Grenzen des Zielobjekts, Daten wurden auf %wu Bit abgeschnitten"
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%KAufruf von %qs mit Attributfehler deklariert: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%KAufruf von %qs mit Attributwarnung deklariert: %s"
@@ -22314,7 +22350,7 @@ msgstr "ungültiges Argument %qs für %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "die Rahmengröße von %wu Bytes überschreitet %wu Bytes"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "endgültige Abzugsdatei %qs der Befehle konnte nicht geöffnet werden: %m"
@@ -22334,37 +22370,37 @@ msgstr "große Festkommakonstante implizit auf Festkommatypen abgeschnitten"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "Vergleich ist immer %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<oder%> bei nicht passenden Ungleichheits-Tests ist immer 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<und%> bei sich gegenseitig ausschließenden Gleichheits-Tests ist immer 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstante in Vergleich verringert wird"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstanten um einen Vergleich kombiniert werden"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "Faltungstest: ursprünglicher Baum durch Faltung geändert"
@@ -22982,13 +23018,13 @@ msgstr "Funktion liefert möglicherweise Adresse einer lokalen Variablen zurück
 msgid "function returns address of local variable"
 msgstr "Funktion liefert Adresse einer lokalen Variablen zurück"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "hier deklariert"
@@ -23556,10 +23592,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "%G%qD Offset %s ist außerhalb der Grenzen von Objekt %qD mit Typ %qT"
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD ist hier deklariert"
@@ -23724,7 +23760,7 @@ msgstr "%qE in umgebendem %<target%> nicht angegeben"
 msgid "enclosing %<target%>"
 msgstr "umgebendes %<target%>"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "Variable %qE in umgebender %<host_data%>-Region deklariert"
@@ -23774,13 +23810,13 @@ msgstr "nichtskalare Variable %qD in bedingter %<lastprivate%>-Klausel"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr "%<task%>-Reduktionsmodifizierer bei einem Konstrukt mit %<nowait%>-Klausel"
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr "ungültiger %<task%>-Reduktionsmodifizierer bei Konstrukt außer %<parallel%>, %<for%> oder %<sections%>"
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "%<inscan%>-%<reduction%>-Klausel am %qs-Konstrukt"
@@ -23790,148 +23826,148 @@ msgstr "%<inscan%>-%<reduction%>-Klausel am %qs-Konstrukt"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-Klausel für Variable, die keine Schleifeniterationsvariable ist, wurde für ein mit %<distribute%> kombiniertes Konstrukt angegeben"
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "Feld %qE der Struktur variabler Länger wird zugeordnet"
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE tritt in Mapklauseln mehrfach auf"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "»copyprivate«-Variable %qE ist im äußeren Kontext weder »threadprivate« noch »private«"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "»%s«-Variable %qE ist im äußeren Kontext »private«"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-Klausel-Modifizierer anstelle %qs erwartet"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr "%qD wurde in %qs-Klausel angegeben, aber nicht in %<inscan%>-%<reduction%>-Klausel am enthaltenden Konstrukt"
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD in implizier %<map%>-Klausel"
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in impliziter %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "selbe Variable wird in %<firstprivate%>- und %<lastprivate%>-Klauseln am %<distribute%>-Konstrukt"
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "inkompatible Datenklausel mit Reduktion an %qE; wird zu %<present_or_copy%> befördert"
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr "%qD ist in %<inscan%>-%<reduction%>-Klausel angegeben, aber nicht in %<scan%>-Direktivenklausel"
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ungültige »private«-Reduktion auf %qE"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "%<inscan%>-%<reduction%>-Klausel wird zusammen mit %<linear%>-Klausel an einer Variable verwendet, die kein Schleifeniterator ist"
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<mutexinoutset%>-Art in %<depend%>-Klausel bei einem %<taskwait%>-Konstrukt"
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "bedingte %<lastprivate%>-Klausel an Schleifeniterator %qD wird ignoriert"
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "%<bind%>-Klausel nicht auf einem %<loop%>-Konstrukt, das nicht in einem anderen OpenMP-Konstrukt geschachtelt ist"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<bind(parallel)%> an einem %<loop%>-Konstrukt, das in einem %<simd%>-Konstrukt geschachtelt ist"
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "%<bind(teams)%> an einer %<loop%>-Region, die nicht streng innerhalb einer %<teams%>-Region geschachtelt ist"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "%<lastprivate%>-Klausel an einem %<loop%>-Konstrukt bezieht sich auf eine Variable %qD, die nicht der Schleifeniterator ist"
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-Konstrukt mit %<depend%>-Klausel muss innerhalb einer Schleife mit %<ordered%>-Klausel und Parameter eng geschachtelt sein"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "Variable %qE ist keine Iteration der äußersten Schleife %d, jedoch %qE erwartet"
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "Anzahl der Variablen in %<depend%>-Klausel mit %<sink%>-Modifizierer passt nicht zur Anzahl der Iterationsvariablen"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "mehr als eine %<depend%>-Klausel mit %<source%>-Modifizierer an einem %<ordered%>-Konstrukt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79999
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<depend%>-Klausel mit %<source%>-Modifizierer zusammen mit %<depend%>-Klauseln mit %<sink%>-Modifizierer an demselben Konstrukt"
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "Gimplifikation gescheitert"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT auf %qT erweitert beim Durchlaufen von %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(Es sollte also %qT statt %qT an %<va_arg%> übergeben werden)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Wenn dieser Code erreicht wird, wird das Programm abgebrochen"
@@ -24006,7 +24042,7 @@ msgstr "Token %u hat %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "Token %u hat %<y-location == %u%>"
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "ungültige Verwendung des Attributs %<fallthrough%>"
@@ -24278,54 +24314,54 @@ msgstr "unverträgliches Speicherlayout"
 msgid "the extra base is defined here"
 msgstr "die zusätzliche Basisklasse ist hier definiert"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] "Wenn Typ %qD »final« wäre, würde %i Aufruf devirtualisiert werden"
 msgstr[1] "Wenn Typ %qD »final« wäre, würden %i Aufrufe devirtualisiert werden"
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Wenn Typ %qD »final« wäre, würde %i Aufruf, der %lli-mal ausgeführt wurde, devirtualisiert werden"
 msgstr[1] "Wenn Typ %qD »final« wäre, würden %i Aufrufe, die %lli-mal ausgeführt wurden, devirtualisiert werden"
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf einschalten"
 msgstr[1] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen einschalten"
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] "Wenn die Methode %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf einschalten"
 msgstr[1] "Wenn die Methode %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen einschalten"
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf, der %lli-mal ausgeführt wurde, einschalten"
 msgstr[1] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen, die %lli-mal ausgeführt wurden, einschalten"
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Wenn die Methode %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf, der %lli-mal ausgeführt wurde, einschalten"
 msgstr[1] "Wenn die Methode %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen, die %lli-mal ausgeführt wurden, einschalten"
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "ungültige »fnsummary« in LTO-Datenstrom"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "IPA-Inline-Zusammenfassung fehlt in Eingabedatei"
@@ -24355,37 +24391,37 @@ msgstr "Funktion könnte Kandidat für Attribut %qs sein, wenn sie als normal zu
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "IPA-Referenzzusammenfassung fehlt in ltrans-Einheit"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr "Offset des Zugriffs liegt vor dem Offset des Elternteils"
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr "Größe des Zugriffs ist größer oder gleich der übergeordneten Größe"
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr "Zugriff endet außerhalb des Elternteils"
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr "Zugriff überschneidet sich mit seinem Geschwisterteil"
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr "IPA-SRA-Zugriffs-Verifikation fehlgeschlagen"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr "Die Funktion %qs, Parameter %u, hat IPA-SRA-Zugriffe, die sich überlappen"
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr "Funktion %s, Parameter %u, wird verwendet, hat aber keinen bestimmten IPA-SRA-Zugriff"
@@ -24435,57 +24471,57 @@ msgstr "inkonsistente Operandenbedingungen in einem %<asm%>"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Höchstzahl der erzeugten Neuladebefehle pro Befehl ist erreicht (%d)"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr "Funktion %qs wurde in ausgelagertem Code referenziert, wurde aber nicht markiert, dass sie im ausgelagerten Code enthalten sein dürfte"
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr "Variable %qs wurde in ausgelagertem Code referenziert, wurde aber nicht markiert, dass sie im ausgelagerten Code enthalten sein dürfte"
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "Bytecode-Strom: Mehrere Instanzen des Cgraph-Knoten mit UID %d gefunden"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "Bytecode-Strom: Kein Aufrufer beim Lesen der Kante gefunden"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "Bytecode-Strom: Kein Gerufener beim Lesen der Kante gefunden"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "Bytecode-Strom: Leeren Cgraph-Knoten gefunden"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Es werden höchstens %i Profildurchläufe unterstützt. Evtl. beschädigte Datei?"
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Profilinformation in %s ist beschädigt"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "LTO cgraph kann in %s nicht gefunden werden"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "LTO-Abschnittsreferenzen können in %s nicht gefunden werden"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "ungültige offload-Tabelle in %s"
@@ -24737,52 +24773,52 @@ msgstr "%<depend%>-Klausel mit %<sink%>-Modifizierer wartet auf lexikalisch spä
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr "%<depend%>-Klausel mit %<sink%>-Modifizierer verweist auf Iteration, die niemals im Iterationsraum ist"
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr "%qs gibt eine widersprüchliche Stufe der Parallelität an"
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr "… zur vorherigen %qs-Klausel hier"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr "%<%s%> kann nicht auf %qD angewendet werden, da diese bereits mit einer OpenACC-»declare target«-Direktive markiert wurde"
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr "inkompatible %qs-Klausel bei Anwendung von %<%s%> auf %qD, die bereits mit einer OpenACC-»routine«-Direktive gekennzeichnet wurde"
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr "fehlende %qs-Klausel bei Anwendung von %<%s%> auf %qD, die bereits mit einer OpenACC-»routine«-Direktive markiert wurde"
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "… mit %qs-Klausel hier"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr "… ohne %qs-Klausel hier in der Nähe"
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> übersteuert andere OpenACC-Schleifenspezifizierer"
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> steht in Konflikt mit anderen OpenACC-Schleifenspezifizierern"
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "innere Schleife verwendet denselben OpenACC-Parallelismus wie enthaltende Schleife"
@@ -25003,52 +25039,52 @@ msgstr "ungültiger Eintritt in strukturierten %s-Block"
 msgid "invalid branch to/from %s structured block"
 msgstr "ungültiger Zweig zu/von strukturiertem %s-Block"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr "Operand für %<-fopenacc-dim%> bei %qs ist falsch"
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr "Unterprogrammaufruf verwendet denselben OpenACC-Parallelismus wie enthaltende Schleife"
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr "enthaltende Schleife ist hier"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr "Unterprogrammaufruf verwendet OpenACC-Parallelismus, der von der umgebenden Routine verboten wurde"
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr "Schleife verwendet OpenACC-Parallelismus, der von der umgebenden Routine verboten wurde"
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "Routine %qD ist hier deklariert"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr "falsch geschachtelter OpenACC-Schleifenparallelismus"
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr "unzureichende Partitionierung verfügbar, um die Elementschleife zu parallelisieren"
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr "unzureichende Partitionierung verfügbar, um die Kachelschleife zu parallelisieren"
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr "unzureichende Partitionierung verfügbar, um Schleife zu parallelisieren"
@@ -26417,132 +26453,132 @@ msgstr "%<-fcf-protection=return%> wird für dieses Ziel nicht unterstützt"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> wird nicht mehr unterstützt"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "Befehlsplanung wird von dieser Zielmaschine nicht unterstützt"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "diese Zielmaschine hat keine verzögerten Zweige"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "%<-f%sleading-underscore%> wird auf dieser Zielmaschine nicht unterstützt"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "Abzugsdatei %qs genullter Befehle konnte nicht geschlossen werden: %m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "Zielsystem unterstützt nicht das Testformat %qs"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "Variablenverfolgung angefordert, jedoch nutzlos ohne Debug-Info"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "Variablenverfolgung angefordert, jedoch nicht von diesem Debug-Format unterstützt"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments ändert selektive Planung"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr "ohne %<-gdwarf-5%> ist %<-gvariable-location-views=incompat5%> gleichbedeutend mit %<-gvariable-location-views%>"
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr "%<-ginternal-reset-location-views%> wird zwangsweise ausgeschaltet, da %<-gvariable-location-views%> nicht angegeben ist"
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr "%<-ginline-points%> wird zwangsweise ausgeschaltet, da %<-gstatement-frontiers%> nicht angegeben ist"
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "%<-ffunction-sections%> wird für dieses Ziel nicht unterstützt"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "%<-fdata-sections%> wird für dieses Ziel nicht unterstützt"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "%<-fprefetch-loop-arrays%> wird für dieses Ziel nicht unterstützt"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "%<-fprefetch-loop-arrays%> wird für dieses Ziel nicht unterstützt (ggf. die %<-march%>-Schalter versuchen)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "%<-fprefetch-loop-arrays%> wird nicht mit %<-Os%> unterstützt"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "%<-fassociative-math%> abgeschaltet; andere Optionen haben Vorrang"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr "%<-fstack-clash-protection%> wird auf Architekturen, deren Stapel von klein nach groß wächst, nicht unterstützt"
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr "%<-fstack-check=%> und %<-fstack-clash_protection%> schließen einander aus. %<-fstack-check=%> wird deaktiviert"
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "%<-fstack-protector%> wird für dieses Ziel nicht unterstützt"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "%<-fsanitize=address%> und %<-fsanitize=kernel-address%> werden für dieses Ziel nicht unterstützt"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "Fehler beim Schreiben der Datei %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "Fehler beim Schließen von %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr "mpfr ist nicht so konfiguriert, dass alle Gleitkommamodi verarbeitet werden können"
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "Selbsttests sind unverträglich mit %<-E%>"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "Selbsttests sind in diesem Build nicht eingeschaltet"
@@ -26637,172 +26673,172 @@ msgstr "%K%<asm%> in %<transaction_safe%>-Funktion ist nicht erlaubt"
 msgid "ignoring loop annotation"
 msgstr "Schleifenannotation wird ignoriert"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "Konstante wird bei %<ADDR_EXPR%>-Änderung nicht neu berechnet"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "Seiteneffekte werden bei %<ADDR_EXPR%>-Änderung nicht neu berechnet"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "%<DECL_GIMPLE_REG_P%> auf einer Variable mit verwendeter Adresse gesetzt"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "Adresse genommen, aber %<TREE_ADDRESSABLE%>-Bit nicht gesetzt"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "ungültiger Ausdruck für Min-L-Wert"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "ungültiger Operand in indirekter Referenz"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr "nicht-skalares %qs"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "ungültiger Positions- oder Größenoperand für %qs"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr "Genauigkeit des ganzzahligen Ergebnistypen passt nicht zur Feldgröße von %qs"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "Betriebsart-Größe des nicht-ganzzahligen Ergebnisses passt nicht zur Feldgröße von %qs"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "Operand von %qs ohne Modus-Genauigkeit"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "Position plus Größe überschreitet die Größe des referenzierten Objekts in %qs"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr "Typunverträglichkeit in %qs-Verweis"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr "nicht-Top-Level %qs"
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "ungültiger Operand für %qs"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "unverträgliche Typen in %qs"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "ungültiger Offset-Operator %qs"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "Umwandlung von %qs auf der linken Seite eines %qs"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "Umwandlung eines Registers auf eine andere Größe in %qs"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "ungültiger Adressoperand in %qs"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "ungültiger Offset-Operand in %qs"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "ungültige Clique in %qs"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "%qs in GIMPLE-IL"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "Gimple-Aufruf hat zwei Ziele"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "Gimple-Aufruf hat kein Ziel"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "ungültige Funktion in GIMPLE-Aufruf"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "Nicht-Funktion in GIMPLE-Aufruf"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "ungültiger »pure const«-Status für Funktion"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "ungültige LHS in GIMPLE-Aufruf"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr "LHS in %<noreturn%>-Aufruf"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "ungültige Umwandlung in GIMPLE-Aufruf"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "ungültige statische Kette in GIMPLE-Aufruf"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "statische Kette mit Funktion, die keine verwendet"
@@ -26813,530 +26849,530 @@ msgstr "statische Kette mit Funktion, die keine verwendet"
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "Aufruf von %<__builtin_unreachable%> oder %<__builtin_trap%> mit Argumenten"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "ungültiges Argument für GIMPLE-Aufruf"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "ungültige Operanden in GIMPLE-Vergleich"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "Vergleichsoperandentypen passen nicht"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "In booleschem Vektorvergleich ist die Operation oder der Typ nicht unterstützt"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "Nicht-Vektoroperanden in Vektorvergleich"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "ungültiger Ergebnistyp in Vektorvergleich"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "falscher Ergebnistyp bei Vergleich"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "Nicht-Register als LHS von unärer Operation"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "ungültiger Operand in unärer Operation"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr "ungültige Vektortypen in NOP-Umwandlung"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "ungültige Typen in NOP-Umwandlung"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "ungültige Typen in Adressraumumwandlung"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "ungültige Typen Festkomma-Umwandlung"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "ungültige Typen in Umwandlung zu Gleitkomma"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "ungültige Typen in Umwandlung in Ganzzahl"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "Typunverträglichkeit in %qs-Ausdruck"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "ungültiger Typen für %qs"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr "%qs sollte von einem Skalar auf einen gleichartigen Vektor abbilden"
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "nicht-triviale Umwandlung in unärer Operation"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "Nicht-Register als LHS von binärer Operation"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "ungültige Operanden in binärer Operation"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "ungültige Nicht-Vektor-Operanden für %qs"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr "Ungültige (Zeiger-)Operanden %qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "Vektortypen erwartet in %qs"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "Typ passt nicht in binärem Ausdruck"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "Nicht-Register als LHS von ternärer Operation"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "ungültige Operanden in ternärer Operation"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "das erste Argument eines %qs muss von booleschem Vektortyp sein und gleich viele Elemente wie das Ergebnis haben"
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "Vektortypen erwartet in %qs"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "Vektoren unterschiedlicher Elementanzahl in %qs gefunden"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "ungültiger Maskentyp in %qs"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "unerlaubte Typkombination in %qs"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "ungültige Position oder Größe in %qs"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs in non-mode-precision Operanden"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "Einschub außerhalb des gültigen Bereichs in %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs nicht an Elementgrenze"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "nicht-triviale Umwandlung in %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "%s auf der linken Seite einer Clobber-Anweisung"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "ungültiger Operand in %qs"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ungültige rechte Seite für GIMPLE-Speicherung: %qs"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "ungültiger Typ der Vektor-%qs-Elemente"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "falsche Anzahl der Vektor-%qs-Elemente"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "falscher Typ der Elemente eines Vektorkonstruktors"
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "Vektor-%qs mit Elementindex, der nicht NULL ist"
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "%qs-Element des Vektors ist kein GIMPLE-Wert"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "%qs mit Elementen ist kein Vektor"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "%qs mit immer falscher Bedingung"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ungültiger Operand in »return«-Anweisung"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "ungültige Umwandlung in »return«-Anweisung"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "Goto-Ziel ist weder eine Marke noch ein Zeiger"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "ungültiger Operand für switch-Anweisung"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "switch-Anweisung ohne eingebauten Typ"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "ungültige %<default%>-Sprungmarke in switch-Anweisung"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "ungültiges %<CASE_CHAIN%>"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "ungültige »case«-Marke in switch-Anweisung"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "ungültiger »case«-Bereich in switch-Anweisung"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "unpassender Typ für »case«-Marke in switch-Anweisung"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "unpassende Präzision für Typ in switch-Anweisung"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "unsortierte case-Marken in switch-Anweisung"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "der Label-Kontext ist nicht die aktuelle Funktionsdeklaration"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "falscher Eintrag in %<label_to_block_map%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "incorrect setting of landing pad number"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "invalid comparison code in gimple cond"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "Ungültiger Marken in GIMPLE-Bedingung"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "ungültiges %<PHI%>-Ergebnis"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93852
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "fehlende %<PHI%>-Definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "ungültiges %<PHI%>-Argument"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "inkompatible Typen in %<PHI%>-Argument %u"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "%<verify_gimple%> failed"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "unerreichbare Anweisung in EH-Tabelle"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "location references block not in block tree"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "local declaration from a different function"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) is set to a wrong basic block"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "PHI node with location"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "incorrect sharing of tree nodes"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "virtual PHI with argument locations"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) is set to a wrong basic block"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "Anweisung für throw markiert, wirft jedoch nichts"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "Anweisung inmitten eines Blocks für throw markiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple failed"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK has IL associated with it"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK has IL associated with it"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru to exit from bb %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "nichtlokale Marke "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH Landefeld-Marke "
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "Marke "
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79878
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "control flow in the middle of basic block %d"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "Fallthru-Kante hinter einer Kontrollanweisung in bb %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "Wahr/Falsch-Kante hinter einer Nicht-GIMPLE_COND in bb %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "Falsche ausgehende Kantenmarken am Ende des bb %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "Explizites Goto am Ende von bb %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "Return-Kante zeigt nicht auf Ausgang in bb %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "Standard-Fall nicht am Anfang des case-Vektors gefunden"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "Case-Marken nicht sortiert: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "Zusätzliche ausgehende Kante %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "Fehlende Kante %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-Funktion kehrt zurück"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "Kontrollfluss erreicht Ende von Nicht-void-Funktion"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "Der Rückgabewert von %qD, der mit dem Attribut %<warn_unused_result%> deklariert wurde, wird ignoriert"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "Rückgabewert der mit dem Attribut %<warn_unused_result%> definierten Funktion wird ignoriert"
@@ -27351,47 +27387,47 @@ msgstr "in Definition des Makros %qs"
 msgid "in expansion of macro %qs"
 msgstr "bei Substitution des Makros %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "Interner Compilerfehler: BB %i has multiple EH edges"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "Interner Compilerfehler: BB %i cannot throw but has an EH edge"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "Interner Compilerfehler: BB %i last statement has incorrectly set lp"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "Interner Compilerfehler: BB %i is missing an EH edge"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "Interner Compilerfehler: Incorrect EH edge %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "Interner Compilerfehler: BB %i is missing an edge"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "Interner Compilerfehler: BB %i too many fallthru edges"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "Interner Compilerfehler: BB %i has incorrect edge"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "Interner Compilerfehler: BB %i has incorrect fallthru edge"
@@ -27913,12 +27949,12 @@ msgstr "Anweisung (%p) nach Optimierungsdurchgang als geändert markiert: "
 msgid "verify_ssa failed"
 msgstr "verify_ssa gescheitert"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "maschinenunabhängiger eingebauter Code außerhalb des Wertebereiches"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "zielspezifische eingebaute Funktion ist nicht verfügbar"
@@ -27983,7 +28019,7 @@ msgstr "Arrayindexwert %E liegt außerhalb der Grenzen des inneren Arraytyps %qT
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "Arrayindex %qE liegt außerhalb der Grenzen des Arraytyps %qT mit Länge 0"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr "beim Referenzieren von %qD"
@@ -27994,27 +28030,27 @@ msgstr "beim Referenzieren von %qD"
 msgid "defined here %qD"
 msgstr "%qD wurde hier definiert"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "Arrayindex %wi ist außerhalb der Arraygrenzen von %qT"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "Arrayindex [%wi, %wi] ist außerhalb der Arraygrenzen von %qT"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "Offset %wi des zwischenzeitlichen Arrays ist außerhalb der Arraygrenzen von %qT"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "Arrayindex %wi ist unterhalb der Arraygrenze von %qT"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "Arrayindex %wu ist oberhalb der Arraygrenze von %qT"
@@ -28089,32 +28125,32 @@ msgstr "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD ist veraltet: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD ist veraltet"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE ist veraltet: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE ist veraltet"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "Typ ist veraltet: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "Typ ist veraltet"
@@ -28139,232 +28175,232 @@ msgstr "Typ ist veraltet"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "Interner Compilerfehler: type variant differs by %s"
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_SIZE_UNIT%>"
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "Interner Compilerfehler: type variant%'s %<TYPE_SIZE_UNIT%>"
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "Interner Compilerfehler: type%'s %<TYPE_SIZE_UNIT%>"
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "Interner Compilerfehler: type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_VFIELD%>"
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_BINFO%>"
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "Interner Compilerfehler: type variant%'s %<TYPE_BINFO%>"
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "Interner Compilerfehler: type%'s %<TYPE_BINFO%>"
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_FIELDS%>"
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "Interner Compilerfehler: first mismatch is field"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr "Interner Compilerfehler: and field"
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "Interner Compilerfehler: type variant has different %<TREE_TYPE%>"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "Interner Compilerfehler: type variant%'s %<TREE_TYPE%>"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "Interner Compilerfehler: type%'s %<TREE_TYPE%>"
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "Interner Compilerfehler: type is not compatible with its variant"
 
-#: tree.c:14387
+#: tree.c:14398
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "Interner Compilerfehler: main variant is not defined"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "Interner Compilerfehler: %<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "Interner Compilerfehler: %<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "Interner Compilerfehler: %<TYPE_CANONICAL%> is not compatible"
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "Interner Compilerfehler: %<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "Interner Compilerfehler: %<TYPE_CANONICAL%> of main variant is not main variant"
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "Interner Compilerfehler: %<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "Interner Compilerfehler: %<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "Interner Compilerfehler: %<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "Interner Compilerfehler: %<TYPE_BINFO%> is not %<TREE_BINFO%>"
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "Interner Compilerfehler: %<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "Interner Compilerfehler: %<TYPE_METHOD_BASETYPE%> is not record nor union"
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "Interner Compilerfehler: %<TYPE_OFFSET_BASETYPE%> is not record nor union"
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "Interner Compilerfehler: %<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "Interner Compilerfehler: %<TYPE_MAX_VALUE_RAW%> non-NULL"
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "Interner Compilerfehler: %<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "Interner Compilerfehler: enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "Interner Compilerfehler: enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "Interner Compilerfehler: enum value name is not %<IDENTIFIER_NODE%>"
 
-#: tree.c:14596
+#: tree.c:14607
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Interner Compilerfehler: array %<TYPE_DOMAIN%> is not integer type"
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "Interner Compilerfehler: %<TYPE_FIELDS%> defined in incomplete type"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Interner Compilerfehler: wrong tree in %<TYPE_FIELDS%> list"
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "Interner Compilerfehler: %<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "Interner Compilerfehler: %<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "Interner Compilerfehler: wrong %<TYPE_CACHED_VALUES%> entry"
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "Interner Compilerfehler: %<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Interner Compilerfehler: wrong entry in %<TYPE_ARG_TYPES%> list"
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "Interner Compilerfehler: %<TYPE_VALUES_RAW%> field is non-NULL"
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "Interner Compilerfehler: %<TYPE_CACHED_VALUES_P%> is set while it should not be"
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "Interner Compilerfehler: %<TYPE_METHOD_BASETYPE%> is not main variant"
@@ -28489,82 +28525,82 @@ msgstr "angeforderte Ausrichtung für %q+D ist größer als die implementierte A
 msgid "storage size of %q+D isn%'t known"
 msgstr "Speichergröße von %q+D ist unbekannt"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "Initialisierung für Ganzzahl-/Gleitkommazahlwert ist zu kompliziert"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "Initialisierung für Gleitkommawert ist keine Gleitkommakonstante"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "ungültiger Anfangswert für Element %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD als schwach deklariert, nachdem es verwendet wurde"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "schwache Deklaration von %q+D wird auf bereits existierende »static«-Definition angewandt"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "schwache Deklaration von %q+D muss öffentlich sein"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "schwache Deklaration von %q+D wird nicht unterstützt"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "in dieser Konfiguration werden nur schwache Aliase unterstützt"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref wird in dieser Konfiguration nicht unterstützt"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "%qs wird auf diesem Ziel nicht unterstützt"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "%<symver%> wird nur auf ELF-Plattformen unterstützt"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "%qs-Symbol %q+D zielt letztendlich auf sich selbst ab"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "%qs-Symbol %q+D muss statische Bindung haben"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "Alias-Definitionen werden in dieser Konfiguration nicht unterstützt"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "%qs wird in dieser Konfiguration nicht unterstützt"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "Sichtbarkeitsattribute werden in dieser Konfiguration nicht unterstützt; ignoriert"
@@ -29144,7 +29180,7 @@ msgstr "Attribut %qE folgt auf %qE"
 msgid "type was previously declared %qE"
 msgstr "Typ war vorher als %qE deklariert"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kann nur für virtuelle Funktionen angegeben werden"
@@ -29164,7 +29200,7 @@ msgstr "%qD ist mit %qD unverträglich"
 msgid "%qE argument is not a function"
 msgstr "Argument %qE ist keine Funktion"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "Veraltete Meldung ist keine Zeichenkette"
@@ -29537,12 +29573,12 @@ msgstr "%<?:%> mit Ganzzahlkonstanten in booleschem Kontext"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "der Compiler kann davon ausgehen, dass die Adresse von %qD immer zu %<true%> evaluiert"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "Um Zuweisung, die als Wahrheitswert verwendet wird, werden Klammern empfohlen"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "Ungültige Verwendung von %<restrict%>"
@@ -29698,12 +29734,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%>-Attribut mit einem Parameter angegeben"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "Zu wenige Argumente für Funktion %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -29804,7 +29840,7 @@ msgstr "Index %E markiert einen Offset größer als die Größe von %qT"
 msgid "size of array is too large"
 msgstr "Arraygröße ist zu groß"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "Operandentyp %qT ist inkompatibel mit Argument %d von %qE"
@@ -29814,124 +29850,124 @@ msgstr "Operandentyp %qT ist inkompatibel mit Argument %d von %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "als Argument 1 wurde entweder ein Zeigertyp oder ein Ganzzahltyp erwartet"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "die beiden Argumente müssen kompatibel sein"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "Falsche Anzahl der Argumente für Funktion %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "Argument 1 von %qE muss ein Nicht-Void-Zeigertyp sein"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "Argument 1 von %qE muss ein Zeiger auf Typen konstanter Größe sein"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "Argument 1 von %qE muss ein Zeiger auf Objekt breiter als Null sein"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "Argument %d von %qE muss eine Zeigertyp sein"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "Argument %d von %qE muss ein Zeiger auf Typen konstanter Größe sein"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "Argument %d von %qE darf kein Zeiger auf eine Funktion sein"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "Unpassende Größe in Argument %d von %qE"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "Nicht-Ganzzahlargument %d für Speichermodell von %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ungültiges Argument %d für Speichermodell von %qE"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "dieses Ziel definiert keine Spekulationsbarriere; das erzeugte Programm wird trotzdem korrekt laufen, aber irrige Spekulationen sind möglicherweise nicht eingeschränkt"
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Indexwert ist außerhalb der Grenzen"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "Umwandlung von Skalar %qT in Vektor %qT führt zum Abschneiden"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "eingebaute Funktion %qE muss direkt aufgerufen werden"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "Größe des Arrays %qE ist kein konstanter Ausdruck"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "Größe des Arrays ist kein konstanter Ausdruck"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "Größe %qE des Arrays %qE ist negativ"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "Größe %qE des Arrays ist negativ"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "Größe %qE des Arrays %qE übersteigt maximale Objektgröße %E"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "Größe %qE des Arrays überschreitet maximale Objektgröße %qE"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "Größe des Arrays %qE übersteigt maximale Objektgröße %E"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "Größe des Arrays übersteigt maximale Objektgröße %qE"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "Umgebungsvariable %qs muss ganzzahlig sein und zwischen 0 und %wd liegen"
@@ -29986,502 +30022,502 @@ msgstr "%qE ist ein nicht erkannter Formatfunktionstyp"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "Format-Zeichenkettenargument folgt den zu formatierenden Argumenten"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "Funktion %qD könnte ein Kandidat für Formatattribut %qs sein"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "fehlende $-Operandennummer im Format"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s unterstützt %%n$-Operandennummerformate nicht"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "Operandennummer außerhalb des Wertebereiches im Format"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "Formatargument %d mehr als einmal im %s-Format verwendet"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr "%<$%>-Operandennummer nach Format ohne Operandennummer angegeben"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "Formatargument %d nicht verwendet vor verwendetem Argument %d im %<$%>-Stil-Format"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "Format ist kein Zeichenkettenliteral, Formatzeichenkette ungeprüft"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "Format ist kein Zeichenkettenliteral, und keine Formatargumente"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "Format ist kein Zeichenkettenliteral, Argumenttypen ungeprüft"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "zu viele Argumente für Format"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr "unverwendete Argumente in %<$%>-Stil-Format"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "Format-Zeichenkette %s der Länge null"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "Format ist »wide character«-Zeichenkette"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "Formatzeichenkette ist kein Array vom Typ %qs"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "unbeendete Formatzeichenkette"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s verwendet mit Format %<%%%c%> %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s unterstützt %s nicht"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s unterstützt %s mit dem Format %<%%%c%> %s nicht"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr "%s wird innerhalb von %%<…%%> verwendet"
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr "%qc-Umwandlung wird unescapet verwendet"
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "wiederholtes %s im Format"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "fehlendes Füllzeichen am Ende des strfmon-Formates"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "Breite null im Format %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "leere linke Präzision im Format %s"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "fehlende Präzision im Format %s"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s unterstützt den Längenmodifizierer %qs für %s nicht"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "unbekanntes Konvertierungstyp-Zeichen %qc im Format"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s unterstützt das Format %<%%%c%> für %s nicht"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s ignoriert mit %s und Format %<%%%c%> für %s"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s ignoriert mit %s im Format für %s"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "Verwendung von %s und %s zusammen mit Format %<%%%c%> für %s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "gleichzeitige Verwendung von %s und %s im Format %s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> liefert in manchen Locales nur die letzten 2 Ziffern des Jahres"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> liefert nur die letzten 2 Ziffern des Jahres"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "kein schließendes %<]%> für %<%%[%>-Format"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "Verwendung des %qs-Längenmodifizierers mit %qc-Typ-Zeichen hat entweder keine Auswirkung oder undefiniertes Verhalten"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s unterstützt das Format %<%%%s%c%> für %s nicht"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "Operandennummer mit unterdrückter Zuweisung angegeben"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "Operandennummer für Format ohne Argumente angegeben"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "Typname %<%.*s%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "Operator %<%.*s%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "Schlüsselwort %<%.*s%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr "verwenden Sie stattdessen %qs"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr "Attribut außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "Name der eingebauten Funktion %<%.*s%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr "Bezeichner oder Schlüsselwort außerhalb von Anführungszeichen %<%.*s%> im Format"
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr "falsch geschriebener Begriff %<%.*s%> im Format; verwenden Sie stattdessen %<%s%s%>"
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr "%qs-Direktive innerhalb von Anführungszeichen im Format; verwenden Sie stattdessen %qs"
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr "Zusammenziehung %<%.*s%> im Format; verwenden Sie stattdessen %qs"
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr "Leerzeichen %qc außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr "überzähliges Leerzeichen am Ende des Formats"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "inkonsistente Großschreibung im Format"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "%i aufeinanderfolgende Leerzeichen außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "Steuerzeichen außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "Steuerzeichen %qc außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "Optionsname %<%.*s%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr "unausgeglichenes Satzzeichen %qc im Format"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr "Vorverarbeitungsdirektive %<%.*s%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr "Apostroph %<'%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr "wenn das Apostroph sich nicht vermeiden lässt, schließen Sie es stattdessen in ein Direktivenpaar %qs und %qs ein"
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr "Gravis-Akzent %<`%> außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr "verwenden Sie stattdessen die Apostroph-Direktive %qs"
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr "Leerzeichen gefolgt von Satzzeichen %<%c%>"
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr "%qs innerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr "wenn %qs nicht verwendbar ist, verwenden Sie stattdessen %qs"
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "verdächtige Folge von Satzzeichen %<%.*s%> am Anfang des Formats"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "verdächtige Folge von Satzzeichen %<%.*s%> am Ende des Formats"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr "Folge von %i aufeinanderfolgenden Satzzeichen %q.*s außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "nicht-grafische Zeichen außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "nicht-grafisches Zeichen %qc außerhalb von Anführungszeichen im Format"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "unausgeglichenes Satzzeichen %<%c%> im Format"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr "unbeendete q-Direktive"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "unbeendetes Anführungszeichen %<%c%> im Format"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "störendes letztes %<%%%> im Format"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "bei der Konvertierung fehlt der Typ am Ende des Formates"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "geschachtelte q-Direktiven"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr "Alleinstehende q-Direktive"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr "Die Direktive %qc ist redundant, da sie bereits vorgekommen ist"
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr "Alleinstehende Farbrücksetz-Direktive"
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr "Umwandlung %qc wird innerhalb einer q-Folge benutzt"
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "eingebettetes %<\\0%> im Format"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr "unbeendete Farbdirektive"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "Schreiben über Null-Zeiger (Argument %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "Lesen über Null-Zeiger (Argument %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "Schreiben in konstantes Objekt (Argument %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "zusätzliche Typqualifizierer in Format-Argument (Argument %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> erwartet Argumenttyp %<%s%s%>, aber Argument %d hat Typ %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> erwartet ein passendes Argument %<%s%s%>"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> erwartet Argumenttyp %<%T%s%>, aber Argument %d hat Typ %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> erwartet ein passendes Argument %<%T%s%>"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> ist nicht als Typ definiert"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> ist nicht als %<long%> oder %<long long%> definiert"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "%qs ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> ist nicht als ein Zeigertyp definiert"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr "zu formatierendes Argument ist nicht %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-Formate können keine Argumente formatieren"
@@ -30644,7 +30680,7 @@ msgstr "%<depobj%>-Abhängigkeitstyp in %<depend%>-Klausel von %<depobj%> angege
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<iterator%>-Modifizierer darf nicht bei einem %<depobj%>-Konstrukt angegeben sein"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -30659,17 +30695,17 @@ msgstr "%<_Atomic%>-Iterationsvariable %qE"
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
@@ -30679,7 +30715,7 @@ msgstr "Erhöhungsausdruck fehlt"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "Erhöhung ist weder konstant 1 noch konstant -1 für die %<!=%>-Bedingung"
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -31275,7 +31311,7 @@ msgid "wrong type argument to %s"
 msgstr "Argument falschen Typs für %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "Überlauf in Konstanten-Ausdruck"
@@ -31952,7 +31988,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr "im Aufruf von %<memset%> ist die Länge gleich der Anzahl der Elemente angegeben, ohne sie mit der Elementgröße zu multiplizieren"
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "Vergleich zwischen den Typen %qT und %qT"
@@ -32028,7 +32064,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "Argument %i wird an den mit %qs qualifizierten Parameter übergeben, dadurch wird es zum Alias für Argument %Z"
 msgstr[1] "Argument %i wird an den mit %qs qualifizierten Parameter übergeben, dadurch wird es zum Alias für die Argumente %Z"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "diese Bedingung hat identische Zweige"
@@ -32048,7 +32084,7 @@ msgstr "Einige Teile des expandierten Makros sind nicht von diesem %qs-Konstrukt
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr "die Umwandlung eines gepackten Zeigers auf %qT (Ausrichtung %d) in einen Zeiger auf %qT (Ausrichtung %d) führt möglicherweise zu einem nicht ausgerichteten Zeiger"
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr "hier definiert"
@@ -32068,7 +32104,7 @@ msgstr "%qs ist keine gültige Präprozessoroption"
 msgid "too many input files"
 msgstr "zu viele Eingabedateien"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "unbekannter Wert %qs für %<-mcpu%>"
@@ -32099,14 +32135,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "unbekannte Option an %%:target_mode_check weitergegeben"
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "gültige Argumente sind: %s; meinten Sie %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "gültige Argumente sind: %s"
@@ -32626,401 +32662,408 @@ msgstr "Alias-Definitionen werden nicht in Mach-O unterstützt; ignoriert"
 msgid "profiler support for VxWorks"
 msgstr "Profilerunterstützung für VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%KArgument %d muss eine direkt angegebene Konstante sein"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%KSpurindex muss eine direkt angegebene Konstante sein"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "%KGesamtgröße und Elementgröße müssen positive, direkt angegebene Konstanten sein"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%KArgument muss eine direkt angegebene 16-Bit-Konstante sein"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "Die Speicher-Tagging-Erweiterung unterstützt nicht %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "%KArgument %d muss eine direkt angegebene Konstante im Bereich [0, 15] sein"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "64-Bit-Adresse erwartet, aber Argument 1 hat %d Bit"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "64-Bit-Adresse erwartet, aber Argument 2 hat %d Bit"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> erfordert eine Zeichenkette als Parameter"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "unbekannte Option %qs für %<#pragma GCC aarch64%>"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "das Attribut %qE kann nicht auf einen SVE-Funktionstyp angewendet werden"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "unerwartetes %<%s%> nach %<%s%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs verträgt sich nicht mit der Verwendung von Gleitkommatypen"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs verträgt sich nicht mit der Verwendung von Vektortypen"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "Feature-Modifizierer %qs verträgt sich nicht mit der Verwendung von Gleitkommatypen"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "Feature-Modifizierer %qs verträgt sich nicht mit der Verwendung von Vektortypen"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "diese Operation erfordert die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "Sie können SVE mit der Befehlszeilenoption %<-march%>, oder mit dem Attribut %<target%> oder Pragma aktivieren"
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "Argumente vom Typ %qT erfordern die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "der SVE-Typ %qT kann nur an prototypisierte Funktionen übergeben werden"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 9.1 geändert"
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE benötigt die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "Aufrufe von Funktionen vom Typ %qT erfordern die SVE-ISA-Erweiterung"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "Stapelsonde für SVE-Rahmen"
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "unbekanntes Flag wurde in %<-moverride=%s%> übergeben (%s)"
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "Zeichenkette für %s falsch geformt\n"
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "ungültiges Format für sve_width"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "ungültiger Wert für sve_width: %d"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Tuning-Zeichenkette fehlt in Option »%s«"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "unbekannte Tuning-Option »%s«"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "die Optionen %<-mstack-protector-guard=global%> und %<-mstack-protector-guard-offset=%s%> sind unverträglich"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90153
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "wenn %<-mstack-protector-guard=sysreg%> angegeben ist, müssen sowohl %<-mstack-protector-guard-offset%> als auch %<-mstack-protector-guard-reg%> angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90154
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "Systemregister mit einem kurzem Namen (weniger als 100 Zeichen) angeben."
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs ist in %qs kein gültiger Offset"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "nur die Werte 12 (4 kB) und 16 (64 kB) werden für die Wächtergröße unterstützt. Der angegebene Wert %d (%llu kB) liegt außerhalb des gültigen Bereichs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90155
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "Größe des Stapelkollisionswächters %d muss gleich dem Sondierungsintervall %d sein"
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "gültige Argumente sind: %s;"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "fehlender CPU-Name in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "unbekannter Feature-Modifizierer %qs in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "ungültiges Argument %qs für %<-mbranch-protection=%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90157
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "fehlendes Argument für %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "fehlender Architekturname in %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "unbekannter Wert %qs für %<-march%>"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "unbekannter Feature-Modifizierer %qs in %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "fehlender CPU-Name in %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "unbekannter Wert %qs für %<-mtune%>"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "Schalter %<-mcpu=%s%> steht mit dem Schalter %<-march=%s%> in Konflikt"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "Assembler unterstützt %<-mabi=ilp32%> nicht"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "Signieren der Rückgabeadresse wird nur für %<-mabi=lp64%> unterstützt"
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "Codemodell %qs mit %<-f%s%>"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "Codemodell %qs wird im ilp32-Modus nicht unterstützt"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"arch=\")%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90158
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"arch=\")%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90158
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "ungültiger Featuremodifizierer %qs mit Wert %qs in Pragma oder Attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "fehlendes Argument für Pragma oder Attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "ungültiger Schutztyp %qs in Pragma oder Attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "fehlender Wert für Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> akzeptiert keine Argumente"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> erlaubt keine negierte Form"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s=%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
-msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich, sofern C++17 aktiviert ist, so geändert, dass es C++14 in GCC 10.1 entspricht"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr "die Parameterübergabe für das Argument vom Typ %qT mit %<[[no_unique_address]]%>-Elementen hat sich %{in GCC 10.1%} geändert"
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich, sofern C++17 aktiviert ist, so geändert, dass es C++14 %{in GCC 10.1%} entspricht"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79872
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%KSpur %wd außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "Spur %wd ist außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "nicht unterstützte simdlen %d"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC unterstützt derzeit keine Typen gemischter Größe für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC bietet derzeit keine Unterstützung für Rückgabetyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "nicht unterstützter Rückgabetyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC bietet derzeit keine Unterstützung für Parametertyp %qT für %<simd%>-Funktionen"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr "GCC unterstützt derzeit %<simdlen %d%> für Typ %qT nicht"
@@ -33201,17 +33244,17 @@ msgstr "Argument des Attributes %qE ist weder »ilink1« oder »ilink2«"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "Argument des Attributes %qE ist weder »ilink« oder »firq«"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33361,12 +33404,12 @@ msgstr "unbekannte Ausgabe %qs des %<asm%>-Schalters"
 msgid "invalid type for %<asm%> flag output"
 msgstr "ungültiger Typ für %<asm%>-Schalter-Ausgabe"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "%KKoprozessor %d ist nicht aktiviert mit +cdecp%d"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr "%KKoprozessornummer muss eine direkt angegebene Konstante im Bereich 0 bis %d sein, die mit +cdecp<N> aktiviert wurde"
@@ -33374,195 +33417,195 @@ msgstr "%KKoprozessornummer muss eine direkt angegebene Konstante im Bereich 0 b
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%KArgument %d von %qE muss eine direkt angegebene Konstante im Bereich [0-%d] sein"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "diese eingebaute Funktion wird auf diesem Ziel nicht unterstützt"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%KBitbereich der Sättigung muss im Bereich [%wd, %wd] liegen"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "%KBitbereich der Sättigung muss eine direkt angegebene Konstante sein"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie MVE-Befehle einschalten."
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90148
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie NEON-Befehle einschalten (zum Beispiel mit %<-mfloat-abi=softfp -mfpu=neon%>)."
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie VFP-Befehle einschalten."
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie Krypto-Befehle einschalten (zum Beispiel mit %<-mfloat-abi=softfp -mfpu=crypto-neon%>)"
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "Wähler muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "der Wertebereich des Selektors sollte 0 bis 7 sein"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "der Wertebereich des Selektors sollte 0 bis 3 sein"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "der Wertebereich des Selektors sollte 0 bis 1 sein"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "Maske muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "der Wertebereich der Maske ist 0 bis 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_rori_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_ror_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_si64 im Code prüfen."
@@ -33572,286 +33615,286 @@ msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sr
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr "Argument %u von Funktion %qE ist vom Typ %qT, und der ist nicht garantiert 128 Bit groß"
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt und NEON sind unverträglich"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "Ziel-CPU unterstützt nicht ARM-Modus"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "Das Einschalten der Ablaufverfolgung ist nur bei der Übersetzung für THUMB sinnvoll"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "Das Einschalten der Unterstützung der Aufgerufenen-Zusammenarbeit ist nur bei der Übersetzung für THUMB sinnvoll"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "%<-g%> mit %<-mno-apcs-frame%> könnte vernünftiges Debugging verhindern"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt wird im Thumb-Modus nicht unterstützt"
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "%<-mtp=cp15%> kann nicht mit 16-Bit-Thumb verwendet werden"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC ist mit Thumb unverträglich"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr "%s unterstützt nicht-PIC-Code nur auf M-Profil-Zielen mit dem MOVT-Befehl"
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr "%s unterstützt nicht-PIC-Code nur auf M-Profil-Zielen"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90160
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "»%s« verträgt sich nicht mit %<-mword-relocations%>"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "Ziel-CPU unterstützt keine THUMB-Befehle"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "Ziel-CPU unterstützt keine unausgerichteten Zugriffe"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "%<-mapcs-stack-check%> verträgt sich nicht mit %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "%<-fpic%> und %<-mapcs-reent%> sind inkompatibel"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "wiedereinsprungsfähiger APCS-Code nicht unterstützt. Ignoriert"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr "option %<-mstructure-size-boundary%> ist veraltet"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "Grenze für Strukturgröße kann nur auf 8, 32 oder 64 gesetzt werden"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "Grenze für Strukturgröße kann nur auf 8 oder 32 gesetzt werden"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC ist mit %<-msingle-pic-base%> unverträglich"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "Der FDPIC-Modus wird im Thumb-1-Modus nicht unterstützt"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "%<-mpic-register=%> ist ohne %<-fpic%> nutzlos"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "%qs kann nicht als PIC-Register verwendet werden"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> wird auf dieser Architektur nicht unterstützt"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "die ausgewählten fp16-Optionen sind inkompatibel"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt erfordert ein AAPCS-kompatibles ABI für den richtigen Einsatz"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt ABI erfordert eine iwmmxt-fähige CPU"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "Ziel-CPU unterstützt keine Zusammenarbeit"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS unterstützt nicht %<-mcaller-super-interworking%>"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS unterstützt nicht %<-mcallee-super-interworking%>"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 ohne ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "Ziel-CPU unterstützt keine ARMv8-M-Security-Erweiterungen"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "ARMv8-M Security Extensions sind mit der gewählten FPU inkompatibel"
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "%<-mfloat-abi=hard%>: ausgewählter Prozessor hat keine FPU"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "%<-mfloat-abi=hard%> und VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "von nicht-AAPCS abgeleitete PCS-Variante"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadische Funktionen müssen die AAPCS-Basisvariante verwenden"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS-Variante"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 Hardware-Gleitkomma VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr "Argument vom Typ %qT ist zusammen mit »-mgeneral-regs-only« nicht erlaubt"
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 7.1 geändert"
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die Argumente auf dem Stack übergeben"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die variable Anzahl von Argumenten haben"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die Argumente auf dem Stack zurückgeben"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "Attribut %qE ignoriert, da die Option %<-mcmse%> nicht angegeben ist."
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "Attribut %qE wirkt sich nicht auf Funktionen mit »static«-Bindung aus"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "Attribut %qE kann nur auf Basistypen von Funktionszeiger angewandt werden"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "Zugriff auf threadlokalen Speicher wird derzeit mit %<-mpure-code%> oder %<-mslow-flash-data%> nicht unterstützt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "Wirkliche Stelle des gestapelten Parameters kann nicht berechnet werden"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Unexpected thumb1 far jump"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "keine unteren Register für das Hervorholen der hohen Register verfügbar"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "Interrupt-Dienst-Routinen können nicht im »Thumb«-Modus codiert werden"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> für Thumb-1"
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
@@ -33859,22 +33902,22 @@ msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatische FPU-Auswahl ist hier momentan nicht erlaubt"
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "Ungültige Architektur für Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "Unbekanntes Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "%<asm%>-Schalter werden im Thumb1-Modus nicht unterstützt"
@@ -33953,17 +33996,17 @@ msgstr "%<-fpie%> wird nicht unterstützt"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> wird nicht unterstützt"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "Funktionsattribute %qs und %qs schließen sich gegenseitig aus"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Funktion %qs kann keine Argumente haben"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "Funktion %qs kann keinen Wert zurückgeben"
@@ -34226,7 +34269,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "indirekter Aufruf in Funktion, das wird von eBPF nicht unterstützt"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "ungültiges Argument für eingebaute Funktion"
@@ -34560,52 +34603,52 @@ msgstr "doppelt angegebener Parameter »%s« in Attribut »amdgpu_hsa_kernel«"
 msgid "too many arguments passed in sgpr registers"
 msgstr "zu viele Argumente, die in SGPR-Registern übergeben werden"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr "Es wurde ein nicht standardmäßiger Satz von Anfangswerten angefordert, was gegen das ABI verstößt!"
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "Argument falschen Typs für »%s«"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "geschachtelte Funktionstrampoline werden auf GCN5 aufgrund nicht ausführbarer Stacks nicht unterstützt"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr "TLS ist für GCN nicht implementiert."
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr "Eingebaute Funktion nicht implementiert"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr "vector_length (64) wird verwendet, %d wird ignoriert"
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr "vector_length (64) wird verwendet, Laufzeiteinstellung wird ignoriert"
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "num_workers (%d) wird verwendet, %d wird ignoriert"
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "Auslagerungsdimension %d liegt außerhalb des Wertebereiches"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr "lokaler Speicher für gemeinsam genutzte Daten aufgebraucht"
@@ -34739,132 +34782,132 @@ msgstr "Parameter für eingebaute Funktion muss Zeichenkettenkonstante oder Lite
 msgid "parameter to builtin not valid: %s"
 msgstr "Parameter für eingebaute Funktion ist ungültig: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "Interrupt-Dienst-Routinen können nicht direkt aufgerufen werden"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Das letzte Argument muss ein 2-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fünftes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "drittes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "das letzte Argument muss ein 3-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Das vorletzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "das dritte Argument muss eine Vergleichskonstante sein"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "Falscher Vergleichsmodus"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "Falscher Rundungsoperand"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Der direkte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Das direkte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Das direkte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "Selektor muss eine Ganzzahlkonstante im Bereich [0, %wi] sein"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE erfordert unbekannte ISA-Option"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE erfordert ISA-Option %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "das letzte Argument muss ein Immediate sein"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "Das letzte muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "Das vierte Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "Falscher Hinweis-Operand"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "Das Argument zum eingebauten %<xabort%> ein 8-Bit-Direktwert sein"
@@ -35244,144 +35287,144 @@ msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstüt
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-Befehle sind in Exception-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-Befehle sind in Interrupt-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-Befehle sind in Funktionen mit %<no_caller_saved_registers%>-Attribut nicht erlaubt"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "Attribute %qs und %qs sind nicht verträglich"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Argument des Attributes %qE ist nicht (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ %qs sein"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp %<void%> haben"
@@ -35828,7 +35871,7 @@ msgstr "%qE kann nicht gleichzeitig die Attribute %qs und %qs haben"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE mit in Konflikt stehenden Attributen %qs redeklariert"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
@@ -36912,52 +36955,52 @@ msgstr "%<__delay_cycles%> nimmt nur nicht-negative Zykluszahlen entgegen"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "%<__delay_cycles%> ist auf 32-Bit-Schleifendurchläufe beschränkt"
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "unbekannte CPU %qs für %<-mtune%>"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI für abgeflachte Struktur mit Bit-Feldern der Länge 0 hat wurde mit GCC 10 geändert"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "Argument des Attributs %qE ist weder »user«, noch »supervisor« noch »machine«"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> erfordert %<-march%>, um die %<M%>-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "die angeforderte ABI erfordert %<-march%>, um die %qc-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e erfordert die ilp32e-ABI"
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI erfordert %<-march=rv%d%>"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> muss zwischen %d und %d liegen"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V-ELF-Attribut erfordert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs-Funktion kann keine andere Interrupt-Art haben"
@@ -37073,323 +37116,324 @@ msgstr "Zahl muss 0 oder 1 sein"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "Ausschuss am Ende von %<#pragma longcall%>"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 3 Argumente"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 1 Argument"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Qualifizierer von Zeiger-Ziel-Typ"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "eingebaute Funktion %qs erfordert eingebaute Funktion %qs"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs wird von dieser Compiler-Konfiguration nicht unterstützt"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ungültige Parameterkombination für AltiVec-spezifisches intrinsisches %qs"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz zurückgegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; %qs schaltet sie ein"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "das ABI der Parameterübergabe für Aggregate mit %d-Byte-Ausrichtung hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; %qs schaltet sie ein"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "das ABI für die Übergabe von homogenen %<float%>-Aggregaten hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz übergegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "internal error: builtin function %qs already processed"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_mffsl%> wird in Kombination mit %<-msoft-float%> nicht unterstützt"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Argument 1 muss ein 8-Bit-Feldwert sein"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_mtfsb0%> und %<__builtin_mtfsb1%> werden in Kombination mit %<-msoft-float%> nicht unterstützt"
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr "Argument muss eine Konstante zwischen 0 und 31 sein."
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_set_fpscr_rn%> wird in Kombination mit %<-msoft-float%> nicht unterstützt"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr "Argument muss ein Wert zwischen 0 und 3 sein."
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "%<__builtin_set_fpscr_drn%> wird im 32-Bit-Modus nicht unterstützt"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_set_fpscr_drn%> wird in Kombination mit %<-msoft-float%> nicht unterstützt"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr "Argument muss ein Wert zwischen 0 und 7 sein."
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Argument 1 muss ein vorzeichenbehaftetes 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 2-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 3-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 4-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 7-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "Argument 1 von %qs muss eine Konstante sein"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "Argument 1 von %qs ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "eingebaute Funktion %qs kann nur im 64-Bit-Modus verwendet werden"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Argument %d muss ein vorzeichenloses Literal sein"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Argument %d ist ein vorzeichenloses Literal, aber außerhalb des gültigen Bereichs"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "eingebaute Funktion %qs kann nur im 64-Bit-Modus verwendet werden"
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "eingebaute Funktion %qs akzeptiert nur ein Zeichenkettenargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "CPU %qs ist ein ungültiges Argument für eingebaute Funktion %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs ist ein ungültiges Argument für eingebaute Funktion %qs"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "eingebaute Funktion %qs erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 4-Bit-Symbol sein"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 1-Bit-Symbol sein"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Argument 1 muss 0 oder 2 sein"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Argument 2 muss 0 oder 1 sein"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "Argument 3 muss im Bereich [0, 15] liegen"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Argument für %qs muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ungelöste Überladung des eingebauten Altivec %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr "zweites Argument für %qs muss im Bereich [0, 12] liegen"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "drittes Argument für %qs muss im Bereich [0, 12] liegen"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "%qs ist nur für den Cell-Prozessor gültig"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "%qs erfordert die Option %qs"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "%qs erfordert die Optionen %qs und %qs"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "%qs erfordert ISA 3.0 IEEE 128-Bit-Gleitkommazahlen"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "%qs erfordert die Optionen %qs (oder neuer), sowie %qs oder %qs"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "%qs wird mit den aktuellen Optionen nicht unterstützt"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "internal error: builtin function %qs had an unexpected return type %qs"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
@@ -37409,219 +37453,224 @@ msgstr "%qs verwendet Register r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Stapelrahmen größer als 2G wird für %<-fsplit-stack%> nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs erfordert %qs oder %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs erfordert PowerPC64-Architektur, wird eingeschaltet"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs wird für 64-Bit-Darwin nicht unterstützt; es ist mit den installierten C- und C++-Bibliotheken unverträglich"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec wird für dieses Ziel nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs wird auf »little endian«-Systemen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "power9-Zieloption ist mit %<%s=<xxx>%> für <xxx> kleiner als power9 inkompatibel"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs inkompatibel mit explizit ausgeschalteten Optionen"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs erfordert %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "Ziel-Attribut oder Pragma ändert Größe von %<long double%>"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs erfordert vollständige Unterstützung von ISA 2.06"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE %<long double%> mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM %<long double%> mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs erfordert VSX-Unterstützung"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "Die Option %<-mfloat128%> wird möglicherweise nicht vollständig unterstützt"
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs erfordert vollständige Unterstützung von ISA 3.0"
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "unbekannter ABI-Typ (%qs) für Vektorisierungsbibliothek für Schalter %qs"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "Ziel-Attribut oder Pragma ändert AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "Ziel-Attribut oder Pragma ändert darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs ist in %qs keine gültige Zahl"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs ist in %qs kein gültiges Basisregister"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs erfordert ein gültiges Basisregister"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "unbekannte Option für %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs ist veraltet und wird unter keinen Umständen empfohlen"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "das Layout von Aggregaten, die Vektoren mit %d-Byte-Ausrichtung enthalten, hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr "%qs ist ein undurchsichtiger Typ, und Sie können ihn nicht auf andere Werte setzen."
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Bei Verwendung der Option %qs kann die Adresse von geschachtelten Funktionen nicht verwendet werden"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ungültige CPU %qs für %s%qs%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s ist ungültig"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> schaltet %<-m%s%> aus"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "das Attribut %<target_clones%> erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Multiversionierung erfordert »ifunc«, was in dieser Konfiguration nicht unterstützt wird"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
@@ -37946,139 +37995,139 @@ msgstr "das angeforderte %qE-Attribut ist kein kommaseparierter Paar von nichtne
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "Argument für %qE ist nicht (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Gesamtgröße der lokalen Variablen übersteigt Grenze der Architektur"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, größer als benutzerdefinierte Stapelgrenze von %d Bytes. Eine unbedingte Falle wird gesetzt."
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, mehr als die Hälfte der Stapelgröße. Dynamische Prüfung wäre nicht zuverlässig. Für diese Funktion wird keine Prüfung ausgegeben."
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Rahmengröße von %qs ist %wd Bytes"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs verwendet dynamische Stapelanforderung"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "auf s390 können geschachtelte Funktionen mit %<-mfentry%> nicht im Profiling verwendet werden"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-Bit-ABI nicht unterstützt im ESA/390-Modus"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline wird nur mit %<-mindirect-branch-jump%> unterstützt"
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "Hardware-Vektorunterstützung ist auf %s nicht verfügbar"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "Hardware-Vektorunterstützung ist mit %<-msoft-float%> nicht verfügbar"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind auf %s nicht verfügbar"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind im ESA/390-Modus nicht verfügbar"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> kann nicht in Verbindung mit %<-msoft-float%> verwendet werden"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "die Kombination aus %<-mbackchain%>, %<-mpacked-stack%> und %<-mhard-float%> wird nicht unterstützt"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "Stapelgröße muss größer als der Stapel-Überwachungswert sein"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "Stapelgröße darf nicht größer als 64k sein"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> bringt %<-mstack-size%> mit sich"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-prologue-check« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-prologue-target« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-epilogue-check« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr "»-mtpf-trace-hook-epilogue-target« erfordert eine Ganzzahl im Bereich 0..4095"
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> wird nur auf 64-Bit-CPUs unterstützt"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "Argumente von %qs sollten nicht-negative Ganzzahlen sein"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "Argument für %qs ist zu groß (max. %d)"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> kann nur zusammen mit %<-fpic%>/%<-fPIC%> verwendet werden"
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) ist unbekannt"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "Wert %qs wird von Attribut %<target%> nicht unterstützt"
@@ -38496,8 +38545,8 @@ msgstr "Attribut %qs bezieht sich nur auf Arraytypen"
 msgid "could not read the BRIG file"
 msgstr "BRIG-Datei konnte nicht gelesen werden"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-Wert nicht ignoriert wie es sein sollte"
@@ -38774,7 +38823,7 @@ msgstr "Deklaration von %q+D überdeckt eine vorhergehende Nicht-Variable"
 msgid "declaration of %qD shadows a parameter"
 msgstr "Deklaration von %qD überdeckt einen Parameter"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
@@ -38844,7 +38893,7 @@ msgstr "%qE nicht deklariert (erste Verwendung in dieser Funktion)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "jeder nicht deklarierte Bezeichner wird nur einmal für jede Funktion, in der er vorkommt, gemeldet"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "Marke %qE außerhalb einer Funktion referenziert"
@@ -38874,7 +38923,7 @@ msgstr "Sprung in Anweisungs-Ausdruck"
 msgid "duplicate label declaration %qE"
 msgstr "Doppelte Markendeklaration %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "doppelte Marke %qD"
@@ -39082,7 +39131,7 @@ msgstr "Objekt mit volatile-Feld kann nicht in Register geladen werden"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "nicht initialisiertes %<const %qD%> ist in C++ ungültig"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
@@ -39421,7 +39470,7 @@ msgstr "Typname als Funktion, die ein Array zurückgibt, deklariert"
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
@@ -39728,7 +39777,7 @@ msgstr "Verschachtelte Redefinition von %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
@@ -39778,7 +39827,7 @@ msgstr "struct hat keine benannten Elemente"
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Arrayelement in Union"
@@ -39814,7 +39863,7 @@ msgstr "Verschachtelte Redefinition von %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "Redeklaration von %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
@@ -39844,7 +39893,7 @@ msgstr "Überlauf in Aufzählungswerten"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO-C beschränkt Aufzählungswerte auf Bereich von %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "der inline-Funktion %qD wurde das Attribut %qs gegeben"
@@ -39874,7 +39923,7 @@ msgstr "kein vorheriger Prototyp für %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
@@ -39989,12 +40038,12 @@ msgstr "Argument %qD passt nicht zu eingebautem Prototypen"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
@@ -40002,257 +40051,257 @@ msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Anfangsdeklarationen in %<for%>-Schleifen sind nur im C99- oder C11-Modus erlaubt"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "die Option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> oder %<-std=gnu11%> verwenden, um den Code zu übersetzen"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "Deklarationen im Initialisierungsteil einer %<for%>-Schleife werden von ISO C90 nicht unterstützt; ab ISO C99 geht es"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der »static«-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der %<extern%>-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der Nicht-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "Inkompatible Adressraumkennzeichen %qs und %qs"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "Doppelter Deklarationsspezifizierer %qE"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO-C90 unterstützt nicht %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO-C90 unterstützt keine komplexen Typen"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO-C unterstützt keine sättigenden Typen"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "doppeltes %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO-C unterstützt die Typen %<__int%d%> nicht"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO-C90 unterstützt keine booleschen Typen"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO-C unterstützt den Typen %<_Float%d%s%> nicht"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO-C unterstützt dezimale Gleitkommazahlen erst ab C2X"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "Festkommatypen werden für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO-C unterstützt keine Ganzzahltypen"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "Nachschlagen von %qD würde in C++ ein Feld, keinen Typen zurückgeben"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ist kein typedef oder eingebauter Typ"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ist nicht am Anfang einer Deklaration"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE mit %<auto%> verwendet"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE mit %<register%> verwendet"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE mit %<typedef%> verwendet"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO-C99 unterstützt nicht %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO-C90 unterstützt nicht %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vor %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vor %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "doppeltes %<_Thread_local%> oder %<__thread%>"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "mehrere Speicherklassen in Deklaration"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs mit %qE verwendet"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> ohne %<_Fract%> oder %<_Accum%> verwendet"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> gefolgt von %<[[]]%>-Attributen"
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-Kombinierer verweist auf Variable %qD, die weder %<omp_out%> noch %<omp_in%> ist"
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-Initialisierung verweist auf Variable %qD, die weder %<omp_priv%> noch %<omp_orig%> ist"
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "left shift of negative value"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "Links-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "Links-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "Rechts-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "Links-Schiebe-Weite >= Breite des Vektorelements"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "Rechts-Schiebe-Weite >= Breite des Vektorelements"
@@ -40272,7 +40321,7 @@ msgstr "Konfliktmarker für Versionskontrolle in Datei"
 msgid "to match this %qs"
 msgstr "andere Fundstelle von %qs ist hier"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -40318,7 +40367,7 @@ msgid "unknown type name %qE"
 msgstr "unbekannter Typname: %qE"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -40338,7 +40387,7 @@ msgstr "%<fallthrough%>-Attribut auf höchster Ebene"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -40353,8 +40402,8 @@ msgstr "Präfixattribute werden für Implementierungen ignoriert"
 msgid "unexpected attribute"
 msgstr "unerwartetes Attribut"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%<fallthrough%>-Attribut ohne darauffolgendes %<;%>"
@@ -40392,7 +40441,7 @@ msgstr "%<__auto_type%> benötigt eine initialisierte Datendeklaration"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kann nur mit einem einzelnen Deklarator verwendet werden"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> oder %<;%> erwartet"
@@ -40420,7 +40469,7 @@ msgstr "ISO-C99 unterstützt nicht %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO-C90 unterstützt nicht %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "Zeichenkettenliteral erwartet"
@@ -40450,7 +40499,7 @@ msgstr "Ausdruck in statischer Behauptung ist nicht konstant"
 msgid "static assertion failed: %E"
 msgstr "statische Behauptung gescheitert: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statische Behauptung gescheitert"
@@ -40495,14 +40544,14 @@ msgstr "Leeres Enum ist ungültig"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "Komma am Ende der Aufzählungsliste"
@@ -40587,7 +40636,7 @@ msgstr "Deklarationsspezifizierer oder %<...%> erwartet"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "Klammern müssen weggelassen werden, wenn die Argumentenliste des Attributs leer ist"
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "Attribut %qE akzeptiert keine Argumente"
@@ -40597,7 +40646,7 @@ msgstr "Attribut %qE akzeptiert keine Argumente"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO-C unterstützt %<[[]]%>-Attribute erst ab C2X"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "Attribut %<deprecated%> darf höchstens einmal in einer Attributliste auftreten"
@@ -40657,7 +40706,7 @@ msgstr "ISO-C90 verbietet gemischte Deklarationen und Code"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> vor %<else%> erwartet"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ohne vorheriges %<if%>"
@@ -40672,7 +40721,7 @@ msgstr "Marke am Ende einer Verbundanweisung"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "Anweisung erwartet"
@@ -40697,17 +40746,17 @@ msgstr "eine Marke kann nur Teil einer Anweisung sein, und eine Deklaration ist
 msgid "expected identifier or %<*%>"
 msgstr "Bezeichner oder %<*%> erwartet"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<if%>-Anweisung empfohlen"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<else%>-Anweisung empfohlen"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "es wird empfohlen, explizite geschweifte Klammern zu setzen, um mehrdeutiges %<else%> zu vermeiden"
@@ -40727,12 +40776,12 @@ msgstr "mehrere Schleifenvariablen in schneller Aufzählung"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ungültiges Schleifenvariable in schneller Aufzählung"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC ivdep%>-Pragma"
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC unroll%>-Pragma"
@@ -40747,8 +40796,8 @@ msgstr "die Sammlung in schneller Aufzählung fehlt"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "doppelter %<asm%>-Qualifizierer %qE"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "erstmals hier gesehen"
@@ -40775,12 +40824,12 @@ msgstr "ISO-C verbietet das Weglassen des mittleren Terms eines %<?:%>-Ausdrucke
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "Division %<sizeof (%T) / sizeof (%T)%> berechnet nicht die Anzahl der Feldelemente"
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "der Operand des ersten %<sizeof%> wurde hier deklariert"
@@ -41171,61 +41220,61 @@ msgstr "Methodendeklaration in Objective-C erwartet"
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<getter%>)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<setter%>)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "das %<setter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "Setter-Name muss mit %<:%> beendet werden"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "das %<getter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> erfordert einen Zuweisungsausdruck, der zu einer nichtnegativen Ganzzahlkonstante kleiner als %u evaluiert"
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> darf nur im Datei-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> darf nur in einem Schleifenkonstrukt mit %<inscan%>-%<reduction%>-Klausel verwendet werden"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
@@ -41235,18 +41284,18 @@ msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt v
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> darf nur im Gültigkeitsbereich einer Datei verwendet werden"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweisung erwartet"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
@@ -41266,53 +41315,53 @@ msgstr "%<)%> oder %<,%> erwartet"
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> oder %<present%> erwartet"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> oder %<shared%> erwartet"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> oder %<exit%> erwartet"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> erwartet"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "zu viele %<if%>-Klauseln mit %qs-Modifizierer"
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "zu viele %<if%>-Klauseln"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "zu viele %<if%>-Klauseln ohne Modifizierer"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "wenn eine der %<if%>-Klauseln einen Modifizierer verwendet, müssen alle %<if%>-Klauseln Modifizierer verwenden"
@@ -41334,12 +41383,12 @@ msgstr "Wert von %<num_threads%> muss positiv sein"
 msgid "%<num_tasks%> value must be positive"
 msgstr "Wert von %<num_tasks%> muss positiv sein"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Wert von %<grainsize%> muss positiv sein"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Wert von %<priority%> muss positiv sein"
@@ -41349,22 +41398,22 @@ msgstr "Wert von %<priority%> muss positiv sein"
 msgid "expected constant integer expression"
 msgstr "konstanten Ganzzahlausdruck erwartet"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> oder %<default%> erwartet"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<scalar%>, %<aggregate%> oder %<pointer%> erwartet"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "zu viele %<defaultmap%>-Klauseln mit %qs-Kategorie"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "zu viele %<defaultmap%>-Klauseln mit nicht angegebener Kategorie"
@@ -41379,52 +41428,52 @@ msgstr "%qs-Ausdruck muss ganzzahlig sein"
 msgid "%qs value must be positive"
 msgstr "Wert %qs muss positiv sein"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "zu viele %<static%>-Argumente"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "unerwartetes Argument"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%>-Argument muss eine positive, ganzzahlige Konstante sein"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> erwartet"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<teams%>, %<parallel%> oder %<thread%> erwartet"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "Argument für %<ordered%> muss ein positiver, ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> oder Bezeichner erwartet"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "widersprüchliche Modifizierer %<monotonic%> und %<nonmonotonic%> angegeben"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
@@ -41434,7 +41483,7 @@ msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 msgid "chunk size value must be positive"
 msgstr "Wert der Chunkgröße muss positiv sein"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -41470,22 +41519,22 @@ msgid "%<simdlen%> clause expression must be positive constant integer expressio
 msgstr "Ausdruck der %<simdlen%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79924
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "Modifizierer %<iterator%> ist unverträglich mit %qs"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ungültige Abhängigkeitsart"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ungültige Zuordnungsart"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ungültige »dist_schedule«-Art"
@@ -41500,77 +41549,77 @@ msgstr "ungültige »proc_bind«-Art"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> oder %<any%> erwartet"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "Klausel %<#pragma acc%> erwartet"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "Klauseln in %<simd%>-Eigenschaft sollten durch %<,%> getrennt werden"
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss die erste Klausel von %qs sein"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "keine gültigen Klauseln in %<#pragma acc declare%> angegeben"
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Arrayabschnitt in %<#pragma acc declare%>"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "In %<#pragma acc declare link%> muss %qD eine globale Variable sein"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ungültige OpenACC-Klausel im Datei-Gültigkeitsbereich"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<extern%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<global%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD muss eine Variable sein, die im selben Gültigkeitsbereich wie %<#pragma acc declare%> deklariert ist"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Variable %qD wird in %<#pragma acc declare%> mehr als einmal verwendet"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "hinter %<#pragma acc %s%> wird %<data%> erwartet"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> hat keine Datenverschiebeklausel"
@@ -41585,7 +41634,7 @@ msgstr "%qE wurde nicht deklariert"
 msgid "expected function name"
 msgstr "Funktionsname erwartet"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD bezeichnet keine Funktion"
@@ -41595,67 +41644,67 @@ msgstr "%qD bezeichnet keine Funktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Funktionsdeklaration oder -definition auftreten"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Deklaration oder Definition einer einzelnen Funktion auftreten"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> muss vor Verwendung angewendet werden"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> muss vor Definition angewendet werden"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> muss mindestens eine %<device%>- oder %<host%>- or %<self%>-Klausel enthalten"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "eine der Klauseln %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> oder %<hint%> erwartet"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "zu viele atomare Klauseln"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "zu viele Speicherreihenfolge-Klauseln"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp atomic read%> ist unverträglich mit den Klauseln %<acq_rel%> und %<release%>"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic write%> ist unverträglich mit den Klauseln %<acq_rel%> und %<acquire%>"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic update%> ist unverträglich mit den Klauseln %<acq_rel%> und %<acquire%>"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
@@ -41665,57 +41714,57 @@ msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrück
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Ausdruck %<depobj%> ist kein lvalue-Ausdruck"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%> oder %<mutexinoutset%> erwartet"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "eine der Klauseln %<depend%>, %<destroy%> oder %<update%> erwartet"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<acq_rel%>, %<release%> oder %<acquire%> erwartet"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<flush%>-Liste wurde zusammen mit Speicherreihenfolge-Klausel angegeben"
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<inclusive%>- oder %<exclusive%>-Klausel erwartet"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> erwartet"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-Klauselparameter ist weniger als %<collapse%>"
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%>-Klausel darf nicht zusammen mit %<ordered%>-Klausel mit einem Parameter angegeben werden"
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
@@ -41725,72 +41774,72 @@ msgstr "Schleifendeklaration oder Initialisierung erwartet"
 msgid "not enough perfectly nested loops"
 msgstr "nicht genügend perfekt geschachtelte Schleifen"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%>-Klausel mit Parameter darf nicht beim %qs-Konstruk angegeben werden"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> mit %<depend%>-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> hinter %qs erwartet"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> erwartet"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> muss mindestens eine %<map%>-, %<use_device_ptr%>- oder %<use_device_addr%>-Klausel enthalten"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> muss mindestens eine %<from%>- oder %<to%>-Klausel enthalten"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> mit Zuordnungstyp außer %<to%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> mit Zuordnungstyp außer %<from%>, %<release%> oder %<delete%> an %<map%>-Klausel"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
@@ -41805,57 +41854,57 @@ msgstr "%<#pragma omp declare %s%> muss von einer Funktionsdeklaration oder -def
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> muss vor der Deklaration oder Definition einer Funktion auftreten"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "Name des Merkmalsselektors erwartet"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "Selektor %qs nicht erlaubt für Kontext-Selektorsatz %qs"
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "Selektor %qs akzeptiert keine Eigenschaften"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "das Score-Argument muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "das Score-Argument darf nicht negativ sein"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "Eigenschaft muss ein konstanter ganzzahliger Ausdruck oder ein Zeichenkettenliteral sein"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "Bezeichner oder Zeichenkettenliteral erwartet"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "Eigenschaft muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "Eigenschaften für %<simd%>-Selektor dürfen nicht in %<metadirective%> angegeben werden"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<construct%>, %<device%>, %<implementation%> oder %<user%> erwartet"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> erwartet"
@@ -41865,12 +41914,12 @@ msgstr "%<match%> erwartet"
 msgid "variant %qD is not a function"
 msgstr "Variante %qD ist keine Funktion"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "Variante %qD und Basis %qD haben unverträgliche Typen"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "die Variante %qD ist eine eingebaute"
@@ -41880,32 +41929,32 @@ msgstr "die Variante %qD ist eine eingebaute"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "hinter %<#pragma omp declare %s%> muss direkt eine Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "hinter %<#pragma omp declare %s%> muss direkt eine einzelne Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD ist sowohl in %<link%>- als auch %<to%>-Klauseln des Deklarationsziels angegeben"
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr "Direktiven mit nur %<device_type%>-Klauseln werden ignoriert"
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> erwartet"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> erwartet"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> ohne zugehöriges %<#pragma omp declare target%>"
@@ -41960,42 +42009,42 @@ msgstr "Funktionsname und %<(%> erwartet"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "eins der Argumente für den Initialisierungsaufruf sollte %<&omp_priv%> sein"
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> oder %<variant%> erwartet"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<seq_cst%>, %<relaxed%> oder %<acq_rel%> erwartet"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "eine der Klauseln %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> oder %<atomic_default_mem_order%> erwartet"
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "die %qs-Klausel wird in der %<requires%>-Direktive noch nicht unterstützt"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "%qs-Klausel wird lexikalisch nach dem ersten Zielkonstrukt oder nach der ersten Auslagerungs-API verwendet"
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "mehr als eine %<atomic_default_mem_order%>-Klausel in einer einzigen Übersetzungseinheit"
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "%<atomic_default_mem_order%>-Klausel wird lexikalisch nach dem ersten %<atomic%>-Konstrukt ohne Speicherreihenfolge-Klausel verwendet"
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> erfordert mindestens eine Klausel"
@@ -42010,27 +42059,27 @@ msgstr "Typ %qT mit Größe 0 in %<reduction%>-Klausel"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "Typ %qT mit variabler Länge in %<reduction%>-Klausel"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Verwendung als %<threadprivate%> deklariert"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
@@ -42040,7 +42089,7 @@ msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "Funktionsaufruf von %<__transaction_cancel%> nicht innerhalb von äußerer %<__transaction_atomic%>- oder %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
@@ -42055,7 +42104,7 @@ msgstr "fehlende schließende geschweifte Klammer"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD hat unvollständigen Typ %qT"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "falsche Verwendung eines void-Ausdruckes"
@@ -42177,7 +42226,7 @@ msgstr "Dereferenzierung eines %<void *%>-Zeigers"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indizierter Wert ist weder Array noch Zeiger noch Vektor"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "Arrayindex ist keine Ganzzahl"
@@ -42202,7 +42251,7 @@ msgstr "ISO-C90 verbietet, ein Nicht-L-Wert-Array zu indizieren"
 msgid "enum constant defined here"
 msgstr "enum-Konstante hier definiert"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> auf Array-Funktionsparameter %qE gibt die Größe von %qT zurück"
@@ -42315,17 +42364,17 @@ msgstr "implizite Umwandlung von %qT in %qT bei Übergabe von Argument an Funkti
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "zu wenige Argumente für eingebaute Funktion %qE, %u erwartet"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Vergleich mit Zeichenkettenliteral führt zu unspezifiziertem Verhalten"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "Vergleich zwischen Zeiger und '\\0'"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "wollten Sie vielleicht den Zeiger dereferenzieren?"
@@ -42350,7 +42399,7 @@ msgstr "Zeiger auf eine Funktion in Subtraktion verwendet"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "Arithmetik mit Zeiger auf unvollständigen Typen"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "Arithmetik mit Zeiger auf leeres Aggregat"
@@ -42598,7 +42647,7 @@ msgstr "Typkonvertierung von Zeiger auf Ganzzahl anderer Breite"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "Typumwandlung von Funktionsaufruf des Typs %qT in unpassenden Typen %qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "Typkonvertierung in Zeiger von Ganzzahl anderer Breite"
@@ -42765,7 +42814,7 @@ msgstr "Links-Zuweisung könnte Kandidat für Formatattribut sein"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
@@ -42925,7 +42974,7 @@ msgstr "Array von %qT kann nicht aus einem Zeichenkettenliteral mit Typ %<Array
 msgid "array of inappropriate type initialized from string constant"
 msgstr "Array unpassenden Typs mit Zeichenkettenkonstante initialisiert"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ungültige Verwendung eines Nicht-L-Wert-Arrays"
@@ -42956,7 +43005,7 @@ msgstr "Initialisierungs-Element ist zur Lade-Zeit nicht berechenbar"
 msgid "invalid initializer"
 msgstr "ungültige Initialisierung"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
@@ -43101,7 +43150,7 @@ msgstr "Elementüberschreitung in Skalarinitialisierung"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO-C verbietet %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
@@ -43141,7 +43190,7 @@ msgstr "%<long%> switch-Ausdruck nicht nach %<int%> konvertiert in ISO C"
 msgid "case label is not an integer constant expression"
 msgstr "»case«-Marke ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-Marke nicht innerhalb einer switch-Anweisung"
@@ -43151,17 +43200,17 @@ msgstr "case-Marke nicht innerhalb einer switch-Anweisung"
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-Marke nicht innerhalb einer switch-Anweisung"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-Anweisung nicht innerhalb einer Schleife oder »switch«"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-Anweisung nicht innerhalb einer Schleife"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-Anweisung mit OpenMP für Schleife verwendet"
@@ -43176,7 +43225,7 @@ msgstr "break-Anweisung innerhalb einer %<#pragma simd%>-Schleife"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-Anweisung innerhalb einer %<#pragma simd%>-Schleife"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "Anweisung ohne Effekt"
@@ -43186,22 +43235,22 @@ msgstr "Anweisung ohne Effekt"
 msgid "expression statement has incomplete type"
 msgstr "Ausdrucksanweisung hat unvollständigen Typ"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Vergleich von Vektoren mit verschiedenen Element-Typen"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Vergleich von Vektoren mit unterschiedlicher Elementanzahl"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "kein ganzzahliger Typ mit derselben Größe wie %qT gefunden"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "Vergleich von Gleitkomma mit %<==%> oder %<!=%> ist unsicher"
@@ -43252,7 +43301,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "geordneter Vergleich von Zeiger mit Null-Zeiger"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordneter Vergleich von Zeiger mit Ganzzahlnull"
@@ -43282,51 +43331,51 @@ msgstr "Wert eines union-Typs anstelle des geforderten Skalars verwendet"
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "Klauselmodifizierer %<cancel%> %<if%> erwartet"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%>-Ausdruck %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "Bitfeld %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE ist ein Element eines Union-Typs"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "%qE in %qs-Klausel kann nicht dereferenziert werden"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE in %qs-Klausel muss eine Variable sein"
@@ -43336,8 +43385,8 @@ msgstr "%qE in %qs-Klausel muss eine Variable sein"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%>-Deklaration %qD in %qs-Klausel"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD in %qs-Klausel ist eine threadprivate Variable"
@@ -43505,12 +43554,12 @@ msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Elementtyp variabler Länge in %<reduction%>-Klausel eines Arrays"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%>-Klausel darf nicht zusammen mit %<copyprivate%> verwendet werden"
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
@@ -43535,8 +43584,8 @@ msgstr "%<_Atomic%> %qD in %<linear%>-Klausel"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "Schrittweite %qE der %<linear%>-Klausel muss konstant oder ein Parameter sein"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
@@ -43551,19 +43600,19 @@ msgstr "%qD tritt in Reduktionsklauseln mehrfach auf"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE tritt in dieser Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD tritt in Daten- und Zuordnungsklauseln mehrfach auf"
@@ -43633,116 +43682,116 @@ msgstr "%qE sollte einen anderen Typ haben als %<omp_depend_t%>, in der %<depend
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Arrayabschnitt in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Bewegungsklausel mehrfach auf"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE in %qs-Klausel ist weder Variablen- noch Funktionsname"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE tritt in derselben %<declare target%>-Direktive mehrfach auf"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "Variable %qs muss ein Zeiger sein"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "Variable %qs ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<order%>-Klausel darf nicht zusammen mit %<ordered%> verwendet werden"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<inbranch%>-Klausel ist inkompatibel mit %<notinbranch%>"
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-qualifiziertes %qE darf nur in %<shared%>- oder %<firstprivate%>-Klauseln vorkommen"
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-Klauselwert ist größer als %<safelen%>-Klauselwert"
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-Planungsmodifizierer zusammen mit %<ordered%>-Klausel angegeben"
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%qs-Klausel darf nicht zusammen mit %<inscan%>-%<reduction%>-Klausel verwendet werden"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-Klauselschritt ist ein Parameter %qD, der nicht in der %<uniform%>-Klausel angegeben ist"
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<nogroup%>-Klausel darf nicht zusammen mit %<reduction%>-Klausel verwendet werden"
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "%<va_arg%> kann nicht zusammen mit umgedreher Speicherreihenfolge verwendet werden"
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "zweites Argument für %<va_arg%> ist vom unvollständigen Typ %qT"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ erfordert weitergegebenen Typ, nicht Enum-Typ, in %<va_arg%>"
@@ -43925,779 +43974,779 @@ msgid "expected case label"
 msgstr "Interner Fehler: expected case label"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "  die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  keine bekannte Umwandlung für impliziten %<this%>-Parameter von %qH nach %qI"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  Umwandlung von Argument %d wäre unzulässig:"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr "  keine bekannte Umwandlung von %qH nach %qI"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  keine bekannte Umwandlung für Argument %d von %qH nach %qI"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  Kandidat erwartet %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet %d Argumente, %d angegeben"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T, %T)%> (eingebaut)"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T)%> (eingebaut)"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%<%D(%T)%> (eingebaut)"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr "%s%qT (Umwandlung)"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr "%s%#qD (in der Nähe der Übereinstimmung)"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr "%s%#qD (gelöscht)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93880
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr "%s%#qD (umgekehrt)"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr "%s%#qD (umgeschrieben)"
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s%#qD"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr "  hier geerbt"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr " Rückgabetyp %qT der expliziten Umwandlungsfunktion kann nicht mit Qualifizierungsänderung in %qT umgewandelt werden"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr " Umwandlung von Rückgabetyp %qT der Spezialisierung der Template-Umwandlungsfunktion in %qT passt nicht exakt"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr " Ersetzung der ermittelten Templateargumente führte zu obigen Fehlern"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  Herleitung/Ersetzung von Templateargument gescheitert:"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr " Ein Konstruktor, der ein einzelnes Argument seines eigenen Klassentyps hat, ist ungültig"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  ein geerbter Konstruktor ist kein Kandidat für Initialisierung aus einem Ausdruck desselben oder eines abgeleiteten Typs"
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "Umformung von %qH nach %qI ist mehrdeutig"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "das Initialisieren von %qH mit %qI in einem umgewandelten konstanten Ausdruck bindet nicht direkt"
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "Umwandlung von %qH nach %qI in einem umgewandelten konstanten Ausdruck"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE konnte nicht von %qH nach %qI umgewandelt werden"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%D(%A)%> ist nicht eindeutig"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "Zeiger auf Elementfunktion %qE kann nicht ohne Objekt aufgerufen werden; verwenden Sie beispielsweise %<.*%> oder %<->*%>"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "keine Übereinstimmung für Aufruf von %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Aufruf von %<(%T) (%A)%> ist nicht eindeutig"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "mehrdeutiges Überladen für "
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr "keine Übereinstimmung für "
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (Operandentypen sind %qT, %qT und %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (Operandentypen sind %qT und %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (Operandentyp ist %qT)"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "ternärer %<operator?:%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "ternärer %<operator?:%> in %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> in %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> in %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs in %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> in %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> in %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> in %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO-C++ verbietet das Auslassen des mittleren Terms eines %<?:%>-Ausdrucks"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "erschlossener skalarer Typ %qT muss ein Ganzzahl- oder Gleitkommatyp derselben Größe wie %qT sein"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "Umwandlung von Skalar %qH in Vektor %qI führt zum Abschneiden"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "unverträgliche Vektortypen in bedingtem Ausdruck: %qT, %qT und %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "zweiter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der dritte Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "dritter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der zweite Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "Operanden für %<?:%> haben unterschiedliche Typen %qT und %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  und jeder Typ kann zu jedem anderen konvertiert werden"
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "implizite Umwandlung von %qH in %qI, um an das Ergebnis im anderen Zweig der Bedingung anzugleichen"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "bedingter Ausdruck enthält unverträgliche Aufzählungswerte der Typen %qT und %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "Aufzählungs- und Nicht-Aufzählungstyp in bedingtem Ausdruck"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert, stattdessen wird Präfixoperator versucht"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "in C++20 ruft dieser Vergleich die aktuelle Funktion rekursiv mit vertauschten Argumenten auf"
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "Rückgabetyp von %qD ist nicht %qs"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "als umgeschriebener Kandidat für den Vergleich von %qT und %qT verwendet"
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "Vergleich zwischen %q#T und %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "Exceptionaufräumen für dieses Placement-New wählt delete-Operator für Nicht-Placement"
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD ist eine übliche (nicht-placement) Deallokationsfunktion in C++14 (oder mit %<-fsized-deallocation%>)"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD ist eine gewöhnliche (nicht-Platzierungs) Deallokationsfunktion"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "keine passende Freigabefunktion für %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "kein geeignetes %<operator %s%> für %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D ist in diesem Zusammenhang »private«"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "hier als »private« deklariert"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D ist in diesem Zusammenhang »protected«"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "hier als »protected« deklariert"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D ist in diesem Zusammenhang unzugänglich"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Übergabe von NULL an Nicht-Zeiger-Argument %P von %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  hier deklariert"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "Konvertierung in Nicht-Zeiger-Typ %qT von NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%<false%> wird für Argument %P von %qD in Zeigertyp umgewandelt"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "%<false%> wird in Zeigertyp %qT umgewandelt"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  Argument %P von %qD wird initialisiert"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Umwandlungen in Arrays mit unbekannten Grenzen sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "zu viele geschweifte Klammern um Initialisierung für %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "Umwandlung von %qH nach %qI erfordert direkte Initialisierung"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ungültige benutzerdefinierte Umwandlung von %qH in %qI"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "ungültige Umwandlung von %qH in %qI"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "Umwandlung in %qT von Initialisierungsliste würde expliziten Konstruktor %qD verwenden"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "in C++11 und neuer kann ein Defaultkonstruktor explizit sein"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "rvalue-Referenz vom Typ %qH kann nicht an lvalue vom Typ %qI gebunden werden"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "nicht-konstante lvalue-Referenz vom Typ %qH kann nicht an rvalue vom Typ %qI gebunden werden"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "Referenz vom Typ %qH kann nicht an %qI gebunden werden, da die Arraygrenzen sich unterscheiden"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "das Binden der Referenz vom Typ %qH an %qI streicht Qualifizierer"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "das Bitfeld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "das gepackte Feld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "der R-Wert %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implizite Umwandlung von %qH in %qI bei Übergabe von Argument an Funktion"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "enum %qT mit eingeschränkter Sichtbarkeit wird vor %<-fabi-version=6%> als Typ %qT, später jedoch als %qT durch %<...%> übergeben"
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "Referenztyp %qT kann nicht über %<...%> empfangen werden"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursive Auswertung des Standardarguments für %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "Aufruf von %qD verwendet das Standardargument für Parameter %P, der noch nicht definiert wurde"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Argument des Funktionsaufrufs könnte Kandidat für Formatattribut sein"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "Verwendung einer multiversionierten Funktion ohne Standardargument"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  in Aufruf von %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT ist keine erreichbare Basis von %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Argumente werden an Auslassungspunkte des geerbten Konstruktors %qD übergeben"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "Zuweisung von temporärer %<initializer_list%> führt nicht dazu, dass die Lebenszeit des zugrundeliegenden Arrays ausgeweitet wird"
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung"
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivialen Typs %#qT%s"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT mit Element %qs %qD"
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung oder Wertinitialisierung"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Wertinitialisierung"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD Säubern eines Objekts von nichttrivialem Typ %#qT%s"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung oder Kopierinitialisierung"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierinitialisierung"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivial kopierbaren Typs %#qT%s"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD Schreibzugriff auf ein Objekt mit einem gelöschten Kopierkonstruktor"
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD Kopieren eines Objekts mit nichttrivialem Typ %#qT aus einem Array von %#qT"
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD Kopieren eines Objekts des Typs %#qT mit Element %qs %qD aus einem Array von %#qT; verwenden Sie eine Zuweisung oder Kopierinitialisierung stattdessen"
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Bytes unverändert"
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Byte unverändert"
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des nichttrivial kopierbaren Typs %#qT; verwenden Sie stattdessen %<new%> oder %<delete%>"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Kopierkonstruktor; verwenden Sie stattdessen %<new%> und %<delete%>"
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Destruktor"
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD Verschieben eines Objekts des nichttrivialen Typs %#qT und Größe %E in eine Region der Größe %E"
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT wird hier deklariert"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Konstruktor verweist auf sich selbst"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr "%qH kann nicht nach %qI umgewandelt werden"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "um eine funktionsartige Umwandlung zu erreichen, entfernen Sie das redundante %<::%D%>"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%s(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%s(%A)%> ist mehrdeutig"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtuelle %q#D aus nichtstatischem Datenelement-Initialisierer heraus aufgerufen"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtuelle %q#D aus Konstruktor heraus aufgerufen"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtuelle %q#D aus Destruktor heraus aufgerufen"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "Elementfunktion %qD kann nicht ohne Objekt aufgerufen werden"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "Übergabe von %qT wählt %qT statt %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "Wahl von %qD statt %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 msgid "  for conversion from %qH to %qI"
 msgstr "  für Umwandlung von %qH in %qI"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  denn die Umwandlungsfolge für das Argument ist besser"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "Zuordnungsfehler der Standardargumente in Überladungsauflösung"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " Kandidat 1: %q#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " Kandidat 2: %q#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ besagt, dass diese mehrdeutig sind, auch wenn die schlechteste Umwandlung für das erste besser ist als die schlechteste Umwandlung für das zweite:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "eine vorübergehende Bindung an %qD besteht nur, bis der Konstruktor beendet ist"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ungültige Initialisierung einer nicht-konstanten Referenz des Typs %qH von rvalue des Typs %qI"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ungültige Initialisierung einer Referenz des Typs %qH von Ausdruck des Typs %qI"
 
@@ -44726,519 +44775,519 @@ msgstr "Umwandlung von Basisklasse %qT in abgeleitete Klasse %qT nicht möglich,
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "Umwandlung von %qT in Basisklasse %qT nicht möglich, da %qT unvollständig ist"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D steht in Konflikt mit von %qT geerbter Version"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "von %qT geerbte Version ist hier deklariert"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kann nicht mit %q#D überladen werden"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "vorherige Deklaration von %q#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "Zugriffsangaben für Methode %q+D stehen in Konflikt, ignoriert"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "Zugriffsangaben für Feld %qE stehen in Konflikt, ignoriert"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "%qD ist in %q#T ungültig wegen lokaler Methode %q#D mit gleichem Namen"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "lokale Methode %q#D ist hier deklariert"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "%qD ist ungültig in %q#T wegen lokalem Element %q#D mit gleichem Namen"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "lokales Element %q#D ist hier deklariert"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD erbt das %E-ABI-Tag, das %qT (im Rückgabetyp verwendet) hat"
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT hier deklariert"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD erbt das %E-ABI-Tag, das %qT (im Typ verwendet) hat"
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT hat nicht das ABI-Tag %E, das die Basis %qT hat"
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT hat nicht das ABI-Tag %E, das %qT (im Typ von %qD verwendet) hat"
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "Es kann nicht von %<final%>-Basis %qT in abgeleiteten Typ %qT abgeleitet werden"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alle Elementfunktionen in Klasse %qT sind privat"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definiert nur einen privaten Destruktor und hat keine »friends«"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definiert nur private Konstruktoren und hat keine »friends«"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D ist %<public%>, benötigt jedoch ein existierendes Objekt vom Typ %q#T"
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD wurde nicht eindeutig und endgültig in %qT überschrieben"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kann als »override« markiert werden"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D als %<override%> markiert, überschreibt aber nicht"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D als %<final%> markiert, ist aber nicht »virtual«"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD war versteckt"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  von %qD"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "diese Flexibilität ist veraltet und wird demnächst entfernt"
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "die Auslassung in %qD wurde nicht vererbt"
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "Bitfeld %q#D mit Nicht-Ganzzahl-Typ %qT"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "Breite des Bitfeldes %q+D ist keine Ganzzahlkonstante"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negative Breite in Bitfeld %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Breite Null für Bitfeld %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "Breite von %qD übersteigt seinen Typen"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD ist zu klein, um alle Werte von %q#T aufzunehmen"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "Element %q+#D mit Konstruktor nicht erlaubt in Union"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "Element %q+#D mit Destruktor nicht erlaubt in Union"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "Element %q+#D mit Copy-Zuweisungsoperator ist nicht erlaubt in Union"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "uneingeschränkte »Unions« sind nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D kann in C++98 nicht static sein, da es ein Union-Element ist"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "nicht-statisches Datenelement %q+D in einer Union darf keinen Referenztypen %qT haben"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "Datenelement %q+D hat ungültigerweise einen Funktionstypen deklariert"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "Datenelement %q+D hat ungültigerweise einen Methodentyp deklariert"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "»packed«-Attribut für ungepacktes nicht-POD-Feld %q#D wird ignoriert"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Element %q+D darf nicht als %<mutable%>-Referenz deklariert sein"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Element %q+D darf nicht gleichzeitig als %<const%> und %<mutable%> deklariert sein"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "in Union %qT werden mehrere Felder initialisiert"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "das initialisierte Element %q+D wurde hier deklariert"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Feld %q#D mit gleichem Namen wie Klasse"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T hat Zeigertypen als Elemente"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  aber deklariert %<%T(const %T&)%> nicht"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  oder %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  aber deklariert %<operator=(const %T&)%> nicht"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "das Zeigerelement %q+D wurde hier deklariert"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "Ausrichtung von %qD wurde in %<-fabi-version=9%> (GCC 5.2) erhöht"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "Ausrichtung von %qD wird in %<-fabi-version=9%> ansteigen"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Initialisierung für nicht-virtuelle Methode %q+D angegeben"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "Destruktor für %qT ist mehrdeutig"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "Methode überschreibt Methoden %<transaction_pure%> und %qE"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "als %qE deklarierte Methode überschreibt Methode %qE"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "umschließende Klasse der %<constexpr%> nicht-statischen Elementfunktion %q+#D ist kein Literaltyp"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T ist kein Literal, denn: "
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT is a Closure-Typ und ist erst ab C++17 literal"
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T hat einen nicht-trivialen Destruktor"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T hat keinen %<constexpr%>-Destruktor"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T ist kein Aggregat, hat keinen trivialen Standardkonstruktor und hat keinen %<constexpr%>-Konstruktor, der kein Kopier- oder Bewegungskonstruktor ist"
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  Basisklasse %qT von %q+T ist kein Literal"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Basisklasse %q#T hat einen zugänglichen nicht-virtuellen Destruktor"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "nicht-statische Referenz %q#D in Klasse ohne Konstruktor"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "nicht-statisches const-Element %q#D in Klasse ohne einen Konstruktor"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuelle Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "Offset von %qD ist ABI-unverträglich und kann sich in zukünftigen GCC-Versionen ändern"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Größe des Typs %qT ist zu groß (%qE Bytes)"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ungültige Verwendung von %q#T mit Array der Größe 0 in %q#D"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ungültige Verwendung von %q#T mit flexiblem Arrayelement in %q#T"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Arrayelement %q#D hier deklariert"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "Arrayelement %qD mit Länge 0 befindet sich nicht am Ende von %q#T"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "Arrayelement %qD mit Länge 0 in ansonsten leerem %q#T"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "in der Definition von %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibles Arrayelement %qD nicht am Ende von %q#T"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibles Arrayelement %qD in ansonsten leerem %q#T"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T hat virtuelle Funktionen und erreichbaren nicht-virtuellen Destruktor"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typtransparentes %q#T hat keine Felder"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "typtransparente Klasse %qT hat Basisklassen"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "typtransparente Klasse %qT hat virtuelle Funktionen"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparentes %q#T kann nicht transparent gemacht werden, weil der Typ des ersten Feldes anderes ABI als gesamte Klasse hat"
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "Definition von %qD entspricht nicht %<#include <initializer_list>%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "Lesen der struct konnte wegen Syntaxfehlern nicht beendet werden"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Sprachen-Zeichenkette %<\"%E\"%> nicht erkannt"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "überladene Funktion %qD konnte nicht durch Umwandlung in Typ %qT aufgelöst werden"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "bei der Umwandlung der Funktion %qD in den Typ %q#T gab es keine Übereinstimmungen"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "Umwandung der überladenen Funktion %qD in den Typ %q#T ist mehrdeutig"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "Zeiger auf Element %qD wird angenommen"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(ein Zeiger auf ein Element kann nur mit %<»&%E%> erzeugt werden)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "zu wenig Typinformationen"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE kann nicht vom Typ %qT in den Typ %qT umgewandelt werden"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "Deklaration von %q#D ändert die Bedeutung von %qD"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD wurde hier als %q#D deklariert"
@@ -45318,7 +45367,7 @@ msgstr "Kontrollfluss für %<constexpr%>-Aufruf fällt hinten aus der Funktion"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "Aufruf für interne Funktion %qE"
@@ -45374,7 +45423,7 @@ msgstr "Versuch, bereits freigegebenen Speicher freizugeben"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "Speicher, der vorher nicht angefordert wurde, wird freigegeben"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "Aufruf der nicht-%<constexpr%>-Funktion %qD"
@@ -45429,369 +45478,368 @@ msgstr "Schiebeausdruck %q+E läuft über"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "Arithmetik mit Nullzeiger in %qE"
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arrays %qD vom Typ %qT"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array %qD vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arraytyps %qT"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "Zugriff auf uninitialisiertes Arrayelement"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Dereferenzierung eines Nullzeigers in %qE"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "veränderliches %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "Zugriff auf uninitialisiertes Element %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "Zugriff auf Element %qD statt auf initialisiertes Element %qD in Konstantenausdruck"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Dereferenzierung eines Null-Zeigers"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "auf Wert von %qE wird über ein %qT GL-Wert in Konstantenausdruck zugegriffen"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "der Wert von uninitialisiertem Speicher ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "wurde hier deklariert"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "angeforderter Speicher wird in konstantem Ausdruck verwendet, nachdem er wieder freigegeben wurde"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "der Wert von %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD in seiner eigenen Initialisierung verwendet"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D ist nicht konstant"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D ist volatile"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD wurde nicht mit konstantem Ausdruck initialisiert"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD wurde nicht als %<constexpr%> definiert"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD hat keinen Ganzzahl- oder Aufzählungstyp"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "Modifikation von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD während der Initialisierung"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "Anweisung ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "Anzahl der Schleifendurchläufe in %<constexpr%> überschreitet Höchstwert %d (%<-fconstexpr-loop-limit=%> verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "Inline-Assembler ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr "nur unausgewerteter Inline-Assemblercode ist in einer %<constexpr%>-Funktion in C++2a erlaubt"
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Wert %qE vom Typ %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "Anzahl der Evaluierungsoperationen in %<constexpr%> überschreitet Höchstwert %wd (%<-fconstexpr-ops-limit=%> verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "Ein %<reinterpret_cast%> ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "Umwandlung eines Nullpointers vom Typ %qT in %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Ausdruck %qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "unerwartete Template-ID %qE"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "Funktionskonzept muss aufgerufen werden"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unexpected expression %qE of kind %s"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE ist kein Konstantenausdruck, da er auf veränderliche Teilobjekte von %qT verweist"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE ist kein Konstantenausdruck, da er auf eine unvollständig initialisierte Variable verweist"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE ist kein konstanter Ausdruck, da er auf das Ergebnis von %<operator new%> verweist"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE ist kein konstanter Ausdruck, da der angeforderte Speicher nicht vollständig freigegeben wurde"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "unmittelbare Auswertung liefert die Adresse der unmittelbaren Funktion %qD"
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Umwandlung von Zeigertyp %qT in arithmetischen Typ %qT in Konstantenausdruck"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "Umwandlung lvalue-in-rvalue eines volatile-lvalue %qE mit Typ %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Lambda-Einfangen von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "da er als glvalue verwendet wird"
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> von Ganzzahl zu Zeiger"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "Verwendung von %<this%> in Konstantenausdruck"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Lambda-Ausdruck ist erst ab C++17 ein konstanter Ausdruck"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "virtuelle Funktionen können erst mit C++2a %<constexpr%> sein"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<static%> deklariert"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<thread_local%> deklariert"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Arrayinitialisierung"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr "beide Zweige der %<if%>-Anweisung als %qs markiert"
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> wird immer %<terminate%> aufrufen"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "in C++11 sind Destruktoren standardmäßig %<noexcept%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "in C++11 ruft dieses %<throw%> %<terminate%> auf, da Destruktoren standardmäßig %<noexcept%> sind"
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "Attribut %qE wird nach dem früheren %qE ignoriert"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ist kein Typ"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD ist kein Klassentyp"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD hat nicht den Typ %<const char *%>"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD hat keinen Ganzzahltyp"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> enthält nicht nur nicht-statische Datenelemente %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> und %<_M_column%>"
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "%qs wird ausgewertet"
@@ -45832,7 +45880,7 @@ msgstr "Umwandlung in nicht-konstanten Referenztyp %q#T von R-Wert des Typs %qT"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "Umwandlung von %qH in %qI löscht Qualifizierer"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Umwandlung von %qT in %qT dereferenziert nicht den Zeiger"
@@ -45870,292 +45918,292 @@ msgstr "%q#T verwendet, wo ein Gleitkommawert erwartet wurde"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "Umwandlung von %qH in nicht-skalaren Typen %qI angefordert"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "der Rückgabewert von %qD (mit %<nodiscard%>-Attribut markiert) wird ignoriert: %<%s%>"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "der Rückgabewert von %qD (mit %<nodiscard%>-Attribut markiert) wird ignoriert%s"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "der Rückgabewert von Typ %qT (mit %<nodiscard%>-Attribut markiert) wird ignoriert: %<%s%>"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "der Rückgabewert von Typ %qT (mit %<nodiscard%>-Attribut markiert) wird ignoriert%s"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "im Aufruf von %qD, hier deklariert"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%qD hat das Attribut %<warn_unused_result%>, daher sollte der Rückgabewert nicht ignoriert werden"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "Pseudo-Destruktor wird nicht aufgerufen"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des unvollständigen Typs %qT zu"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in zweitem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in drittem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in rechtem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in linkem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des Typs %qT zu"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in zweitem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in drittem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in rechtem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in linkem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT zu"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im zweiten Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im dritten Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im rechten Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im linken Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt %qE des unvollständigen Typs %qT zu"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im zweiten Operanden des bedingten Ausdrucks zugegriffen"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im dritten Operanden des bedingten Ausdrucks zugegriffen"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im rechten Operanden des Kommaoperators zugegriffen"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im linken Operanden des Kommaoperators zugegriffen"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird in Anweisung nicht zugegriffen"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird in Erhöhungsausdruck nicht zugegriffen"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "Umwandlung in void kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "zweiter Operand des bedingten Ausdrucks kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "dritter Operand des bedingten Ausdrucks kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "rechter Operand des Komma-Operators kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "linker Operand des Komma-Operators kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "Anweisung kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "Erhöhungsausdruck kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "zweiter Operand des bedingten Ausdrucks ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "dritter Operand des bedingten Ausdrucks ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "rechter Operand des Komma-Operators ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "linker Operand des Komma-Operators ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "Anweisung ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "Erhöhungsausdruck ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "zweiter Operand des bedingten Ausdrucks hat keinen Effekt"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "dritter Operand des bedingten Ausdrucks hat keinen Effekt"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "rechter Operand des Komma-Operators hat keinen Effekt"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "linker Operand des Komma-Operators hat keinen Effekt"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "Anweisung hat keinen Effekt"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "Erhöhungsausdruck hat keinen Effekt"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "Umwandlung von NULL in Nicht-Zeiger-Typ"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "Template-Argument für %qD kann nicht aus Default-Typumwandlung bestimmt werden"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "mehrdeutige Standard-Typumwandlung von %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  in Frage kommende Umwandlungen beziehen %qD und %qD ein"
@@ -46221,7 +46269,7 @@ msgstr "von vorheriger Deklaration %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Redeklaration %qD unterscheidet sich in %qs von vorheriger Deklaration"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "vorherige Deklaration %qD"
@@ -46402,12 +46450,12 @@ msgstr "vorherige Deklaration von %qD war hier"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "Funktion %qD wurde als %<[[noreturn]]%> deklariert, das weicht von der ersten Deklaration ab"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "redundante Redeklaration von %qD im selben Gültigkeitsbereich"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "Definition von %qD gelöscht"
@@ -46420,44 +46468,44 @@ msgstr "Definition von %qD gelöscht"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explizite Spezialisierung von %qD nach erster Verwendung"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: Sichtbarkeitsattribut ignoriert, da es in Konflikt mit vorheriger Deklaration steht"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "Redefinition von %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD steht mit verwendeter Funktion in Konflikt"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D nicht in Klasse deklariert"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D mit Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D ohne Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "Vergleichsoperator %q+D mit Standardimplementierung nach der ersten Deklaration [class.compare.default]"
@@ -46465,842 +46513,842 @@ msgstr "Vergleichsoperator %q+D mit Standardimplementierung nach der ersten Dekl
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Redeklaration des »friend« %q#D kann keine Standardtemplateargumente haben"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "Thread-lokale Deklaration von %q#D folgt nicht-Thread-lokaler Deklaration"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "Nicht-Thread-lokale Deklaration von %q#D folgt Thread-lokaler Deklaration"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "Redeklaration von %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redundante Redeklaration von %<constexpr%>static-Datenmember %qD"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "lokale Sprungmarke %qE steht in Konflikt mit bestehender Sprungmarke"
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr "vorherige Sprungmarke"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  von hier"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  beendet OpenMP-strukturierten Block"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  überschneidet Initialisierung von %q#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  Eintritt in Gültigkeitsbereich von %q#D mit nicht-trivialem Destruktor"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  betritt %<try%>-Block"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  betritt %<catch%>-Block"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  tritt in OpenMP-strukturierten Block ein"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  synchronisierte oder atomare Anweisung wird betreten"
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  betritt %<constexpr if%>-Anweisung"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  überspringt Initialisierung von %q#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  Eintritt in Gültigkeitsbereich von %q#D mit nicht-trivialem Destruktor"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ungültiger Ausgang von strukturiertem OpenMP-Block"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD wird ohne Template-Argumente verwendet"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ist keine Klasse"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "kein Klassentemplate namens %q#T in %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "kein Typ namens %q#T in %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "Nachschlagen von %qT in %qT ist nicht eindeutig"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Klassentemplate ist"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Typ ist"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "Template-Parameter passen nicht zum Template %qD"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> ist keine Zweierpotenz"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Konstruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Destruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Zuweisungsoperator ist in anonymem Aggregt nicht erlaubt"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "Attribut in Deklaration von %q#T ignoriert"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "Attribut für %q#T muss dem Schlüsselwort %qs folgen"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "mehrere Typen in einer Deklaration"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "Redeklaration des eingebauten C++-Typs %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kann nur für Variablen oder Funktionsdeklarationen angegeben werden"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "fehlender Typname in typedef-Deklaration"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO-C++ verbietet anonyme structs"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kann nur innerhalb einer Klasse angegeben werden"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kann nur für Konstruktoren angegeben werden"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "eine Speicherklasse kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> wurde in dieser Deklaration ignoriert"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kann nicht für Typdeklarationen verwendet werden"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "Attribut in expliter Instanziierung %q#T ignoriert"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "auf explizite Instanziierung kann kein Attribut angewendet werden"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "auf Klassentyp %qT angewandte Attribute außerhalb einer Definition werden ignoriert"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "auf abhängigen Typ %qT angewandte Attribute ohne zugehörige Deklaration werden ignoriert"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen %qs verwenden)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "Deklaration von %q#D hat %<extern%> und ist initialisiert"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "Definition von %q#D ist als %<dllimport%> markiert"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D ist kein static-Datenelement von %q#T"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "Nichtelement-Templatedeklaration von %qD"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "entspricht nicht der Element-Templatedeklaration hier"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO-C++ erlaubt nicht, %<%T::%D%> als %<%T::%D%> zu definieren"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "doppelte Initialisierung von %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "Deklaration von %q#D außerhalb einer Klasse ist keine Definition"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD in %qs-Funktion als %<thread_local%> deklariert"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD in %qs-Funktion als %<static%> deklariert"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "Variable %q#D hat Initialisierung, aber unvollständigen Typ"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "Elemente des Arrays %q#D haben unvollständigen Typ"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "Aggregat %q#D hat unvollständigen Typ und kann nicht definiert werden"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD als Referenz deklariert, aber nicht initialisiert"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "Name in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "Name %qD in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "nicht-trivial markierte Initialisierungen nicht unterstützt"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-Designator %qE ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "Initialisierung gibt nicht die Größe von %qD an"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "Arraygröße fehlt in %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "Array %qD der Größe null"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Speichergröße von %qD ist unbekannt"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Speichergröße von %qD ist nicht konstant"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik der Inline-Variable %q#D ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik von static-Variable %q#D in inline-Funktion ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "dies kann durch das Löschen der Initialisierung umgangen werden"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "nicht initialisiertes %<const %D%>"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Funktion"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Kontext"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T hat keinen benutzerdefinierten Default-Konstruktor"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "Konstruktor ist nicht benutzerdefiniert, da er im Klassenkörper ausdrücklich standardisiert ist"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "und der implizit definierte Konstruktor initialisiert %q#D nicht"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Ungültiger Typ %qT als Initialisierung für einen Vektor des Typs %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "Initialisierung für %qT muss geklammert sein"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> in benannter Initialisierung im GNU-Stil für Klasse %qT verwendet"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT hat kein nicht-statisches Datenelement namens %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ungültige Initialisierung für %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90182
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "zu viele geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "geschweifte Klammern fehlen um Initialisierung für %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "Elemente des Arrays %q#T haben unvollständigen Typ"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "zusammengesetztes Literal variabler Größe"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D hat unvollständigen Typ"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalares Objekt %qD erfordert ein Element in Initialisierung"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "in C++98 muss %qD mit Konstruktor initialisiert werden, nicht mit %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "Array %qD mit geklammerter Zeichenkettenkonstante %qE initialisiert"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "Initialisierung ungültig für statisches Element mit Konstruktor"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(eine Initialisierung außerhalb der Klasse ist erforderlich)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "Referenz %qD wird mit sich selbst initialisiert"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Variantendeklaration nicht gefunden"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> für Konstruktor %qD"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> für Destruktor %qD"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> an %qD mit Vorgabewert"
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> an gelöschter %qD"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> an virtueller %qD"
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO-C++17 erlaubt Speicherklassenangabe %<register%> nicht"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-Speicherklassenangabe verwendet"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "Initialisierung für %<decltype(auto) %D%> hat Funktionstyp; %<()%> vergessen?"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "Variablenkonzept hat keine Initialisierung"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "vorherige Typdeklaration von %q#D wird überschattet"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Attribut %<constinit%> kann nur für Variablen verwendet werden, die »static« oder threadlokel sind"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Strukturelement hat"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Unionelement hat"
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "unzugreifbares Element %qD von %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da sowohl er als auch seine Basisklasse %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da seine Basisklassen %qT und %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "Array mit variabler Länge %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u Name für strukturelle Bindung angegeben"
 msgstr[1] "%u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "nur %u Name für strukturelle Bindung angegeben"
 msgstr[1] "nur %u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "während %qT in %wu Element zerlegt wird"
 msgstr[1] "während %qT in %wu Elemente zerlegt wird"
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "Vektor %qT variabler Länge kann nicht zerlegt werden"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "während %qT in %E Elemente zerlegt wird"
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "in Initialisierung der Variable %qD für strukturierte Bindung"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "Union-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "nicht-Array-nicht-Klassentyp %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Lambda-Abschluss-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Klassentypen %qT"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "Klassentyp %qT ohne nicht-static-Datenelemente kann nicht dekomponiert werden"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Arraygröße fehlt in %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Array %qT der Größe null"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "Konzept %q#D mit Funktionsparametern deklariert"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "Konzept %q#D mit hergeleitetem Rückgabetyp deklariert"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Konzept %q#D mit nicht-%<bool%>-Rückgabetyp %qT"
@@ -47570,7 +47618,7 @@ msgstr "Überlauf in Arraygröße"
 msgid "%qD declared as array of %qT"
 msgstr "%qD als Array von %qT deklariert"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
@@ -47735,7 +47783,7 @@ msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
@@ -47936,810 +47984,810 @@ msgstr "Attribut wird ignoriert"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ein Attribut, das sich auf eine Typspezifizierung bezieht, wird ignoriert"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "unnötige Klammern in Deklaration von %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "»requires«-Klausel für Rückgabetyp"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "hergeleiteter Rückgabetyp nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen kann keinen hergeleiteten Rückgabetyp haben"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit nachgestelltem Rückgabetyp hat %<decltype(auto)%> als Typ statt einfachem %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ungültige Verwendung von %<decltype(auto)%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "hergeleiteter Klassentyp %qD in Rückgabetyp von Funktion"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Herleitungshinweis für %qT muss angehängten Rückgabetyp haben"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "angehängter Rückgabetyp %qT den Ableitungshinweises ist keine Spezialisierung von %qT"
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "nachgestellter Rückgabetyp nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-qualifizierter Rückgabetyp ist veraltet"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> ist am Rückgabetyp einer Funktion nicht erlaubt"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Konstruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Konstruktoren dürfen nicht als %<virtual%> deklariert sein"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "%<friend%>-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<::%> qualifiziert ist"
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<%D::%> qualifiziert ist"
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "eine Umwandlungsfunktion darf keinen angehängten Rückgabetyp haben"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT definiert werden"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT deklariert werden"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> in »friend«-Deklaration"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren und Umwandlungsoperatoren können %<explicit%> sein"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<static%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<const%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "mit %<typedef%> definierte Funktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "mit %<typedef%> definierte Elementfunktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> ist in Aliasdeklaration nicht erlaubt"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-clause an Typedef"
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-clause an type-id"
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "»requires«-Klausel in Deklaration von Nichtfunktionstyp %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "Parameter kann nicht mit %<decltype(auto)%> deklariert werden"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%>-Parameter darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "nicht-statisches Datenelement mit Platzhalter %qT deklariert"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO-C++ verbietet flexibles Arrayelement %qs"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO-C++ verbietet flexible Arrayelemente"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Funktion %qD wurde innerhalb einer Union als %<virtual%> deklariert"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kann nicht als %<virtual%> deklariert werden, da es immer statisch ist"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ein Destruktor kann nicht %qs sein"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%>-Destruktoren sind erst ab %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "ein Konstruktor kann nicht %<concept%> sein"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ein Konzept kann keine Elementfunktion sein"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kann nicht %qs sein"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Variablentemplates %qD als Funktion deklariert"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "Variablentemplate hier deklariert"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen %qT"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "unbenanntes Feld ist weder eine Funktion noch Elementfunktion; kann nicht als %<friend%> deklariert werden"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (%<constexpr%>) muss Initialisierung haben"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "nicht-statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> ist für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs ungültig"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "Deklaration der %<constexpr%>-Variable %qD ist keine Definition"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "eine Variable kann nicht als %<consteval%> deklariert sein"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von cv-qualifiziertem Typ %qT in Parameterdeklaration"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von Typ %<void%> in Parameterdeklaration"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-qualifizierter Parameter ist veraltet"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO-C++ verbietet Überladen von %<operator ?:%>"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD darf keine Argumente nehmen"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "Umwandlung von %qT in %<void%> wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT hat hier eine vorherige Deklaration"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -48751,95 +48799,95 @@ msgstr "%qT als enum verwendet"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT ist mit mehreren direkten Basisklassen definiert"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT ist mit direkter virtueller Basisklasse definiert"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
@@ -48848,72 +48896,72 @@ msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Aufzählungswert für %qD muss ganzzahligen oder Aufzählungstyp ohne Gültigkeitsbereich haben"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<long%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Aufzählungswert %qE ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen %qT"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -48953,7 +49001,7 @@ msgstr "Eine Funktion kann nicht gelöscht werden. Nur Zeiger auf Objekte sind g
 msgid "deleting %qT is undefined"
 msgstr "Löschen von %qT ist nicht definiert"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "Templatedeklaration von %q#D"
@@ -48963,7 +49011,7 @@ msgstr "Templatedeklaration von %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "angegebene Template-Parameterlisten passen nicht zu Templateparametern von %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "Destruktor %qD als Element-Template deklariert"
@@ -49288,147 +49336,147 @@ msgstr "da %qT vom Benutzer bereitgestelltes %qD hat"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "Lambda, das %<...%> verwendendet, wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "Verwendung der Funktion %qD mit nicht erfüllten Einschränkungen"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "Verwendung von eingebautem Parameterpack %qD außerhalb eines Templates"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(kein Argument)"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[…]"
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "erweiterte Initialisierungslisten nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "explizite Umwandlungsoperatoren nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "variadische Templates nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Lambda-Ausdrücke nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11 %<auto%> ist nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "enums mit Gültigkeitsbereich nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Standard- und gelöschte Funktionen nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "»inline«-Namensräume nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Überschreibsteuerung (override/final) nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "nicht-statische Initialisierungen für Datenelemente nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "benutzerdefinierte Literale nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "delegierende Konstruktoren nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "erbende Konstruktoren nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11-Attribute nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-Qualifizierer sind nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "unvollständiger Typ %qT in geschachtelter Namensangabe verwendet"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "Referenz auf %<%T::%D%> ist mehrdeutig"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD ist kein Element von %qT; meinten Sie %qs?"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD ist kein Element von %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD ist kein Element von %qD; meinten Sie %qs?"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ist kein Element von %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> wurde nicht deklariert; meinten Sie %qs?"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> wurde nicht deklariert"
@@ -49609,338 +49657,338 @@ msgstr "Wertinitialisierung des Referenztypen %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursive Instanziierung von Vorgabeinitialisierer für Element %qD"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "Vorgabeinitialisierer für Element %qD erforderlich vor dem Ende der umschließenden Klasse"
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "Initialisierung eines flexiblen Arrayelements %q#D"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr "dadurch, dass %qD mittels %qE initialisiert wird, verlängert sich die Lebenszeit des zugrundeliegenden Arrays nicht"
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD sollte in Elementinitialisierungsliste initialisiert werden"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD wird mit sich selbst initialisiert"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ungültige Initialisierung für Arrayelement %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "nicht initialisiertes konstantes Element in %q#T"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D sollte initialisiert werden"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "nicht initialisiertes Referenzelement in %q#T"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD wird initialisiert nach"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Basis %qT wird initialisiert nach"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  Basis %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  während es hier initialisiert wurde"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "mehrere Initialisierungen für %qD angegeben"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "mehrere Initialisierungen für Basis %qT angegeben"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Initialisierungen für mehrere Elemente von %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "Basisklasse %q#T sollte explizit im Kopierkonstruktor initialisiert werden"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "Klasse %qT hat keinen Feldnamen %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D« ist ein statisches Datenelement; es kann nur bei seiner Definition initialisiert werden"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D ist kein Nicht-static-Datenelement von %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unbenannte Initialisierung für %qT, das keine Basisklassen hat"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unbenannte Initialisierung für %qT, das Mehrfachvererbung verwendet"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD ist sowohl eine direkte Basis als auch eine indirekte virtuelle Basis"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Typ %qT ist keine direkte oder virtuelle Basis von %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Typ %qT ist keine direkte Basis von %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ist kein Klassentyp"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "unvollständiger Typ %qT hat kein Element %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ungültiger Zeiger auf Bitfeld %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion %qD"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ungültige Verwendung des nicht-statischen Datenelementes %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Objekt vom Typ %<%T [%wu]%> und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Array vom Typ %qT und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Objekt vom Typ %qT und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Ganzzahlüberlauf in Arraygröße"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "Arraygröße in »new«-Ausdruck muss konstant sein"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "im »new«-Ausdruck ist kein variabel modifizierter Typ erlaubt"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "nichtkonstante Länge für neues Array muss direkt angegeben werden, nicht über %<typedef%>"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "Nichtkonstante Länge in Array-new muss ohne Klammern um die Typ-ID angegeben werden"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "ungültiger Typ %<void%> für %<new%>"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "%<new%> einer %<initializer_list%> führt nicht zu einer längeren Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "nicht initialisierte Konstante in %<new%> von %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "Kein passendes %qD in Klasse %qT gefunden"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "Abfrage des Elementes %qD ist mehrdeutig"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> für Typ %qT mit erweiterter Ausrichtung %d"
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "verwendet %qD, das jedoch keinen Ausrichtungsparameter hat"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "verwenden Sie %<-faligned-new%>, um die C++17-Unterstützung für überausgerichtetes New einzuschalten"
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "geklammerte Initialisierung in Array-»new«"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "Größe des Arrays bei »new« muss Ganzzahltyp haben"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "»new« kann nicht auf Referenztyp angewendet werden"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "»new« kann nicht auf Funktionstyp angewendet werden"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "mögliches Problem bei Aufruf von %<operator delete []%> erkannt"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische %<operator delete []%> wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "Initialisierung endet vorzeitig"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "unbekannte Arraygröße in »delete«"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "mögliches Problem bei Aufruf von %<operator delete%> erkannt"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische %<operator delete%> wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "Löschen des Objekts mit abstraktem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt undefiniertes Verhalten"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "Löschen des Objekts mit polymorphem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt möglicherweise undefiniertes Verhalten"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "Typ für Vektor-»delete« ist weder Zeiger- noch Arraytyp"
@@ -50100,12 +50148,12 @@ msgstr "der gemangelte Name von %qD ändert sich zwischen %<-fabi-version=%d%> u
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "der gemangelte Name der Initialisierungswächter-Variable für %qD ändert sich zwischen %<-fabi-version=%d%> und %<-fabi-version=%d%>"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "nicht-statisches konstantes Element %q#D, Standard-Zuweisungsoperator kann nicht verwendet werden"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "nicht-statisches Referenzelement %q#D, Standard-Zuweisungsoperator kann nicht verwendet werden"
@@ -50130,157 +50178,162 @@ msgstr "beim Formen des Typs von %qs"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "standardmäßiges %qD ist erst ab %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "Dreiwege-Vergleichsoperator kann nur in einer Klassendefinition die Standardimplementierung bekommen"
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "Gleichheits-Vergleichsoperator kann nur in einer Klassendefinition die Standardimplementierung bekommen"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr "%qD mit %<default%> muss den Rückgabetyp %<bool%> haben"
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, gcc-internal-format
 msgid "defaulted %qD must be %<const%>"
 msgstr "standardmäßiges %qD muss %<const%> sein"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "%qD mit Vorgabewert kann keinen %<&&%>-ref-Qualifizierer haben"
+
+#: cp/method.c:1155
+#, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD mit Vorgabewert ist kein »friend« von %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr "das Member %qD mit %<default%> muss den Parametertyp %<const %T&%> haben"
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr "%qD mit %<default%> muss entweder Parameter vom Typ %<const %T&%> oder %qT haben"
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr "%qD mit %<default%> muss Parameter vom Typ %<const %T&%> oder %qT haben, nicht beide"
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "für Union-Typ %qT ist kein Standardvergleich definiert"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "für Referenzelement %qD ist kein Standardvergleich definiert"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "für Element der unbenannten Union ist kein Standardvergleich definiert"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr "Dreiwege-Vergleich von %qD hat den Typ %qT, nicht den Vergleichskategorie-Typ"
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr "erzeugte Methode %qD zuerst hier erfordert"
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "Union-Element %q+D mit nichttrivialem %qD"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "Standarddestruktor ruft nicht-%<constexpr%> %qD auf"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "vorgegebener Konstruktor ruft nicht-%<constexpr%> %qD auf"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "Initialisierung für %q#D ist ungültig"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "Standardisierter Standardkonstruktor initialisiert %q#D nicht"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "Kopieren von nicht-statischem Datenelement %q#D von rvalue-Referenztyp"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "Standardisierter Standardkonstruktor initialisiert kein nicht-statisches Datenelement"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "Standard-Kopierzuweisung für %qT ruft nichttrivialen Operator zur Kopierzuweisung für virtuelle Basis %qT auf"
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "Lambda-Abschlusstyp hat gelöschten Standardkonstruktor"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "Lambda-Abschlusstyp hat gelöschten Kopier-Zuweisungsoperator"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D ist implizit als gelöscht deklariert, da %qT einen Bewegungskonstruktor oder Bewegungs-Zuweisungsoperator deklariert"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D erbt von mehreren Basis-Teilobjekten"
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D wird implizit gelöscht, da die Standarddefinition ungültig wäre:"
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F wird implizit gelöscht, da ihre Ausnahme-Spezifikation nicht zur impliziten Ausnahme-Spezifikation %qX passt"
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "Default-Deklaration %q+D passt nicht zur erwarteten Signatur"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "erwartete Signatur: %qD"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "Explizite Standardfunktion %q+D kann nicht als %qs deklariert werden, da die implizite Deklaration nicht %qs ist:"
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "ein Template kann nicht vorbelegt werden"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD kann nicht vorgegeben werden"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "vorgegebene Funktion %q+D mit Standardargument"
@@ -50320,212 +50373,212 @@ msgstr "Lambdaparameter %qD war vorher als Einfänger deklariert"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "Deklaration von %q#D überdeckt einen Parameter"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "Deklaration von %qD überdeckt ein Element von %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "lokale externe Deklaration von %q#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "passt nicht zu vorheriger Deklaration %q#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "Friend-Deklaration %qD in lokaler Klasse ohne vorherige Deklaration"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "»using«-Deklaration für Nicht-Element im Gültigkeitsbereich der Klasse"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93883
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "%<using%>-Deklaration darf den Enumerator %<%E::%D%> nicht benennen"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "%<using%>-Deklaration für Element außerhalb des Gültigkeitsbereichs der Klasse"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> benennt Destruktor"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> benennt Konstruktor in %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "Konstruktoren können nicht von indirekter Basis %qT geerbt werden"
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "%qD wurde nicht innerhalb von %qE deklariert"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "%<using%>-Deklaration darf den Namensraum %qD nicht benennen"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "Deklaration von %qD nicht in einem Namensbereich um %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explizite Qualifizierung in Deklaration von %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD wurde nicht innerhalb von %qD deklariert"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "sondern nur hier als %<friend%>"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD sollte innerhalb von %qD deklariert werden"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "Attribut %qD erfordert ein einzelnes NTBS-Argument"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "Attribut %qD ist bedeutungslos, da die Elemente des anonymen Namensraums lokale Symbole erhalten"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "Attribut %qD an unbenanntem Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "Attribut %qD an nicht-»inline«-Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "Attribut-Anweisung %qD wird ignoriert"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "obere Grenze von %d Namensräumen für %qE durchsucht"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "empfohlene Alternative:"
 msgstr[1] "empfohlene Alternativen:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> ist im Header %qs definiert; haben Sie vergessen, %<#include %s%> zu schreiben?"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79869
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> ist erst ab %s verfügbar"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "das Makro %qs war noch nicht definiert"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "es wurde später hier definiert"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "Deklaration von %<std::initializer_list%> entspricht nicht %<#include <initializer_list>%>, ist kein Template"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "die Direktive %<strong%>-%<using%> wird nicht mehr unterstützt"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "Sie können stattdessen einen inline-Namensraum verwenden"
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> ist mehrdeutig"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "Namensbereich-Alias %qD ist hier nicht erlaubt, %qD angenommen"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "es können maximal %d Namensräume geschachtelt werden"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "ein %<inline%>-Namensraum muss bei der ersten Definition angegeben werden"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD hier definiert"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX %<pop_everything%> wird betreten"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX %<pop_everything%> wird verlassen"
@@ -50550,7 +50603,7 @@ msgstr "Bezeichner %qE wird in C++20 zum Schlüsselwort"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> ist nicht auf true gesetzt"
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> muss direkt von einer Funktionsdeklaration oder -definition gefolgt sein"
@@ -50575,7 +50628,7 @@ msgstr "%<::%E%> wurde nicht deklariert"
 msgid "request for member %qE in non-class type %qT"
 msgstr "Abfrage des Elementes %qE in Nicht-Klassentyp %qT"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> wurde nicht deklariert"
@@ -50655,7 +50708,7 @@ msgstr "ungültige Template-ID"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO-C++ verbietet Gleitkommaliterale in Konstanten-Ausdrücken"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "Eine Typumwandlung, die weder zu ganzzahligen noch Aufzählungstypen führt, kann nicht in einem Konstantenausdruck auftreten"
@@ -50776,7 +50829,7 @@ msgstr "%<constinit%> aus C++20 ist erst ab %<-std=c++2a%> oder %<-std=gnu++2a%>
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<concept%> ist erst ab %<-std=c++2a%> oder mit %<-fconcepts%> verfügbar"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<requires%> ist erst ab %<-std=c++2a%> oder mit %<-fconcepts%> verfügbar"
@@ -50896,7 +50949,7 @@ msgstr "verwenden Sie %<-fext-numeric-literals%>, um weitere eingebaute Suffixe
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "literaler Operator für Zeichenketten %qD mit Argumenten %qT, %qT konnte nicht gefunden werden"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "Deklaration erwartet"
@@ -50996,12 +51049,12 @@ msgstr "Deklaration von %<~%T%> als Element von %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-Name %qD als Destruktor-Deklarator verwendet"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ist kein Template"
@@ -51036,7 +51089,7 @@ msgstr "Bezeichner %qD für Variablentemplate ist geschachteltem Namens-Spezifiz
 msgid "expected nested-name-specifier"
 msgstr "Spezifikation mit geschachteltem Namen erwartet"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Typen dürfen nicht in Typumwandlungen definiert werden"
@@ -51051,7 +51104,7 @@ msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
@@ -51066,7 +51119,7 @@ msgstr "ISO-C++ verbietet zusammengesetzte Literale"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "zwei aufeinander folgende %<[%> dürfen nur ein Attribut einführen"
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ungültige Verwendung von %qD"
@@ -51091,914 +51144,919 @@ msgstr "ISO-C++ erlaubt kein %<alignof%> mit einem Nicht-Typ"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "Typen dürfen nicht in %<noexcept%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "Typen dürfen nicht in einem %qs-Ausdruck definiert werden"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "%<__builtin_has_attribute%> mit abhängigem Argument wird noch nicht unterstützt"
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "Typen dürfen nicht in einem »new«-Ausdruck definiert werden"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "Arraygrenze hinter geklammerter type-id ist verboten"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "Klammern um die Type-ID sollten entfernt werden"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "Initialisierung des new-Ausdrucks für Typ %<auto%> erfordert genau ein Element"
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "»expression-list« oder »type-id« erwartet"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "Typen dürfen nicht in einem »new-type-id« definiert werden"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "Ausdruck in new-Deklarator muss Ganzzahl- oder Aufzählungstyp haben"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "Verwendung einer Typumwandlung nach %q#T im alten Stil"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "Operator %<>>%> wird in C++11 wie zwei spitze schließende Klammern behandelt"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "Klammern um %<>>%>-Ausdruck empfohlen"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "in ISO-C++ darf der mittlere Operand von %<?:%> nicht weggelassen werden"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "ungeklammerte Komma-Ausdrücke in Arrayindex-Ausdrücken sind veraltet"
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "Typen dürfen nicht innerhalb von %<__builtin_offsetof%> definiert werden"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Lambda-Templates sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Lambda-Templates sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "nicht-lokaler Lambdaausdruck kann keinen »capture-default« haben"
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "unerwartetes Ende der Auffangliste"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %<this%> ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "%qD bereits in Lambda-Ausdruck erfasst"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<*this%>-Capture ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "%<this%> kann nicht per Referenz eingefangen werden"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Lambda-Templates sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr "%<&%> sollte vor %<...%> kommen"
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Initialisierungen für Lambda-Captures sind nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "nicht-leere Initialisierung »init-capture« eines Lambdas"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "Erfassung von Nicht-Variable %qE"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D hier deklariert"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "Erfassung der Variable %qD ohne automatische Speicherdauer"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "zu viele %<...%> in Lambda-Capture"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %qD ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "Explizite Erfassung (als Referenz) von %qD ist mit Standarderfassung (als Referenz) gedoppelt"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Lambda-Templates sind nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Lambda-Templates sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Standardargument für Lambda-Parameter angegeben"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "doppeltes %<mutable%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%>-Lambda ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "Attribute am Anfang der Anweisung werden ignoriert"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "benannte Anweisung erwartet"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-Marke %qE nicht innerhalb einer switch-Anweisung"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> vor %qE erforderlich, da %qT ein abhängiger Gültigkeitsbereich ist"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> benennt Konstruktor, nicht den Typ"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "zusammengesetzte Anweisung in %<constexpr%>-Funktion"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<if constexpr%> ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "»init-statement in Auswahlanweisungen« ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr "Bedingung deklariert ein Array"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "Bedingung deklariert eine Funktion"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "Typen dürfen nicht in Bedingungen definiert werden"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "Initialisierung erwartet"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat unvollständigen Typ"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Bereichsbasierte %<for%>-Schleifen mit Initialisierer sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Bereichsbasierte %<for%>-Schleifen sind nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> in %<constexpr%>-Funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "zusätzliches %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> nicht am Anfang eines Blocks"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "Nicht-Variable %qD in Deklaration mit mehr als einem Deklarator mit Platzhaltertyp"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für %qT: %qT und dann %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "Vermischung von Deklarationen und Funktionsdefinitionen ist verboten"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "in einer for-Bereichs-Deklaration dürfen keine Typen definiert werden"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "Initialisierung in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "mehrere Deklarationen in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "strukturierte Bindungen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "leere Deklaration für strukturierte Bindung"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ungültige Initialisierung für strukturierte Bindungsdeklaration"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> außerhalb einer Klasse verwendet"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "das Schlüsselwort %<bool%> ist in einer Konzeptdefinition in C++20 nicht erlaubt"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr "Die Schreibweise der C++20-Konzeptdefinition ist %<concept <Name> = <Ausdruck>%>"
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "Bedeutung von %<auto%> ändert in C++11 die Bedeutung; Bitte entfernen"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%<decl-specifier%> ist in Bedingung ungültig"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD ungültig in Lambda"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "type-specifier ist in Lambda ungültig"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "Klassendefinition darf nicht als »friend« deklariert sein"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "Typen dürfen nicht in explicit-specifier definiert werden"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<explicit(bool)%> ist nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ungültige Bindungsspezifikation"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<static_assert%> ohne Text ist erst ab %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "Typen dürfen nicht in %<decltype%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "Typen dürfen nicht in einem »conversion-type-id« definiert werden"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ungültige Verwendung von %<auto%> in Umwandlungsoperator"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "Verwendung von %<auto%> in Umwandlungsoperator von Elementtemplate kann niemals hergeleitet werden"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "Initialisierung für Element %qD kann nicht expandiert werden"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "veraltete Basisklasseninitialisierung"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> in diesem Kontext nicht erlaubt (eine qualifizierte Elementinitialisierung ist implizit ein Typ)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "unerwartetes Schlüsselwort; entfernen Sie Leerzeichen zwischen Anführungszeichen und Suffixbezeichner"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "Suffixbezeichner erwartet"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "hinter Schlüsselwort %<operator%> wird leere Zeichenkette erwartet"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ungültiges Encoding-Präfix in Literal-Operator"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "Operator erwartet"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Schlüsselwort %<export%> nicht implementiert, und wird ignoriert"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ungültiger beschränkter Typparameter"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualifizierter Typparameter"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ungültige Verwendung von %<auto%> in Default-Templateargument"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Templateparameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "Template-Parameterpacks können keine Standardargumente haben"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "Template-ID erwartet"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kann keine Templateargumentliste einleiten"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ist eine andere Schreibweise für %<[%>. Leerraum zwischen %<<%> und %<::%> einfügen"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(bei Verwendung von %<-fpermissive%>, %<-std=c++11%> oder %<-std=gnu++11%> wird G++ den Code akzeptieren)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "ungültige template-argument-list"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr "Funktionsname als linker Operand von %<<%> ist in C++2a verboten; verpacken Sie den Funktionsnamen in %<()%>"
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<(%> hinter template-argument-list erwartet"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "Syntaxfehler in Templateargumentliste"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "Templatename erwartet"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "Nicht-Template %qD als Template verwendet"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "%<%T::template %D%> verwenden, um dies als Template zu kennzeichnen"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "Parameterbündel vor %<...%> erwartet"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "Templateargument erwartet"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ungültiges Templateargument ohne Typ"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "explizite Instanziierung darf kein %<inline%> verwenden"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "explizite Instanziierung darf kein %<constexpr%> verwenden"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "explizite Instanziierung darf kein %<consteval%> verwenden"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "Templatespezialisierung mit C-Bindung angegeben"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Typspezifizierer erwartet"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Verwendung von %<auto%> in Lambda-Parameterdeklaration ist nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration ist nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration ist nur mit %<-fconcepts-ts%> verfügbar"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "Template-ID für Typ erwartet"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "Typ-Name erwartet"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE schränkt keinen Typ ein"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr "das Konzept wurde hier definiert"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<auto%> oder %<decltype(auto)%> nach %qE erwartet"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "unerwarteter Platzhalter in eingeschränktem Ergebnistyp"
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "ausführliche Typ-Spezifikation für einen enum mit Gültigkeitsbereich darf nicht das Schlüsselwort %qD verwenden"
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%<template%> muss auf einen nested-name-specifier folgen"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "Deklaration %qD deklariert nichts"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "Attribute an instanziiertem Typen ignoriert"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "Attribute an Templateinstanziierung ignoriert"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "Attribute an Spezifizierer ausführlichen Typs ignoriert, der keine Vorwärtsdeklaration ist"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ist ein Aufzählungstemplate"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD benennt keinen Aufzählungstyp in %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "unbenanntes »enum« mit Gültigkeitsbereich ist nicht erlaubt"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> oder %<{%> erwartet"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aufzählungsliste kann nicht zu Template-Instanziierung hinzugefügt werden"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "geschachtelter Namensgeber %qT für enum-Deklaration benennt weder Klasse noch Namensraum"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in Namensraum %qD, der nicht %qD einschließt"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in %qD, das nicht %qD einschließt"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "zusätzliche Qualifizierung nicht erlaubt"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO-C++ verbietet leere unbenannte Aufzählung"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "intransparente Enum-Spezifikation ohne Namen"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "intransparente Enum-Spezifikation muss einfachen Bezeichner verwenden"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD bezeichnet Namensraum-Namen; meinten Sie %qs?"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ist kein Namensbereichs-Name"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "Namensraumname erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90183
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "verschachtelte inline-Namensraumdefinitionen sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr "Standardattribute für Namensräume müssen vor dem Namen des Namensraums stehen"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90183
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "verschachtelte Namensraumdefinitionen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "Name eines geschachtelten Namensraums erwartet"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "Name eines Namensraums erwartet"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "eine verschachtelte Namensraum-Definition darf keine Attribute haben"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "eine verschachtelte Namensraumdefinition darf nicht inline sein"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "Namensbereich %qD betreten"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-Definition ist hier nicht erlaubt"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "Pack-Expansion in using-Deklaration ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "eine Template-ID darf nicht in »using«-Deklaration auftreten"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "kommagetrennte Liste in using-Deklaration ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "Zugriffsdeklarationen sind zugunsten von %<using%>-Deklarationen veraltet; Vorschlag: %<using%> hinzufügen"
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "Typen dürfen nicht in Alias-Templatedeklarationen definiert werden"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<asm%> innerhalb einer %<constexpr%>-Funktion ist erst ab %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "doppelter %<asm%>-Qualifizierer %qT"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%<asm%>-Qualifizierer %qT wird ignoriert, da außerhalb des Funktionsrumpfes"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT ist kein %<asm%>-Qualifizierer"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%<asm%>-Qualifizierer außerhalb des Funktionsrumpfes"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "eine Funktionsdefinition ist hier nicht erlaubt"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "eine %<asm%>-Spezifikation ist bei Funktionsdefinition nicht erlaubt"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Konstruktor, Destruktor oder Typumwandlung erwartet"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Initialisierung für Funktion bereitgestellt"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "Attribute hinter geklammerter Initialisierung werden ignoriert"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Nicht-Funktion %qD als implizites Template deklariert"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "Arraygrenze ist keine Ganzzahlkonstante"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "Element des abhängigen Typedef %qT kann nicht definiert werden"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ist kein Typ"
@@ -52007,431 +52065,431 @@ msgstr "%<%T::%E%> ist kein Typ"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ungültiger Deklarator"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ungültige Verwendung des Konstruktors als Template"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "%<%T::%D%> statt %<%T::%D%> verwenden, um den Konstruktor mit qualifiziertem Namen zu benennen"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id in Deklaration"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "Deklarator erwartet"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD ist ein Namensbereich"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "Zeiger auf Element der Nicht-Klasse %q#T kann nicht erzeugt werden"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Ptr-Operator erwartet"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "mehrere ref-qualifier"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE benötigt %<-fgnu-tm%>"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "doppelter Virt-Spezifizierer"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "fehlende Templateargumente nach %qT"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ungültige Verwendung von %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "in Template-Argumenten dürfen keine Typen definiert werden"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ungültige Verwendung von %<auto%> in Templateargument"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Typspezifikation erwartet"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> oder %<...%> erwartet"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "Typen dürfen nicht in Parametertypen definiert werden"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "Standardargumente sind nur für Funktionsparameter zugelassen"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Parameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "Templateparameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Parameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Rumpf eines function-try-block in einem %<constexpr%>-Konstruktor ist nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Rumpf eines function-try-block in einer %<constexpr%>-Funktion ist nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "designierte Initialisierer für C++ sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen (GNU)"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen von C99"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "entweder sollten alle Initialisierer-Klauseln benannt sein oder gar keine"
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> ist in benannten Initialisierungen nicht erlaubt"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "%<.%s%>-Name wird mehrfach in derselben Initialisierungsliste verwendet"
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "Klassenname erwartet"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> hinter Klassendefinition erwartet"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> hinter Strukturdefinition erwartet"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> hinter Uniondefinition erwartet"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> oder %<:%> erwartet"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "für eine Klasse kann kein %<override%> angegeben werden"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globale Qualifizierung von Klassenname ist ungültig"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "qualifizierter Name benennt keine Klasse"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "Schlüsselwort %<template%> nicht innerhalb des Klassenkopfnamens erlaubt"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ungültiger Klassenname in Deklaration von %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "einer expliziten Spezialisierung muss %<template <>%> vorausgehen"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Funktions-Template %qD als Klassentemplate redeklariert"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "Typnamen-Typ kann nicht aufgelöst werden"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "vorherige Definition von %q#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ISO-C++ verbietet typename-Schlüssel in Template-Template-Parameter; verwenden Sie %<-std=c++17%> oder %<-std=gnu++17%>"
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> oder %<typename%> erwartet"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "in C++03 muss bei Deklaration eines »friend« ein Klassenschlüssel verwendet werden"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "»friend«-Deklaration benennt keine Klasse oder Funktion"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "Speicherklasse an anonymem Aggregat im Klassenbereich ist nicht erlaubt"
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Defaultinitialisierer für Bitfeld-Elemente sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "Defaultinitialisierer für unbenanntes Bitfeld-Element"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ erlaubt Bitfeld-Attribute nur vor dem %<:%>-Token"
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "Bitfeld %qD mit Nicht-Ganzzahl-Typ %qT"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "reiner Spezifizierer bei Funktionsdefinition"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "zusätzliches %<;%> hinter Funktionsdefinition innerhalb einer Klasse"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "überflüssiges %<,%> am Ende der Elementdeklaration"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> am Ende von Elementdeklaration erwartet"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ungültige reine Spezifikation (nur %<= 0%> ist erlaubt)"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "eine geschweift geklammerte Initialisierung ist hier nicht erlaubt"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> mehr als einmal in Basisspezifikation angegeben"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mehr als ein Zugriff in Basisspezifikation angegeben"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "Schlüsselwort %<typename%> nicht außerhalb von Templates erlaubt"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> nicht erlaubt in diesem Kontext (die Basisklasse ist implizit ein Typ)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "Typen dürfen nicht in einer Ausnahmespezifikation definiert werden"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 erlaubt keine dynamischen Ausnahmespezifikationen"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamische Ausnahmespezifikationen sind in C++11 veraltet"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ungültige Verwendung von %<auto%> in Ausnahmespezifikation"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<try%> innerhalb einer %<constexpr%>-Funktion ist nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "Typen dürfen nicht in Ausnahmedeklarationen definiert werden"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Attribut, das Präfix verwendet, wird zusammen mit Gültigkeitsbereich-Attribut-Token verwendet"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "Bezeichner für den Attributnamen erwartet"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr "Klammern müssen weggelassen werden, wenn die Argumentliste des %qE-Attributs leer ist"
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "Attribut %<noreturn%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr "Attribut %<nodiscard%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Attribut vor %<...%> erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90184
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribute-using-prefix ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "Ausdruck muss in runden Klammern eingeschlossen sein"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "Fehlendes zusätzliches %<requries%>, um eine requires-expression zu beginnen"
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "Rückgabetyp ist keine einfache Typ-Einschränkung"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "%<return-type-requirement%> ist keine Typ-Einschränkung"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -52440,544 +52498,544 @@ msgstr "zu wenige Templateparameterlisten"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90185
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ unterstützt keine Operatortemplates in Zeichenkettenliteralen, die eine Argumentpackung von Zeichen bekommen"
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "literales Operatortemplate %qD hat ungültige Parameterliste; nicht-Typ Templateargumentpack %<<char…>%> oder einzelner Nicht-Typ-Parameter von Klassentyp erwartet"
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "literales Operatortemplate %qD hat ungültige Parameterliste; Template für Nicht-Typ Argumentpack %<<char…>%> erwartet"
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr "Template-Einführungen sind nicht Teil der C++20-Konzepte [-fconcepts-ts]"
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "kein passendes Konzept für template-introduction"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "eine Klassen-Templatedeklaration darf nichts anderes deklarieren"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> erwartet"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> erwartet"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "redundanter Aufzählungsschlüssel %<enum%s%> in Bezug auf %q#T"
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "redundanter Klassenschlüssel %qs in Verweis auf %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT mit nicht zusammenpassendem Klassenschlüssel %qs deklariert"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "entfernen Sie den Klassenschlüssel oder ersetzen Sie ihn durch %qs"
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "Klassenschlüssel durch %qs ersetzen"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT wurde hier als %qs definiert"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT wurde erstmals hier als %qs deklariert"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++-Nachrichtenempfänger erwartet"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Liste von Ganzzahlausdrücken erwartet"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ungültiger reduction-identifier"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Typen dürfen nicht in Iteratortyp definiert werden"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%>-Klausel mit Parameter in %<for%>-Schleife über einen Bereich"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "zu wenige for-Schleifen um sie einzuklappen"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> gefolgt von %<#pragma omp declare %s%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierungsklausel"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "»id-expression (arguments)« erwartet"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "eins der Aufrufargumente für die Initialisierung sollte %<omp_priv%> oder %<&omp_priv%> sein"
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "vordeklarierter arithmetischer Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "Referenztyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<const%>-, %<volatile%>- oder %<__restrict%>-qualifizierter Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> benennt eine Menge von Überladungen"
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bezeichnet keine Funktion innerhalb eines Namensraum"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "Ausschuss am Ende von %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> darf nur im Gültigkeitsbereich einer Datei oder eines Namensraums verwendet werden"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Optimierungen zwischen Modulen noch nicht implementiert für C++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "Platzhaltertyp ist in diesem Kontext nicht erlaubt"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Implizite Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-Bindung beginnt hier"
@@ -53248,7 +53306,7 @@ msgstr "Expansionsmuster %qE enthält keine Parameterpacks"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "Parameterbündel nicht mit %<...%> aufgelöst:"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -53273,84 +53331,84 @@ msgstr "Deklaration von %q+#D überdeckt einen Templateparameter"
 msgid "template parameter %qD declared here"
 msgstr "Templateparameter %qD hier deklariert"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "Spezialisierung des Variablenkonzepts %q#D"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "Templateparameter nicht in partieller Spezialisierung herleitbar:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente und ist nicht eingeschränkter als das primäre Template; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "ursprüngliches Template hier"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partielle Spezialisierung ist nicht näher spezialisiert als das ursprüngliche Template, da es mehrere Parameter mit einer »pack«-Erweiterung ersetzt"
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "zu viele Argumente für teilweise Spezialisierung %qT"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "Teilspezialisierung %qD ist nicht spezialisierter als"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "primäres Template %qD"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "Argument %qE für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "Argument %qT für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "Templateargument %qE betrifft Templateparameter"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "Typ %qT des Templatearguments %qE hängt von Templateparameter ab"
 msgstr[1] "Typ %qT des Templatearguments %qE hängt von Templateparametern ab"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "Deklaration von %qD macht vorherige Template-Instanziierung für %qD mehrdeutig"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "teilweise Spezialisierung von %qD nach Instanziierung von %qD"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "kein Standard-Argument für %qD"
@@ -53358,47 +53416,47 @@ msgstr "kein Standard-Argument für %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "Parameterpack %q+D muss am Ende der Templateparameterliste sein"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "Standardtemplateargumente dürfen in friend-Redeklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "Standardtemplateargumente dürfen in friend-Deklaration nicht verwendet werden"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Standardtemplateargumente dürfen in Funktionstemplates nur mit %<-std=c++11%> und %<-std=gnu++11%> verwendet werden"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Standardtemplateargumente dürfen in teilweiser Spezialisierung nicht verwendet werden"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "Template %qD deklariert"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "Templateklasse ohne Namen"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
@@ -53408,493 +53466,493 @@ msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ungültige Templatedeklaration von %qD"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "Template-Definition eines Nicht-Templates %q#D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d Ebenen von Template-Parametern für %q#D erwartet, %d erhalten"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d Template-Parameter für %q#D erhalten"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d Template-Parameter für %q#T erhalten"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  aber %d benötigt"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "Template-Argumente für %qD passen nicht zum ursprünglichen Template %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "verwenden Sie %<template<>%> für eine explizite Spezialisierung"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ist kein Template-Typ"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "keine Templatespezifizierer in Deklaration von %qD angegeben"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "mit %d Template-Parameter redeklariert"
 msgstr[1] "mit %d Template-Parametern redeklariert"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 msgstr[1] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "Template-Parameter %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "hier als %q#D redeklariert"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "Deklaration von Templateparameter %q+D mit unterschiedlichen Einschränkungen"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprüngliche Deklaration trat hier auf"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Redefinition des Standardarguments für %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprüngliche Definition trat hier auf"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "Redeklaration %q#D mit unterschiedlichen Constraints"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "es muss die Adresse einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "es muss der Name einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "es muss ein Zeiger auf ein Element der Form %<&X::Y%> sein"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "da es ein Element von %qT ist"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  Template-Parameter %qD konnte nicht hergeleitet werden"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr " Typen %qT und %qT haben unverträgliche CV-Qualifizierer"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr " unpassende Typen %qT und %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr " Templateparameter %qD ist kein Parameterpack wie Argument %qD"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr " Templateargumente %qE passt nicht zum konstanten Zeiger auf Element %qE"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr " %qE entspricht nicht %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr " unpassende Herleitung von Parameterpack mit %qT und %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr " hergeleitete Typen für Parameter %qT stehen in Konflikt (%qT und %qT)"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr " hergeleitete Werte für Nicht-Typ-Parameter %qE stehen in Konflikt (%qE und %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr " Arraytyp %qT mit veränderlicher Größe ist kein gültiges Templateargument"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr " Typ %qT von Elementfunktion ist kein gültiges Templateargument"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  Kandidat erwartet mindestens %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet mindestens %d Argumente, %d angegeben"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr " %qE (Typ %qT) kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr " %qT ist mehrdeutige Basisklasse von %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr " %qT ist nicht vom Typ %qT abgeleitet"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr " Templateparameter eines Template-Templatearguments sind mit anderen hergeleiteten Templateargumenten unverträglich"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  für %qT kann kein Template aus Nicht-Templatetyp %qT hergeleitet werden"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr " Template-Argument %qE passt nicht zu %qE"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qE keine Variable ist"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE ist in C++98 kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "die Adresse des %qT-Teilobjekts von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument, weil sie keine statische Lebensdauer hat"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ist kein gültiges Templateargument für %qT, da es keine Adresse einer Variable ist"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da Zeichenkettensymbole in diesem Zusammenhang nicht verwendet werden können"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "in Templateargument für Typ %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "Templateargument %qE für Typ %qT ist keine konstante Ganzzahl"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "Attribute an Templateargument %qE werden ignoriert"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Verwendung des Destruktors %qE als Typ"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  mehrdeutiges Templateargument für Nichttyp-Templateparameter wird wie ein Funktionstyp behandelt"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "unpassende Beschränkungen für Argument %d in Template-Parameterliste für %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD erwartet, %qD erhalten"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "Templateargument %qE konnte nicht von %qT in %qT umgewandelt werden"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte mindestens %d sein)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "für %qD bereitgestellt"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Alias-Template %qD"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Konzept %qD"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "jegliche Instanziierung mit nichtleerer Parameterpackung wäre unzulässig"
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "Template-Einschränkung für %qD fehlgeschlagen"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Verwendung des ungültigen Variablentemplates %qE"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (%<-ftemplate-depth=%> verwenden, um dies zu erhöhen)"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibles Arrayelement %qD in Union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "Falten einer leeren Expansion über %O"
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE ist nicht das vollständige Muster einer Packexpansion"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qT"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qE"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %qD"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
@@ -53912,291 +53970,291 @@ msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Array zurück"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD wird für ein leeres Pack instanziiert"
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT wird in %qT aufgelöst, aber das ist kein Klassentyp"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "Initialisierer für %q#D expandiert zu einer leeren Ausdrucksliste"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_convertvector%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "Explizite Instanziierung des Variablenkonzepts %q#D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "Explizite Instanziierung des Funktionskonzepts %q#D"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
@@ -54208,132 +54266,132 @@ msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d beim Instanziieren von %q+D, möglicherweise wegen Generierung der virtuellen Tabelle (%<-ftemplate-depth=%> verwenden, um den Höchstwert zu erhöhen)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Nichttypen-Templateparameter von hergeleitetem Klassentyp sind erst ab %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Nichttypen-Templateparameter von Klassentyp sind nur mit %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT ist kein gültiger Typ für einen Nichttyp-Templateparameter, da er nicht strukturell ist"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "Schlüsselwort %<template%> nicht innerhalb der declarator-id erlaubt"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ein Konzept kann nicht eingeschränkt werden"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "das Konzept %qE ist nicht im Gültigkeitsbereich des Namensraums"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert %<#include <initializer_list>%>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "nicht herleitbares Templates %qT wird ohne Template-Argumente verwendet"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Alias-Template-Herleitung ist erst ab %<-std=c++2a%> oder %<-std=gnu++2a%> verfügbar"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "Templateargumente für %qT können nicht abgeleitet werden, da es keine Ableitungshinweise gibt"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ungültige Verwendung von %qT in Templateargument"
@@ -54538,7 +54596,7 @@ msgstr "ungültige Verwendung von %<this%> auf höchster Ebene"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ungültiger angegebener Gültigkeitsbereich in Pseudodestruktor-Name"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "qualifizierter Typ %qT passt nicht zum Destruktornamen ~%qT"
@@ -54588,7 +54646,7 @@ msgstr "ungültige Spezifizierung der Basisklasse"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
@@ -54687,7 +54745,7 @@ msgstr "%<offsetof%> innerhalb von Typ %qT (der kein Standardlayout hat) ist bed
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> ist in OpenMP nur innerhalb von %<declare simd%>-Klauseln erlaubt"
@@ -54727,7 +54785,7 @@ msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ga
 msgid "linear step expression must be integral"
 msgstr "Ausdruck für »linear«-Schrittweite muss ganzzahlig sein"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
@@ -54852,117 +54910,117 @@ msgstr "%qD tritt in %<nontemporal%>-Klauseln mehrfach auf"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD ist in %<depend%>-Klausel weder lvalue-Ausdruck noch Arrayabschnitt"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "Template %qE in Klausel %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "überladener Funktionsname %qE in Klausel %qs"
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "Ausdruck für %<grainsize%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "Ausdruck für %<priority%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<hint%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%<hint%>-Ausdruck muss ganzzahlig und konstant sein"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "Variable %qs ist weder Zeiger noch Referenz auf Zeiger"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Variable %qs ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Argument für %<tile%> erfordert ganzzahligen Typ"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-qualifiziertes %qE ohne %<mutable%>-Element darf nur in %<shared%>- oder %<firstprivate%>-Klauseln vorkommen"
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist weder Datei-, Namens- noch Blockbereichsvariable"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> Direktive %qE nicht in Definition von %qT"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> zusammen mit Iterationsvariable %qE verwendet"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statische Erklärung gescheitert: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "Argument für %<decltype%> muss ein Ausdruck sein"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
@@ -55202,798 +55260,798 @@ msgstr "bei Umwandlung zwischen unterschiedlichen Zeiger-auf-Element-Typen %qT u
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "im Bedingungsausdruck mit unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "kanonische Typen unterscheiden sich für identische Typen %qT und %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "selber kanonischer Typknoten für die unterschiedlichen Typen %qT und %qT"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ungültige Anwendung von %qs auf Elementfunktion"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ungültige Anwendung von %<sizeof%> auf ein Bitfeld"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<sizeof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ungültige Anwendung von %<__alignof%> auf ein Bitfeld"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<__alignof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "Argument für %<alignas%> hat nicht-ganzzahligen Typen %qT"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion vom Typ %qT"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "Adresse eines temporären Wertes wird verwendet"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbietet, eine Zeichenkettenkonstante in %qT zu konvertieren"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "veraltete Konvertierung von Zeichenkettenkonstante in %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "Anforderung des Elements %qD in %qE, das vom Zeigertyp %qT ist (vielleicht war %<->%> gemeint?)"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "Abfrage des Elementes %qD in %qE, das vom Nicht-Klassentyp %qT ist"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ungültige Verwendung des nicht-statischen Datenelements %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ungültiger Zugriff auf nicht-statisches Datenelement %qD in virtueller Basis des NULL-Objektes"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "Objekttyp %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "der zerstörte Typ ist %qT, aber der Destruktor verweist auf %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "auf Feld %q#D kann mittels %q#D zugegriffen werden"
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T hat kein Element namens %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %q#D? (zugreifbar über %q#D)"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %q#D? (aus diesem Kontext nicht zugreifbar)"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %qE?"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ist kein Element von %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT ist keine Basis von %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD ist keine Elementtemplatefunktion"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT ist kein Zeiger auf Objekt"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ungültige Verwendung von Arrayindizierung bei Zeiger auf Element"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ungültige Verwendung des unären %<*%> bei Zeiger auf Element"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ungültige Verwendung impliziter Umwandlung bei Zeiger auf Element"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "linker Operand von %<->*%> muss Zeiger auf Klasse sein, ist aber ein Zeiger auf Element des Typs %qT"
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "Index fehlt in Arrayreferenz"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "Indizierung eines als %<register%> deklarierten Arrays"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indizierter Wert ist weder ein Array noch ein Zeiger"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "bei Verwendung von %qE fehlt Objekt"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO-C++ verbietet den Aufruf von %<::main%> vom Programm aus"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<.*%> oder %<->*%> muss verwendet werden, um Zeiger auf Element als Funktion in %<%E (...)%> aufzurufen, z.B. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Ausdruck kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "zu viele Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "zu wenige Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "zu viele Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Zu wenige Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "zu viele Argumente für Funktion %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "zu wenige Argumente für Funktion %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "zu viele Argumente für Methode %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "zu wenige Argumente für Methode %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "zu viele Argumente für Funktion"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "zu wenige Argumente für Funktion"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "Parameter %P von %qD hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "Parameter %P hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "Die Adresse von %qD wird nie NULL sein"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "der Compiler kann annehmen, dass die Adresse von %qD niemals NULL ist"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "Umwandlung in Typ %qT von überladener Funktion wird angenommen"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL in Arithmetik verwendet"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger und Ganzzahl"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Operandentypen sind %qT und %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "Drei-Wege-Vergleich von Vektoren"
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "ungeordneter Vergleich mit Nicht-Gleitkomma-Argument"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qH in %qI zur Anpassung an anderen Operanden des Binärausdrucks"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ungültige Operanden der Typen %qT und %qT für binäres %qO"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers des Typs %<void *%> in Subtraktion"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf eine Funktion in Subtraktion"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf Methode in Subtraktion"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ungültige Verwendung eines Zeigers auf einen unvollständigen Typen in Zeigerarithmetik"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "Adresse des Konstruktors %qD wird genommen"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "Adresse des Destruktors %qD wird genommen"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ungültige Verwendung von %qE um Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  eine qualifizierte ID ist erforderlich"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "Klammern um %qE können nicht verwendet werden, einen Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer nicht qualifizierten oder geklammerten nicht-statischen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer gebundenen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "Adresse eines rvalues wird ermittelt"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse der Funktion %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "Zeiger auf Referenzelement %qD kann nicht erzeugt werden"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "Versuch, die Adresse eines Bitfelds zu bestimmen"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "Adresse der direkten Funktion %qD wird genommen"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> auf einem Ausdruck vom Typ %<bool%>"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "meinten Sie ein logisches Nicht (%<!%>)?"
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO-C++ verbietet erhöhen einer Aufzählung"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO-C++ verbietet verringern einer Aufzählung"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht erhöht werden"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht verringert werden"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Erhöhen eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Verringern eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "%qs-Ausdruck von %<volatile%>-qualifiziertem Typ ist veraltet"
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator--%> ist verboten"
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist in C++17 verboten"
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist veraltet"
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "Adresse von %<this%> kann nicht ermittelt werden, das ein R-Wert-Ausdruck ist"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "Adresse für %qD angefordert, was als %<register%> deklariert ist"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "Listeninitialisierung für Nicht-Klassentyp darf nicht geklammert sein"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Initialisierung behandelt"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Speicherinitialisierung behandelt"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in funktionaler Umwandlung behandelt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80191
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Ausdrucksliste für »%s« wird als zusammengesetzten Ausdruck behandelt"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "kein Kontext, um Typ von %qE aufzulösen"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "Umwandlung des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> von Typ %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> von Typ %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "nutzlose Umwandlung in Typ %q#T"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "Typkennzeichner an Umwandlungs-Rückgabetyp ignoriert"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ungültiges %<static_cast%> von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "Klassentyp %qT ist unvollständig"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 msgid "converting from %qH to %qI"
 msgstr "Umwandlung von %qH nach %qI"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ungültige Typumwandlung eines R-Wert-Ausdrucks des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr "Typumwandlung von %qH nach %qI verliert Genauigkeit"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Funktionstypen von %qH nach %qI"
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Elementzeigertypen von %qH nach %qI"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "Umwandlung von %qH in %qI erhöht erforderliche Ausrichtung des Zieltyps"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "Umwandlung zwischen Zeiger auf Funktion und Zeiger auf Objekt ist bedingt unterstützt"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ungültige Umwandlung von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ungültige Verwendung von %<const_cast%> mit Typ %qT, der weder Zeiger, Referenz, noch Zeiger auf ein Datenelement ist"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ungültige Verwendung von %<const_cast%> mit Typ %qT, der ein Zeiger oder Referenz auf Funktionstyp ist"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ungültiges %<const_cast%> eines R-Wertes des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ungültiges %<const_cast%> von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO-C++ verbietet Umwandlung in Arraytyp %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ungültige Umwandlung in Funktionstyp %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr "Verbundzuweisung mit %<volatile%>-qualifiziertem linken Operanden ist veraltet"
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  in Auswertung von %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "Zuweisung an Array von Initialisierungsliste"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "unverträgliche Typen in Zuweisung von %qT an %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "Array als Initialisierung verwendet"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Ungültige Arrayzuweisung"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   in Umwandlung in Zeiger auf Elementfunktion"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Umwandlung in Zeiger auf Element über virtuelle Basis %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   in Umwandlung in Zeiger auf Element"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ungültige Umwandlung in Typ %qT von Typ %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qH kann nicht nach %qI im Standardargument umgewandelt werden"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qH kann nicht nach %qI bei Argumentübergabe umgewandelt werden"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qH kann nicht nach %qI in Initialisierung umgewandelt werden"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qH kann nicht nach %qI in Rückgabe umgewandelt werden"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qH kann nicht nach %qI in Zuweisung umgewandelt werden"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Parameter %qP von %qD könnte Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "Parameter könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Ziel der Umwandlung könnte Kandidat ein für ein Formatattribut sein"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Ziel der Initialisierung könnte ein Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "linke Seite der Zuweisung könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "bei Übergabe des Arguments %P von %qD"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "Referenz auf temporären Wert wird zurückgegeben"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "das Zurückgeben einer temporären %<initializer_list%> verlängert nicht die Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "Referenz auf lokale Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "das Zurückgeben der lokalen %<initializer_list%>-Variable %qD verlängert nicht die Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "das Verschieben eines lokalen Objekts in einer return-Anweisung verhindert das Einsparen der Kopie"
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "entfernen Sie den Aufruf von %<std::move%>"
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "redundantes Verschieben in Rückgabeanweisung"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "Wert von Destruktor zurückgegeben"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "vom Behandler eines Funktions-try-Blocks eines Konstruktors kann nicht zurückgekehrt werden"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "Rückgabe eines Wertes von einem Konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "Return-Anweisung ohne Wert, in %qT zurückgebender Funktion"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "Initialisierungsliste wird zurückgegeben"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "widersprüchliche Typen %qT und %qT für Lambda-Rückgabetypen hergeleitet"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für automatischen Rückgabetyp: %qT und dann %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "Return-Anweisung mit Wert, in Funktion mit Rückgabetyp %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> darf nicht NULL zurückgeben, außer er ist mit %<throw%> deklariert (oder %<-fcheck-new%> ist eingeschaltet)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "rvalue wird als lvalue verwendet"
@@ -56252,107 +56310,107 @@ msgstr "entfernen Sie die %<{ }%> um den Initialisierer"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD mit nicht initialisierten Feldern"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "Designator-Reihenfolge für Feld %qD passt nicht zur ursprünglichen Deklaration in %qT"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen rvalue"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen lvalue"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht vor C++2a einen lvalue"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Arraytyp %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "Templateargumente für %qT von %<()%> können nicht hergeleitet werden"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -56589,10 +56647,10 @@ msgstr "Feldreferenz bei %C darf nur maximal 7 Dimensionen haben"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "Feldreferenz bei %C kann nicht mehr als %d Dimensionen haben"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -56760,7 +56818,7 @@ msgstr "Feldkonstruktoren im [...]-Stil bei %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Feldkonstruktor mit Typspezifikation bei %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Typspezifikation bei %L kann keine Parameter mit aufgeschobenem Typ haben"
@@ -56884,7 +56942,7 @@ msgstr "Die BOZ-Literalkonstante bei %L darf kein tatsächliches Argument für %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argumente von %qs bei %L und %L können nicht beide literale BOZ-Konstanten sein"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Ungültige Verwendung der BOZ-Literalkonstante bei %L"
@@ -56924,7 +56982,7 @@ msgstr "Fortran 2003: Zeichen für Argument %qs des intrinsischen %qs bei %L"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss INTEGER, REAL oder CHARACTER sein"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss ein intrinsischer Typ sein"
@@ -56939,7 +56997,7 @@ msgstr "Argument %qs des intrinsischen %qs bei %L muss REAL oder COMPLEX sein"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "Argument %qs für intrinsisches %qs bei %L muss INTEGER oder PROCEDURE sein"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss eine Konstante sein"
@@ -57059,167 +57117,167 @@ msgstr "Ungleiche Zeichenlängen (%ld, %ld) in %s bei %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "Argumente %qs und %qs des intrinsischen %qs bei %L müssen denselben Typ haben"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "Verschiedene Typ-Arten bei %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "NULL bei %L ist nicht als tatsächliches Argument der intrinsischen Funktion %qs erlaubt"
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss ein POINTER sein"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf keinen Koindex haben"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss ein Zeiger oder Ziel VARIABLE oder FUNCTION sein"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss ein POINTER oder ein TARGET sein"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "Feldabschnitt mit Vektorindex bei %L darf nicht das Ziel eines Zeigers sein"
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "NULL-Zeiger bei %L ist nicht als effektives Argument der intrinsischen Funktion %qs erlaubt"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "ATOM-Argument bei %L für intrinsische Funktion %s muss eine ATOMIC_INT_KIND-Ganzzahl oder ein ATOMIC_LOGICAL_KIND-Logikwert sein"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "ATOM-Argument bei %L der intrinsischen Funktion %s muss Koarray oder koindiziert sein"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss vom gleichen Typ und gleicher Art wie %qs bei %L sein"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "STAT=-Argument für %s bei %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "ATOM-Argument der intrinsischen Funktion »%s« bei %L muss definierbar sein"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "ATOM-Argument bei %L für intrinsische Funktion %s muss eine ATOMIC_INT_KIND-Ganzzahl sein"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "VALUE-Argument der intrinsischen Funktion »%s« bei %L muss definierbar sein"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "Argument %qs des intrinsischen %qs bei %L ist noch nicht unterstützt"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss eine gültige Ganzzahlart sein"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "OLD-Argument der intrinsischen Funktion »%s« bei %L muss definierbar sein"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "EVENT-Argument bei %L für die intrinsische EVENT_QUERY muss vom Typ EVENT_TYPE sein"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "COUNT-Argument der intrinsischen Funktion »EVENT_QUERY« bei %L muss definierbar sein"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "COUNT-Argument der intrinsischen Funktion EVENT_QUERY bei %L muss mindestens den Gültigkeitsbereich von Standard-Integer abdecken"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Negatives Argument N bei %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf nicht vorhanden sein, wenn %<x%> COMPLEX ist"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "%qs-Argument des intrinsischen %qs bei %L muss vom Typ REAL oder INTEGER sein"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr "Umwandlung von %s in standardartiges COMPLEX(%d) bei %L könnte Genauigkeit verlieren, evtl. KIND-Argument verwenden"
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr "Argument %<A%> mit INTENT(OUT) bei %L des intrinsischen Unterprogramms %s darf keinen Vektorindex haben"
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "Argument A bei %L des intrinsischen %s darf keinen Koindex haben"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "Das Argument »stat=« bei %L muss INTEGER-Variable mit »kind=4« sein"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "Das Argument »errmsg=« bei %L muss eine standardartige Zeichenvariable sein"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "Koarrays bei %L ausgeschaltet, %<-fcoarray=%> schaltet sie ein"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr "Unterstützung für das A-Argument bei %L, das ein polymorphes A-Argument ist oder allozierbare Komponenten hat, ist noch nicht implementiert"
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "Das A-Argument bei %L von CO_REDUCE darf nicht polymorph sein"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr "Unterstützung für das A-Argument bei %L mit allozierbaren Komponenten ist noch nicht implementiert"
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "OPERATOR-Argument bei %L muss eine PURE-Funktion sein"
@@ -57227,699 +57285,699 @@ msgstr "OPERATOR-Argument bei %L muss eine PURE-Funktion sein"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Intrinsische Funktion »%s« bei %L ist nicht für CO_REDUCE erlaubt"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wird, muss zwei Argumente haben"
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr "Argument A bei %L hat Typ »%s«, aber die Funktion, die bei %L als OPERATOR übergeben wurde, gibt »%s« zurück"
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wurde, hat Argumente vom Typ »%s« und »%s«, muss aber Typ »%s« haben"
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wird, muss Argumente haben, die nichtallozierbar und keine Zeiger sind, und der Rückgabewert muss nichtallozierbar, kein Zeiger und skalar sein"
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wird, muss das VALUE-Attribut entweder für keins oder für beide Argumente haben"
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wird, muss das TARGET-Attribut entweder für keins oder für beide Argumente haben"
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wird, muss das ASYNCHRONOUS-Attribut entweder für keins oder für beide Argumente haben"
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr "Die Funktion, die bei %L als OPERATOR übergeben wird, darf bei keinem der Argumente das OPTIONAL-Attribut haben"
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr "Die Zeichenlänge des A-Arguments bei %L und die Länge der Argumente für den OPERATOR bei %L muss dieselbe sein"
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr "Die Zeichenlänge des A-Arguments bei %L und die Länge des Funktionsergebnisses des OPERATORs bei %L muss dieselbe sein"
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss vom Typ integer, read oder character sein"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "intrinsisches %qs mit KIND-Argument bei %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat ungültige Form in Dimension %d (%ld/%ld)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss Rang %d haben oder ein Skalar sein"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss numerisch oder LOGICAL sein"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "Unterschiedliche Form für Argumente %qs und %qs bei %L für intrinsisches %<dot_product%>"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss ein Standard-Real sein"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "%qs muss vom gleichen Typ und gleicher Art wie %qs bei %L in %qs sein"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "Argument %qs des intrinsischen %qs bei %L für %qs des Typs %qs fehlt"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "Nicht-Standard Argument der Art INTEGER für intrinsisches »%s« bei %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "COMPLEX-Argument %qs ist Argument des intrinsischen %qs bei %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "Argumente von %qs unterscheiden sich im Typ bei %L"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Argument von %s bei %L muss von der Länge eins sein"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss von der selben Art wie %qs sein"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr "Das intrinsische Unterprogramm %qs bei %L ist veraltet. Verwenden Sie das intrinsische Unterprogramm INT."
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "SIZE bei %L muss positiv sein"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "Der absolute Wert von SHIFT bei %L muss kleiner oder gleich SIZE bei %L sein"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "STATUS bei %L muss eine »INTENT(OUT)«-Variable sein"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "%qs bei %L muss eine %<INTENT(OUT)%>-Variable sein"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss eine Datenentität sein"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Das intrinsische %qs bei %L muss mindestens zwei Argumente haben"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Fehlendes %qs-Argument für %qs bei %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Doppeltes Argument %qs bei %L für intrinsisches %s"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Unbekanntes Argument %qs bei %L für intrinsisches %s"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "Argument %<a%d%> des intrinsischen %qs bei %L muss %s(%d) sein"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "intrinsisches %qs mit CHARACTER-Argument bei %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "Argument %<a1%> des intrinsischen %qs bei %L muss INTEGER, REAL oder CHARACTER sein"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Argumenttypen des intrinsischen %qs bei %L müssen passen (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "Andere Form bei Dimension 1 für Argumente %qs und %qs bei %L für intrinsisches matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "Andere Form bei Dimension 2 für Argument %qs und Dimension 1 für Argument %qs bei %L für intrinsisches matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss vom Rang 1 oder 2 sein"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss typkonform zu Argument %qs bei %L sein"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss ein INTEGER sein"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Das FROM-Argument für MOVE_ALLOC bei %L darf keinen Koindex haben"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Das TO-Argument für MOVE_ALLOC bei %L darf keinen Koindex haben"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "Die TO-Argumente in MOVE_ALLOC bei %L müssen polymorph sein, wenn FROM polymorph ist"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "Die FROM- und TO-Argumente des intrinsischen MOVE_ALLOC bei %L müssen den selben Rang %d/%d haben"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "Die FROM- und TO-Argumente des intrinsischen MOVE_ALLOC bei %L müssen den selben Ko-Rang %d/%d haben"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr "Die FROM- und TO-Argumente bei %L verletzen die Aliasing-Beschränkungen (F2003 12.4.1.7)"
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "Argument %<S%> von NEAREST bei %L darf nicht Null sein"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss POINTER, ALLOCATABLE oder Prozedurzeiger sein"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "intrinsisches NULL mit reservierbarem MOLD bei %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss mindestens so viele Elemente haben wie es .TRUE.-Werte %qs (%ld/%d) gibt"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss eine Scheinvariable sein"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss eine OPTIONALe Scheinvariable sein"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf kein Unterobjekt von %qs sein"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Argument des intrinsischen RANK bei %L muss ein Datenobjekt sein"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "Argument %<shape%> des intrinsischen %<reshape%> bei %L muss ein Feld konstanter Größe sein"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "Argument %qs des intrinsischen %qs bei %L ist leer"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "Argument »shape« des intrinsischen »reshape« bei %L hat mehr als %d Elemente"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat negatives Element (%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Element %d des tatsächlichen Arguments von RESHAPE bei %L darf nicht negativ sein"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat falsche Anzahl der Elemente (%d/%d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat Dimension außerhalb des Wertebereiches (%d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat ungültige Permutation der Dimensionen (Dimension %qd doppelt)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Ohne Auffüllen gibt es nicht genügend Elemente in intrinsischer RESHAPE-Quelle bei %L, um zur Form zu passen"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "Argument %qs des intrinsischen %qs bei %L kann nicht Typ %s haben"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss erweiterbaren Typ haben"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND ohne Argument %<P%> oder %<R%> bei %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "intrinsisches %qs mit RADIX-Argument bei %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "Argument %<source%> des intrinsischen %<shape%> bei %L darf kein Feld impliziter Größe sein"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf keine Prozedur sein"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf nicht TYPE(*) sein"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf kein Feld impliziter Größe sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr failed"
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss austauschbare Datenentität sein: %s"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "Argument C_PTR_1 bei %L für C_ASSOCIATED muss den Typ TYPE(C_PTR) oder TYPE(C_FUNPTR) haben"
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "Argument C_PTR_2 bei %L für C_ASSOCIATED muss denselben Typ wie C_PTR_1 haben: %s statt %s"
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "Argument CPTR bei %L für C_F_POINTER muss den Typen TYPE(C_PTR) haben"
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Argument FPTR bei %L für C_F_POINTER muss ein Zeiger sein"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "Argument FPTR für C_F_POINTER bei %L darf nicht polymorph sein"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "Argument FPTR für C_F_POINTER bei %L darf nicht koindiziert sein"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Unerwartetes SHAPE-Argument bei %L für C_F_POINTER mit skalarem FPTR"
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "SHAPE-Argument für C_F_POINTER mit Array-FPTR bei %L erwartet"
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "SHAPE-Argument bei %L für C_F_POINTER muss dieselbe Größe haben wie der RANK des FPTR"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "Polymorpher FPTR bei %L für C_F_POINTER"
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Unverträglicher Feld-FPTR bei %L für C_F_POINTER: %s"
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "Argument CPTR bei %L für C_F_PROCPOINTER muss den Typen TYPE(C_FUNPTR) haben"
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "Argument FPTR bei %L für C_F_PROCPOINTER muss ein Prozedurzeiger sein"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "Argument FPTR bei %L für C_F_PROCPOINTER darf nicht koindiziert sein"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Unverträglicher Prozedurzeiger bei %L für C_F_PROCPOINTER"
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "Argument X bei %L für C_FUNLOC darf nicht koindiziert sein"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Funktionsergebnis %qs bei %L ist als X-Argument für C_FUNLOC ungültig"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "Argument X bei %L für C_FUNLOC muss eine Prozedur oder ein Prozedurzeiger sein"
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Unverträgliche Prozedur bei %L für C_FUNLOC"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "Argument X bei %L für C_LOC darf nicht koindiziert sein"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "X-Argument bei %L für C_LOC darf nicht polymorph sein"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Argument X bei %L für C_LOC muss entweder POINTER- oder TARGET-Attribut haben"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "Argument X bei %L für C_LOC darf keine Zeichenkette der Länge 0 sein"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Argument bei %L für C_LOC darf nicht polymorph sein"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Unverträgliches Feld bei %L als Argument für C_LOC: %s"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Feld von interoperablem Typ bei %L für C_LOC; es ist nichtallozierbar und hat weder angenommene noch explizite Größe"
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Feldabschnitt bei %L für C_LOC"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "REAL-Argument ohne doppelte Genauigkeit für intrinsisches %s bei %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "Argument %qs für intrinsisches %qs bei %L muss geringer als Rang %d sein"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "Argument %qs des intrinsischen %qs bei %L ist kein gültiger Dimensionsindex"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "Argument »%s« für IMAGE_INDEX muss Feld mit Rang 1 bei %L sein"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Die Anzahl der Feldelemente des SUB-Arguments für IMAGE_INDEX bei %L muss %d (Korang) sein, nicht %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "Argument DISTANCE= für NUM_IMAGES bei %L"
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "Argument FAILED= für NUM_IMAGES bei %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "TEAM-Argument bei %L für die intrinsische TEAM_NUMBER muss vom Typ TEAM_TYPE sein"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM-Argument ohne COARRAY-Argument ist für intrinsisches THIS_IMAGE bei %L nicht erlaubt"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "Das DISTANCE-Argument darf in intrinsischer Routine bei %L nicht zusammen mit COARRAY- oder DIM-Argument angegeben werden"
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Unerwartetes DIM-Argument mit Nicht-COARRAY-Argument bei %L"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "Argument DISTANCE= für THIS_IMAGE bei %L"
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr "Argument %<MOLD%> des intrinsischen %<TRANSFER%> bei %L ist ein Array und darf nicht die Speichergröße 0 haben, da das %<SOURCE%>-Argument größer als 0 ist"
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "Argument %<SOURCE%> des intrinsischen %<TRANSFER%> bei %L darf kein %s sein"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "Argument %<MOLD%> des intrinsischen %<TRANSFER%> bei %L darf kein %s sein"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "Argument %<MOLD%> des intrinsischen %<TRANSFER%> bei %L darf nicht %s sein"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Intrinsisches TRANSFER bei %L hat teilweise undefiniertes Ergebnis: Quellgröße %ld < Ergebnisgröße %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss den selben Rang wie %qs haben oder skalar sein"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Argumente %qs und %qs des intrinsischen %qs bei %L müssen gleiche Form haben."
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Größe des Arguments %qs des intrinsischen %qs bei %L ist zu klein (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Zu viele Argumente für %s bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "fe_runtime_error string must be null terminated"
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Das COUNT-Argument für SYSTEM_CLOCK bei %L hat nicht-Standard-Art"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Reelles COUNT_RATE-Argument für SYSTEM_CLOCK bei %L"
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Das COUNT_RATE-Argument für SYSTEM_CLOCK bei %L hat nicht-Standard-Art"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Das COUNT_MAX-Argument für SYSTEM_CLOCK bei %L hat nicht-Standard-Art"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf von der Art nicht breiter als der Standard (%d) sein"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "Argument bei %L von der intrinsischen Funktion %qs muss ein verbundener Zeiger sein"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "Argument %qs der intrinsischen Funktion %qs bei %L muss INTEGER, LOGICAL oder ein BOZ-Literal sein"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "Intrinsische Funktion NULL bei %L kann kein tatsächliches Argument für STORAGE_SIZE sein, da es einen disassoziierten Zeiger zurückgibt"
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "Polymorphe Objekte oder Komponenten mit vermuteter Größe, so wie bei %C, wurden noch nicht implementiert"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Höchste Erweiterungsstufe mit Typ %qs bei %L erreicht"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "%qs von %qs bei %L ist PRIVATE"
@@ -58115,1760 +58173,1760 @@ msgstr "Falsche INTENT-Spezifikation bei %C"
 msgid "deferred type parameter at %C"
 msgstr "Parameter mit zurückgestelltem Typ bei %C"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalarer INTEGER-Ausdruck bei %L erwartet"
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Zeichenlänge alten Stils bei %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Syntaxfehler in Zeichenlängenangabe bei %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Prozedur %qs bei %C wurde bereits bei %L definiert"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Enthaltene Prozedur %qs bei %C steht in Konflikt mit Prozedur, die bei %L definiert wurde"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Name %qs bei %C ist bereits als eine allgemeine Schnittstelle bei %L definiert"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Prozedur %qs bei %C hat eine explizite Schnittstelle aus einer vorherigen Deklaration"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "Die Prozedur %qs, die im Interface-Körper bei %L definiert ist, passt nicht zu der internen Prozedur bei %C"
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Prozedur %qs bei %L muss das BIND(C)-Attribut haben, um mit C interoperabel zu sein"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Variable %qs bei %L ist ein Scheinargument für die BIND(C)-Prozedur %qs, jedoch nicht interoperabel mit C, da der abgeleitete Typ %qs nicht mit C interoperabel ist"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Variable %qs bei %L ist ein Scheinargument für die BIND(C)-Prozedur %qs, jedoch nicht interoperabel mit C, da sie polymorph ist"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Variable %qs bei %L ist ein Scheinargument für die BIND(C)-Prozedur %qs, könnte jedoch unverträglich mit C sein"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Zeichenargument %qs bei %L muss Länge 1 haben, da Prozedur %qs BIND(C) ist"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs bei %L mit OPTIONAL-Attribut in Prozedur %qs, die BIND(C) ist"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs bei %L mit OPTIONAL-Attribut in Prozedur %qs, die BIND(C) ist"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute OPTIONAL und VALUE haben, da Prozedur %qs BIND(C) ist"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variable %qs bei %L mit OPTIONAL-Attribut in Prozedur %qs, die jedoch BIND(C) ist"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Feld mit angenommener Form %qs bei %L als Scheinargument für die BIND(C)-Prozedur %qs bei %L"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Symbol %qs bei %C ist bereits bei %L als ein Typ deklariert"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %C muss mit einer mit C interoperablen Art deklariert sein, da der gemeinsame Block %qs BIND(C) ist"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "CHARACTER-Länge bei %L muss konstant sein"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER-Ausdruck bei %L wird abgeschnitten (%ld/%ld)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Die CHARACTER-Elemente des Feldkonstruktors bei %L müssen dieselbe Länge haben (%ld/%ld)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Initialisierer nicht erlaubt für PARAMETER %qs bei %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Fehlende Initialisierung für PARAMETER bei %L"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variable %qs bei %C mit Initialisierung tritt bereits in einer DATA-Anweisung auf"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Parameter-Feld bei %L kann nicht mit Elementen variabler Länge initialisiert werden"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "Das implied-shape-Feld bei %L kann nicht mit Skalar initialisiert werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr "Interner Fehler: gfc_array_size failed"
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Nicht-konstante untere Grenze in Deklaration mit impliziter Form bei %L"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponente bei %C muss ein POINTER-Attribut haben"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Komponente %qs mit CLASS bei %C muss allozierbar oder Zeiger sein"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Feldkomponente der Struktur bei %C muss explizite oder aufgeschobene Form haben"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponente %qs bei %C bereits bei %L deklariert"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Zeigerfeld-Komponente der Struktur bei %C muss eine aufgeschobene Form haben"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allozierbare Komponente der Struktur bei %C muss eine aufgeschobene Form haben"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Feldkomponente der Struktur bei %C muss eine explizite Form haben"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Typparameter %qs bei %C hat keinen zugehörigen Eintrag in der Typparameter-Namensliste bei %L"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-Initialisierung bei %C ist mehrdeutig"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-Initialisierung bei %C könnte kein MOLD haben"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung des Zeigers bei %C ist nicht in einer PURE-Prozedur erlaubt"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Fehler in Zeigerinitialisierung bei %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Nicht-NULL-Zeigerinitialisierung bei %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr "Die RESULT-Variable %qs bei %L verbietet, dass der FUNCTION-Name %qs bei %C in einer Spezifikationsanweisung auftritt"
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "%qs ist außerhalb der STRUCTURE bei %C nicht erlaubt"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs bei %C ist eine DEC-Erweiterung, muss mit %<-fdec-structure%> eingeschaltet werden"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "Entität %qs bei %C kann keine Argumente haben"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Ungültiges Zeichen %qc in Variablenname bei %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Nicht-PARAMETER-Symbol %qs bei %L kann nicht implied-shape sein"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Feld mit impliziter Form bei %L"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Feld mit expliziter Form, aber nichtkonstanten Grenzen bei %C"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs bei %C ist eine Redefinition der Deklaration in der entsprechenden Schnittstelle für MODUL PROCEDURE %qs"
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Entität %qs bei %C kann keine Initialisierung haben"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Doppelte Feldspezifikation für Cray-Zeigerende bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "Interner Fehler: Cannot set pointee array spec."
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisierung im alten Stil bei %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Ungültige Initialisierung im alten Stil für abgeleitete Typkomponente bei %C"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Syntaxfehler in Initialisierung im alten Stil von %s bei %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisierung bei %C ist nicht für eine Zeigervariable"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Zeigerinitialisierung bei %C benötigt %<=>%>, nicht %<=%>"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung einer Variablen bei %C ist in einer PURE-Prozedur nicht erlaubt"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initialisierung einer allozierbaren Komponente bei %C ist nicht erlaubt"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "Initialisierung einer Strukturkomponente mit einer HOLLERITH-Konstante bei %L ist nicht erlaubt"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Die Komponente bei %C mit KIND- oder LEN-Attribut erscheint nicht in der Typparameterliste bei %L"
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Die Komponente bei %C, die in der Typparameterliste bei %L erscheint, hat weder KIND- noch LEN-Attribut"
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Die Komponente bei %C, die ein Typparameter ist, muss ein Skalar sein"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "Die BOZ-Literalkonstante bei %L darf nicht als Initialisierer vorkommen"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr "Inkompatible Initialisierung zwischen einer abgeleiteten Typentität und einer Entität mit Typ %qs bei %C"
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Deklaration %s*%d im alten Stil wird bei %C nicht unterstützt"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nicht-Standard Typ-Deklaration %s*%d bei %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Fehlende rechte Klammer bei %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Skalaren Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Die Art %d wird für Typ %s bei %C nicht unterstützt"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Typ-Parameter nach C-Art ist für Typ %s, aber Typ bei %L ist %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Fehlende rechte Klammer oder Komma bei %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Die Art %d wird für CHARACTER bei %C nicht unterstützt"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfehler in CHARACTER-Deklaration bei %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "RECORD bei %C ist eine Erweiterung, muss mit %<-fdec-structure%> eingeschaltet werden"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Strukturname nach RECORD bei %C erwartet"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "Die Typparameter-Angabenliste bei %C kann nicht gleichzeitig ASSUMED- und DEFERRED-Parameter enthalten"
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Die Typparameter-Angabenliste bei %C enthält nicht genug Parameterausdrücke"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Der abgeleitete Parameter %qs bei %C hat keinen Vorgabewert"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Der Parameterausdruck bei %C muss vom Typ INTEGER sein, nicht %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "Der KIND-Parameter %qs bei %C darf weder ASSUMED noch DEFERRED sein"
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Der Wert für den KIND-Parameter %qs bei %C lässt sich nicht auf einen konstanten Ausdruck reduzieren"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "Die Typparameter-Angabenliste bei %C enthält zu viele Parameterausdrücke"
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Der parametrisierte abgeleitete Typ bei %C ist mehrdeutig"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-Typ bei %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Bei %C verwendeter BYTE-Typ ist auf der Zielmaschine nicht verfügbar"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Vermuteter Typ bei %C ist für Komponenten nicht erlaubt"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Vermuteter Typ bei %C"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE mit intrinsischer Typspezifikation bei %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "Falsch geformte Typspezifikation bei %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX bei %C"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typname %qs bei %C ist mehrdeutig"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-Anweisung bei %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typname %qs bei %C in Konflikt mit vorher deklarierter Entität bei %L, die den gleichen Namen hat"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Doppelte IMPLICIT NONE-Anweisung bei %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE mit Angabenliste bei %C"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Fehlender Zeichenbereich in IMPLICIT bei %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Buchstaben in IMPLICIT-Anweisung bei %C müssen in alphabetischer Reihenfolge sein"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-Anweisung bei %C folgt auf IMPLICIT NONE (Typ-)Anweisung"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Leere IMPLICIT-Anweisung bei %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-Anweisung bei %C ist nur in einem INTERFACE-Körper erlaubt"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT-Anweisung bei %C ist im Körper einer Schnittstelle für Modulprozedur nicht erlaubt"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste benannter Einträge bei %C erwartet"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "IMPORT %qs aus Host-Sichtbarkeitseinheit bei %C nicht möglich - existiert nicht."
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs bereits aus Host-Sichtbarkeitseinheit bei %C IMPORTiert"
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfehler in IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Fehlende Kodimensionsangabe bei %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Fehlende Dimensionsangabe bei %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Doppeltes Attribut %s bei %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s bei %L ist eine DEC-Erweiterung, muss mit %<-fdec-static%> eingeschaltet werden"
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Attribut ALLOCATABLE bei %C in einer STRUCTURE-Definition"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "KIND-Attribut bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "KIND-Attribut bei %C in einer STRUCTURE-Definition"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Komponente mit KIND-Attribut bei %C muss ein INTEGER sein"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Komponente mit KIND-Attribut bei %C muss per Default Ganzzahlart (%d) sein"
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "LEN-Attribut bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "LEN-Attribut bei %C in einer STRUCTURE-Definition"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponente mit LEN-Attribut bei %C muss INTEGER sein"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Komponente mit LEN-Attribut bei %C muss per Default Ganzzahlart (%d) sein"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut bei %L ist in TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "Attribut bei %L ist in STRUCTURE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s bei %L in einer TYPE-Definition"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Attribut %s bei %L ist außerhalb des Spezifikationsabschnitts eines Moduls nicht erlaubt"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribut bei %L ist außerhalb einer TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "ASYNCHRONOUS-Attribut bei %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "CONTIGUOUS-Attribut bei %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED bei %C nur in Spezifikationsabschnitts eines Moduls erlaubt"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "PROTECTED-Attribut bei %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "VALUE-Attribut bei %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "VOLATILE-Attribut bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Bad attribute"
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Mehrere Bezeichner mit einzelner Spezifikation NAME= bei %C angegeben"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implizit deklarierte BIND(C)-Funktion %qs bei %L ist möglicherweise nicht interoperabel mit C"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %L könnte inkompatibel mit C sein, obwohl gemeinsamer Block %qs BIND(C) ist"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs bei %L ist nicht C-kompatibel, aber sie ist BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variable %qs bei %L könnte mit C inkompatibel sein, aber sie ist BIND(C)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %L kann nicht mit BIND(C) deklariert werden, da sie nicht global ist"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute POINTER und BIND(C) haben"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute ALLOCATABLE und BIND(C) haben"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Rückgabetyp der BIND(C)-Funktion %qs bei %L kann kein Feld sein"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "Rückgabetyp der BIND(C)-Funktion %qs von Zeichentyp bei %L muss die Länge 1 haben"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbol %qs bei %L ist als PRIVATE markiert, aber wurde mit Bindung %qs markiert"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Entweder Entität oder Name eines gemeinsamen Blocks für Attribut-Spezifikationsanweisung bei %C erforderlich"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entität oder Name eines gemeinsamen Blocks für Attribut-Spezifikationsanweisung bei %C fehlt"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Fehlendes Symbol"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-Anweisung bei %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Abgeleiteter Typ bei %C wurde vorher nicht definiert und kann daher nicht in einer abgeleiteten Typdefinition auftreten"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaxfehler in anonymer Struktur-Deklaration bei %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfehler in Daten-Deklaration bei %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE-Präfix bei %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "MODULE-Präfix bei %C muss innerhalb eines Moduls, Teilmoduls oder Interfaces sein"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-Prozedur bei %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE und IMPURE dürfen bei %C nicht gleichzeitig stehen"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "Bei %C wird eine Typparameterliste erwartet"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Argument für Alternativrückgabe bei %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Bei %C wird ein Parametername erwartet"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Name %qs bei %C ist der Name der Prozedur"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Parameterliste in Typdeklaration bei %C erwartet"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Unerwartete Angaben in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Doppelter Name %qs in Parameterliste bei %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Doppeltes Symbol %qs in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Konflikt in formalen Argumentnamen (%s/%s) von MODULE PROCEDURE bei %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Konflikt in Anzahl der formalen Argumente von MODULE PROCEDURE bei %C"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-Variable bei %C muss vom Funktionsnamen verschieden sein"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Unerwartete Angaben hinter Funktionsdeklaration bei %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "BIND(C)-Attribut bei %L kann nicht für eine interne Prozedur angegeben werden"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C)-Attribut bei %C erfordert eine Schnittstelle mit BIND(C)"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-Prozedur mit NAME darf kein POINTER-Attribut bei %C haben"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Scheinprozedur bei %C kann kein BIND(C)-Attribut mit NAME haben"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Prozedur %qs bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfehler in PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> nach Bindeattributen bei %C erwartet"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS oder explizite Schnittstelle bei %C erforderlich"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfehler in Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE bei %C muss in einer allgemeinen Schnittstelle sein"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "»::« in MODULE PROCEDURE-Anweisung bei %L"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formale Argumentliste in Funktionsdefinition bei %C erwartet"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C)-Attribut bei %L kann nur für Variablen oder gemeinsame Blöcke verwendet werden"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr "Unverträglichkeit in BIND(C)-Namen (%qs/%qs) bei %C"
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines PROGRAMmes auftreten"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines MODULEs auftreten"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SUBMODULEs auftreten"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von BLOCK DATA auftreten"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines STRUCTURE-Blockes auftreten"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DERIVED TYPE Blockes auftreten"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines IF-THEN-Blockes auftreten"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DO-Blockes auftreten"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SELECT-Blockes auftreten"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines FORALL-Blockes auftreten"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines WHERE-Blockes auftreten"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines enthaltenen Subprogrammes auftreten"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Unerwartete ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-Anweisung bei %C kann nicht in einer enthaltenen Prozedur auftreten"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Erforderte Klammern vor BIND(C) bei %C fehlen"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "ENTRY-Anweisung bei %L mit BIND(C) ist in einer elementaren Prozedur verboten"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "Alternatives Rückgabe-Dummyargument kann nicht in einer SUBROUTINE mit BIND(C)-Attribut bei %L auftreten"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ungültiger C-Name in NAME=-Spezifizierung bei %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfehler in NAME=-Spezifikation für Bindungsmarke bei %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Spezifikation NAME= bei %C sollte ein konstanter Ausdruck sein"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-Angabe bei %C sollte ein Skalar der Standardzeichenart sein"
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Schließende Klammer für Bindungsmarke bei %C fehlt"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "In BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "For Schein-Prozedur %s in BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME nicht erlaubt bei BIND(C) für ABSTRACT INTERFACE bei %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Unerwartete END-Anweisung bei %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-Anweisung statt %s-Anweisung bei %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "»%s«-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamen von %qs in »%s«-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Beendenden Namen bei %C erwartet"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Marke %qs für »%s«-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Fehlende Feldspezifikation bei %L in DIMENSION-Anweisung"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Für %s bei %L wurden Dimensionen nach dessen Initialisierung angegeben"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Feldspezifikation bei %L in CODIMENSION-Anweisung fehlt"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Feldspezifikation muss bei %L aufgeschoben werden"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Doppeltes DIMENSION-Attribut bei %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Unerwartetes Zeichen in Variablenliste bei %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> bei %C erwartet"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variablennamen bei %C erwartet"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-Zeiger bei %C muss eine Ganzzahl sein"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-Zeiger bei %C hat %d Bytes Genauigkeit; Speicheradressen benötigen %d Bytes"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "»,« bei %C erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr "Interner Fehler: Cannot set Cray pointee array spec."
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "»)« bei %C erwartet"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> oder Ende der Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "Cray-Zeiger-Deklaration bei %C benötigt den Schalter %<-fcray-pointer%>"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators %s bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators .%s. bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfehler in PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variablennamen bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Zeichen »=« in PARAMETER-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ausdruck bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisierung einer bereits initialisierten Variablen bei %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER ohne »()« bei %C"
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Unerwartete Zeichen in PARAMETER-Anweisung bei %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s bei %C ist eine DEC-Erweiterung, muss mit %<-fdec-static%> eingeschaltet werden"
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "In AUTOMATIC-Anweisung bei %C wird eine »entity-list« erwartet"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaxfehler in AUTOMATIC-Anweisung bei %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "»entity-list« in STATIC-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaxfehler in STATIC-Anweisung bei %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Umfassende SAVE-Anweisung bei %C folgt vorheriger SAVE-Anweisung"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-Anweisung bei %C folgt umfassender SAVE-Anweisung"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfehler in SAVE-Anweisung bei %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfehler in VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE für Coarray-Variable %qs bei %C angegeben, die use-/host-assoziiert ist"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfehler in VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfehler in ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE-PROCEDURE-Deklaration bei %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE bei %C muss in einer generischen Modulschnittstelle sein"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsische Prozedur bei %L kann keine MODULE PROCEDURE sein"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Mehrdeutiges Symbol in TYPE-Definition bei %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbol %qs bei %C wurde vorher noch nicht definiert"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs in EXTENDS-Ausdruck bei %C ist kein abgeleiteter Typ"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kann bei %C nicht erweitert werden, da es BIND(C) ist"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kann bei %C nicht erweitert werden, da es ein SEQUENCE-Typ ist"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PRIVATE im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PUBLIC im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT-Typ bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Failed to create structure type '%s' at %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Typdefinition von %qs bei %C wurde bereits bei %L definiert"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Ausschuss hinter MAP-Anweisung bei %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Ausschuss hinter UNION-Anweisung bei %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s bei %C ist eine DEC-Erweiterung, muss mit %<-fdec-structure%> eingeschaltet werden"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Strukturname erwartet in unverschachtelter Strukturdeklaration bei %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Ausschuss hinter unverschachtelter STRUCTURE-Anweisung bei %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Strukturname %qs bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "»::« in TYPE-Definition bei %C erwartet"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "Gemangelte abgeleitete Typdefinition bei %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typname %qs bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Abgeleiteter Typname %qs bei %C hat bereits einen Basistypen von %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Abgeleiteter Typname %qs bei %C hat bereits einen Basistyp"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "Scheinargument %qs bei %L darf kein abgeleiteter Typ bei %C sein"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Abgeleitete Typdefinition von %qs bei %C wurde bereits definiert"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Syntaxfehler hinter PARAMETERIZED-TYPE-Deklaration bei %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-Zeigerende bei %C kann nicht Feld mit impliziter Form sein"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM und ENUMERATOR bei %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Zähler übersteigt den C-Ganzzahltyp bei %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L nicht mit Ganzzahlausdruck initialisiert"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Anweisung zur ENUM-Definition vor %C erwartet"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfehler in ENUMERATOR-Definition bei %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Doppelte Zugriffsspezifikation bei %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges NOPASS bei %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges PASS bei %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Doppeltes POINTER-Attribut bei %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Doppeltes NON_OVERRIDABLE bei %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Doppeltes DEFERRED bei %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Zugriffsspezifikation bei %C erwartet"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindeattribut bei %C erwartet"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE und DEFERRED können nicht gleichzeitig bei %C auftreten"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-Attribut ist für Prozedurzeiger-Komponente bei %C erforderlich"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Schnittstellenname nach %<(%> bei %C erforderlich"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> bei %C erwartet"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Schnittstelle muss für DEFERRED-Bindung bei %C angegeben werden"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(Schnittstelle) bei %C sollte als DEFERRED deklariert sein"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-Liste bei %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> ist ungültig für DEFERRED-Bindung bei %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> in PROCEDURE-Bindung mit explizitem Ziel bei %C erforderlich"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindungsziel hinter %<=>%> bei %C erforderlich"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typ %qs mit DEFERRED-Bindung bei %C ist nicht ABSTRACT"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine Prozedur mit Bindungsname %qs für den abgeleiteten Typ %qs bei %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC bei %C muss innerhalb eines CONTAINS eines abgeleiteten Typs sein"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> bei %C erwartet"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generischer Name oder Operatordeskriptor bei %C erwartet"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Kaputte GENERIC-Anweisung bei %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> bei %C erwartet"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine nicht-generische Prozedur mit Bindungsname %qs für den abgeleiteten Typ %qs bei %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindung bei %C muss denselben Zugriff wie bereits definierte Bindung %qs haben"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Spezifischer Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs bereits als spezifische Bindung für das generische %qs bei %C definiert"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Ausschuss hinter GENERIC-Bindung bei %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-Deklaration bei %C muss innerhalb eines CONTAINS-Abschnitts eines abgeleiteten Typs stehen"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklaration abgeleiteten Typs mit FINAL bei %C muss im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Leeres FINAL bei %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Prozedurname im Modul bei %C erwartet"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> bei %C erwartet"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Unbekannter Prozedurname %qs bei %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs bei %C ist bereits als FINAL-Prozedur definiert"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Unbekanntes Attribut in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfehler in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Direktive %<GCC unroll%> bei %2$C verlangt eine konstante Anzahl (maximal %1$u)"
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaxfehler in !GCC$-UNROLL-Direktive bei %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Syntaxfehler in !GCC$-IVDEP-Direktive bei %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Syntaxfehler in !GCC$-VECTOR-Direktive bei %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "Syntaxfehler in !GCC$-NOVECTOR-Direktive bei %C"
@@ -60005,12 +60063,12 @@ msgstr "Index in Dimension %d ist außerhalb der Grenzen bei %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "Die Anzahl der Elemente im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "LEN-part_ref bei %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "KIND-part_ref bei %C"
@@ -60085,7 +60143,7 @@ msgstr "Transformierende intrinsische Routine %qs bei %L ist in einem Initialisi
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Auswertung des nicht standardisierten Initialisierungsausdrucks bei %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "Funktion %qs in Initialisierungs-Ausdruck bei %L muss eine intrinsische Funktion sein"
@@ -60355,7 +60413,7 @@ msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %qs
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explizite Schnittstelle für Komponente %qs bei %L erforderlich: %s"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explizite Schnittstelle für %qs bei %L erforderlich: %s"
@@ -60413,167 +60471,167 @@ msgstr "Ziel der Rang-Neuzuordnung ist nicht Rang 1 bei %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datenziel bei %L darf keinen Koindex haben"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Zielausdruck in Zeigerzuweisung bei %L muss ein Zeigerergebnis liefern"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Ziel der Zeigerzuweisung in Initialisierungsausdruck bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel bei %L ist weder TARGET noch POINTER"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Falsches Ziel in Zeigerzuweisung in PURE-Prozedur bei %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Zeigerzuweisung mit Vektorindex für rhs bei %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Zeiger-Zuweisungsziel hat PROTECTED-Attribut bei %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Zuweisung an zusammenhängenden Zeiger von nichtzusammenhängendem Ziel bei %L"
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Zeiger bei %L in Zeigerzuweisung könnte Zeigerziel überdauern"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Ziel der Zeigerinitialisierung bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das SAVE-Attribut haben"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Ziel der Zeigerinitialisierung für Prozedur bei %L darf kein Prozedurzeiger sein"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Interne Prozedur %qs ist in Initialisierung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Dummyprozedur %qs ist in Initialisierung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "Interner Fehler: generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Zeigerfunktionen in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Nicht-variabler Ausdruck in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Benannte Konstante %qs in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs in Variablen-Definitionskontext (%s) bei %L ist keine Variable"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Nicht-POINTER in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typ nicht zugreifbar in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in einem Zeigerzuordnungskontext (%s) bei %L vorkommen"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variable %qs kann nicht in Variablen-Definitionskontext (%s) bei %L in PURE-Prozedur auftreten"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit vektorindiziertem Ziel verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit Ausdruck verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associate-Name %qs kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten, da sein Ziel bei %L es auch nicht kann"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Elemente mit demselben Wert bei %L und %L in Vektorindex in einem Variablen-Definitionskontext (%s)"
@@ -60599,7 +60657,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Illegal id in copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -60790,12 +60848,12 @@ msgstr "Erstes Argument der definierten Zuweisung bei %L muss INTENT(OUT) oder I
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -60865,587 +60923,587 @@ msgstr "Mehrdeutige Schnittstellen in %s für %qs bei %L und %qs bei %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Obwohl nicht referenziert, hat %qs mehrdeutige Schnittstellen bei %L"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs bei %L ist keine Modulprozedur"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Feld mit vermutetem Rang bei %L erfordert Scheinargument %qs mit vermutetem Rang"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Unpassender Rang in Argument %qs bei %L (Skalar und Rang-%d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Unpassender Rang in Argument %qs bei %L (Rang-%d und Skalar)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Unpassender Rang in Argument %qs bei %L (Rang-%d und Rang-%d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (skalar und Rang-%d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (Rang-%d und skalar)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Unverträgliche Ränge zwischen Argument bei %L und Argument bei %L (Rang-%d und Rang-%d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ungültiges Argument für Prozedur bei %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Schnittstelle in Scheinprozedur %qs bei %L passt nicht: %s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Effektives Argument für fortlaufenden Schein-Zeiger %qs bei %L muss einfach fortlaufend sein"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Unverträgliche Typen zwischen Argument bei %L und Argument bei %L (%s/%s)."
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Unpassender Typ in Argument %qs bei %L; %s wurde an %s übergeben"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Feld mit vermutetem Rang bei %L erfordert Scheinargument %qs mit vermutetem Rang"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Effektives Argument für %qs bei %L muss polymorph sein"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Effektives Argument für %qs bei %L muss denselben deklarierten Typ haben"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Effektives Argument für %qs bei %L muss unbegrenzt polymorph sein, da das formale Argument ein Zeiger oder reservierbare unbegrenzt polymorphe Entität ist [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Effektives Argument für %qs bei %L sein muss Koarray sein"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Unpassender Korang in Argument %qs bei %L (%d und %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Effektives Argument für %qs bei %L muss einfach fortlaufend oder ein Element eines solchen Feldes sein"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter %qs bei %L mit Typ LOCK_TYPE oder einer Komponente LOCK_TYPE"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Effektives Argument für Nicht-INTENT(INOUT)-Platzhalter %qs bei %L mit Typ EVENT_TYPE oder einer EVENT_TYPE-Komponente"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Scheinargument %qs muss Zeiger oder Feld mit angenommener Form ohne CONTIGUOUS-Attribut sein, da das effektive Argument bei %L nicht einfach fortlaufend ist und beide ASYNCHRONOUS oder VOLATILE sind"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray, INTENT(OUT) Scheinargument %qs übergeben"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Koarray bei %L wird an reservierbares, Nicht-Coarray-Scheinargument %qs übergeben, das ungültig wird, wenn der Reservierungsstatus geändert wird"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphes Skalar wird an Feld-Scheinargument %qs bei %L übergeben"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Element des Feldes mit vermuteter Form oder von Zeigern bei %L kann nicht zum Argument bei %L passen"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element des Feldes mit vermuteter Form oder von Zeigern wird bei %2$L an ein Feld-Scheinargument %1$qs übergeben"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Erweiterung: Skalares effektives nicht-standardartiges, nicht-C_CHAR CHARACTER-Argument mit Feld-Scheinargument %qs bei %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalares effektives CHARACTER-Argument mit Feld-Scheinargument %qs bei %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Schlüsselwort-Argument %qs bei %L darf innerhalb einer Anweisungsfunktion nicht auftauchen"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Schlüsselwort-Argument %qs bei %L ist nicht in der Prozedur; meinen Sie %qs?"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Schlüsselwort-Argument %qs bei %L ist nicht in der Prozedur"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Schlüsselwort-Argument %qs bei %L ist bereits mit einem anderen effektiven Argument verbunden"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Mehr effektive als formale Argumente in Prozeduraufruf bei %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Unerwartete alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Unerwartetes intrinsisches NULL() bei %L für Schein-%qs"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nullzeiger bei %L an Nicht-Zeiger-Schein-%qs"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Effektives Argument bei %L für Scheinparameter vermuteten Typs hat abgeleiteten Typ mit typgebundenen oder FINAL-Prozeduren"
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Zeiger oder reservierbarem Scheinargument %qs bei %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Zeichenlänge passt nicht (%ld/%ld) zwischen effektivem Argument und Scheinargument %qs mit vermuteter Form bei %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Effektives Argument bei %L an reservierbares oder Zeiger-Scheinargument %qs muss Parameter mit Typ aufgeschobener Länge haben, genau dann, wenn das Scheinargument einen solchen hat"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Zeichenlänge des effektiven Arguments kürzer als das des Scheinarguments %qs (%lu/%lu) bei %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Effektives Argument enthält zuwenige Elemente für Scheinargument %qs (%lu/%lu) bei %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Prozedurzeiger für Argument %qs bei %L erwartet"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Prozedur für Argument %qs bei %L erwartet"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Effektives Argument für %qs kann nicht Feld vermuteter Größe bei %L sein"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Effektives Argument für %qs muss ein Zeiger bei %L sein"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Effektives Nicht-Zeiger-Argument bei %L an Scheinzeiger %qs"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Koindiziertes effektives Argument bei %L an Scheinzeiger %qs"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L an scheinreservierbares %qs erfordert INTENT(IN)"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Koindiziertes effektives ASYNCHRONOUS- oder VOLATILE-Argument bei %L erfordert, dass Schein-%qs weder ASYNCHRONOUS noch VOLATILE hat"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Koindiziertes effektives Argument bei %L mit reservierbarer endgültiger Komponente für Schein-%qs erfordert entweder VALUE oder INTENT(IN)"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Effektives CLASS-Feldargument für %qs muss ein vollständiges Feld bei %L sein"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Effektives Argument für %qs muss ALLOCATABLE bei %L sein"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Feldbereich mit Vektorindex als effektives Argument bei %L ist unverträglich mit INTENT(OUT), INTENT(INOUT), VOLATILE- und ASYNCHRONOUS-Attribut des Scheinarguments %qs"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Effektives Argument mit vermuteter Form bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form %qs"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Feldbereich als effektives Argument bei %L ist wegen VOLATILE-Attribut unverträglich mit dem Scheinargument ohne vermutete Form %qs"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Zeigerfeld als effektives Argument bei %L erfordert wegen VOLATILE-Attribut ein Scheinargument %qs mit vermuteter Form oder als Zeigerfeld"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Fehlende alternative Rückgabespezifikation in Unterprogrammaufruf bei %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Fehlendes effektives Argument für Argument %qs bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Bad component code"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): List mismatch"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): corrupted data"
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Gleiches effektives Argument mit INTENT(%s)-Argument %qs und INTENT(%s)-Argument %qs bei %L verbunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): List mismatch"
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prozedurargument bei %L ist lokal für PURE-Prozedur und hat das POINTER-Attribut"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an INTENT(%s)-Argument übergeben"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Effektives koindiziertes Argument bei %L in PURE-Prozedur wird an POINTER-Scheinargument übergeben"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Koindiziertem polymorphen effektiven Argument bei %L wird polymorphes Scheinargument %qs übergeben"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Prozedur %qs, die bei %L aufgerufen wird, ist nicht explizit deklariert; meinen Sie %qs?"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prozedur %qs, die bei %L aufgerufen wird, ist nicht explizit deklariert"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prozedur %qs mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das Zeigerobjekt %qs bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Das reservierbare Objekt %qs bei %L muss eine explizite Funktionsschnittstelle haben oder als Feld deklariert sein"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Reservierbare Funktion %qs bei %L muss eine explizite Funktionsschnittstelle haben"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Explizite Schnittstelle für polymorphes Argument bei %L erforderlich"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Schlüsselwort-Argument erfordert explizite Schnittstelle für Prozedur %qs bei %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argument »%s« bei %L vermuteten Typs erfordert eine explizite Schnittstelle"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit LOCK_TYPE oder mit LOCK_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur %qs"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Effektives Argument mit EVENT_TYPE oder mit EVENT_TYPE-Komponente bei %L erfordert eine explizite Schnittstelle für Prozedur %qs"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-Argument an NULL bei %L erforderlich"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argument vermuteten Ranges erfordert eine explizite Schnittstelle bei %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prozedurzeiger-Komponente %qs mit einer impliziten Schnittstelle bei %L aufgerufen"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Schlüsselwortargument erfordert explizite Schnittstelle für Prozedurzeigerkomponente %qs bei %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "In NULL()-Argument bei %L wird MOLD= benötigt: Mehrdeutig zwischen spezifischen Funktionen %s und %s"
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Symbol %qs kann nicht gefunden werden"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entität %qs bei %L ist bereits in der Schnittstelle vorhanden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Bad interface type"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "GENERIC %qs bei %L kann nicht überschrieben werden"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs bei %L überschreibt eine Prozedurbindung, die als NON_OVERRIDABLE deklariert ist"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs bei %L darf nicht DEFERRED sein, da es eine Nicht-DEFERRED-Bindung überschreibt"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs bei %L überschreibt eine PURE-Prozedur und muss auch PURE sein"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs bei %L überschreibt eine ELEMENTAL-Prozedur und muss auch ELEMENTAL sein"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs bei %L überschreibt eine Nicht-ELEMENTAL-Prozedur und darf ebenfalls nicht ELEMENTAL sein"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs bei %L überschreibt eine SUBROUTINE und muss auch eine SUBROUTINE sein"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs bei %L überschreibt eine FUNCTION und muss auch eine FUNCTION sein"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassendes Ergebnis für die überschreibende Prozedur %qs bei %L: %s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs bei %L überschreibt eine PUBLIC-Prozedur und darf nicht PRIVATE sein"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Scheinargument %qs von %qs bei %L sollte %qs genannt werden, um zum zugehörigen Argument der überschriebenen Prozedur zu passen"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Unpassende Argumente für die überschreibende Prozedur %qs bei %L: %s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs bei %L muss die gleiche Anzahl formaler Argumente wie die überschriebene Prozedur haben"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs bei %L überschreibt eine NOPASS-Bindung und muss ebenfalls NOPASS sein"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs bei %L überschreibt eine Bindung mit PASS und muss ebenfalls PASS sein"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Scheinargument des übergebenen Objektes von %qs bei %L muss an der gleichen Stelle wie das Scheinargument des übergebenen Objektes der überschriebenen Prozedur stehen"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO-Scheinargument bei %L muss vom Typ %s sein"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO-Scheinargument bei %L muss von KIND = %d sein"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO-Scheinargument bei %L muss ein Skalar sein"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO-Scheinargument bei %L muss ein ASSUMED SHAPE ARRAY sein"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "DTIO-Zeichenargument bei %L muss angenommene Länge haben"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO-Scheinargument bei %L muss INTENT %s haben"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Alternativer Rücksprung bei %L ist in einer DTIO-Prozedur nicht erlaubt"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO-Prozedur %qs bei %L muss ein Unterprogramm sein"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Zu wenige Scheinargumente in DTIO-Prozedur %qs bei %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Zu viele Scheinargumente in DTIO-Prozedur %qs bei %L"
@@ -61555,75 +61613,75 @@ msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "Im Aufruf von %qs bei %L ist eine Typunverträglichkeit bei Argument %qs; %s wurde an %s übergeben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr "resolve_intrinsic(): Too many args for intrinsic"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "do_simplify(): Too many args for intrinsic"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "init_arglist(): too many arguments"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "Invalid standard code on intrinsic %qs (%d)"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "Intrinsisches %qs (ist %s) wird bei %L verwendet"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "Funktion %qs als Initialisierungsausdruck bei %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "Transformierende Funktion %qs bei %L darf nicht in einem Initialisierungs-Ausdruck auftreten"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Elementare Funktion als Initialisierungsausdruck mit Nicht-Ganzzahl-/Nicht-Zeichen-Argumenten bei %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Unterprogrammaufruf von intrinsischem %qs in »DO CONCURRENT«-Block bei %L ist nicht PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Unterprogrammaufruf des intrinsischen %qs bei %L ist nicht PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Erweiterung: Umwandlung von %s in %s bei %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Nichtstandard-Umwandlung von %s in %s bei %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Mögliche Wertänderung bei Umwandlung von %s in %s bei %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Umwandlung von %s in %s bei %L"
@@ -61631,22 +61689,22 @@ msgstr "Umwandlung von %s in %s bei %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "%s kann nicht nach %s bei %L umgewandelt werden"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Interner Fehler: Cannot convert %qs to %qs at %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "Bei %2$L deklariertes %1$qs überdeckt intrinsische Funktion mit gleichem Namen. Um die aufzurufen, sind explizite INTRINSIC-Deklarationen erforderlich."
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "Bei %2$L deklariertes %1$qs ist auch der Name einer intrinsischen Funktion. Sie kann nur über eine explizite Schnittstelle oder als EXTERNAL deklariert aufgerufen werden."
@@ -61992,12 +62050,12 @@ msgstr "ACTION-Typ bei %L steht in Konflikt mit READONLY-Spezifizierer"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= bei %L ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "BLANK= bei %L ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr "DECIMAL= bei %L ist in Fortran 95 nicht erlaubt"
@@ -62007,7 +62065,7 @@ msgstr "DECIMAL= bei %L ist in Fortran 95 nicht erlaubt"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "ENCODING= bei %L ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr "ROUND= bei %L ist in Fortran 95 nicht erlaubt"
@@ -62052,7 +62110,7 @@ msgstr "CLOSE-Anweisung bei %L erfordert eine UNIT-Zahl"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-Zahl in CLOSE-Anweisung bei %L muss nicht-negativ sein"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
@@ -62147,7 +62205,7 @@ msgstr "NAMELIST %qs in READ-Anweisung bei %L enthält Symbol %qs, das im Kontex
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
@@ -62214,7 +62272,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Ausdruck in %s-Anweisung bei %C erwartet"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfehler in Anweisung %s bei %C"
@@ -62229,83 +62287,83 @@ msgstr "Interne Datei bei %L mit Namensliste"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "IO UNIT in %s-Anweisung bei %L muss eine interne Datei in einer PURE-Prozedur sein"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "PAD= bei %L ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "DELIM= bei %L ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT-Namensliste bei %C ist eine Erweiterung"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "Komma hinter * bei %C ist nur zusammen mit einer I/O-Liste erlaubt"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Komma in E/A-Liste bei %C erwartet"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-Anweisung bei %C innerhalb PURE-Prozedur nicht erlaubt"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "NULL() in der Nähe von %L darf nicht in einer INQUIRE-Anweisung vorkommen"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH-Markierung in INQUIRE-Anweisung bei %C ungültig"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE-Anweisung bei %L kann nicht sowohl FILE- als auch UNIT-Spezifikationssymbole enthalten"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE-Anweisung bei %L erfordert entweder FILE- oder UNIT-Spezifikationssymbol"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "UNIT-Zahl in INQUIRE-Anweisung bei %L darf nicht %d sein"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE-Anweisung bei %L erfordert PENDING= mit Spezifizierung ID="
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT-Anweisung ist in PURE-Prozedur bei %C nicht erlaubt"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "identifier overflow: %d"
@@ -62552,505 +62610,505 @@ msgstr "Ausschuss hinter ASSOCIATE-Anweisung bei %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Ungültiges Typspezifikation bei %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Syntaxfehler in FORALL-Iterator bei %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "DO CONCURRENT-Konstrukt bei %C"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Name %qs in %s-Anweisung bei %C ist unbekannt"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Name %qs in %s-Anweisung bei %C ist kein Konstruktname"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "Anweisung %s bei %C hinterlässt CRITICAL-Konstrukt"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "Anweisung %s bei %C hinterlässt DO CONCURRENT-Konstrukt"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "Anweisung %s bei %C ist nicht innerhalb eines Konstrukts"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "Anweisung %s bei %C nicht innerhalb des Konstrukts %qs"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "CYCLE-Anweisung bei %C ist nicht auf Nicht-Schleifenkonstrukt %qs anwendbar"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "EXIT-Anweisung ohne DO-CONSTRUCT-Name bei %C"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Anweisung %s bei %C nicht auf Konstrukt %qs anwendbar"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "Anweisung %s bei %C verlässt OpenACC-strukturierten Block"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "Anweisung %s bei %C verlässt OpenMP-strukturierten Block"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "EXIT-Anweisung bei %C beendet »!$ACC LOOP«-Schleife"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "CYCLE-Anweisung bei %C für nicht-innerste gekachelte »!$ACC LOOP«-Schleife"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "CYCLE-Anweisung bei %C für nicht-innerste eingeklappte »!$ACC LOOP«-Schleife"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "EXIT-Anweisung bei %C beendet !$OMP DO Schleife"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "CYCLE-Anweisung bei %C für nicht-innerste eingestürzte !$OMP DO-Schleife"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "Leerzeichen in %s-Anweisung in der Nähe von %C erwartet"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "STOP-Code bei %C darf nicht negativ sein"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr "STOP-Code bei %C enthält zu viele Ziffern"
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "Anweisung %s bei %C in PURE-Prozedur"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "STOP-Anweisung zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "STOP-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr "STOP-Code bei %L muss eine skalare CHARACTER-Konstante oder Ziffer[Ziffer[Ziffer[Ziffer[Ziffer]]]] sein"
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "STOP-Code bei %L muss eine skalare CHARACTER- oder INTEGER-Konstante sein"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "STOP-Code bei %L muss entweder INTEGER- oder CHARACTER-Typ haben"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "STOP-Code bei %L muss Skalar sein"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "STOP-Code bei %L muss Standardzeichentyp KIND=%d sein"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-Code bei %L muss Standardganzzahltyp KIND=%d sein"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "PAUSE-Anweisung bei %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ERROR STOP-Anweisung bei %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "Anweisung »EVENT %s« zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "Anweisung »EVENT %s« zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "Anweisung »EVENT %s« zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr "Redundante STAT-Marke bei %L gefunden"
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "Redundante ERRMSG-Marke bei %L gefunden"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "Redundante UNTIL_COUNT-Marke bei %L gefunden"
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "»EVENT POST«-Anweisung bei %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "»EVENT WAIT«-Anweisung bei %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "»FAIL IMAGE«-Anweisung bei %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "FORM-TEAM-Anweisung bei %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "CHANGE-TEAM-Anweisung bei %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "END-TEAM-Anweisung bei %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "SYNC-TEAM-Anweisung bei %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Anweisung %s zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "Redundante ACQUIRED_LOCK-Marke bei %L gefunden"
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "LOCK-Anweisung bei %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "UNLOCK-Anweisung bei %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "SYNC-Anweisung zur Image-Steuerung bei %C in PURE-Prozedur"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "SYNC-Anweisung bei %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "SYNC-Anweisung zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "SYNC-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ASSIGN-Anweisung bei %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Zugewiesene GOTO-Anweisung bei %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Anweisungsmarkenliste in GOTO bei %C kann nicht leer sein"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Berechnetes GOTO bei %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Fehler in Typspezifikation bei %L"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Typspezifikation in ALLOCATE bei %L"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr "Die Spezifikationsliste für Typparameter in der Spezifikation bei %L darf keine DEFERRED-Parameter enthalten"
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "Unerwartete Konstante bei %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Falsches Reservierungs-Objekt bei %C für eine PURE-Prozedur"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "Inkompatibles ALLOCATE-Objekt bei %C für CHARACTER-Typspezifikation bei %L"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE von Koarray bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE von Koarray bei %C in CRITICAL-Block"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "ALLOCATE-Objekt bei %L ist weder ein Datenzeiger noch eine reservierbare Variable"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Typ der Entität bei %L ist mit Typspezifikation unverträglich"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Parameter mit KIND-Typ für Entität bei %L unterscheidet sich vom Parameter mit KIND-Typ der Typspezifikation"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Formspezifikation für reservierbares Skalar bei %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "STAT-Angabe bei %L darf keine Konstante sein"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG-Markierung bei %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE-Marke bei %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr "Überflüssige SOURCE-Marke bei %L gefunden"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "SOURCE-Marke bei %L steht mit Typspezifikation bei %L in Konflikt"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "SOURCE-Marke bei %L mit mehr als einem reservierbaren Objekt"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD-Marke bei %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "Überflüssige MOLD-Marke bei %L gefunden"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "MOLD-Marke bei %L steht mit Typspezifikation bei %L in Konflikt"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "MOLD-Marke bei %L steht mit SOURCE-Marke bei %L in Konflikt"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "ALLOCATE-Objekt bei %L mit Parameter aufgeschobenen Typs erfordert entweder eine Typspezifikation, SOURCE-Marke oder MOLD-Marke"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Unbeschränkt polymorphes ALLOCATE-Objekt bei %L erfordert entweder eine Typspezifikation, SOURCE-Marke oder MOLD-Marke"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "Zeigerobjekt bei %C darf nicht koindiziert sein"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr "NULLIFY erlaubt keine Neuzuordnung von Grenzen für Zeigerobjekt bei %C"
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Unzulässiges ALLOCATE-Objekt bei %C für eine PURE-Prozedur"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE von Koarray bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE von Koarray bei %C in CRITICAL-Block"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allocate-Objekt bei %C ist kein Nicht-Prozedur-Zeiger oder reservierbare Variable"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG bei %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "RETURN-Anweisung zur Image-Steuerung bei %C in CRITICAL-Block"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "PRINT-Anweisung zur Image-Steuerung bei %C in DO CONCURRENT-Block"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Alternative RETURN-Anweisung bei %C ist nur innerhalb einer SUBROUTINE erlaubt"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN-Anweisung im Hauptprogramm bei %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Referenz auf Komponente bei %C erwartet"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Ausschuss hinter CALL bei %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Typgebundene Prozedur oder Prozedurzeiger-Komponente bei %C erwartet"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr "Eine BOZ-Literalkonstante bei %L kann nicht als tatsächliches Argument in einer Unterprogrammreferenz erscheinen"
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Syntaxfehler im allgemeinen Blocknamen bei %C"
@@ -63058,217 +63116,217 @@ msgstr "Syntaxfehler im allgemeinen Blocknamen bei %C"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "Variable %qs bei %L in Common-Block %qs bei %C muss in einer C-kompatiblen Art deklariert sein, da Common-Block %qs bind(c) ist"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "Variable %qs in Common-Block %qs bei %C kann nicht BIND(C) sein, da sie nicht global ist"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Symbol %qs bei %C ist bereits in einem COMMON-Block"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Initialisiertes Symbol %qs bei %C kann nur COMMON in BLOCK DATA sein"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Feldspezifikation für Symbol %qs in COMMON bei %C muss explizit sein"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Symbol %qs in COMMON bei %C kann kein POINTER-Feld sein"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Symbol %qs in COMMON-Block %qs bei %C wird indirekt verglichen mit anderem COMMON-Block %qs"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr "BLOCK-DATA-Konstrukt bei %L"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Gruppenname %qs der Namensliste bei %C hat bereits einen Basistypen von %qs"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Gruppenname %qs der Namensliste bei %C ist bereits USE-verbunden und kann nicht respezifiziert werden."
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %C ist nicht erlaubt"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Komponente %C abgeleiteten Typs ist kein zulässiges EQUIVALENCE-Element"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Feldreferenz in EQUIVALENCE bei %C kann kein Feldabschnitt sein"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE bei %C erfordert zwei oder mehr Objekte"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Versuch, die COMMON-Blöcke %s und %s durch EQUIVALENCE bei %C indirekt zu überschneiden"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Komma in EQUIVALENCE bei %C erwartet"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "EQUIVALENCE-Anweisung bei %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Anweisungsfunktion bei %L ist rekursiv"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Anweisungsfunktion %qs bei %L steht in Konflikt mit Funktionsname"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "Anweisungsfunktion bei %L darf nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Anweisungsfunktion bei %C"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L darf nicht %s sein"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Erwarteter Initialisierungsausdruck in CASE bei %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Blockname %qs des SELECT-Konstrukts bei %C erwartet"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "SELECT TYPE bei %C darf nicht in diesem Gültigkeitsbereich vorkommen"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Syntaxfehler in »SELECT TYPE«-Anweisung bei %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Selektor in SELECT TYPE bei %C ist keine benannte Variable; associate-name=> verwendet"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "SELECT-RANK-Anweisung bei %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Der SELECT-RANK-Selektor bei %C muss eine angenommene Rangvariable sein"
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Syntaxfehler in SELECT-RANK-Anweisung bei %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Unerwartete CASE-Anweisung bei %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfehler in CASE-Spezifikation bei %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Unerwartete TYPE IS-Anweisung bei %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspezifikation darf keinen Sequenz-abgeleiteten Typ oder Typ mit BIND-Attribut in SELECT TYPE bei %C beschreiben [F2003:C815]"
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Alle LEN-Typparameter in der TYPE-IS-Anweisung bei %C müssen ASSUMED sein"
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfehler in TYPE IS-Spezifikation bei %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfehler in CLASS IS-Spezifikation bei %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Unerwartete RANK-Anweisung bei %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Der SELECT-RANK-CASE-Ausdruck bei %C muss eine skalare, ganzzahlige Konstante sein"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "Der Wert des SELECT-RANK-CASE-Ausdrucks bei %C darf nicht kleiner als Null oder größer als %d sein"
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Syntaxfehler in RANK-Spezifikation bei %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-Anweisung bei %C nicht eingeschlossen in WHERE-Block"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Marke %qs bei %C passt nicht zur WHERE-Marke %qs"
@@ -63312,13 +63370,13 @@ msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Undefined type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Undefined type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Bad code"
@@ -64009,8 +64067,8 @@ msgstr "Implizit deklariertes Unterprogramm %s wird in !$OMP DECLARE REDUCTION b
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-Parameter der Klausel bei %L ist weniger als COLLAPSE"
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
@@ -65424,175 +65482,175 @@ msgstr "Unerwartetes %<%c%> für Variable %qs nicht-abgeleiteten Typs bei %C"
 msgid "Expected structure component name at %C"
 msgstr "Strukturkomponentenname bei %C erwartet"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr "RE oder IM part_ref bei %C"
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr "Die RE oder IM part_ref bei %C kann nur auf einen COMPLEX-Ausdruck angewendet werden"
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "Die LEN part_ref bei %C kann nur auf einen CHARACTER-Ausdruck angewendet werden"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Argumentliste bei %C erwartet"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr "RE oder IM part_ref bei %C"
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "Die KIND part_ref bei %C kann nur auf einen Ausdruck von intrinsischem Typ angewendet werden"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "Prozedurzeiger-Komponente %qs erfordert eine Argumentliste bei %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "Nichtpolymorphe Referenz auf abstrakten Typ bei %C"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Koindizierte Prozedurzeiger-Komponente bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): Expression isn't a variable"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_caf_attr(): Expression isn't a variable"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_caf_attr(): Bad array reference"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Strukturkonstruktor mit fehlenden optionalen Argumenten bei %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "Im Strukturkonstruktor bei %2$C wurde keine Initialisierung für allozierbare Komponente %1$qs angegeben"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "Im Strukturkonstruktor bei %2$C wurde keine Initialisierung für Komponente %1$qs angegeben"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "ABSTRACT-Typ %qs bei %L kann nicht konstruiert werden"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "Strukturkonstruktor mit benannten Argumenten bei %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr "Komponenteninitialisierung ohne Namen hinter Komponente namens »%s« bei %L"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "Zu viele Komponenten in Strukturkonstruktor bei %L"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "CHARACTER-Ausdruck wird in Konstruktor (%ld/%ld) bei %L abgeschnitten"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Komponente %qs wird im Strukturkonstruktor bei %L doppelt initialisiert"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Koindizierter Ausdruck auf Zeigerkomponente %qs in Strukturkonstruktor bei %L"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "Komponente %qs bei %L wurde bereits von Konstruktor für abgeleitete Typen durch einen Elternteil gesetzt"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr "%%LOC() als rvalue bei %C"
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "%qs bei %C ist der Name einer rekursiven Funktion und verweist damit auf die Ergebnisvariable. Für direkte Rekursion, eine explizite RESULT-Variable verwenden (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Symbol bei %C passt nicht zu einem Ausdruck"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Unerwartete Verwendung des Unterprogrammnamens %qs bei %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Anweisungsfunktion %qs erfordert Argumentliste bei %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "Funktion %qs erfordert eine Argumentliste bei %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Fehlendes Argument für %qs bei %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr "Bei %C darf das am weitesten links stehende part-ref in einem data-ref keine Funktionsreferenz sein"
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Fehlende Argumentliste in Funktion %qs bei %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Abgeleiteter Typ %qs kann bei %C nicht als Variable verwendet werden"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Benannte Konstante bei %C in EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%qs bei %C ist keine Variable"
@@ -65919,504 +65977,504 @@ msgstr "%qs bei %L ist mehrdeutig"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC-Prozedur %qs ist bei %L nicht als effektives Argument erlaubt"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Für intrinsische Funktion %qs angegebener Typ bei %L wird ignoriert"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Intrinsisches Unterprogramm %qs bei %L darf keine Typspezifizierung haben"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "INTRINSIC deklariertes %qs bei %L existiert nicht"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Das bei %2$L deklarierte INTRINSIC %1$qs ist in den derzeitigen Standardeinstellungen nicht verfügbar, außer %3$s. Entsprechende Option %<-std=*%> verwenden, oder %<-fall-intrinsics%> einschalten, um es zu verwenden."
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit %<-frecursive%> verwendet werden"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert, aber nirgendwo definiert"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Abgeleiteter Typ %qs wird als Argument bei %L verwendet"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Anweisungsfunktion %qs bei %L ist nicht als effektives Argument erlaubt"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Eingebautes %qs bei %L ist nicht als effektives Argument erlaubt"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Interne Prozedur %qs wird als effektives Argument bei %L verwendet"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL, nicht-INTRINSIC-Prozedur %qs ist nicht als effektives Argument bei %L erlaubt"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Spezifische INTRINSIC-Prozedur für Referenz %qs bei %L kann nicht gefunden werden"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Symbol %qs bei %L ist mehrdeutig"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Wertargument bei %L hat keinen numerischen Typ"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Wertargument bei %L kann kein Feld oder Feldabschnitt sein"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Wertargument bei %L ist in diesem Kontext nicht erlaubt"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Übergabe der eingebauten Prozedur über die Speicherstelle ist bei %L nicht erlaubt"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL Prozedurzeigerkomponente %qs ist nicht als effektives Argument bei %L erlaubt"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Koindiziertes effektives Argument bei %L mit endgültiger Zeigerkomponente"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%qs bei %L ist ein Feld und OPTIONAL; wenn es fehlt, kann es nicht das effektive Argument einer ELEMENTAL-Prozedur sein, es sei denn, es gibt ein nicht-optionales Argument mit demselben Rang (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Effektives Argument bei %L für INTENT(%s)-Dummy %qs von ELEMENTAL-Unterprogramm %qs ist skalar, aber ein anderes effektives Argument ist ein Feld"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Unpassender Rückgabetyp der Funktion %qs bei %L (%s/%s)"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Schnittstelle in globaler Prozedur %qs bei %L passt nicht: %s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Es gibt keine spezifische Funktion für das allgemeine %qs bei %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generische Funktion %qs bei %L ist nicht mit spezifischer intrinsischer Schnittstelle vereinbar"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Funktion %qs bei %L ist INTRINSIC, aber nicht mit einer intrinsischen Funktion verträglich"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Spezifische Funktion %qs bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ; meinen Sie %qs?"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Referenz auf Nicht-PURE-Funktion %qs bei %L innerhalb eines FORALL %s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Referenz auf Nicht-PURE-Funktion %qs bei %L innerhalb eines DO CONCURRENT %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Referenz auf Nicht-PURE-Funktion %qs bei %L innerhalb einer PURE-Prozedur"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Unerwarteter Ausschuss hinter %qs bei %L"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs bei %L ist keine Funktion"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs darf bei %L nicht referenziert werden"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr "ABSTRACT INTERFACE %qs bei %L darf kein angenommenes Zeichenlängenergebnis haben (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Funktion %qs ist als CHARACTER(*) deklariert und kann nicht bei %L verwendet werden, da es kein Scheinargument ist"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "Interner Fehler: resolve_function(): bad function type"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr "Eine BOZ-Literalkonstante bei %L kann nicht als tatsächliches Argument in einer Funktionsreferenz verwendet werden"
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Benutzerdefinierte nicht-ELEMENTAL-Funktion %qs bei %L ist in WORKSHARE-Konstrukt nicht erlaubt"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs bei %L kann nicht rekursiv aufgerufen werden, da Funktion %qs nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktion %qs bei %L kann nicht rekursiv aufgerufen werden, da sie nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Unterprogrammaufruf von %qs in FORALL-Block bei %L ist nicht PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Unterprogrammaufruf von %qs in »DO CONCURRENT«-Block bei %L ist nicht PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Unterprogrammaufruf von %qs bei %L ist nicht PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Es gibt kein spezifisches Unterprogramm für allgemeines %qs bei %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generisches Unterprogramm %qs bei %L ist nicht mit intrinsischer Unterprogrammschnittstelle vereinbar"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Unterprogramm %qs bei %L ist INTRINSIC, aber nicht mit intrinsischer Funktion verträglich"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Spezifisches Unterprogramm %qs bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs bei %L hat einen Typen, der nicht zum CALL bei %L passt"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs bei %L kann nicht rekursiv aufgerufen werden, da Unterprogramm %qs nicht RECURSIVE ist"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs bei %L kann nicht rekursiv aufgerufen werden, da sie nicht RECURSIVE ist"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): bad function type"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Formen der Operanden bei %L und %L stimmen nicht überein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Bad intrinsic"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Unreine Funktion %qs bei %L wird möglicherweise nicht ausgewertet"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "Unreine Funktion bei %L wird möglicherweise nicht ausgewertet"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "BOZ-Literalkonstante bei %L kann kein Operand des einstelligen Operators %qs sein"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Operanden bei %L und %L können nicht als Operanden des binären Operators %qs verwendet werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Bad intrinsic"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Bad expression"
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Unzulässiger Schritt von Null bei %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Bad array reference"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rechte obere Schranke des Feldabschnitts angenommener Größe nicht angegeben bei %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge des Koindex in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Koindex der Kodimension %d muss bei %L ein Skalar sein"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Feldindex bei %L muss skalar sein"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Feldindex bei %L muss INTEGER-Typ haben, %s gefunden"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-Feld-Index bei %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argument dim bei %L muss skalar sein"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argument dim bei %L muss INTEGER-Typ haben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Missing spec"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): unused as(1)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): unused as(2)"
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Feldindex bei %L ist ein Feld mit Rang %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L ist kleiner als Eins"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "End-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "End-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "End-Index der Teilzeichenkette bei %L überschreitet Zeichenkettenlänge"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "End-Index der Teilzeichenkette bei %L ist zu groß"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Bad array reference"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang größer Null darf kein POINTER-Attribut bei %L haben"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang ungleich Null darf bei %L kein Attribut ALLOCATABLE haben"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Zwei oder mehr Teilreferenzen mit Rang größer Null dürfen nicht bei %L angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Two array specs"
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut kann nur als effektives Argument verwendet werden"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verwendet werden"
@@ -66425,12 +66483,12 @@ msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verw
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Typs bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument verwendet werden"
@@ -66439,284 +66497,284 @@ msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument ve
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Ranges bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variable %s vermuteten Typs bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variable »%s« vermuteten Ranges bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "In Spezifikationsausdruck verwendete Variable %qs wird bei %L vor Anweisung ENTRY referenziert, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variable %qs wird bei %L vor Anweisung ENTRY verwendet, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphes Subobjekt des koindizierten Objektes bei %L"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fehler in Typbeschränktem Aufruf bei %L"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC %qs bei %L gefunden"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs bei %L sollte eine FUNCTION sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Bad expression type"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie überläuft"
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie unterläuft"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index %qs kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L müssen Typparameter der gleichen Art haben"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ LOCK_TYPE sein noch eine LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ EVENT_TYPE sein noch eine EVENT_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Feldspezifikation oder feldwertiger SOURCE=-Ausdruck erforderlich in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze bei %L"
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze von 1 bei %L"
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird »*« erwartet"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L darf nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "»ERRMSG=«-Variable bei %L muss skalare Default-CHARACTER-Variable sein"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L darf nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -66725,284 +66783,284 @@ msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurzeiger"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Abgeleiteter Typ %qs kann bei %L nicht als Variable verwendet werden"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurname"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Der zuordnende Selektor-Ausdruck bei %L ergibt eine Prozedur"
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektor bei %L darf nicht NULL() sein"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektor bei %L hat keinen Typ"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name %qs bei %L wird als Feld verwendet"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor muss in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS bei %L überlappt sich mit TYPE IS bei %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ %qs bei %L muss erweiterbar sein"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ %qs bei %L muss eine Erweiterung von %qs sein"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ %qs bei %L"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Die Typspezifikation bei %L muss angeben, dass jeder Parameter mit Längentyp vermutet ist"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) bei %L kann nicht mit dem Zeiger oder dem allozierbaren Selektor bei %L verwendet werden"
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO-%s-Prozedur bei %L muss rekursiv sein"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Ereignis-Variable bei %L muss Skalar mit EVENT_TYPE sein"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray oder koindiziert sein"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray, aber nicht koindiziert sein"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Argument UNTIL_COUNT= bei %L muss ein skalarer INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -67010,190 +67068,190 @@ msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke be
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index %qs wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-Konstrukt bei %L"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Bad block type"
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%ld/%ld) bei %L abgeschnitten"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "In einem reinen Unterprogramm darf ein INTENT(IN)-Dummy-Argument nicht als »expr« bei %L einer intrinsischen Zuweisungsanweisung verwendet werden, in der die Variable von einem abgeleiteten Typ ist, wenn der abgeleitete Typ eine Zeigerkomponente auf irgendeiner Ebene der Komponentenauswahl hat."
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Zuweisung an polymorphes Koarray bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L erfordert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein - bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Ausdrücken als Zwischenergebnisse auftreten würden."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsergebnis auf der linken Seite der Zuweisung bei %L muss Zeiger-Attribut haben."
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
-msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine INTEGER-Variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
+msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine skalare INTEGER-Variable"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable %qs bei %L wurde keine Zielmarke zugewiesen"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ungültiges NULL bei %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen skalaren REAL- oder INTEGER-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): No expression on DO WHILE"
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Bad statement code"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variable %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet denselben globalen Bezeichner wie Entität bei %L aus Modul %qs"
@@ -67201,955 +67259,955 @@ msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet densel
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Prozedur %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt %qs bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld %qs bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ %qs der CLASS-Variable %qs bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable %qs bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %qs bei %L darf nicht mit Wirt verbunden sein, da er von unverträglichem bei %L definierten Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Einbezogenes SAVE für Modulvariable %qs bei %L, benötigt wegen Standardinitialisierung"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat Parameter mit aufgeschobenem Typ und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Das Feld %qs im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable %qs bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-%qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s bei %L"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion %qs bei %L muss konstante Länge haben"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs hat PRIVATE-Typ und kann kein Scheinargument von %qs bei %L sein, das PUBLIC ist"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur %qs in PUBLIC-Schnittstelle %qs bei %L nimmt Scheinargumente von %qs, das PRIVATE ist"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-Funktion %qs bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion %qs bei %L darf weder POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht feld-wertig sein"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht zeiger-wertig sein"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rein sein"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rekursiv sein"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion %qs bei %L"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedurzeiger %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionsergebnisvariable %qs bei %L von elementarer Funktion %qs darf nicht die Attribute ALLOCATABLE oder POINTER haben"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis %qs als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in ELEMENTAL-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in PURE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in RECURSIVE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s zwischen der MODULE-PROCEDURE-Deklaration in Modul %qs und der Deklaration bei %L in (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur %qs bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ %qs haben"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur %1$qs hat denselben Rang (%3$d) wie %4$qs"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Bei %2$L wurde nur FINAL-Feldprozedur für abgeleiteten Typ %1$qs definiert, skalare wird ebenfalls empfohlen"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs und %qs können nicht gemischte FUNCTION/SUBROUTINE für GENERIC %qs bei %L sein"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs und %qs für GENERIC %qs bei %L sind mehrdeutig"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung %qs als Ziel des GENERIC %qs bei %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs bei %L muss auf spezifische Bindung abzielen, %qs ist ebenfalls GENERIC"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs bei %L muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle sein"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %qs für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur %qs bei %L hat den gleichen Namen wie eine Komponente von %qs"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur %qs bei %L hat den selben Namen wie eine vererbte Komponente von %qs"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ %1$qs muss ABSTRACT sein, da %3$qs DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente %qs bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente %qs bei %L mit Koarray-Komponente darf ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente %qs bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponente %qs von BIND(C)-Typ bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter %qs von %qs mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente %qs von %qs bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente %qs muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente %qs von %qs bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente %qs ist ein PRIVATE-Typ und kann nicht Komponente von %qs sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "In Konflikt stehende Initialisierungen in Union bei %L und %L"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ %qs bei %L eine Koarray-Komponente hat, muss der Elterntyp %qs auch eine haben"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parametrisierter Typ %1$qs hat bei %3$L keine Komponente, die zu Parameter %2$qs gehört"
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Abgeleiteter Typ %qs bei %L wurde nicht deklariert"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Das Objekt %qs bei %L hat aufgeschobenen LEN-Parameter %qs und ist weder allozierbar noch ein Zeiger"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "Das AUTOMATIC-Objekt %qs bei %L darf kein SAVE-Attribut haben und dard auch keine Variable im main-Programm, einem Modul oder einem Teilmodus sein (F08/C513)"
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Das Objekt %qs bei %L mit ASSUMED-Typparametern muss ein Dummy oder ein SELECT-TYPE-Selektor sein (F08/4.2)"
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Falsche Spezifikation für Feld bei %L mit angenommener Größe"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-Variable %qs bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variable %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbare Entität bei %L erwartet"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "Das DATA-Objekt in der Nähe von %L hat das Zeiger-Attribut und der entsprechende DATA-Wert ist kein gültiges initial-data-target"
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-Blockelement %qs bei %L darf in der PURE-Prozedur %qs kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Selbstreferenz im Zeichenlängenausdruck für %qs bei %L"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -68858,154 +68916,154 @@ msgstr "%qs bei %L hat außerhalb seines INTERFACE-Körpers spezifizierte Attrib
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Symbol %qs bei %L steht mit Symbol aus Modul %qs in Konflikt, verbunden durch Verwendung bei %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbol %qs bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prozedur %qs bei %L kann nicht grundlegenden Typen %s haben"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbol %qs bei %L kann keinen Typen haben"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponente %qs bei %C bereits im Elterntypen bei %L deklariert"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbol %qs bei %C ist mehrdeutig"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Abgeleiteter Typ %qs bei %C wird verwendet, bevor er definiert wird"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponente %qs bei %C ist eine PRIVATE-Komponente von %qs"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs bei %C ist kein Element der Struktur %qs; meinen Sie %qs?"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs bei %C ist kein Element der Struktur %qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Doppelte Anweisungsmarke %d bei %L und %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Marke %d bei %C bereits als Sprungziel referenziert"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Marke %d bei %C bereits als eine Formatmarke referenziert"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO-Abbruchanweisung ist nicht »END DO« oder »CONTINUE« mit Marke %d bei %C"
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Marke %d bei %C vorher als FORMAT-Marke verwendet"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Marke %d bei %C vorher als Sprungziel verwendet"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Gemeinsam genutzte DO-Abbruchmarke %d bei %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "DO-Anweisung mit Label bei %L"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Name %qs bei %C ist eine mehrdeutige Referenz auf %qs vom Modul %qs"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Name %qs bei %C ist eine mehrdeutige Referenz auf %qs von aktueller Programmeinheit"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbol %qs bei %C wurde bereits mit Host verbunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Abgeleiteter Typ %qs, bei %L deklariert, muss BIND-Attribut haben, um C-kompatibel zu sein"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Abgeleiteter Typ %qs mit Attribut BIND(C) bei %L ist leer und könnte für entsprechenden C-Prozessor unzugreifbar sein"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs bei %L kann nicht POINTER-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs %qs bei %L ist"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs des Prozedurzeigers bei %L kann kein Element des BIND(C)-abgeleiteten Typs %qs bei %L sein"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs bei %L kann nicht ALLOCATABLE-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs %qs bei %L ist"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponente %qs in abgeleitetem Typ %qs bei %L könnte nicht C-kompatibel sein, obwohl abgeleiteter Typ %qs BIND(C) ist"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponente %qs in abgeleitetem Typ %qs bei %L könnte nicht C-kompatibel sein"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Abgeleiteter Typ %qs bei %L kann nicht das SEQUENCE-Attribut haben, da er BIND(C) ist"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbol %qs wird bei %L verwendet, bevor es typisiert wird"
@@ -69042,85 +69100,85 @@ msgstr "Überlappende ungleiche Initialisierungen in EQUIVALENCE bei %C"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Die Anzahl der Elemente im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Bei %L wird ein vorübergehendes Feld für Argument %qs erzeugt"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Falscher Ausdruckstyp beim Durchlaufen (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "Benannter COMMON-Block %qs bei %L muss die gleiche Größe wie anderswo haben (%lu Bytes gegenüber %lu Bytes)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "get_mpz(): Not an integer constant"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr "element_number(): Bad dimension type"
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Ungültige Feldreferenz bei %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Ungültiger Referenztyp bei %L als EQUIVALENCE-Objekt"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Inkonsistente Äquivalenzregeln mit %qs bei %L und %qs bei %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "Die Äquivalenzmenge für bei %2$L deklarierte Variable %1$qs verletzt Ausrichtungsanforderungen"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "Äquivalenz für %qs passt nicht zur Anordnung von COMMON %qs bei %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "Die Äquivalenzmenge für %qs bewirkt eine ungültige Erweiterung für COMMON %qs bei %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Auffüllen mit %d Bytes vor %qs in COMMON %qs bei %L erforderlich; bitte Elemente umordnen oder %<-fno-align-commons%> verwenden"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Auffüllen mit %d Bytes vor %qs in COMMON bei %L erforderlich; bitte Elemente umordnen oder %<-fno-align-commons%> verwenden"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr "COMMON %qs bei %L existiert nicht"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON %qs bei %L erfordert Auffüllen mit %d Bytes; bitte Elemente umordnen oder %<-fno-align-commons%> verwenden"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON bei %L erfordert Auffüllen mit %d Bytes; bitte Elemente umordnen oder %<-fno-align-commons%> verwenden"
@@ -69140,72 +69198,72 @@ msgstr "Nicht-konstanter Initialisierungsausdruck bei %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr "Das Feld %qs bei %L ist größer als der Grenzwert, der durch %<-fmax-stack-var-size=%> festgelegt wurde, daher wurde es vom Stapel in den statischen Speicher verschoben. Dies macht die Prozedur unsicher, wenn sie rekursiv oder gleichzeitig von mehreren Threads aus aufgerufen wird. Erwägen Sie die Verwendung von %<-frecursive%>, oder erhöhen Sie die Grenze %<-fmax-stack-var-size=%>, oder ändern Sie den Code, um ein ALLOCATABLE-Feld zu verwenden."
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "innere Variable, die keine Prozedur ist"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Rückgabewert der Funktion %qs bei %L nicht gesetzt"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Parameter aufgeschobenen Typs wird noch nicht unterstützt"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Backend-Deklaration für Modulvariable %qs ist bereits vorhanden"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Ungenutzte PRIVATE-Variable %qs bei %L deklariert"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Scheinargument %qs bei %L war als INTENT(OUT) deklariert, aber nicht gesetzt"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Scheinargument %qs abgeleiteten Typs bei %L war als INTENT(OUT) deklariert, aber nicht gesetzt und hat keine Standardinitialisierung"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Ungenutztes Dummyargument %qs bei %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Ungenutzte Modulvariable »%qs«, die bei %L ausdrücklich importiert wurde"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Ungenutzte Variable %qs, bei %L deklariert"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Ungenutzter Parameter %qs, bei %L deklariert"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Ungenutzter Parameter %qs, der bei %L ausdrücklich importiert wurde"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Rückgabewert %1$qs der bei %3$L deklarierten Funktion %2$qs nicht gesetzt"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Entschuldigung, !$ACC DECLARE bei %L ist in einem BLOCK-Konstrukt nicht erlaubt"
@@ -69220,27 +69278,27 @@ msgstr "Länge des Arrays bei %L kann nicht berechnet werden."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Code zur Neu-Reservierung der reservierbaren Variable bei %L wird hinzugefügt"
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf ein unbegrenzt polymorphes Objekt wird nicht unterstützt"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf eine unbegrenzt polymorphe Komponente wird nicht unterstützt"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Unbekannte eingebauter Operator"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Unbekannte Argumentlistenfunktion bei %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Wenn die Neuzuordnung von Grenzen bei %L angegeben wird, darf das Zeigerziel nicht NULL sein"
@@ -69276,23 +69334,23 @@ msgstr "build_dt: Format mit Namensliste"
 msgid "Bad IO basetype (%d)"
 msgstr "Falscher IO-Basistyp (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr "Implizite Zuordnung von Feld %qD mit angenommener Größe"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, gcc-internal-format
 msgid "optional class parameter"
 msgstr "optionaler Klassenparameter"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr "unbehandelte Komponente eines abgeleiteten Typs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Bad statement code"
@@ -69406,82 +69464,82 @@ msgstr "unpassende Klammern"
 msgid "unable to open file"
 msgstr "Datei kann nicht geöffnet werden"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "Bytecode-Strom: Ausschuss am Ende des »symbols«-Abschnitts"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "Hex-Zahl konnte nicht eingelesen werden"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "unerwarteter Dateiname %s in Linker-Auflösungsdatei. %s erwartet"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "Datei-Offset konnte nicht eingelesen werden"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "unerwarteter Offset"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ungültige Zeile in Auflösungsdatei"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ungültige Auflösung in Auflösungsdatei"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "Auflösungs-Sub-ID %wx nicht in Objekt-Datei"
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "Bytecode-Strom in Datei %qs, mit einem älteren GCC-Compiler als 10.0 erzeugt"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "Fehler beim Einlesen von %<LOT_section_decls%> aus %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "»%s« kann nicht geöffnet werden"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "»%s« kann nicht in den Speicher geladen werden"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "»%s« kann nicht gelesen werden"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "Datei zur Symbolauflösung konnte nicht geöffnet werden: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "fehlende Auflösungsdaten für %s"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "Fehler beim Einfügen von Übersetzungseinheiten"
@@ -70608,7 +70666,7 @@ msgstr "Makroname fehlt hinter %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "fehlender Dateiname hinter %qs"
@@ -70808,21 +70866,33 @@ msgstr "unbekannter Basisblock-Umsortierungs-Algorithmus %qs"
 msgid "unknown TLS model %qs"
 msgstr "unbekanntes TLS-Modell %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "Unbekanntes Vektorisierer-Kostenmodell %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "unbekannter Sichtbarkeitswert %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Unbekannte Initialisierungspriorität %qs für VTable-Verifikation"
 
+#~ msgid "Warn about code paths in which an uninitialized value is used."
+#~ msgstr "Bei Codepfaden warnen, in denen ein uninitialisierter Wert verwendet wird."
+
+#~ msgid "Use instructions for a future architecture."
+#~ msgstr "Befehle für eine zukünftige Architektur verwenden."
+
+#~ msgid "three-way comparison operator can only be defaulted in a class definition"
+#~ msgstr "Dreiwege-Vergleichsoperator kann nur in einer Klassendefinition die Standardimplementierung bekommen"
+
+#~ msgid "equality comparison operator can only be defaulted in a class definition"
+#~ msgstr "Gleichheits-Vergleichsoperator kann nur in einer Klassendefinition die Standardimplementierung bekommen"
+
 #~ msgid "Same as %s.  Use the latter option instead."
 #~ msgstr "Identisch mit %s. Verwenden Sie daher bitte diese Option."
 
diff --git a/gcc/po/el.po b/gcc/po/el.po
index c428155d6d6..c3095201fd1 100644
--- a/gcc/po/el.po
+++ b/gcc/po/el.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -1997,85 +1997,85 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2091,18 +2091,18 @@ msgid "invalid %%r value"
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, fuzzy, c-format
 msgid "invalid %%R value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
@@ -2132,7 +2132,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid %%U value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
@@ -2142,7 +2142,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid %%C value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
@@ -2152,10 +2152,10 @@ msgstr "μη έγκυρος χρήστης"
 msgid "unknown relocation unspec"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, fuzzy, c-format
 msgid "invalid %%xn code"
 msgstr "μη έγκυρο δικαίωμα"
@@ -2238,35 +2238,35 @@ msgstr "μη έγκυρη μετατόπιση UTC"
 msgid "unrecognized supposed constant"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2274,13 +2274,13 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2411,7 +2411,7 @@ msgstr "Μη ορισμένο όνομα %s"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2662,25 +2662,25 @@ msgstr "αρχείο εξόδου"
 msgid "bad output_condmove_single operand"
 msgstr "αρχείο εξόδου"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 msgid "invalid operand %%xn code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr ""
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 msgid "invalid fp constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -2829,7 +2829,7 @@ msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 msgid "invalid %%P operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -2885,7 +2885,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -2941,8 +2941,8 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -3073,170 +3073,215 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+msgid "invalid %%A value"
+msgstr "μη έγκυρος χρήστης"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3247,89 +3292,89 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Μη έγκυρος κώδικας αίτησης"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3600,8 +3645,8 @@ msgstr "((ανώνυμο))"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3621,7 +3666,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3629,7 +3674,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3647,21 +3692,21 @@ msgstr ""
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3672,12 +3717,12 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3686,7 +3731,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3696,18 +3741,18 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -3715,19 +3760,19 @@ msgstr ""
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
@@ -3737,7 +3782,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -3748,35 +3793,35 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "expected label"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr ""
 
@@ -3876,7 +3921,7 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4055,49 +4100,49 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4141,17 +4186,17 @@ msgstr "κενό αλφαριθμητικό"
 msgid "elemental binary operation"
 msgstr "Αγνωστος δυαδικός χειριστής."
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr ""
@@ -4225,7 +4270,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "προειδοποίηση: "
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4240,7 +4285,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4362,12 +4407,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -4376,224 +4421,224 @@ msgstr "προσπέρασμα ορίσματος"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 #, fuzzy
 msgid "elemental procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 msgid "allocatable argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "no arguments"
 msgid "pointer argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 msgid "value argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "χωρίς ορίσματα"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "Δεν είναι δυνατό να δεσμευτεί μνήμη"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4606,27 +4651,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -4702,7 +4747,7 @@ msgstr ""
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5176,7 +5221,7 @@ msgstr "ΣΦΑΛΜΑ: Αδυναμία δημιουργίας προσωρινο
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5758,8 +5803,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -8201,105 +8246,100 @@ msgstr ""
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr ""
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12736,7 +12776,7 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
+msgid "Use instructions added in ISA 3.1."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:576
@@ -12749,6 +12789,11 @@ msgstr "Ακατάλληλη εντολή"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Ακατάλληλη εντολή"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17693,7 +17738,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18337,367 +18382,367 @@ msgstr ""
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <αρχείο>              Τοποθέτηση της εξόδου στο <αρχείο>\n"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 msgid "Display the compiler's version."
 msgstr "  --help                   Εμφάνιση αυτών των πληροφοριών\n"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 msgid "Suppress warnings."
 msgstr "%s: προειδοποίηση: "
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19848,8 +19893,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -19879,7 +19924,7 @@ msgid "expected boolean type"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "Μη ορισμένο όνομα %s"
@@ -19956,7 +20001,7 @@ msgstr "χωρίς ορίσματα"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "πάρα πολλά ορίσματα"
@@ -20356,7 +20401,7 @@ msgstr ""
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -20440,12 +20485,12 @@ msgstr ""
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20463,8 +20508,8 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -20584,7 +20629,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -20871,7 +20916,7 @@ msgstr "Λείπει παράμετρος για `%s'"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -21163,12 +21208,12 @@ msgstr ""
 msgid "%<asm%> clobber conflict with input operand"
 msgstr ""
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21678,304 +21723,304 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "δεν δώθηκε συμβολικό όνομα"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -22061,12 +22106,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -22220,7 +22265,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "αδυναμία ανοίγματος του `%s'"
@@ -22554,22 +22599,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, fuzzy, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr ""
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, fuzzy, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22629,7 +22674,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -22659,12 +22704,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -22679,7 +22724,7 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
@@ -22699,37 +22744,37 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23354,13 +23399,13 @@ msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 msgid "function returns address of local variable"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -23931,10 +23976,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -24100,7 +24145,7 @@ msgstr ""
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
@@ -24151,13 +24196,13 @@ msgstr ""
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -24167,147 +24212,147 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -24382,7 +24427,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -24654,54 +24699,54 @@ msgstr ""
 msgid "the extra base is defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24731,37 +24776,37 @@ msgstr ""
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr ""
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24811,57 +24856,57 @@ msgstr ""
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "αδυναμία ανοίγματος υποδοχής: %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -25114,52 +25159,52 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr ""
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25380,52 +25425,52 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -26756,132 +26801,132 @@ msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτ
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, fuzzy, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr ""
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr ""
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, fuzzy, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "σφάλμα εγγραφής %s"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, fuzzy, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr ""
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -26976,172 +27021,172 @@ msgstr ""
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr ""
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr ""
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr ""
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "μη έγκυρος χρήστης"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr ""
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "μη έγκυρη επιλογή %s"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "μη έγκυρος αρχικός αριθμός γραμμής: `%s'"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "μη έγκυρη διαμόρφωση συντόμευσης"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "μη έγκυρος αρχικός αριθμός γραμμής: `%s'"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -27152,507 +27197,507 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr ""
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, fuzzy, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, fuzzy, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, fuzzy, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "μη έγκυρη διαμόρφωση συντόμευσης"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "παράληψη ορίσματος αρχείου"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "μη έγκυρη επιλογή %s"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "διπλός ορισμός συνόλου"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "ο έλεγχος φθάνει στο τέλος μη-κενής συνάρτησης"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -27667,47 +27712,47 @@ msgstr "κανένας ορισμός του `UNDEFINED'"
 msgid "in expansion of macro %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -28216,12 +28261,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr ""
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, fuzzy, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "μη έγκυρη διαδικασία διαφυγής στο τέλος του αλφαριθμιτικού"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -28286,7 +28331,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28296,27 +28341,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "αχρησιμοποίητη μεταβλητή `%s'"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -28391,32 +28436,32 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:13103
+#: tree.c:13105
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:13106
+#: tree.c:13108
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:13112
+#: tree.c:13114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -28441,232 +28486,232 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -28791,82 +28836,82 @@ msgstr ""
 msgid "storage size of %q+D isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
@@ -29446,7 +29491,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "type was previously declared %qE"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -29466,7 +29511,7 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 msgid "%qE argument is not a function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -29836,12 +29881,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -29997,12 +30042,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -30103,7 +30148,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
@@ -30113,124 +30158,124 @@ msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30285,502 +30330,502 @@ msgstr "άγνωστο πρόθεμα: %s"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr ""
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, fuzzy, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "Λείπει ο δεκαεξαδικός αριθμός στον χαρακτήρα διαφυγής."
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr ""
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, fuzzy, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr ""
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr ""
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr ""
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr ""
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr ""
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, fuzzy, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "λίστα με όλα τα γνωστά σύνολα χαρακτήρων"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, fuzzy, gcc-internal-format
 msgid "unterminated format string"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, fuzzy, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr ""
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, fuzzy, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, fuzzy, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr ""
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr ""
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr ""
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr ""
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, fuzzy, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr ""
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr ""
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr ""
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr ""
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "%%%c: κατευθυντήριος γραμμή μη έγκυρη."
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, fuzzy, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr "%%%c: κατευθυντήριος γραμμή μη έγκυρη."
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, fuzzy, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr "μη αναγνωρίσημη επιλογή `-%c'"
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, fuzzy, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "repeated leap second moment"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 msgid "unterminated color directive"
 msgstr "μη αναγνωρίσημη επιλογή `-%c'"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, fuzzy, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -30942,7 +30987,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -30957,17 +31002,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
@@ -30977,7 +31022,7 @@ msgstr "παράληψη ορίσματος αρχείου"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -31578,7 +31623,7 @@ msgid "wrong type argument to %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -32262,7 +32307,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -32338,7 +32383,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -32358,7 +32403,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -32378,7 +32423,7 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgid "too many input files"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
@@ -32409,14 +32454,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -32940,393 +32985,400 @@ msgstr "αρχεία fifo δεν υποστηρίζονται"
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "Το ai_socktype δεν υποστηρίζεται"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
 # src/dfa.c:569 src/dfa.c:583 src/dfa.c:587
 # src/dfa.c:577 src/dfa.c:591 src/dfa.c:595
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "κακοσχηματισμένος μετρητής επανάληψης"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr ""
@@ -33509,17 +33561,17 @@ msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένα
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33669,12 +33721,12 @@ msgstr ""
 msgid "invalid type for %<asm%> flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -33682,194 +33734,194 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33879,285 +33931,285 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr ""
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 # src/getopt1.c:155
 # src/getopt1.c:155
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "επιλογή α\n"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -34165,22 +34217,22 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -34261,17 +34313,17 @@ msgstr "το -pipe δεν υποστηρίζεται"
 msgid "%<-fPIE%> is not supported"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "οι επιλογές --string και --check είναι αμοιβαίως αποκλειόμενες"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
@@ -34536,7 +34588,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -34869,52 +34921,52 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, fuzzy, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr "σφάλμα επεξεργασίας· επίσης η μνήμη εξαντλήθηκε"
@@ -35048,132 +35100,132 @@ msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένα
 msgid "parameter to builtin not valid: %s"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
@@ -35553,144 +35605,144 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -36140,7 +36192,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -37216,52 +37268,52 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -37377,323 +37429,324 @@ msgstr ""
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "πάρα πολλά ορίσματα"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -37714,219 +37767,224 @@ msgstr "Δεν είναι δυνατή η καταχώρηση της υπηρε
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "μη έγκυρο δικαίωμα"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -38249,139 +38307,139 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -38803,8 +38861,8 @@ msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζετ
 msgid "could not read the BRIG file"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -39081,7 +39139,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "declaration of %qD shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -39152,7 +39210,7 @@ msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -39183,7 +39241,7 @@ msgstr "Πρόωρο τέλος της κανονικής έκφρασης"
 msgid "duplicate label declaration %qE"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "διπλό κλειδί"
@@ -39392,7 +39450,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39732,7 +39790,7 @@ msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -40039,7 +40097,7 @@ msgstr "αδυναμία ανοίγματος αρχείου ορισμού loca
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -40090,7 +40148,7 @@ msgstr "επώνυμα μέλη"
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -40127,7 +40185,7 @@ msgstr "αδυναμία ανοίγματος αρχείου ορισμού loca
 msgid "redeclaration of %<enum %E%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -40157,7 +40215,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -40187,7 +40245,7 @@ msgstr "διατήρηση ωρών στο %s"
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -40302,12 +40360,12 @@ msgstr "λάθος αριθμός ορισμάτων"
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -40315,257 +40373,257 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -40585,7 +40643,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -40631,7 +40689,7 @@ msgid "unknown type name %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -40651,7 +40709,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -40666,8 +40724,8 @@ msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζοντ
 msgid "unexpected attribute"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -40705,7 +40763,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -40733,7 +40791,7 @@ msgstr "αρχεία fifo δεν υποστηρίζονται"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, fuzzy, gcc-internal-format
 msgid "expected string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
@@ -40763,7 +40821,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -40808,14 +40866,14 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, fuzzy, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "σκουπίδια στο τέλος του αριθμού"
@@ -40900,7 +40958,7 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -40910,7 +40968,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -40970,7 +41028,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -40985,7 +41043,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -41010,17 +41068,17 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr ""
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -41040,12 +41098,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -41060,8 +41118,8 @@ msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχ
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -41088,12 +41146,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -41485,61 +41543,61 @@ msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χ
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -41549,18 +41607,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
@@ -41580,53 +41638,53 @@ msgstr ""
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41648,12 +41706,12 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
@@ -41663,22 +41721,22 @@ msgstr ""
 msgid "expected constant integer expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr ""
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -41693,52 +41751,52 @@ msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr ""
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -41748,7 +41806,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -41783,22 +41841,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -41813,77 +41871,77 @@ msgstr "Μη έγκυρη ημερομηνία `%s'."
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr ""
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41898,7 +41956,7 @@ msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 msgid "expected function name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -41908,67 +41966,67 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41978,57 +42036,57 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr ""
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr ""
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr ""
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr ""
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -42038,72 +42096,72 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -42118,57 +42176,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr ""
@@ -42178,12 +42236,12 @@ msgstr ""
 msgid "variant %qD is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -42193,32 +42251,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -42273,42 +42331,42 @@ msgstr "%s: αναμενόταν αριθμητική τιμή."
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr ""
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr ""
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -42323,27 +42381,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -42353,7 +42411,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -42368,7 +42426,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, fuzzy, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -42493,7 +42551,7 @@ msgstr "Δεν μπορεί να καθοριστεί το όνομα του σ
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -42518,7 +42576,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42631,17 +42689,17 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -42666,7 +42724,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -42914,7 +42972,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -43088,7 +43146,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -43248,7 +43306,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -43279,7 +43337,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -43424,7 +43482,7 @@ msgstr ""
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -43464,7 +43522,7 @@ msgstr ""
 msgid "case label is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -43474,17 +43532,17 @@ msgstr ""
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -43499,7 +43557,7 @@ msgstr ""
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
@@ -43509,22 +43567,22 @@ msgstr ""
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -43575,7 +43633,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -43605,51 +43663,51 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -43659,8 +43717,8 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
@@ -43828,12 +43886,12 @@ msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -43858,8 +43916,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -43874,19 +43932,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -43956,116 +44014,116 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -44248,718 +44306,718 @@ msgid "expected case label"
 msgstr "διπλό κλειδί"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 msgid "  no known conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr ""
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 msgid "  inherited here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
 # src/main.c:785
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "Ασαφής μορφή `%s'"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "σφάλμα στην ανάγνωση εισόδου: %s"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr ""
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr ""
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%s(%A)%>"
@@ -44967,81 +45025,81 @@ msgstr "δεν ταιριάζει συνάρτηση για την κλήση σ
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "η κλήση της υπερφορτωμένης %<%s(%A)%> είναι διφορούμενη"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
@@ -45071,521 +45129,521 @@ msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "  κατά `%D'"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -45665,7 +45723,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
@@ -45722,7 +45780,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
@@ -45778,369 +45836,368 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "διπλό κλειδί"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr ""
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -46185,7 +46242,7 @@ msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαρ
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -46225,293 +46282,293 @@ msgstr ""
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
 # src/request.c:37
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "%s σε %s"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -46577,7 +46634,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -46759,12 +46816,12 @@ msgstr "Δεν υπάρχει προηγούμενη κανονική έκφρα
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "κανένας ορισμός του `UNDEFINED'"
@@ -46777,44 +46834,44 @@ msgstr "κανένας ορισμός του `UNDEFINED'"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -46822,846 +46879,846 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
@@ -47931,7 +47988,7 @@ msgstr ""
 msgid "%qD declared as array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -48096,7 +48153,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
@@ -48297,813 +48354,813 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
 # src/shred.c:1134
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -49115,97 +49172,97 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -49214,72 +49271,72 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -49319,7 +49376,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -49329,7 +49386,7 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -49655,150 +49712,150 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "χωρίς ορίσματα"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -49979,342 +50036,342 @@ msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρ
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/request.c:263
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, fuzzy, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ακατάλληλος τύπος δικτύου :`%s'\n"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -50474,12 +50531,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr ""
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr ""
@@ -50504,159 +50561,164 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
+#: cp/method.c:1115
 #, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr ""
+#: cp/method.c:1123
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD must be %<const%>"
+msgstr "διπλό κλειδί"
 
-#: cp/method.c:1126
+#: cp/method.c:1128
 #, gcc-internal-format
-msgid "defaulted %qD must return %<bool%>"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1155
 #, fuzzy, gcc-internal-format
-msgid "defaulted %qD must be %<const%>"
-msgstr "διπλό κλειδί"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/method.c:1158
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "μη έγκυρο byte ή λίστα πεδίων"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "αδυναμία προσπέλασης(stat()) αρχείου `%s': %s"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -50696,214 +50758,214 @@ msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 # src/request.c:37
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
 # src/request.c:37
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -50928,7 +50990,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50953,7 +51015,7 @@ msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 msgid "request for member %qE in non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -51033,7 +51095,7 @@ msgstr "Μη έγκυρη ημερομηνία `%s'."
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -51154,7 +51216,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -51274,7 +51336,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "κενό αλφαριθμητικό"
@@ -51374,12 +51436,12 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -51414,7 +51476,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -51429,7 +51491,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -51444,7 +51506,7 @@ msgstr ""
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "μη έγκυρος χρήστης"
@@ -51469,914 +51531,919 @@ msgstr ""
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "παλαιού είδους θέση"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "πολλαπλός αριθμός επιλογών την εντολή `s'"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "Μη ορισμένο όνομα %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
 # src/dfa.c:962
 # src/dfa.c:970
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Δεν ορίστηκε συντακτικό"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -52385,430 +52452,430 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -52817,545 +52884,545 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53627,7 +53694,7 @@ msgstr ""
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, fuzzy, gcc-internal-format
 msgid "        %qD"
 msgstr "        `%D'"
@@ -53652,84 +53719,84 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "template parameter %qD declared here"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgstr[1] "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -53737,47 +53804,47 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -53787,493 +53854,493 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "διπλό όνομα χαρακτήρα `%s'"
 msgstr[1] "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 msgstr[1] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
@@ -54291,293 +54358,293 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
 # src/request.c:37
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -54589,134 +54656,134 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -54922,7 +54989,7 @@ msgstr "μη έγκυρος χρήστης"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -54972,7 +55039,7 @@ msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -55071,7 +55138,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -55113,7 +55180,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -55238,117 +55305,117 @@ msgstr ""
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "αποτυχία κατά την εγγραφή δεδομένων για την κατηγορία `%s'"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -55588,804 +55655,804 @@ msgstr ""
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 # src/main.c:697 src/main.c:751
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "Άγνωστη γλώσσα `%s'"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "μη έγκυρος χρήστης"
@@ -56646,107 +56713,107 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -56970,10 +57037,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -57140,7 +57207,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -57257,7 +57324,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -57297,7 +57364,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -57312,7 +57379,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -57432,167 +57499,167 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "είδος μορφής"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr ""
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr ""
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr ""
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr ""
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr ""
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr ""
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr ""
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr ""
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -57600,697 +57667,697 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr ""
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr ""
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr ""
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr ""
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr ""
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr ""
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr ""
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr ""
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr ""
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr ""
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr ""
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr ""
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr ""
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr ""
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr ""
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr ""
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr ""
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "πάρα πολλά ορίσματα"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr ""
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr ""
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -58486,1763 +58553,1763 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "κενό αλφαριθμητικό"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
 # src/request.c:263
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
 # src/request.c:263
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr ""
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "έχει παραληφθεί το όνομα της παραμέτρου"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr ""
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Αγνωστος δυαδικός χειριστής."
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr ""
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr ""
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων κατηγοριών"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected"
 msgid "%<)%> expected at %C"
 msgstr "αναμενόταν '('"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr ""
@@ -60369,12 +60436,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr ""
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr ""
@@ -60449,7 +60516,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -60715,7 +60782,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -60773,167 +60840,167 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -60959,7 +61026,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -61150,12 +61217,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -61225,582 +61292,582 @@ msgstr ""
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "πολύ λίγα ορίσματα"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to procedure `%s'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -61908,73 +61975,73 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr ""
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
@@ -61982,22 +62049,22 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -62343,12 +62410,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62358,7 +62425,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62403,7 +62470,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -62498,7 +62565,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -62564,7 +62631,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at %qs token"
 msgid "Syntax error in %s statement at %C"
@@ -62580,83 +62647,83 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr ""
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr ""
@@ -62903,505 +62970,505 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr ""
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr ""
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr ""
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr ""
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr ""
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr ""
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
@@ -63409,217 +63476,217 @@ msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χ
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr ""
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "πάρα πολλά ορίσματα"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr ""
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
@@ -63660,12 +63727,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -64346,8 +64413,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -65753,172 +65820,172 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr ""
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
 #, gcc-internal-format, gfc-internal-format
-msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
+msgid "RE or IM part_ref at %C"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
-msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
+msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected argument list at %C"
+msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2366
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
+msgid "Expected argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr ""
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr ""
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -66248,495 +66315,495 @@ msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -66745,12 +66812,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -66759,283 +66826,283 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67044,284 +67111,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67329,187 +67396,187 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67517,956 +67584,956 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
 # src/request.c:37
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -69152,155 +69219,155 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -69337,83 +69404,83 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -69433,74 +69500,74 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -69515,28 +69582,28 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
 # src/grep.c:1133
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -69572,22 +69639,22 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 msgid "optional class parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -69697,82 +69764,82 @@ msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 msgid "unable to open file"
 msgstr "Αδυναμία μεταφοράς στη μνήμη (mmap) του αρχείου %s.\n"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, fuzzy, gcc-internal-format
 msgid "unexpected offset"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr ""
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -70910,7 +70977,7 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, fuzzy, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "παράληψη ορίσματος αρχείου"
@@ -71113,19 +71180,19 @@ msgstr ""
 msgid "unknown TLS model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "άγνωστο σετ `%s'"
 
 # src/request.c:806 src/request.c:912
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
 # src/request.c:263
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
diff --git a/gcc/po/es.po b/gcc/po/es.po
index 4d8f2147e67..d3562e2ce0c 100644
--- a/gcc/po/es.po
+++ b/gcc/po/es.po
@@ -42,7 +42,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1-b20200209\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2020-03-22 16:48+0100\n"
 "Last-Translator: Antonio Ceballos Roa <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
@@ -1939,86 +1939,86 @@ msgstr "modificador de longitud en formato strfmon"
 msgid "<command-line>"
 msgstr "<línea-de-órdenes>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "no se admite el operando para el código '%c'"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "operando no válido para '%%%c'"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante de vector no válida"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "falta un operando"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "constante no válida"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "operando no válido"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "prefijo de operando no válido '%%%c'"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr "modo de direccionamiento no válido"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operación no permitida con el tipo %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operandos no válidos en la operación binaria"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
@@ -2034,18 +2034,18 @@ msgid "invalid %%r value"
 msgstr "valor %%r no válido"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "valor %%R no válido"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
@@ -2075,7 +2075,7 @@ msgstr "valor %%M no válido"
 msgid "invalid %%U value"
 msgstr "valor %%U no válido"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
@@ -2085,7 +2085,7 @@ msgstr "valor %%s no válido"
 msgid "invalid %%C value"
 msgstr "valor %%C no válido"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
@@ -2095,10 +2095,10 @@ msgstr "valor %%E no válido"
 msgid "unknown relocation unspec"
 msgstr "reubicación unspec desconocida"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "código %%xn no válido"
@@ -2180,35 +2180,35 @@ msgstr "UNSPEC no válido como operando: %d"
 msgid "unrecognized supposed constant"
 msgstr "no se reconoce la constante supuesta"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "operando de desplazamiento no válido"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instrucción de predicado Thumb"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instrucción de predicado en una secuencia condicional"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "No se admite el operando para el código '%c'"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2216,13 +2216,13 @@ msgstr "No se admite el operando para el código '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "la instrucción nunca se ejecuta"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "código de formato Maverick obsoleto '%c'"
@@ -2348,7 +2348,7 @@ msgstr "operando inesperado"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2565,26 +2565,26 @@ msgstr "operando output_move_double erróneo"
 msgid "bad output_condmove_single operand"
 msgstr "operando output_condmove_single erróneo"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr "dirección ADDR_SPACE_GLOBAL errónea"
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, c-format
 msgid "invalid operand %%xn code"
 msgstr "operando no válido para el código %%xn"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "c4x_operand_subword: invalid mode"
 msgid "operand %%xn code invalid for QImode"
 msgstr "c4x_operand_subword: modo no válido"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, c-format
 msgid "invalid fp constant"
 msgstr "constante fp no válida"
@@ -2731,7 +2731,7 @@ msgstr "operación no válida en %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "operando %%P no válido"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -2785,7 +2785,7 @@ msgid "post-increment address is not a register"
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -2837,8 +2837,8 @@ msgstr "'%%%c' no es un prefijo de operando válido"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "uso no válido de '%%%c'"
@@ -2977,165 +2977,219 @@ msgstr "Espacio de pila agotado.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Pruebe ejecutar '%s' en el intérprete de órdenes para elevar su límite.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> requiere coma flotante de hardware"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> necesita direccionamiento indexado"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> y -%<mno-altivec%> son incompatibles"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> desactiva vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> requiere modo de 64 bits"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> requiere modo de 64 bits"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> no está disponible en modo little endian"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "valor %%J no válido"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "valor %%D no válido"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, c-format
 msgid "invalid %%t value"
 msgstr "valor %%t no válido"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "valor %%V no válido"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "valor %%z no válido"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 y __ibm128 no pueden utilizarse en la misma expresión"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to type %<bfloat16_t%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "conversión no válida al tipo %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "conversión no válida de %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "conversión no válida a %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to type %<bfloat16_t%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "conversión no válida al tipo %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "conversión no válida de %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "conversión no válida a %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3146,88 +3200,88 @@ msgstr "las referencias a memoria simbólica sólo se admiten en z10 o posterior
 msgid "cannot decompose address"
 msgstr "no se puede descomponer la dirección"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operador de comparación no válido para el modificador de salida 'E'"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "referencia no válida para el modificador de salida 'J'"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "dirección no válida para el modificador de salida 'O'"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "dirección no válida para el modificador de salida 'R'"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "se esperaba una referencia de memoria para el modificador de salida 'S'"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "dirección no válida para el modificador de saida 'S'"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'N'"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'M'"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vector constante no válido para el modificador de salida '%c'"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expresión no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expresión no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr "se pasó un argumento vector a una función sin prototipo"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "los tipos difieren en el signo"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr "el operador binario no admite dos operadores bool vector"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr "el operador binario no admite operador bool vector"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "el operador binario no admite que se mezclen operandos bool vector y vector de coma flotante"
 
@@ -3490,8 +3544,8 @@ msgstr "({anónimo})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
@@ -3511,7 +3565,7 @@ msgstr "se esperaba %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -3519,7 +3573,7 @@ msgstr "se esperaba %<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -3537,21 +3591,21 @@ msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -3562,12 +3616,12 @@ msgstr "se esperaba %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
@@ -3576,7 +3630,7 @@ msgstr "se esperaba %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -3585,18 +3639,18 @@ msgstr "se esperaba %<,%>"
 msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
@@ -3604,19 +3658,19 @@ msgstr "se esperaba %<,%> o %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
@@ -3625,7 +3679,7 @@ msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -3636,37 +3690,37 @@ msgstr "se esperaba %<<%>"
 msgid "expected label"
 msgstr "se esperaba etiqueta"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "candidato 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Activa las instrucciones definidas por el usuario."
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
 msgstr[1] "los candidatos son:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "candidato 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "candidato 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "salto a la etiqueta %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "salto a la etiqueta case"
 
@@ -3755,7 +3809,7 @@ msgstr "<error de parámetro de plantilla>"
 msgid "<statement>"
 msgstr "<sentencia>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<desconocido>"
@@ -3921,48 +3975,48 @@ msgstr "la conversión descarta la constancia"
 msgid "source type is not polymorphic"
 msgstr "el tipo fuente no es polimórfico"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argumento de tipo erróneo para el decremento unario"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argumento de tipo erróneo para el incremento unario"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argumento de tipo erróneo para complemento de bits"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argumento de tipo erróneo para abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argumento de tipo erróneo para la conjugación"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "en el argumento para el ! unario"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "no hay operador de pre-incremento para el tipo"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "no hay operador de post-incremento para el tipo"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "no hay operador de pre-decremento para el tipo"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "no hay operador de post-decremento para el tipo"
 
@@ -4002,17 +4056,17 @@ msgstr "Typo ilegal en concatenación de caracteres en %L"
 msgid "elemental binary operation"
 msgstr "operación binaria elemental"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "argumentos 'a%d' y 'a%d' para el intrínseco '%s'"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "argumentos '%s' y '%s' para el intrínseco %s"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "argumentos '%s' y '%s' para el intrínseco '%s'"
@@ -4091,7 +4145,7 @@ msgstr "Desajuste de frontera de matriz en la dimensión 2 de la matriz (%ld/%ld
 msgid "Driving:"
 msgstr "Conduciendo:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argumento actual de INTENT = OUT/INOUT"
 
@@ -4106,7 +4160,7 @@ msgstr "unidad interna en WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "etiqueta %s con INQUIRE"
@@ -4212,11 +4266,11 @@ msgstr "bloque IF"
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
@@ -4224,199 +4278,199 @@ msgstr "asignación de puntero"
 msgid "simple IF"
 msgstr "IF simple"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "procedimiento elemental"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr "argumento asignable"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr "argumento asíncrono"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "argumento opcional"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "argumento puntero"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "argumento destino"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "argumento de valor"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr "argumento volátil"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr "se asume argumento de aspecto"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr "se asume argumento de rango"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr "argumento de coarray"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr "argumento de tipo derivado parametrizado"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr "argumento polimórfico"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "atributo NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr "se asume argumento de tipo"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "resultado array"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr "puntero o resultado asignable"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr "resultado con longitud de carácter no constante"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr "procedimiento bind(c)"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador numérico unitario %%<%s%%> en %%L es %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Entidades de tipos derivados no esperadas en el operador numérico intrínseco binario %%<%s%%> en %%L"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador numérico binario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Los operandos del operador de concatenación de cadenas en %%L son %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador lógico %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "El operando del operador .not. en %%L es %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Las cantidades COMPLEX no se pueden comparar en %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Los lógicos en %%L se deben comparar con %s en lugar de %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de comparación %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Operador %%<%s%%> desconocido en %%L; ¿quiso decir '%s'?"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operador %%<%s%%> desconocido en %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador de usuario %%<%s%%>  en %%L es %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de usuario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangos inconsistentes para el operador en %%L y %%L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -4429,27 +4483,27 @@ msgstr "Longitudes de CHARACTER diferentes (%ld/%ld) en el constructor de matriz
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Desborde entero al calcular la cantidad de memoria a reservar"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "El valor del parámetro PDT LEN '%s' no concuerda con el de la declaración «dummy»"
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual no coincide con la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual es más corta que la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "El objetivo del remapeo de rango es demasiado pequeño (%ld < %ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr "Asignación de escalar a un array sin espacio asignado"
 
@@ -4526,7 +4580,7 @@ msgstr "El número de unidad en la declaración de E/S es demasiado grande"
 msgid "Assigned label is not a target label"
 msgstr "La etiqueta asignada no es una etiqueta objetivo"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Número de imagen %d no válido en SYNC IMAGES"
@@ -4956,7 +5010,7 @@ msgstr "Avisa sobre la creación de matrices temporales."
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "No hace nada. Preservado por compatibilidad hacia atrás."
@@ -5543,8 +5597,8 @@ msgstr "Agrega subrayado a los nombres visibles externamente."
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "No hace nada.  Se preserva por compatibilidad hacia atrás."
@@ -8023,109 +8077,103 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "Avisa sobre macros definidas en el fichero principal que no se usan."
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves."
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Avisa sobre variables que se inicialicen ellas mismas."
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "-fdump-<tipo>\tVuelca varios internos del compilador a un fichero."
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgid "Dump various analyzer internals to stderr."
 msgstr "-fdump-<tipo>\tVuelca varios internos del compilador a un fichero."
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12612,9 +12660,9 @@ msgstr "Activa las conversiones predefinidas entre __float128 y long double."
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "BMX instructions are only supported with R2 architecture"
-msgid "Use instructions for a future architecture."
-msgstr "las instrucciones BMX solo se admiten con la arquitectura R2"
+#| msgid "Use vector instructions added in ISA 3.0."
+msgid "Use instructions added in ISA 3.1."
+msgstr "Usa instrucciones vectoriales añadidas en ISA 3.0."
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -12628,6 +12676,12 @@ msgstr "Genera instrucciones de memoria quad word (lq/stq)."
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "No genera accessos a memoria sin alinear"
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate the quad word memory instructions (lq/stq)."
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Genera instrucciones de memoria quad word (lq/stq)."
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17667,7 +17721,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18311,374 +18365,374 @@ msgstr "Realiza el desenrollamiento del bucle cuando se conoce la cuenta de iter
 msgid "Perform loop unrolling for all loops."
 msgstr "Realiza el desenrollamiento del bucle para todos los bucles."
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Permite la optimización para la aritmética de coma flotante la cual puede cambiar el resultado de la operación debido a redondeo."
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Igual que -fassociative-math para las expresiones que incluyen división."
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Permite optimizaciones matemáticas que pueden violar los estándares IEEE ó ISO."
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Realiza la eliminación de opciones de bucle."
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Realiza la división de bucles."
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Sólo genera tablas de desenredo para manejo de excepciones."
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Usa el enlazador bfd eb lugar del predeterminado."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Usa el enlazador de oro eb lugar del predeterminado."
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Use the gold linker instead of the default linker."
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Usa el enlazador de oro eb lugar del predeterminado."
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Realiza seguimiento de variables."
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Realiza seguimiento de variables con asignación de anotaciones."
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Cambia -fvar-tracking-assignments."
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Realiza el seguimiento de variables y también marca las variables que no se inicializaron."
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Activa la vectorización en árboles."
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Activa la vectorización de bucles en árboles."
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Activa la vectorización de bloque básico (SLP) en árboles."
 
-#: common.opt:2959
+#: common.opt:2963
 #, fuzzy, no-c-format
 #| msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Especifica el modelo de coste para vectorización. -fvect-cost-model=[unlimited|dynamic|cheap]\tEspecifica el modelo de coste para vectorización."
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tEspecifica el modelo de coste de la vectorización para código marcado con directiva simd."
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Activa el modelo de coste de vectorizador dinámico.  Se preserva por compatibilidad hacia atrás."
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activa la propagación de copia de la información escalar-evolución."
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Agrega comentarios extra a la salida de ensamblador."
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tEstablece la visibilidad de símbolos por defecto."
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Valida los punteros vtable antes de usarlos."
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Contadores de verificación de vtable de salida."
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Información sobre los conjuntos de vectores de verificación de vtable de salida."
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Usa perfiles de valor de expresión en las optimizaciones."
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Construye redes y divide usos no relacionados de una sola variable."
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Activa la eliminación de código muerto condicional para llamadas internas."
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Realiza optimizaciones del programa completo."
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Asume que el desbordamiento de punteros se envuelve."
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Asume que el desbordamiento aritmético con signo se envuelve."
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Pone los datos inicializados a cero en la sección bss."
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Genera información de depuración en el formato por defecto."
 
-#: common.opt:3076
+#: common.opt:3080
 #, fuzzy, no-c-format
 #| msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Asume soporte del ensamblador para las directivas .loc (DWARF2+)"
 
-#: common.opt:3080
+#: common.opt:3084
 #, fuzzy, no-c-format
 #| msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Asume soporte del ensamblador para visualización en las directivas .loc (DWARF2+)"
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Registro DW_AT_decl_column y DW_AT_call_column en DWARF."
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Genera información de depuración en la versión predeterminada del formato DWARF."
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Genera información de depuración en el formato DWARF v2 (o posterior)."
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Genera información de depuración en el formato extendido por defecto."
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate extended entry point information for inlined functions"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Genera información extendida sobre el punto de entrada para funciones en línea"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "No genera nombres públicos DWARF y secciones de tipos públicos."
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Genera nombres públicos DWARF y secciones de tipos públicos."
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Genera nombres públicos DWARF y secciones de tipos públicos con extensiones GNU."
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en DW_AT_producer de DWARF."
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Genera información de depuración en ficheros .dwo separados."
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Genera información de depuración en el formato STABS."
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Genera información de depuración en el formato STABS extendido."
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "No emite adiciones DWARF más allá de la versión seleccionada."
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Cambia la generación de información de depuración."
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Genera información de depuración en el formato VMS."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Genera información de depuración en el formato XCOFF."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Genera información de depuración en el formato XCOFF extendido."
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Genera secciones de depuración comprimidas."
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<formato>\tGenera secciones de depuración comprimidas en formato <formato>."
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tDefine <dir> como el directorio de plugins por defecto."
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <dir>\tDefine <dir> como el subdirectorio de inclusión de multilib."
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fichero>\tColoca la salida en el <fichero>."
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Activa el análisis de perfil de las funciones."
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Como -pedantic pero los muestra como errores."
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "No muestra las funciones compiladas o el tiempo transcurrido."
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Activa la salida detallada."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Muestra la versión del compilador."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Suprime avisos."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Crea una biblioteca compartida."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "No genera un ejecutable independiente de posición enlazado dinámicamente."
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Genera un ejecutable independiente de posición enlazado dinámicamente."
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Genera un ejecutable independiente de posición estático."
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Usa registro de guarda de invocador entre llamadas si es posible."
@@ -19850,8 +19904,8 @@ msgstr "Límite en el número de revisiones de tiempo de ejecución insertadas p
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Límite en el número de revisiones de tiempo de ejecución insertadas por las versiones de bucle del vectorizador para revisión de alineación."
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "no se usa el valor calculado"
@@ -19877,7 +19931,7 @@ msgid "expected boolean type"
 msgstr "se esperaba un tipo booleano"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "se esperaba un entero"
@@ -19943,7 +19997,7 @@ msgstr "faltan argumentos"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "demasiados argumentos"
@@ -20299,7 +20353,7 @@ msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atribut
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20384,12 +20438,12 @@ msgstr "se descartan los atributos de tipo después de que el tipo ya se defini
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20407,8 +20461,8 @@ msgstr "se descarta el atributo %qE"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "falta el atributo %<target%> para %qD multiversionado"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "declaración previa de %qD"
@@ -20531,7 +20585,7 @@ msgstr "el argumento %qD se declara aquí"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "el desplazamiento %qwi fuera de los límites de la constante de cadena"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -20845,7 +20899,7 @@ msgstr "argumento %qs no válido para %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack ()%>"
@@ -21152,12 +21206,12 @@ msgstr "la sobreescritura asm genera un conflicto con el operando de salida"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "la sobreescritura asm genera un conflicto con el operando de entrada"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "el protector de pila no protege las variables locales: almacenamiento temporal de longitud variable"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "el protector de pila no protege la función: todas las matrices locales son de longitud menor a %d bytes"
@@ -21669,309 +21723,309 @@ msgstr "los bloques básicos no están ubicados consecutivamente"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "el número de notas bb en la cadena insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "la cuenta de borde llamador no es válida"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing counts for called function %s"
 msgid "missing direct call for speculation %i"
 msgstr "Faltan las cuentas para la función invocada %s"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "falta una barrera después del bloque %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "campo aux establecido para el borde %s->%s"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "cuenta de cgraph no válida"
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "clon en línea en el mismo grupo comdat"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "inline clone is forced to output"
 msgid "inline clone count is not compatible"
 msgstr "se fuerza en la salida un clon incluido en línea"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "tp_first_run must be non-negative"
 msgstr "el valor de %<priority%> debe ser no negativo"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "los símbolos locales deben definirse"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clon incluido en línea visible externamente"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clon incluido en línea con dirección tomada"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "se fuerza en la salida un clon incluido en línea"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 #| msgid "returns_nonnull attribute on a function not returning a pointer"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "atributo returns_nonnull en una función que no devuelve puntero"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "se define el campo aux para el borde indirecto desde %s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Un borde indirecto de %s no está marcado como indirecto o tiene indirect_info asociado, la declaración correspondiente es: "
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "función comdat-local llamada por %s fuera de su comdat"
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "el puntero inlined_to está mal"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "múltiples llamantes inline"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "se estableció el puntero inlined_to para llamantes no-inline"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "la cuenta de borde llamador no coincide con la cuenta BB"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "la cuenta de llamadas indirectas no coincide con la cuenta BB"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "se estableció el puntero inlined_to, pero no se encontraron predecesores"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "el puntero inlined_to se refiere a sí mismo"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "el cgraph_node tiene un clone_of erróneo"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "el cgraph_node tiene una lista de clones errónea"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "el cgraph_node está en la lista de clones pero no es clon"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "el cgraph_node tiene un puntero prev_clone erróneo"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "lista de clones doblemente ligada corrrupta"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias tiene bordes de llamada"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias tiene una referencia que no es alias"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias tiene más de una referencia alias"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "El alias analizado no tiene referencia"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "No hay un borde fuera de un nodo thunk"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Más de un borde fuera de un nodo thunk"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "No se supone que thunk tenga cuerpo"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt compartida:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "puntos de borde para una declaración errónea:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "un borde indirecto con un llamante desconocido que corresponde a call_stmt con una declaración conocida:"
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "falta el borde de callgraph para la llamada stmt:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referencia a sentencia muerta"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "el borde %s->%s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "un borde indirecto desde %s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "origin points to a different parent"
 msgstr "conversión de registro a un tamaño diferente"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "falló verify_cgraph_node"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: section %s is missing"
 msgid "%s: section %s.%d is missing"
@@ -22068,12 +22122,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "se descarta el atributo %<weakref%> porque ya se inicializó la variable"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "se usa %q+F pero nunca se define"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
@@ -22236,7 +22290,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "el soporte para LTO no se activó en esta configuración"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "no se puede abrir %s: %m"
@@ -22586,22 +22640,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "se encontró UNSPEC %s (%d) que no está delegitimado la ubicación de variable"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "se encontró una compartición de rtl no válida en la insn"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "rtx compartido"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "falla interna de consistencia"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: se usa emit_insn donde se necesita emit_jump_insn:\n"
@@ -22666,7 +22720,7 @@ msgstr "region_array no coincide con region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array no coincide con region_tree"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -22697,12 +22751,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kla llamada a %qs se redeclaró con error de atributo: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kla llamada a %qs se redecló con aviso de atributo: %s"
@@ -22718,7 +22772,7 @@ msgstr "argumento %qs no válido para %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "el tamaño de marco de %wd bytes es mayor que %wd bytes"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "no se puede abrir el fichero de volcado de insn final %qs: %m"
@@ -22738,37 +22792,37 @@ msgstr "se truncó la constante de coma fija grande implícitamente al tipo de c
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "la comparación siempre es %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de pruebas no equivalentes sin coincidencia siempre es 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de pruebas equivalentes mutuamente exclusivas siempre es 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se reduce la constante en comparación"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se combinan constantes alrededor de una comparación"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold check: el árbol original cambió por un pliegue"
@@ -23419,13 +23473,13 @@ msgstr "la función puede devolver la dirección de una variable local"
 msgid "function returns address of local variable"
 msgstr "la función devuelve la dirección de una variable local"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "se declara aquí"
@@ -24046,10 +24100,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "el desplazamiento de %G%qD %s está fuera de los límites ] del objeto %qD con tipo %qT"
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -24227,7 +24281,7 @@ msgstr "no se especificó %qE en el %qs que lo contiene"
 msgid "enclosing %<target%>"
 msgstr "región objetivo contenedora"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE se declaró en la región %<host_data%> que la contiene"
@@ -24279,13 +24333,13 @@ msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
@@ -24296,158 +24350,158 @@ msgstr "aún no se admite el modelo de código %<large%>"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "cláusula %<linear%> para una variable que no es iterador de bucle especificada en una construcción combinada con %<distribute%>"
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "se asocia el campo %qE de una estructura de longitud variable"
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE aparece más de una vez en las cláusulas map"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable copyprivate %qE no es threadprivate o private en el contexto externo"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable %s %qE es private en el contexto externo"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "se esperaba el modificador de cláusula %qs %<if%> en vez de %qs"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD en cláusula %<map%> implícita"
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> implícita en una construcción %<target%>"
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "se ha usado la misma variable en cláusulas %<firstprivate%> y %<lastprivate%> en una construcción %<distribute%>"
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "cláusula de datos incompatible con reducción en %qE; se promociona a present_or_copy"
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "reducción privada no válida en %qE"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<ordered%> con un parámetro"
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "construcción %<teams%> no bien anidada dentro de construcción %<target%>"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, fuzzy, gcc-internal-format
 #| msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "las regiones %<distribute%> deben estar estrictamente anidadas dentro de construcciones %<teams%>"
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, fuzzy, gcc-internal-format
 #| msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "solamente a las regiones %<distribute%> o %<parallel%> se les permite estar estrictamente anidadas dentro de la región %<teams%>"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "el combinador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_out%> ni %<omp_in%>"
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "la construcción %<ordered%> con cláusula %<depend%> debe estar bien anidada dentro de un bucle con una cláusula %<ordered%> con un parámetro"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE no es una iteración del bucle más externo %d; se esperaba %qE"
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, fuzzy, gcc-internal-format
 #| msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "el número de variables en la cláusula %<depend(sink)%> no coincide con el número de variables de iteración"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, fuzzy, gcc-internal-format
 #| msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "más de una cláusula %<depend(source)%> en una construcción %<ordered%>"
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, fuzzy, gcc-internal-format
 #| msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(sink:)%> en la misma construcción"
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "falló la gimplificación"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT se promueve a %qT cuando pasa a través de %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(así que debe pasar %qT y no %qT a %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si se alcanza este código, el programa abortará"
@@ -24525,7 +24579,7 @@ msgstr "el elemento %u tiene ubicación-x == %u"
 msgid "token %u has %<y-location == %u%>"
 msgstr "el elemento %u tiene ubicación-y == %u"
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "uso no válido del atribute  %<fallthrough%>"
@@ -24802,55 +24856,55 @@ msgstr "El límite de la matriz no coincide"
 msgid "the extra base is defined here"
 msgstr "la base extra se define aquí"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] "Declarar el tipo %qD final permitiría desvirtualizar %i llamada"
 msgstr[1] "Declarar el tipo %qD final permitiría desvirtualizar %i llamadas"
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Declarar el tipo %qD final permitiría desvirtualizar %i llamada ejecutada %lli veces"
 msgstr[1] "Declarar el tipo %qD final permitiría desvirtualizar %i llamadas ejecutadas %lli veces"
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamada"
 msgstr[1] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamadas"
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] "Declarar el método %qD final permitiría desvirtualizar %i llamada"
 msgstr[1] "Declarar el método %qD final permitiría desvirtualizar %i llamadas"
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamada ejecutada %lli veces"
 msgstr[1] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamadas ejecutadas %lli veces"
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Declarar el método %qD final permitiría desvirtualizar %i llamada ejecutada %lli veces"
 msgstr[1] "Declarar el método %qD final permitiría desvirtualizar %i llamadas ejecutadas %lli veces"
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid fnsummary in LTO stream"
 msgstr "función no válida en la llamada gimple"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "falta el resumen de inclusión en línea ipa en el fichero de entrada"
@@ -24881,38 +24935,38 @@ msgstr "la función puede ser candidata para el atributo %qs si se sabe que reto
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "falta el resumen de referencia ipa en la unidad ltrans"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "HSA SSA verification failed"
 msgid "IPA-SRA access verification failed"
 msgstr "error de verificación HSA SSA"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24965,57 +25019,57 @@ msgstr "restricciones de operandos inconsistentes en un %<asm%>"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Se ha alcanzado el número máximo de insns de recarga generadas (%d)\n"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "flujo de bytecode: se encontraron instancias múltiples del nodo cgraph con uid %d"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "flujo de bytecode: no se encontró un llamante al leer el borde"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "flujo de bytecode: no se encontró un llamado al leer el borde"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "flujo de bytecode: se encontró un nodo cgraph vacío"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Por lo menos se admiten %i corridas de perfil. ¿Tal vez se corrompió el perfil?"
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "La información de análisis de perfil en %s está corrupta"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "no se puede encontrar cgraph de LTO en %s"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "no se pueden encontrar las referencias de sección LTO en %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "tabla de descarga no válida en %s"
@@ -25286,54 +25340,54 @@ msgstr "cláusula %<depend(sink)%> esperando iteración léxica posterior"
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr "%<depend(sink)%> se refiere a una iteración ajena al espacio de iteración"
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "previously used here"
 msgid "... to the previous %qs clause here"
 msgstr "se usó previamente aquí"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "...is duplicated here"
 msgid "... with %qs clause here"
 msgstr "...está duplicada aquí"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> ignora otros especificadores de bucle OpenACC"
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> está en conflicto con otros especificadores de bucle OpenACC"
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "el bucle interno usa el mismo paralelismo OpenACC que el bucle que lo contiene"
@@ -25570,54 +25624,54 @@ msgstr "entrada no válida a un bloque estructurado %s"
 msgid "invalid branch to/from %s structured block"
 msgstr "ramificación no válida desde/para un bloque estructurado %s"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "-fopenacc-dim operand is malformed at '%s'"
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr "operando -fopenacc-dim defectuoso en '%s'"
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr "la llamada a la rutina usa el mismo paralelismo OpenACC que el bucle que lo contiene"
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr "bucle que lo contiene aquí"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr "la llamada a la rutina usa paralelismo OpenACC no permitido por la rutina que lo contiene"
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr "el bucle usa paralelismo OpenACC no permitido por la rutina que lo contiene"
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "la rutina %qD se declara aquí"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr "paralelismo de bucle OpenACC incorrectamente anidado"
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr "insuficiente paralelismo disponible para paralelizar bucle de elemento"
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, fuzzy, gcc-internal-format
 #| msgid "insufficient partitioning available to parallelize element loop"
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr "insuficiente paralelismo disponible para paralelizar bucle de elemento"
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr "insuficiente paralelismo disponible para paralelizar bucle"
@@ -27047,142 +27101,142 @@ msgstr "no se admite %<-fcf-protection=return%> para este objetivo"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> ya no tiene soporte"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "no se admite la planificación de instrucciones en este objetivo"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "esta máquina objetivo no tiene ramificaciones retardadas"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "no se admite -f%sleading-underscore en este objetivo"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "no se puede cerrar el fichero de volcado de insn en ceros %qs: %m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "el sistema objetivo no admite el formato de depuración %qs"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "se solicitó seguimiento de variables, pero es inútil a menos que se produzca información de depuración"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "se solicitó seguimiento de variables, pero no se admite este formato de depuración"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "las asignaciones-de-rastreo-de-variable cambian el planificador selectivo"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "no se admite -ffunction-sections para este objetivo"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "no se admite -fdata-sections para este objetivo"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "no se admite -fprefetch-loop-arrays para este objetivo"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "no se admite -fprefetch-loop-arrays para este objetivo (intente los interruptores -march)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays no se admite con -Os"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math desactivado; otras opciones toman precedencia"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "no se admite -fstack-protector para este objetivo"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fsanitize=address y -fsanitize=kernel-address no se admiten para este objetivo"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "error al escribir a %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "error al cerrar %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "self-tests incompatible with -E"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "self-tests es incompatible con -E"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "self-tests no están activadas en este build"
@@ -27280,194 +27334,194 @@ msgstr "%Kno se permite asm en una función %<transaction_safe%>"
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "no se recomputa la constante cuando cambia ADDR_EXPR"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "no se recomputan los efectos laterales cuando cambia ADDR_EXPR"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "DECL_GIMPLE_REG_P set on a variable with address taken"
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "se definió DECL_GIMPLE_REG_P en una variable con dirección tomada"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "se tomó la dirección, pero el bit ADDRESSABLE no está activado"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "expresión no válida para el l-valor min"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "operando no válido en la referencia indirecta"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "non-scalar type"
 msgid "non-scalar %qs"
 msgstr "tipo que no es escalar"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "posición o tamaño de operando no válido para BIT_FIELD_REF"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "integral result type precision does not match field size of BIT_FIELD_REF"
 msgid "integral result type precision does not match field size of %qs"
 msgstr "la precisión del tipo de resultado integral no coincide con el tamaño del campo de BIT_FIELD_REF"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
 #| msgid "mode size of non-integral result does not match field size of BIT_FIELD_REF"
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "el modo de tamño del resultado que no es integral no coincide con el tamaño del campo de BIT_FIELD_REF"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs of non-mode-precision operand"
 msgstr "desplazamiento de un operando que no es entero"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
 #| msgid "position plus size exceeds size of referenced object in BIT_FIELD_REF"
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "posición más tamaño supera el tamaño del objeto referenciado en BIT_FIELD_REF"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "los tipos de datos no coinciden en la referencia de matriz"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "non-lvalue in %s"
 msgid "non-top-level %qs"
 msgstr "no es valor-l en %s"
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "operando no válido para %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in parameter %i"
 msgid "type mismatch in %qs"
 msgstr "los tipos no coinciden en el parámetro %i"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offset operand of MEM_REF"
 msgid "invalid %qs offset operator"
 msgstr "operando de desplazamiento de MEM_REF no válido"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of an SSA_NAME on the left hand side"
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "conversión de un SSA_NAME del lado izquierdo"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "conversión de registro a un tamaño diferente"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address operand in MEM_REF"
 msgid "invalid address operand in %qs"
 msgstr "operando de dirección no válido en MEM_REF"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offset operand in MEM_REF"
 msgid "invalid offset operand in %qs"
 msgstr "operando de desplazamiento no válido en MEM_REF"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "uso no válido de %qD"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "IF simple"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "la llamada gimple tiene dos objetivos"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "la llamada gimple no tiene objetivo"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "función no válida en la llamada gimple"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "no es función en la llamada gimple"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "estado const pure no válido para la función"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "LHS no válido en la llamada gimple"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, fuzzy, gcc-internal-format
 #| msgid "LHS in noreturn call"
 msgid "LHS in %<noreturn%> call"
 msgstr "LHS en la llamada noreturn"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "conversión no válida en la llamada gimple"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "cadena estática no válida en la llamada gimple"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "cadena static con una función que no usa una"
@@ -27478,545 +27532,545 @@ msgstr "cadena static con una función que no usa una"
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_unreachable or __builtin_trap call with arguments"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "llamada a __builtin_unreachable o __builtin_trap con argumentos"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "argumento no válido en la llamada gimple"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "operandos no válidos en la comparación gimple"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "comparación de tipos de operandos que no coinciden"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "operandos que no son vectores en la comparación de vectores"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "tipo resultante no válido de la comparación de vectores"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "tipo resultante no válido de la comparación"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "el LHS de una operación unaria no es un registro"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "operando no válido en la operación unaria"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "tipos no válidos en la conversión nop"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "tipos no válidos en la conversión nop"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "tipos no válidos en la conversión nop"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "tipos no válidos en la conversión de coma fija"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "tipos no válidos en la conversión a coma flotante"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "tipos no válidos en la conversión a entero"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in sad expression"
 msgid "type mismatch in %qs expression"
 msgstr "no coincide el tipo en expresión triste"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid prototype for '%s'"
 msgid "invalid types for %qs"
 msgstr "prototipo no válido para '%s'"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "conversión que no es trivial en la operación unaria"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "el LHS de una operación binaria no es un registro"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "operandos no válidos en la operación binaria"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-vector operands to vector valued plus"
 msgid "invalid non-vector operands to %qs"
 msgstr "operandos que no son vectores no válidos para un vector valuado con más"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "modo de puntero %qs no válido"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "vector type expected in %qs"
 msgstr "se esperaban tipos vector en una expresión de permutación de vector"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "los tipos de datos no coinciden en la expresión binaria"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "el LHS de una operación terniaria no es un registro"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "operandos no válidos en la operación terniaria"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "el primer argumento de una VEC_COND_EXPR debe ser de tipo vector de booleanos del mismo número de elementos que el resultado"
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "vector types expected in %qs"
 msgstr "se esperaban tipos vector en una expresión de permutación de vector"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 #| msgid "vectors with different element number found in vector permute expression"
 msgid "vectors with different element number found in %qs"
 msgstr "se encontraron vectores con número de elementos diferentes en la expresión de permutación"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offload table in %s"
 msgid "invalid mask type in %qs"
 msgstr "tabla de descarga no válida en %s"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "not allowed type combination in BIT_INSERT_EXPR"
 msgid "not allowed type combination in %qs"
 msgstr "no se permite combinar tipos en BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size in BIT_INSERT_EXPR"
 msgid "invalid position or size in %qs"
 msgstr "posición o tamaño no válido en BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 #| msgid "'h' applied to non-register operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "`h' aplicado a un operando no registro"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "insertion out of range in BIT_INSERT_EXPR"
 msgid "insertion out of range in %qs"
 msgstr "inserción fuera de rango en BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 #| msgid "vector insertion not at element boundary"
 msgid "%qs not at element boundary"
 msgstr "inserción de vector no en contorno de elemento"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "conversión que no es trivial en la asignación"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "non-decl/MEM_REF LHS in clobber statement"
 msgid "%qs LHS in clobber statement"
 msgstr "non-decl/MEM_REF LHS en sentencia clobber"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "operando no válido para %%R"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "rhs no válido para el almacenamiento de memoria gimple"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect type of vector CONSTRUCTOR elements"
 msgid "incorrect type of vector %qs elements"
 msgstr "tipo incorrecto de elementos de CONSTRUCTOR de vector"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect number of vector CONSTRUCTOR elements"
 msgid "incorrect number of vector %qs elements"
 msgstr "número incorrecto de elementos de CONSTRUCTOR de vector"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "tipo incorrecto de elementos de CONSTRUCTOR de vector"
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR with non-NULL element index"
 msgid "vector %qs with non-NULL element index"
 msgstr "CONSTRUCTOR de vector con índice de elemento no NULL"
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR element is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "el elemento CONSTRUCTOR de vector no es un valor GIMPLE"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "non-vector CONSTRUCTOR with elements"
 msgid "non-vector %qs with elements"
 msgstr "CONSTRUCTOR no vector con elementos"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR con una condición que es siempre falsa"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "operando no válido en la declaración return"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "conversión no válida en la declaración return"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "el destino de goto no es una etiqueta ni un puntero"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "operando no válido para la declaración switch"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "sentencia switch de tipo no entero"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "etiqueta case default no váilda en sentencia switch"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "invalid CASE_CHAIN"
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "CASE_CHAIN no válido"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "etiqueta case no váilda en sentencia switch"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "rango case no váildo en sentencia switch"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "discordancia de tipos para etiqueta case en sentencia switch"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "discordancia en precisión de tipo en sentencia switch"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "etiquetas case no ordenadas en sentencia switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "label's context is not the current function decl"
 msgid "label context is not the current function declaration"
 msgstr "el contexto de la etiqueta no es la declaración de función actual"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "entrada incorrecta en label_to_block_map"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "definición incorrecta del número de relleno de aterrizaje"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "código de comparación no válido en la condición gimple"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "etiquetas no válidas en la condición gimple"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "resultado PHI no válido"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "falta la definición PHI"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "argumento PHI no válido"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in PHI argument %u"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "tipos incompatibles en el argumento PHI %u"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "falló verify_gimple"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "STMT muerto en la tabla EH"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "la ubicación referencia un bloque que no está en el árbol de bloques"
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "Local declaration from a different function"
 msgid "local declaration from a different function"
 msgstr "Declaración local desde una función diferente"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "se estableció gimple_bb (phi) a un bloque básico erróneo"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "nodo PHI con ubicación"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "compartición incorrecta de nodos de árbol"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "PHI virtual con ubicaciones de argumento"
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "se estableció gimple_bb (stmt) a un bloque básico erróneo"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "se marcó la sentencia para throw, pero no lo hace"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "se marcó la sentencia para throw en medio del bloque"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "falló verify_gimple"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK tiene IL asociado con él"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK tiene IL asociado con él"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "caida para salir del bb %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "etiqueta no local "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "etiqueta de relleno de aterrizaje EH "
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "etiqueta "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "control de flujo enmedio del bloque básico %d"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "borde de caída después de una sentencia de control en bb %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "borde verdadero/falso después de una expresión que no es GIMPLE_COND en bb %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "banderas de borde de salida erróneas al final del bb %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "goto explícito al final del bb %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "el borde de devolución no apunta a exit en el bb %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "se encontró un case por defecto que no está al inicio del vector case"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "las etiquetas case no están ordenadas:"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "borde de salida extra %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "falta el borde %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "la función %<noreturn%> devuelve"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "el control alcanza el final de una función que no es void"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -28032,48 +28086,48 @@ msgstr "en definición de macro %qs"
 msgid "in expansion of macro %qs"
 msgstr "en expansión de macro %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "el BB %i tiene múltiples bordes EH"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has an EH edge"
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "el BB %i no puede hacer throw pero tiene un borde EH"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "la última sentencia del BB %i tiene establecido incorrectamente lp"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "al BB %i le falta un borde EH"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "Borde EH %i->%i incorrecto"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "al BB %i le falta un borde"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i demasiados bordes de respaldo"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i tiene un borde incorrecto"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i tiene un borde de respaldo incorrecto"
@@ -28623,12 +28677,12 @@ msgstr "se modificó el stmt (%p) marcado después del paso de optimización: "
 msgid "verify_ssa failed"
 msgstr "falló verify_ssa"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "código interno independiente de máquina fuera de rango"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "no está disponible la orden interna específica del objetivo"
@@ -28696,7 +28750,7 @@ msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28707,30 +28761,30 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "se definió union aquí"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "el subíndice [%E, %E] de la matriz está fuera de los límites de matriz de %qT"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "el subíndice [%E, %E] de la matriz está fuera de los límites de matriz de %qT"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "el subíndice [%E, %E] de la matriz está fuera de los límites de matriz de %qT"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "el subíndice %wi de la matriz está por debajo de los límites de matriz de %qT"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "el subíndice %wu de la matriz está por encima de los límites de matriz de %qT"
@@ -28809,32 +28863,32 @@ msgstr "revisión de árbol: acceso del operando %d de %s con %d operandos en %s
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de omp_clause %s con %d operandos en %s, en %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD es obsoleto: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD es obsoleto"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE es obsoleto: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE es obsoleto"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "el tipo es obsoleto: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "el tipo es obsoleto"
@@ -28859,272 +28913,272 @@ msgstr "el tipo es obsoleto"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "tipo variante difiere en %s"
 
-#: tree.c:13924
+#: tree.c:13935
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "tipos variantes difieren en TYPE_SIZE_UNIT"
 
-#: tree.c:13926
+#: tree.c:13937
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_SIZE_UNIT"
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT del tipo variante"
 
-#: tree.c:13928
+#: tree.c:13939
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_SIZE_UNIT"
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT del tipo"
 
-#: tree.c:13951
+#: tree.c:13962
 #, fuzzy, gcc-internal-format
 #| msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "tipo variante con TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13964
+#: tree.c:13975
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_VFIELD"
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "tipo variante con diferente TYPE_VFIELD"
 
-#: tree.c:14000
+#: tree.c:14011
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "tipo variante con diferente TYPE_BINFO"
 
-#: tree.c:14002
+#: tree.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_BINFO"
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO del tipo variante"
 
-#: tree.c:14004
+#: tree.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_BINFO"
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO del tipo"
 
-#: tree.c:14043
+#: tree.c:14054
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_FIELDS"
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "tipo variante con diferente TYPE_FIELDS"
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "el primer descuadre es campo"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr "y campo"
 
-#: tree.c:14064
+#: tree.c:14075
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TREE_TYPE"
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "tipo variante con diferente TREE_TYPE"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE del tipo variante"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, fuzzy, gcc-internal-format
 #| msgid "type's TREE_TYPE"
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE del tipo"
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "el tipo no es compatible con su variante"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "Main variant is not defined"
 msgid "main variant is not defined"
 msgstr "La variante principal no está definida"
 
-#: tree.c:14392
+#: tree.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_MAIN_VARIANT tiene diferente TYPE_MAIN_VARIANT"
 
-#: tree.c:14404
+#: tree.c:14415
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "TYPE_CANONICAL tiene diferente TYPE_CANONICAL"
 
-#: tree.c:14423
+#: tree.c:14434
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL no es compatible"
 
-#: tree.c:14431
+#: tree.c:14442
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_MODE de TYPE_CANONICAL no es compatible"
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "TYPE_VFIELD no es FIELD_DECL ni TREE_LIST"
 
-#: tree.c:14463
+#: tree.c:14474
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "TYPE_NEXT_PTR_TO no es POINTER_TYPE"
 
-#: tree.c:14473
+#: tree.c:14484
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "TYPE_NEXT_REF_TO no es REFERENCE_TYPE"
 
-#: tree.c:14494
+#: tree.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO is not TREE_BINFO"
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "TYPE_BINFO no es TREE_BINFO"
 
-#: tree.c:14500
+#: tree.c:14511
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "El tipo TYPE_BINFO no es TYPE_MAIN_VARIANT"
 
-#: tree.c:14511
+#: tree.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE no es registro ni unión"
 
-#: tree.c:14522
+#: tree.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE no es registro ni unión"
 
-#: tree.c:14540
+#: tree.c:14551
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "TYPE_ARRAY_MAX_SIZE no es INTEGER_CST"
 
-#: tree.c:14547
+#: tree.c:14558
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW no NULL"
 
-#: tree.c:14554
+#: tree.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "El campo TYPE_LANG_SLOT_1 (binfo) es no NULL"
 
-#: tree.c:14570
+#: tree.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "El valor enumerado no es CONST_DECL ni INTEGER_CST"
 
-#: tree.c:14578
+#: tree.c:14589
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "El tipo de valor enumerado no es INTEGER_TYPE ni puede convertirse al enumerado"
 
-#: tree.c:14586
+#: tree.c:14597
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value name is not IDENTIFIER_NODE"
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "El nombre de valor enumerado no es IDENTIFIER_NODE"
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "Array TYPE_DOMAIN is not integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "El array TYPE_DOMAIN no es de un tipo entero"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_FIELDS defined in incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "TYPE_FIELDS definidos en un tipo incompleto"
 
-#: tree.c:14627
+#: tree.c:14638
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Árbol incorrecto en una lista TYPE_FIELDS"
 
-#: tree.c:14642
+#: tree.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "TYPE_CACHED_VALUES_P es %i mientras que TYPE_CACHED_VALUES es %p"
 
-#: tree.c:14649
+#: tree.c:14660
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "TYPE_CACHED_VALUES no es TREE_VEC"
 
-#: tree.c:14662
+#: tree.c:14673
 #, fuzzy, gcc-internal-format
 #| msgid "wrong TYPE_CACHED_VALUES entry"
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "entrada TYPE_CACHED_VALUES incorrecta"
 
-#: tree.c:14675
+#: tree.c:14686
 #, fuzzy, gcc-internal-format
 #| msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "TREE_PURPOSE es no NULL en una lista TYPE_ARG_TYPES"
 
-#: tree.c:14681
+#: tree.c:14692
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Entrada incorrecta en una lista TYPE_ARG_TYPES"
 
-#: tree.c:14688
+#: tree.c:14699
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VALUES_RAW field is non-NULL"
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "El campo TYPE_VALUES_RAW es no NULL"
 
-#: tree.c:14700
+#: tree.c:14711
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "TYPE_CACHED_VALUES_P está activado y no debería"
 
-#: tree.c:14710
+#: tree.c:14721
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
@@ -29253,87 +29307,87 @@ msgstr "la alineación solicitada para %q+D es mayor que la alineación implemen
 msgid "storage size of %q+D isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %q+D"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "el inicializador para un valor entero/coma fija es demasiado complicado"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "el inicializador para un valor de coma flotante no es una constante de coma flotante"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "valor inicial no válido para el miembro %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD se declaró débil después de usarse"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "la declaración débil de %q+D se está aplicando a una definición estática que ya existe"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "la declaración weak de %q+D debe ser public"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "no se admite la declaración weak de %q+D"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "sólo se admiten los aliases weak en esta configuración"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref no se admite en esta configuración"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "no se admiten ifunc en este objetivo"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "gsplit-dwarf is not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "gsplit-dwarf no se admite en esta plataforma"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "la referencia débil %q+D finalmente apunta a sí misma"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "la referencia débil %q+D debe tener enlace estático"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "no se admiten las definiciones de alias en esta configuración"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s no se admite en esta configuración"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "no se admiten los atributos de visibilidad en esta configuración; descartados"
@@ -29960,7 +30014,7 @@ msgstr "atributo %qE a continuación de %qE"
 msgid "type was previously declared %qE"
 msgstr "el tipo se declaró previamente %qE"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> solo se puede especificar para funciones virtuales"
@@ -29980,7 +30034,7 @@ msgstr "%qD no es compatible con %qD"
 msgid "%qE argument is not a function"
 msgstr "el argumento %qE no es una función"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "el mensaje obsoleto no es una cadena"
@@ -30386,12 +30440,12 @@ msgstr "?: usando constantes enteras en contexto boolean"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "el compilador puede asumir que la dirección de %qD siempre se evaluará como %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "se sugieren paréntesis alrededor de la asignación usada como valor verdadero"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "uso no válido de %<restrict%>"
@@ -30550,12 +30604,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "el atributo %<fallthrough%> se especificó con un parámetro"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "faltan argumentos para la función %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -30657,7 +30711,7 @@ msgstr "el índice %E denota un desplazamiento mayor que el tamaño de %qT"
 msgid "size of array is too large"
 msgstr "el tamaño de la matriz es demasiado grande"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "el tipo %qT del operando es incompatible con el argumento %d de %qE"
@@ -30668,133 +30722,133 @@ msgstr "el tipo %qT del operando es incompatible con el argumento %d de %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "el paso del argumento %d de %qE crea un puntero desde un entero sin una conversión"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "el argumento izquierdo debe ser una rebanada"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "número incorrecto de argumentos para la función %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "el argumento 1 de %qE debe ser un tipo puntero que no sea void"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "el argumento 1 de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "el argumento 1 de %qE debe ser un puntero a un objeto de tamaño diferente de cero"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "el argumento %d de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "el argumento %d de %qE no debe ser un puntero a función"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "no coincide el tamaño en el argumento %d de %qE"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "argumento de modelo de memoria %d que no es entero de %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "argumento de modelo de memoria %d no válido de %qE"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "el valor del índice está fuera del límite"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "la conversión del escalar %qT al vector %qT implica truncado"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "el tamaño de la matriz %qE es negativo"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "el tamaño de la matriz es negativo"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "%Kargumento %i, valor %qE, supera el tamaño máximo %E del objeto"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "%K%qD: el tamaño especificado %E excede el tamaño máximo %E del objeto"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "%Kargumento %i, valor %qE, supera el tamaño máximo %E del objeto"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "size of array exceeds maximum object size %qE"
 msgstr "el límite especificado %wu supera el tamaño máximo del objeto %wu"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30850,536 +30904,536 @@ msgstr "%qE es un formato de tipo de función que no se reconoce"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "el argumento de la cadena de formato se encuentra después de los argumentos que recibirán formato"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "la función %qD puede ser un candidato para el atributo de formato %qs"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "falta el operando numérico $ en el formato"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s no admite los formatos de operando numérico %%n$"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "operando numérico fuera de rango en el formato"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "se usa más de una vez el argumento de formato %d en el formato %s"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "se usó el número de operando $ después de un formato sin número de operando"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "no se usa el argumento de formato %d antes de usar el argumento %d en el formato de estilo-$"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "el formato no es una cadena literal, no se revisó la cadena de formato"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "el formato no es una cadena literal y no tiene argumentos de formato"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "el formato no es una cadena literal, no se revisaron los tipos de argumento"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "demasiados argumentos para el formato"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "no se usaron argumentos en el formato de estilo $"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "cadena de formato %s de longitud cero"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "el formato es una cadena de carácter ancha"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string argument is not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "el argumento de la cadena de formato no es un tipo de cadena"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "constante de formato sin terminar"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "se usó %s con el formato %<%%%c%> %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s no admite %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s no admite %s con el formato %<%%%c%> %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "se repitió %s en el formato"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "falta el carácter de relleno al final del formato strfmon"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "anchura cero en el formato %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "precisión izquierda vacía en el formato %s"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "precisión vacía en el formato %s"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s no admite el modificador de longitud %qs %s"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s no admite el formato %<%%%c%> %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "se descarta %s con %s y el formato %<%%%c%> %s"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "se descarta %s con %s en el formato %s"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "uso de %s y %s junto con el formato %<%%%c%> %s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "uso de %s y %s juntos en el formato %s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> sólo produce los dos últimos dígitos del año en algunos lugares"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> sólo produce los dos últimos dígitos del año"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "no hay un %<]%> que cierre para el formato %<%%[%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "el uso del modificador de longitud %qs con el carácter de tipo %qc o no tiene ningún efecto o el comportamiento es indefinido"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s no admite el formato %<%%%s%c%> %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "se especificó un número de operandos con asignación suprimida"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "el número de operandos especificados para el formato no toma argumentos"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "se repitió %s en el formato"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "se repitió %s en el formato"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "%<\\0%> incrustado en el formato"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "unquoted attribute in format"
 msgstr "no coincide el atributo de función"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "argumento no válido para la función interna %s"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr "%<-misel=yes%> es obsoleto; utilice en su lugar %<-misel%>"
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "%<%%%> final espurio en el formato"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "inconsistent capitalization in format"
 msgstr "expresión de inicialización que no es constante en %L"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "%<%%%> final espurio en el formato"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid preprocessing directive #%s"
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr "directiva de preprocesamiento #%s no válida"
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "se repitió %s en el formato"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "se repitió %s en el formato"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "se repitió %s en el formato"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "%<%%%> final espurio en el formato"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "%<%%%> final espurio en el formato"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "Nonconforming tab character at %C"
 msgid "unquoted non-graph characters in format"
 msgstr "Carácter de tabulación que no es conforme en %C"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "undefined or invalid # directive"
 msgid "unterminated quoting directive"
 msgstr "directiva # no definida o no válida"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "se desconoce el carácter de tipo de conversión %qc en el formato"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "%<%%%> final espurio en el formato"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "la conversión carece de tipo al final del formato"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "undefined or invalid # directive"
 msgid "nested quoting directive"
 msgstr "directiva # no definida o no válida"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, fuzzy, gcc-internal-format
 #| msgid "unmatched open paren"
 msgid "unmatched quoting directive"
 msgstr "paréntesis abierto sin coincidencia"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr "directiva %qc redundante tras ocurrencia previa de la misma"
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr "directiva de reinicio de color desconocida"
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "%<\\0%> incrustado en el formato"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr "directiva de color no terminada"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "escribiendo a través de un puntero nulo (argumento %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "leyendo a través de un puntero nulo (argumento %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "escribiendo en un objeto constante (argumento %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "calificadores de tipo extra en el argumento de formato (argumento %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> espera un argumento de tipo %<%s%s%>, pero el argumento %d es de tipo %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> espera un argumento %<%s%s%> coincidente"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> espera un argumento de tipo %<%T%s%>, pero el argumento %d es de tipo %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> espera un argumento %<%T%s%> coincidente"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> no se define como un tipo"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> no se define como %<long%> o %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> no se define como un tipo"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> no se define como un tipo"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> no se define como un tipo"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> no se define como un tipo"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> no se define como un tipo puntero"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "los argumentos que recibirán formato no son %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "los formatos de strftime no pueden dar formato a los argumentos"
@@ -31546,7 +31600,7 @@ msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo no válido para la variable de iteración %qE"
@@ -31561,17 +31615,17 @@ msgstr "variable de iteración %<_Atomic%> %qE"
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador no válido"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
@@ -31581,7 +31635,7 @@ msgstr "falta la expresión de incremento"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento no válida"
@@ -32223,7 +32277,7 @@ msgid "wrong type argument to %s"
 msgstr "argumento de tipo erróneo para %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "desbordamiento en la expresión constante"
@@ -32907,7 +32961,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparación entre los tipos %qT y %qT"
@@ -32990,7 +33044,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 msgstr[1] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "esta condición tiene bifurcaciones idénticas"
@@ -33010,7 +33064,7 @@ msgstr "algunas partes de la expansión de macro no están flanqueadas por esta
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
@@ -33031,7 +33085,7 @@ msgstr "%qs no es una opción válida para el preprocesador"
 msgid "too many input files"
 msgstr "demasiados ficheros de entrada"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -33065,14 +33119,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "se pasa opción no reconocida a %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "los argumentos válidos son: %s; ¿quiso decir %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "los argumentos válidos son: %s"
@@ -33632,432 +33686,442 @@ msgstr "las definiciones de alias no se admiten en Mach-O; descartadas"
 msgid "profiler support for VxWorks"
 msgstr "soporte de análisis de perfil para VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "el %Kargumento %d debe ser un inmediato constante"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "el índice %Klane debe ser un inmediato constante"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "el tamaño %Ktotal y el tamaño de elemento han de ser un inmediato constante distinto de cero"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "el %Kargumento %d debe ser un inmediato constante"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "assembler does not support -mabi=ilp32"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "el ensamblador no tiene soporte para -mabi=ilp32"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "el %Kargumento %d debe ser un inmediato constante"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "se esperaba %qT pero el argumento es de tipo %qT"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "se esperaba %qT pero el argumento es de tipo %qT"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> no es una cadena o un número"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "basura al final de #pragma GCC coprocessor %E"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "se esperaba %<fork%> después de %qs"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the SVE ISA extension"
 msgstr "No usa las extensiones de ABI SPE."
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, fuzzy, gcc-internal-format
 #| msgid "unknown flag passed in -moverride=%s (%s)"
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "indicador pasado en -moverride=%s (%s) desconocido"
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "cadena %s mal formada\n"
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for sve_width"
 msgstr "formato no válido de %s"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %h value"
 msgid "invalid sve_width value: %d"
 msgstr "valor %h no válido"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "falta la cadena de ajuste en la opción (%s)"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "opción de cadena de ajuste desconocida (%s)"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Especifica el orden de asignación de registros"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs no es un desplazamiento válido en %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments are: %s"
 msgid "valid arguments are: %s;"
 msgstr "los argumentos válidos son: %s"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "falta el nombre de la cpu en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "modificador de característica no válido en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argumento no válido para %<-fpatchable_function_entry%>"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "falta el nombre de la arquitectura en %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "valor %qs desconocido para -march"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "modificador de característica no válido en %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "falta el nombre de la cpu en %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "valor %qs desconocido para -mtune"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "la opción -mcpu=%s genera un conflicto con la opción -march=%s"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "el ensamblador no tiene soporte para -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "modelo de código %qs con -f%s"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "valor no válido (\"%s\") en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "falta el nombre en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, fuzzy, gcc-internal-format
 #| msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, fuzzy, gcc-internal-format
 #| msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "falta el valor en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "pragma o atributo %<target()%> mal formado"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta un argumento"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta forma negada"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s=%s\")%> no es válido"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %<target%> no es una cadena"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s\")%> no es válido"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "pragma o atributo %<target(\"%s\")%> mal formado"
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, fuzzy, gcc-internal-format
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+#, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+#, fuzzy
+#| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Klane %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "vía %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d no admitido"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported return type %qT for simd"
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported return type %qT for simd"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type %qT for simd"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -34256,17 +34320,17 @@ msgstr "el argumento del atributo %qE no es \"ilink1\" o \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "el argumento del atributo %qE no es \"ilink\" o \"firq\""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -34424,13 +34488,13 @@ msgstr "salida del indicador asm %qs desconocida"
 msgid "invalid type for %<asm%> flag output"
 msgstr "tipo no válido para la salida del indicador asm"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "coprocessor not enabled"
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "el coprocesador no está activado"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
@@ -34439,200 +34503,200 @@ msgstr "el %Kargumento %d debe ser un inmediato constante"
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "el %Kargumento %d debe ser un inmediato constante"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "no se admite este interno para este objetivo"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s espera una literal entera en el rango [%d, %d]"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "%Klane index must be a constant immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "el índice %Klane debe ser un inmediato constante"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, fuzzy, gcc-internal-format
 #| msgid "You must enable VFP instructions to use these intrinsics."
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr "Debe activar las instrucciones VFP para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, fuzzy, gcc-internal-format
 #| msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr "Debe activar las instrucciones NEON (e.g. -mfloat-abi=softfp -mfpu=neon) para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Debe activar las instrucciones VFP para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, fuzzy, gcc-internal-format
 #| msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr "Debe activar las instrucciones crypto (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) para usar estos intrínsecos."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "el selector debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "el rango del selector debe estar entre 0 y 7"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "el rango del selector debe estar entre 0 y 3"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "el rango del selector debe estar entre 0 y 1"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "la máscara debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "el rango de la máscara debe estar entre 0 y 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -34642,301 +34706,301 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt y NEON son incompatibles"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "el CPU objetivo no tiene soporte para el modo ARM"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "habilitar el soporte de rastreo hacia atrás sólo tiene significado cuando se compila para el Thumb"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "habilitar el soporte de trabajo interno de llamado sólo tiene significado cuando se compila para el Thumb"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g con -mno-apcs-frame no permite una depuración sensible"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "no se puede usar -mtp=cp15 con Thumb de 16-bit"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "El PIC de RTP es incompatible con Thumb"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr "%s solo admite códico no pic en objetivos de perfil M con instrucción MOVT"
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr "%s solo admite códico no pic en objetivos de perfil M con instrucción MOVT"
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-fjni es incompatible con el -freduced-reflection"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "el CPU objetivo no admite las instrucciones THUMB"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "el CPU objetivo no admite accesos sin alinear"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check es incompatible con -mno-apcs-frame"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic y -mapcs-reent son incompatibles"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "no se admite el código reentrante APCS.  Descartado"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8, 32 o 64"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8 o 32"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "El PIC de RTP es incompatible con -msingle-pic-base"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= es inútil sin -fpic"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "no se puede usar '%s' para registro PIC"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "no se admite -freorder-blocks-and-partition en esta arquitectura"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "las opciones fp16 seleccionadas son incompatibles"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt requiere una ABI compatible con AAPCS para una operación adecuada"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "el abi iwmmxt requiere un cpu capaz de iwmmxt"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "el CPU objetivo no admite trabajo interno"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS no admite -mcaller-super-interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS no admite -mcallee-super-interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 sin ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "la CPU objetivo no admite las instrucciones de seguridad ARMv8-M"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard: el procesador seleccionado carece de FPU"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard y VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "variante PCS derivada de un no AAPCS"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "las funciones variadic debe usar la variante AAPCS base"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "variante PCS"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "ABI de VFP de coma flotante dura de Thumb-1"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "el atributo %qE no está disponible para funciones con argumentos pasados en la pila"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "el atributo %qE no está disponible para funciones con un número variable de argumentos"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "el atributo %qE no está disponible para funciones que devuelven valor en la pila"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored without -mcmse option."
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "se descarta el atributo %qE sin la opción -mcmse."
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "el atributo %qE no tiene efecto en funciones con enlazado estático"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "el atributo %qE se aplica solamente al tipo base de un puntero a función"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "no se puede calcular la ubicación real del parámetro apilado"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Fin de módulo inesperado"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "no hay registros inferiores disponibles para extraer registros superiores"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "no se pueden codificar las Rutinas de Servicios de Interrupción en el modo Thumb"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific para Thumb-1"
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
@@ -34944,22 +35008,22 @@ msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "selección automática de fpu actualmente no permitida aquí"
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "arquitectura no válida para el atributo o pragma objetivo %qs"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "atributo o pragma objetivo %qs desconocido"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -35043,17 +35107,17 @@ msgstr "no se admite -fpie"
 msgid "%<-fPIE%> is not supported"
 msgstr "no se admite -fPIE"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "los atributos de función %qs y %qs son mutuamente excluyentes"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la función %qs no puede tener argumentos"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la función %qs no puede devolver un valor"
@@ -35328,7 +35392,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "la llamada requiere ifunc, que no se admite en este objetivo"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "argumento no válido para la función interna"
@@ -35676,59 +35740,59 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "demasiados argumentos para el proceso"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "wrong type of argument %s"
 msgstr "argumento de tipo erróneo para %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "nested function trampolines not supported on this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "no se admiten trampolines de funciones anidadas para este objetivo"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "TLS is not implemented for GCN."
 msgstr "DW_LOC_OP %s no está implementado"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "VARYING bit-strings not implemented"
 msgid "Builtin not implemented"
 msgstr "no se han implementado las cadenas de bit VARYING"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "using vector_length (%d), ignoring %d"
 msgid "using vector_length (64), ignoring %d"
 msgstr "se usa vector_length (%d); se hace caso omiso de %d"
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "using vector_length (%d), ignoring runtime setting"
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr "se usa vector_length (%d); se hace caso omiso de la configuración de tiempo de ejecución"
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "se usa num_workers (%d); se hace caso omiso de %d"
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "número operando fuera de rango"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "memory exhausted"
 msgid "local data-share memory exhausted"
@@ -35879,134 +35943,134 @@ msgstr "El parámetro para la función interna debe ser una cadena constante o l
 msgid "parameter to builtin not valid: %s"
 msgstr "El parámetro para la función interna no es válido: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't be called directly"
 msgid "interrupt service routine cannot be called directly"
 msgstr "no se puede llamar directamente a la rutina de servicio de interrupciones"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 2-bit"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "el quinto argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 3-bit"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "el tercer argumento debe ser una constante de comparación"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "modo de comparación incorrecto"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "operando de redondeo incorrecto"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 4-bit"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 5-bit"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 8-bit"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE necesita la opción isa desconocida"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE necesita la opción isa %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "el último argumento debe ser un inmediato"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "el último argumento debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "el argumento delantero debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "operando de pista incorrecto"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -36417,151 +36481,151 @@ msgstr "Solo se admite el formato de depuración DWARF para la rutina de servici
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la rutina de atención de interrupciones debería tener como segundo argumento un unsigned %sint"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
@@ -37037,7 +37101,7 @@ msgstr "%qE no puede tener los atributos %qs y %qs al mismo tiempo"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE se redeclaró con los atributos %qs en conflicto"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "el atributo %qE requiere una cadena como argumento"
@@ -38187,59 +38251,59 @@ msgstr "__delay_cycles solo permite número de ciclos no negativo"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "__delay_cycles está limitado a números de bucles de 32 bits"
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown cpu %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "cpu %qs desconocida para -mtune"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv requiere -march para subsumir la extensión %<M%>"
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "la ABI solicitada requiere -march para subsumir la extensión %qc"
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI requiere -march=rv%d"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d debe estar entre %d y %d"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -38364,347 +38428,348 @@ msgstr "el número debe ser 0 ó 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "basura al final de #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "el interno %qs sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "el interno %qs solo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "el interno %qs solo acepta 1 argumento"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "la función interna %qs requiere la función interna %qs"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s no se admite en esta configuración"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinación de parámetros no válida para el intrínseco AltiVec %qs"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "Se devolvió un vector GCC por referencia: extensión de ABI no estándar sin garantía de compatibilidad"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use %qs para activarlas"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "la ABI para pasar agregados con alineación de %d bytes cambió en GCC 5"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use %qs para activarlas"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "la ABI para pasar agregados flotantes homogéneos cambió en GCC 5"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vector GCC pasado por referencia: extensión ABI que no es estándar sin garantía de compatibilidad"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "error interno: la función interna %qs ya se procesó"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "no se admite __builtin_saveregs en este subobjetivo"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "el argumento 1 debe ser un valor de un campo de 8 bits"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%Kel último argumento de %qD no es una constante entera entre 0 y 3"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "no se admite __builtin_eh_return en este objetivo"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "El argumento de ACOS en %L debe estar entre -1 y 1"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "no se admite __builtin_set_thread_pointer en este objetivo"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "no se admite __builtin_eh_return en este objetivo"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "El argumento de ACOS en %L debe estar entre -1 y 1"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "el argumento 1 debe ser un literal con signo de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 1 bit"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "el argumento 1 debe ser un literal sin signo de 6 bits"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 7 bits"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "el argumento 1 de %qs debe ser constante"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "el argumento 1 de %qs está fuera de rango"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "el interno %qs solo es válido en el modo de 64 bits"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "el argumento %d debe ser un literal sin signo"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "el argumento %d es un literal sin signo fuera de rango"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "el interno %qs solo es válido en el modo de 64 bits"
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "el interno %qs sólo acepta un argumento de cadena"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "la cpu %qs es un argumento no válido para el interno %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs es un argumento no válido para el interno %qs"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 4-bit"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "el argumento 1 debe ser 0 o 2"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "el argumento 1 debe ser un literal sin signo de 1 bit"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 6 bits"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "el argumento 2 debe ser 0 ó 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "el argumento d de debe estar dentro del rango 0..15"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "el argumento para %qs debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "sobrecarga sin resolver para el interno Altivec %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %qs must be 0..12"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "el segundo argumento de %qs debe estar en 0..12"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %qs must be 0..12"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "el tercer argumento de %qs debe estar en 0..12"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs is only valid for the cell processor"
 msgid "%qs is only valid for the cell processor"
 msgstr "la función interna %qs solo es válida para el procesador cell"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "%qs requires the %qs option"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs and %qs options"
 msgid "%qs requires the %qs and %qs options"
 msgstr "la función interna %qs requiere las opciones %qs y %qs"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "la función interna %qs requiere requiere coma flotante de 128 bits del IEEE de ISA 3.0"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "la función interna %qs requiere las opciones %qs (o más reciente), y %qs o %qs"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs is not supported with the current options"
 msgid "%qs is not supported with the current options"
 msgstr "la función interna %qs no se admite con las opciones actuales"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "error interno: la función interna %qs tiene un tipo de devolución inesperado %qs"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "error interno: función interna %qs, el argumento %d tiene el tipo de argumento inesperado %qs"
@@ -38725,224 +38790,229 @@ msgstr "%qs usa el registro r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "No se admite un marco de pila mayor de 2G con -fsplit-stack"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs requiere %qs o %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs requiere la arquitectura PowerPC64, activando"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "no se admite %qs para Darwin de 64 bits; es incompatible con las bibliotecas C y C++ instaladas"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "no se admite AltiVec en este objetivo"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "no se admite %qs en sistemas little endian"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "la opción del objetivo power9 es incompatible con %<%s=<xxx%> para <xxx> menor que power9"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs es incompatible con las opciones desactivadas explícitamente"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs requiere %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "el atributo o pragma target cambia el tamaño de double long"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires full ISA 3.0 support"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs requiere suporte pleno de ISA 3.0"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Se usa long double de precisión extendida de IEEE"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Se usa long double de precisión extendida de IBM"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs necesita soporte para VSX"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, fuzzy, gcc-internal-format
 #| msgid "The -mfloat128 option may not be fully supported"
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "Es posible que la opción -mfloat128 no funcione perfectamente"
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs requiere suporte pleno de ISA 3.0"
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "tipo de ABI de biblioteca de vectorización desconocida (%qs) para la opción %qs"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "el atributo o pragma target cambia la ABI Altivec"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "el atributo o pragma target cambia la ABI darwin64"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs no es un número válido en %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs no es un registro base válido en %qs"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs necesita un registro bae válido"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "opción desconocida para %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs está obsoleto y no está recomendada bajo ninguna circunstancia"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "la disposición de los agregados que contienen vectores con alineamiento de %d bytes cambió en GCC 5"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "no se puede tomar la dirección de una función anindada si se usa la opción %qs"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "el uso de %<long%> en tipos AltiVec no es válido para código de 64 bits sin %qs"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<long long%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<double%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "cpu %qs no válida para %s%qs%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s no es válido"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno=%s%> anula %<-m%s%>"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
@@ -39285,147 +39355,147 @@ msgstr "el atributo %qE solicitado no es una pareja de constantes enteras no neg
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "el tamaño total de las variables locales excede el límite de la arquitectura"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "el tamaño de marco de la función %qs de %wd bytes excede el límite de pila definido por el usuario de %d bytes.  Se agrega una trampa incondicional."
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "el tamaño de marco de la función %qs de %wd bytes es mayor que la mitad del tamaño de la pila. La revisión dinámica no será confiable. No se emitirá revisión para esta función."
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "el tamaño de marco de %qs es de %wd bytes"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utiliza alojamiento dinámico de pila"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "la función %<__RTL%> no se puede compilar con %<-flto%>"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "no se admite la ABI de 64-bit en el modo ESA/390"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, fuzzy, gcc-internal-format
 #| msgid "thunk-inline is only supported with -mindirect-branch-jump"
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline solo se admite con -mindirect-branch-jump"
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vector de hardware no está disponible en %s"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
 #| msgid "hardware vector support not available with -msoft-float"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "vector de hardware no está disponible con -msoft-float"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en %s"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en el modo ESA/390"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp no se puede usar en conjunción con -msoft-float"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "no se admiten -mbackchain -mpacked-stack -mhard-float en combinación"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "el tamaño de la pila debe ser mayor que el valor de la guardia de pila"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "el tamaño de la pila no debe ser mayor a 64k"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard implica el uso de -mstack-size"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "el atributo %qE solo se admite para SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "los argumentos para %qs deben ser enteros no negativos"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "el argumento para %qs es demasiado grande (máx. %d)"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-pic-data-is-text-relative cannot be used without -fpic/-fPIC"
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "-mno-pic-data-is-text-relative no puede utilizarse sin -fpic/-fPIC"
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "no se admite el valor %qs para el atributo %<target%>"
@@ -39866,8 +39936,8 @@ msgstr "el atributo %qs solamente se aplica a tipos de matriz"
 msgid "could not read the BRIG file"
 msgstr "no se puede leer el fichero BRIG"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "no se descarta el valor void como debería de ser"
@@ -40152,7 +40222,7 @@ msgstr "la declaración de %q+D oscurece a una declaración previa que no es var
 msgid "declaration of %qD shadows a parameter"
 msgstr "la declaración de %qD oscurece un parámetro"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la declaración de %qD oscurece a una declaración global"
@@ -40222,7 +40292,7 @@ msgstr "%qE no se declaró aquí (primer uso en esta función)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "cada identificador sin declarar se reporta sólo una vez para cada función en el que aparece"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "la etiqueta %qE es referenciada fuera de cualquier función"
@@ -40252,7 +40322,7 @@ msgstr "salto a una expresión de declaración"
 msgid "duplicate label declaration %qE"
 msgstr "declaración duplicada de la etiqueta %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "etiqueta %qD duplicada"
@@ -40465,7 +40535,7 @@ msgstr "no se puede poner un objeto con un campo volatile en register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "const %qD sin inicializar es no válida en C++"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D en directiva de objetivo de declaración no tiene tipo asociable"
@@ -40807,7 +40877,7 @@ msgstr "el nombre de tipo que se declaró como función devuelve una matriz"
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
@@ -41114,7 +41184,7 @@ msgstr "redefinición anidada de %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "la definición de tipo en %qs es no válida en C++"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
@@ -41164,7 +41234,7 @@ msgstr "struct no tiene miembros nombrados"
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
@@ -41200,7 +41270,7 @@ msgstr "redefinición anidada de %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeclaración de %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -41231,7 +41301,7 @@ msgstr "desbordamiento en valores de enumeración"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -41263,7 +41333,7 @@ msgstr "no hay un prototipo previo para %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
@@ -41378,12 +41448,12 @@ msgstr "el argumento %qD no coincide con el prototipo interno"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
@@ -41391,260 +41461,260 @@ msgstr "se definió el parámetro %qD pero no se usa"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "sólo se permiten las declaraciones iniciales del bucle %<for%> en modo C99 o C11"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "use la opción -std=c99, -std=gnu99, -std=c11 o -std=gnu11 para compilar su código"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable static %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de %qD que no es variable en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "calificadores de espacio de direcciones incompatibles %qs y %qs"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "especificador %qE de declaración duplicado"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 no admite %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C no admite tipos saturantes"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE duplicado"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C no admite los tipos %<__int%d%>"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "no se admite %<__int%d%> para este objetivo"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 no admite tipos booleanos"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C no admite el tipo %<_float%d%s%>"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "no se admite %<_float%d%s%> para este objetivo"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "no se admiten tipos de coma fija para este objetivo"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C no admite tipos de coma fija"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la búsqueda en C++ de %qD devolvería un campo, no un tipo"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE falla al ser un typedef o un tipo interno del compilador"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE no está al inicio de la declaración"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "se usó %qE con %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 no admite %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 no admite %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> antes de %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> antes de %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> o %<__thread%> duplicado"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "múltiples clases de almacenamiento en los especificadores de declaración"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "se usó %qs con %qE"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "se usó %<_Sat%> sin %<_Fract%> o %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "el combinador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "el nicializador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "desplazamiento a la izquierda o valor negativo"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del tipo"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del tipo"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del elemento del vector"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del elemento del vector"
@@ -41665,7 +41735,7 @@ msgstr "marcador de conflicto en control de versiones en el fichero"
 msgid "to match this %qs"
 msgstr "%J  otro tipo aquí"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -41712,7 +41782,7 @@ msgid "unknown type name %qE"
 msgstr "nombre de tipo %qE desconocido"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -41733,7 +41803,7 @@ msgstr "el atributo %<fallthrough%> no está seguido de %<;%>"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -41748,8 +41818,8 @@ msgstr "se descartan los atributos de prefijo para las implementaciones"
 msgid "unexpected attribute"
 msgstr "atributo inesperado"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "el atributo %<fallthrough%> no está seguido de %<;%>"
@@ -41787,7 +41857,7 @@ msgstr "%<__auto_type%> requiere una declaración de datos inicializados"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> sólo se puede utilizar con una declaración simple"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "se esperaba %<,%> o %<;%>"
@@ -41815,7 +41885,7 @@ msgstr "ISO C99 no admite %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 no admite %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "se esperaba una cadena literal"
@@ -41846,7 +41916,7 @@ msgstr "la expresión en la aserción static no es una constante"
 msgid "static assertion failed: %E"
 msgstr "falló la aserción estática: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -41893,14 +41963,14 @@ msgstr "un enum vacío no es válido"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "coma al final de la lista de enumeradores"
@@ -41986,7 +42056,7 @@ msgstr "se esperaban especificadores de declaración o %<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "los paquetes de parámetros deben estar al final de la lista de parámetros"
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute does not take any arguments"
@@ -41998,7 +42068,7 @@ msgstr "el atributo %qD requiere un solo argumento NTBS"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -42059,7 +42129,7 @@ msgstr "ISO C90 prohíbe mezclar declaraciones y código"
 msgid "expected %<}%> before %<else%>"
 msgstr "se esperaba %<}%> antes de %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sin un %<if%> previo"
@@ -42074,7 +42144,7 @@ msgstr "etiqueta al final de una declaración compuesta"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "se esperaba una declaración"
@@ -42099,17 +42169,17 @@ msgstr "una etiqueta sólo puede ser parte de una declaración y una declaració
 msgid "expected identifier or %<*%>"
 msgstr "se esperaba un identificador o %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<if%>"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<else%>"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "se sugieren llaves explícitas para evitar un %<else%> ambiguo"
@@ -42129,12 +42199,12 @@ msgstr "múltiples variables de iteración en una enumeración rápida"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable de iteración no válida en la enumeración rápida"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "falta la condición del bucle en bucle con pragma %<GCC ivdep%>"
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "falta la condición del bucle en bucle con pragma %<GCC unroll%>"
@@ -42150,8 +42220,8 @@ msgstr "falta la colección en la enumeración rápida"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "calificador-cv duplicado"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "first seen here"
@@ -42181,12 +42251,12 @@ msgstr "ISO C prohíbe la omisión del término medio de una expresión ?:"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la división %<sizeof (%T) / sizeof (%T)%> no computa el número de elementos del array"
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "el primer operando %<sizeof%> se declaró aquí"
@@ -42580,62 +42650,62 @@ msgstr "se esperaba una declaración método objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<getter%>)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<setter%>)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "el atributo %<setter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "el atributo %<getter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiere una expresión de asignación que evaluada dé una constante entera no negativa menor que %u"
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> debe estar en el alcance del fichero"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
@@ -42646,18 +42716,18 @@ msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for, while o do"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
@@ -42678,53 +42748,53 @@ msgstr "se esperaba %<,%> o %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable puntero"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "se esperaba %<data%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "demasiadas cláusulas %<if%> sin modificador"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si alguna cláusula %<if%> tiene modificador, entonces todas las cláusulas %<if%> tienen que usar modificador"
@@ -42746,12 +42816,12 @@ msgstr "el valor de %<num_threads%> debe ser positivo"
 msgid "%<num_tasks%> value must be positive"
 msgstr "el valor de %<num_tasks%> debe ser positivo"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "el valor de %<grainsize%> debe ser positivo"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "el valor de %<priority%> debe ser no negativo"
@@ -42762,25 +42832,25 @@ msgstr "el valor de %<priority%> debe ser no negativo"
 msgid "expected constant integer expression"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with unspecified category"
@@ -42796,55 +42866,55 @@ msgstr "la expresión %qs debe ser integral"
 msgid "%qs value must be positive"
 msgstr "el valor de %qs debe ser positivo"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "demasiados argumentos %<static%>"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argumento inesperado"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "el argumento de %<tile%> necesita una constante entera positiva"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "se esperaba %<new%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "se usaron al mismo tiempo los modificadores %<monotonic%> y %<nonmonotonic%>"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
@@ -42855,7 +42925,7 @@ msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
 msgid "chunk size value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de planificador no válido"
@@ -42894,23 +42964,23 @@ msgstr "%Hel argumento de collapse necesita ser una expresión entera constante
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "tipo de dependencia no válida"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "tipo de mapa no válida"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -42928,78 +42998,78 @@ msgstr "género de planificador no válido"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "se esperaba una cláusula %<#pragma acc%>"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs debe ser la primera cláusula de %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "no hay cláusulas válidas especificadas en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "sección de matriz en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "cláusula OpenACC no válida en el alcance del fichero"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<extern%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<global%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "La variable %qD se usa más de una vez con %<#pragma acc declare%>"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "se esperaba %<data%> después de %<#pragma acc %s%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> no tiene cláusula de movimiento de datos"
@@ -43014,7 +43084,7 @@ msgstr "%qE no se ha declarado"
 msgid "expected function name"
 msgstr "se esperaba nombre de función"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD no hace referencia a una función"
@@ -43024,73 +43094,73 @@ msgstr "%qD no hace referencia a una función"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una declaración o definición de función"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una única declaración o definición de función"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de uso"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de definición"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> debe contener al menos una cláusula %<device%>, %<host%> o %<self%>"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador no válido para %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos expresiones diferentes para la memoria"
@@ -43100,64 +43170,64 @@ msgstr "%<#pragma omp atomic capture%> usa dos expresiones diferentes para la me
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<ordered%> con un parámetro"
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<present%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "el parámetro de la cláusula %<ordered%> es menor que %<collapse%>"
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<ordered%> con un parámetro"
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
@@ -43167,74 +43237,74 @@ msgstr "se esperaba una declaración de iteración o una inicialización"
 msgid "not enough perfectly nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<fork%> después de %qs"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "se esperaba %<point%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> con map-type distinto de %<to%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> con map-type distinto de %<from%>, %<release%> y %<delete%> en la cláusula %<map%>"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
@@ -43251,67 +43321,67 @@ msgstr "%<#pragma omp declare simd%> debe ir seguida de una declaración o defin
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> debe ir seguida de una declaración o definición de función"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "se esperaba una declaración de selección"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, fuzzy, gcc-internal-format
 #| msgid "constructor not allowed for non-vector types"
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "no se permite un constructor para tipos que no sean vectores"
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> no acepta argumentos"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "se esperaba una cadena literal"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, fuzzy, gcc-internal-format
 #| msgid "property %qs already specified in %<@synthesize%>"
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "la propiedad %qs ya se especificó en %<@synthesize%>"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -43323,13 +43393,13 @@ msgstr "se esperaba %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%qs y %qs son incompatibles"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43340,33 +43410,33 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función sencilla"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "se esperaba %<target%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "se esperaba %<declare%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
@@ -43421,45 +43491,45 @@ msgstr "se esperaba nombre-de-función %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "se esperaba %<simd%>, %<reduction%> o %<target%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<pragma omp requires%> requires at least one clause"
@@ -43477,27 +43547,27 @@ msgstr "ISO C prohíbe los tipos de función calificados"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
@@ -43508,7 +43578,7 @@ msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "la llamada a la función %<transaction_may_cancel_outer%> no está en una transacción más externa o %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
@@ -43523,7 +43593,7 @@ msgstr "llave sin cerrar"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD tiene un tipo de dato incompleto %qT"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "uso no válido de la expresión void"
@@ -43648,7 +43718,7 @@ msgstr "deferenciando el puntero %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "el valor del subíndice no es ni matriz ni puntero ni vector"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "el subíndice de la matriz no es un entero"
@@ -43673,7 +43743,7 @@ msgstr "ISO C90 prohíbe el subíndice de una matriz no-lvaluada"
 msgid "enum constant defined here"
 msgstr "se definió la constante enum aquí"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sobre el parámetro matriz %qE de función devolverá el tamaño de %qT"
@@ -43788,18 +43858,18 @@ msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "faltan argumentos para la función %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "la comparación con una literal de cadena resulta en una conducta no especificada"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "comparación entre puntero y entero"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "¿pretendía desreferenciar el puntero?"
@@ -43824,7 +43894,7 @@ msgstr "se utilizó un puntero a una función en la sustracción"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmética en puntero a un agregado vacío"
@@ -44077,7 +44147,7 @@ msgstr "conversión de puntero a entero de tamaño diferente"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "conversión a puntero desde un entero de tamaño diferente"
@@ -44246,7 +44316,7 @@ msgstr "el lado izquierdo de la asignación puede ser un candidato para un atrib
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
@@ -44411,7 +44481,7 @@ msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "matriz de tipo inapropiado inicializada con una constante de cadena"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "uso no válido de matriz no-lvaluada"
@@ -44442,7 +44512,7 @@ msgstr "el elemento inicializador no es calculable al momento de la carga"
 msgid "invalid initializer"
 msgstr "inicializador no válido"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
@@ -44588,7 +44658,7 @@ msgstr "exceso de elementos en el inicializador de escalar"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C prohíbe %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
@@ -44628,7 +44698,7 @@ msgstr "no se convierte la expresión de switch %<long%> a %<int%> en ISO C"
 msgid "case label is not an integer constant expression"
 msgstr "la etiqueta de case no es una expresion constante entera"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "la etiqueta case no se encuentra dentro de una declaración switch"
@@ -44638,17 +44708,17 @@ msgstr "la etiqueta case no se encuentra dentro de una declaración switch"
 msgid "%<default%> label not within a switch statement"
 msgstr "la etiqueta %<default%> no está dentro de una declaración switch"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "la declaración continue no está dentro de un bucle"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "se usó la declaración break en un bucle for de OpenMP"
@@ -44663,7 +44733,7 @@ msgstr "la declaración break está dentro de un bucle %<#pragma simd%>"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "la declaración continue está dentro de un bucle %<#pragma simd%>"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "declaración sin efecto"
@@ -44673,22 +44743,22 @@ msgstr "declaración sin efecto"
 msgid "expression statement has incomplete type"
 msgstr "la declaración de la expresión tiene tipo de dato incompleto"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "se comparan vectores con tipos de elemento diferentes"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "se comparan vectores con números de elementos diferentes"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "no se puede encontrar un tipo entero del mismo tamaño que %qT"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -44740,7 +44810,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "comparación ordenada de puntero con un puntero nulo"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparación ordenada de puntero con el entero cero"
@@ -44770,53 +44840,53 @@ msgstr "se usa un valor de tipo union cuando se requiere un escalar"
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "se esperaba el modificador de cláusula %<parallel%> o %<target%> %<if%>"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE en cláusula %qs"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE no es un miembro de una unión"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
@@ -44827,8 +44897,8 @@ msgstr "%qE no es una variable en la cláusula %qs"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hdemasiadas cláusulas %qs"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
@@ -45015,12 +45085,12 @@ msgstr "No se encontró una definición de etiqueta para %qs"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
@@ -45045,8 +45115,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "cláusula %<linear%> paso %qE no es ni constante ni parámetro"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
@@ -45061,19 +45131,19 @@ msgstr "%qD aparece más de una vez en las cláusulas de reducción"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
@@ -45150,128 +45220,128 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "la fuente no es un puntero"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs no es un puntero ni una matriz"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la cláusula %<inbranch%> es incompatible con %<notinbranch%>"
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "el valor de la cláusula %<simdlen%> es mayor que el valor de la cláusula %<safelen%>"
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "no se puede utilizar %<va_arg%> con orden de almacenamiento inverso"
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "el segundo argumento para %<va_arg%> es del tipo incompleto %qT"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ requiere un tipo promovido, no un tipo enum, en %<va_arg%>"
@@ -45479,854 +45549,854 @@ msgid "expected case label"
 msgstr "se esperaba etiqueta"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> descarta a los calificadores"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  no hay una conversión conocida para el parámetro %<this%> implícito de %qH a %qI"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  no hay una conversión conocida para el argumento %d de %qT a %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr "  no hay una conversión de %qH a %qI"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  no hay una conversión conocida para el argumento %d de %qH a %qI"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s%<%D(%T, %T, %T)%> <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T, %T)%> <interno>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s%<%D(%T, %T)%> <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T)%> <interno>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s%<%D(%T)%> <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%<%D(%T)%> <interno>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s%qT <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s%qT <conversión>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#qD <near match>"
 msgid "%s%#qD (near match)"
 msgstr "%s%#qD <coincidencia cercana>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#qD <deleted>"
 msgid "%s%#qD (deleted)"
 msgstr "%s%#qD <borrado>"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#qD <deleted>"
 msgid "%s%#qD (reversed)"
 msgstr "%s%#qD <borrado>"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s%#qD"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr "  heredado aquí"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  el tipo de devolución %qT de la función de conversiń explícita no se puede convertir a %qT con una conversión de calificación"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr " la conversión del tipo de devolución %qT de la especialización de función de conversión de plantilla a %qT no es una coincidencia exacta"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr " la sustitución de los argumentos de plantilla deducidos resultó en errores vistos con anterioridad"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  un constructor que toma un solo argumento de su propio tipo de clase es no válido"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  un constructor interno no es un candidato para la inicialización desde una expresión del mismo tipo o derivado"
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "la conversión de %qH a %qI es ambigua"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversión de %qH a %qI en una expresión constante convertida"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "no se puede convertir %qE de %qT a %qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "la llamada del %<%D(%A)%> sobrecargado es ambigua"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "la función puntero-a-miembro %qE no se puede llamar sin un objeto; considere utilizar %<.*%> o %<->*%>"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "no hay coincidencia para la llamada a %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "la llamada de %<(%T) (%A)%> es ambigua"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "sobrecarga ambigua para "
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr "no hay coincidencia para "
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (los tipos de los operandos son %qT, %qT y %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "(los tipos de los operandos son %qT y %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr "(el tipo del operando %qT)"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "no hay coincidencia para el %<operator?:%> terniario en %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> en %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> en %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs en %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> en %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> en %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> en %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ prohíbe la omisión del término medio de una expresión ?:"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, fuzzy, gcc-internal-format
 #| msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "el tipo escalar %qT inferido no es un tipo entero ni coma flotante del mismo tamaño que %qT"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "la conversión del escalar %qH al vector %qT implica truncado"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "tipos de vector incompatibles en la expresión condicional: %qT, %qT y %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "el segundo operando del operador condicional es del tipo %<void%>, pero el tercer operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "el tercer operando del operador condicional es del tipo %<void%>, pero el segundo operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "los operandos de ?: tienen tipos diferentes %qT y %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  y cada tipo puede convertirse al otro"
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "conversión implícita de %qH a %qI para coincidir con otro resultado del condicional"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "no coincide el enumeral en la expresión condicional: %qT vs %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "tipos enumeral y no enumeral en la expresión condicional"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo, intentando en su lugar el operador prefijo"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparación entre %q#T y %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "no existe una función de desalojo correspondiente para %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "no hay un %<operator %s%> adecuado para %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "se declara aquí"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "se declara aquí"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D es inaccesible"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "se pasó NULL al argumento %P de %qD que no es puntero"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "se declara aquí"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "se convierte al tipo %qT que no es puntero desde NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "se convierte %<false%> a tipo puntero para el argumento %P de %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "se convierte %<false%> al tipo puntero %qT"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  argumento de inicialización %P de %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "demasiadas llaves alrededor del inicializador para %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid user-defined conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "conversión definida por el usuario no válida de %qT a %qT"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversión no válida de %qT a %qT"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversión a %qT desde la lista del inicializador usaría el constructor explícito %qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "no se puede unir el campo de bits %qE a %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "no se unir el campo packed %qE a %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "no se puede unir el r-valor %qE a %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "el paso de objetos de tipo no-copiable-trivialmente %q#T a través de %<...%> se admite condicionalmente"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "no se puede recibir el tipo de referencia %qT a través de %<...%>"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la recepción de objetos de tipo no-copiable-trivialmente %q#T a través de %<...%> se admite condicionalmente"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluación recursiva del argumento por defecto para %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "la llamada a %qD usa el argumento por defecto para el parámetro %P, el cual no se ha definido aún"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "el argumento de la llamada a función puede ser un candidato para un atributo de formato"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted function %q+D with default argument"
 msgid "use of multiversioned function without a default"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT no es una base inaccesible de %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "; use value-initialization instead"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Extensión: reinicialización de '%s' en %L"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "la constante se refiere a sí misma"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "no se puede convertir %qT a %qT"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  para una conversión de estilo de función, borre el %<::%D%> redundante"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "la llamada del %<%s(%A)%> sobrecargado es ambigua"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "virtual abstracto `%#D' llamado desde un constructor"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "virtual abstracto `%#D' llamado desde un destructor"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "no se puede llamar a la función miembro %qD sin un objeto"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "al pasar %qT se escoge %qT sobre %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "se escoge %qD sobre %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  porque la secuencia de conversión para el argumento es mejor"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "no coincide el argumento por defecto en la resolución de sobrecarga"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " candidato 1: %q+#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " candidato 2: %q+#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "un enlace temporal a %qD sólo persiste hasta que el constructor termina"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -46362,567 +46432,567 @@ msgstr "no se puede convertir de la base %qT al tipo derivado %qT a través de l
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "no se puede convertir de la base %qT al tipo derivado %qT a través de la base virtual %qT"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration here"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "genera un conflicto con la declaración previa aquí"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "version inherited from %qT declared here"
 msgstr "la rutina %qD se declara aquí"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %q#D"
 msgstr "declaración previa de %q+#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "especificaciones de acceso en conflicto para el método %q+D, descartado"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "especificaciones de acceso en conflicto para el campo %qE, descartado"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  debido al método local %q+#D con el mismo nombre"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "local method %q#D declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  debido al miembro local %q+#D con el mismo nombre"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT se declara aquí"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "no se puede derivar de la base %<final%> %qT al tipo derivado %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "todos las funciones miembros en la clase %qT son privadas"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T solamente define un destructor privado y no tiene friends"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T solamente define constructores privados y no tiene friends"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D es público, pero requiere que exista un objeto %q#T"
 
 # Ojo, no es impostor, sino impositor, el que impone. cfuga
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "no hay un impositor único final para %qD en %qT"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D se marca como %<override%>, pero no hace override"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "se marca %q+#D como %<final%>, pero no es virtual"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD estaba oculto"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  por %qD"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D no válido; una union anónima solo puede tener miembros con datos no estáticos públicos"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "esta flexibilidad es obsoleta y será eliminada"
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "campo de bits %q+#D con tipo no entero"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la anchura del campo de bits %q+D no es una constante entera"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "anchura negativa en el campo de bits %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "anchura cero para el campo de bits %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "la anchura de %q+D excede su tipo"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D es demasiado pequeño para contener todos los valores de %q#T"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con constructor en la union"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con destructor en la union"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en la union"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D no debe ser static porque es el miembro de una unión"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "el campo %q+D no válidamente se declara como un tipo de función"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "se descartan los atributos packed por el campo %q+#D sin empacar que no es POD"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "múltiples campos inicializados en la unión %qT"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "campo %q+#D con el mismo nombre que la clase"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T tiene miembros punteros a datos"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  pero no se impone a %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  o a %<operator=(cont %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  pero no se impone a %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "el alineamiento de %qD se ha incrementado en -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD will increase in -fabi-version=9"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "la alineación de %qD aumentará en -fabi-version=9"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "se especificó un inicializador para el método %q+D que no es virtual"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "el método anula tanto %<transaction_pure%> como los métodos %qE"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "el método declarado como %qE anula el método %qE"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "la clase envolvente de la función miembro que no es estática %<constexpr%> %q+#D no es un tipo literal"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T no es literal porque:"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE does not designate a constexpr function"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "la expresión %qE no designa una función constexpr"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T no es un agregado, no tiene un constructor trivial por defecto y no tiene un constructor %<constexpr%> que no es un constructor copy o move"
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la clase base %qT de %q+T no es literal"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la clase base %q#T tiene un destructor no virtual"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referencia %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "miembro const %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "base directa %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "base virtual %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "el desplazamiento de %q+D no cumple con la ABI y puede cambiar en una versión futura de GCC"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "uso no válido de %<...%> con algo que no es rebanada"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T tiene funciones virtuales y destructor no virtual accesible"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "type transparent class %qT does not have any fields"
 msgid "type transparent %q#T does not have any fields"
 msgstr "la clase transparente tipo %qT no tiene ningún campo"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la clase transparente tipo %qT tiene clases base"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la clase transparente tipo %qT tiene funciones virtuales"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "la definición de %qD no coincide con %<#include <initializer_list>%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "se trató de terminar struct, pero fue sacado debido a errores previos de decodificación"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "no se reconoce la cadena de lenguaje %<\"%E\"%>"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "no se puede resolver la función sobrecargada %qD basándose en la conversión al tipo %qT"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "no hay coincidencias al convertir la función %qD al tipo %q#T"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversión de la función sobrecargada %qD al tipo %q#T es ambigua"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "asumiendo el puntero a miembro %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "no hay suficiente información de tipo"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "no se puede convertir %qE desde el tipo %qT al tipo %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -47010,7 +47080,7 @@ msgstr "Avisa en las llamadas a estas funciones"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E no es una expresión constante"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
@@ -47074,7 +47144,7 @@ msgstr "Se intentó alojar una variable ya alojada"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "la declaración de %qD oscurece a una declaración local previa"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-constexpr function %qD"
 msgid "call to non-%<constexpr%> function %qD"
@@ -47136,418 +47206,417 @@ msgstr "la expresión integral %qE no es una constante"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD mutable no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "se accede al miembro %qD  en lugar del miembro inicializado %qD en la expresión constante"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "se accede al valor de %qE a través de glvalue %qT en una expresión constante"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "se declara aquí"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "uso del valor del objeto en construcción en una expresión constante"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "se usó %qD en su propio inicializador"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D no es const"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D es volatile"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD no se inicializó con una expresion constante"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast no válido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "la dirección de %qD siempre se evaluará como %<true%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD no es un tipo"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE no es de tipo puntero o matriz"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -47597,7 +47666,7 @@ msgstr "inicialización a un tipo de referencia que no es constante %q#T desde u
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversión de %qT a %qT descarta los calificadores"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "la conversión de %qT a %qT no dereferencía a los punteros"
@@ -47641,299 +47710,299 @@ msgstr "se usó %q#T donde se esperaba un valor de coma flotante"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "se solicitó la conversión desde %qT al tipo no escalar %qT"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "no se llamó al seudo-destructor"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo incompleto %qT"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "la indirección no accederá a un objeto de tipo incompleto %qT en la declaración"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo %qT"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en la declaración"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en la declaración"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "la conversión a void no accederá al objeto %qE de tipo incompleto %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el operando derecho del operador coma"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en la declaración"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en la expresión de incremento for"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "la conversión a void no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "el segundo operando de la expresión condicional no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "el tercer operando de la expresión condicional no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "el operando derecho del operador coma no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "el operador izquierdo del operador coma no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "la declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "la expresión de incremento for no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "el segundo operando de la expresión condicional es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "el tercer operando de la expresión condicional es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "el operando derecho del operador coma es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "el operando izquierdo del operador coma es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "la declaración es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "la expresión de incremento for es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "el segundo operando de la expresión condicional no tiene efecto"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "el operando derecho del operador coma no tiene efecto"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "el operando izquierdo del operador coma no tiene efecto"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "la declaración no tiene efecto"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "se convierte NULL a un tipo que no es puntero"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "conversión de tipo por defecto ambigua desde %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  las conversiones candidatas incluyen %qD y %qD"
@@ -48005,7 +48074,7 @@ msgstr "de la declaración previa de %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
@@ -48218,12 +48287,12 @@ msgstr "la declaración previa de %q+D estaba aquí"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "declaración redundante de %qD en el mismo ámbito"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD"
@@ -48237,45 +48306,45 @@ msgstr "se borró la definición de %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "'setter' attribute of property %qD conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "el atributo 'setter' de la propiedad %qD genera un conflicto con la declaración previa"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redefinición de %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD genera un conflicto con la función utilizada"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D no se declaró en la clase"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea con el atributo %<gnu_inline%>"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea sin el atributo %<gnu_inline%>"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48283,701 +48352,701 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redeclaración de friend %q#D no puede tener argumentos de plantilla por defecto"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "declaración thread-local de %q#D después de una declaración que no es thread-local"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "declaración que no es thread-local de %q#D después de una declaración thread-local"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redeclaración de %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "declaración redundante de `%s' en el mismo ámbito"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "un local previo"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  desde aquí"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sale del bloque estructurado OpenMP"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  cruza la inicialización de %q+#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  entra al ámbito de %q+#D el cual tiene un destructor que no es trivial"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  entra al bloque try"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  entra al bloque catch"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entra al bloque estructurado OpenMP"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "se esperaba una declaración"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  salta la inicialización de %q+#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  entra al ámbito de %q+#D el cual tiene un destructor que no es trivial"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "salida no válida de un bloque estructurado OpenMP"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "se usa %qD sin parámetros de plantilla"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T no es una clase"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "no hay una plantilla de clase llamada %q#T en %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la búsqueda de %qT en %qT es ambigua"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es una plantilla de clase"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es un tipo"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "no se admite -falign-labels=%d"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con constructor en un agregado anónimo"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con destructor en un agregado anónimo"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en un agregado anónimo"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "el atributo para %q#T debe estar a continuación de la palabra clave %qs"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "tipos múltiples en una declaración"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeclaración del tipo interno de C++ %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "falta el nombre del tipo en la declaración typedef"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ prohíbe structs anónimos"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sólo se puede especificar para constructores"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "se descartó %<typedef%> en esta declaración"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "se descartan los atributos aplicados al tipo de clase %qT fuera de la definición"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "se descartan los atributos aplicados al tipo dependiente %qT sin una declaración asociada"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD está inicializado (utilice decltype en su lugar)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la declaración de %q#D tiene %<extern%> y está inicializada"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la definición de %q#D se marca como %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ no permite que %<%T::%D%> se defina como %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "inicialización duplicada de %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D tiene inicializador pero de tipo de dato incompleto"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementos de la matriz %q#D con tipo de dato incompleto"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "el agregado %q#D tiene un tipo incompleto y no se puede definir"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD declarado como referencia pero no se inicializa"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "se usó un nombre en un inicializador designado de estilo GNU para una matriz"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "el nombre %qD se utiliza en un inicializador designado en estilo GNU para una matriz"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "no se admiten los inicializadores designados como no triviales"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "el inicializador no puede determinar el tamaño de %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "falta el tamaño de la matriz en %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "matriz %qD de tamaño cero"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %qD"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "el tamaño de almacenamiento de %qD no es constante"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  puede evitar esto eliminando el inicializador"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T no tiene constructor por defecto proporcionado por el usuario"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "el constructor no es proporcionado por el usuario porque está marcado explícitamente por defecto en el cuerpo de la clase"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, fuzzy, gcc-internal-format
 #| msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "y el constructor implícitamente definido no inicializa %q+#D"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipo %qT no válido como inicializador para un vector de tipo %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "el inicializador para %qT debe estar encerrado entre llaves"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "se usa %<[%E] =%> en un inicializador designado en estilo GNU para la clase %qT"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT no tiene un dato miembro que no es static llamado %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementos de la matriz %q#T tienen tipo de dato incompleto"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "literal compuesta de tamaño variable"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "el objeto escalar %qD requiere un elemento en el inicializador"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98 %qD debe ser inicializado por un constructor, no por %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "matriz %qD inicializada con una constante de cadena entre paréntesis %qE"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "inicializador no válido para el miembro static con constructor"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant in-class initialization invalid for static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(se requiere una inicialización fuera de la clase)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: invocación recursiva del constructor %qs"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "uso no válido de la función miembro (¿Olvidó el %<&%>?)"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "se oscurece la declaración de tipo previa de %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "el atributo %qE se aplica solamente a variables en almacenamiento estático"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -48985,7 +49054,7 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "se especificó %qs para el campo de estructura"
 msgstr[1] "se especificó %qs para el campo de estructura"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "only %u name provided for structured binding"
@@ -48993,195 +49062,195 @@ msgid_plural "only %u names provided for structured binding"
 msgstr[0] "inicializador no válido para la cadena de bits"
 msgstr[1] "inicializador no válido para la cadena de bits"
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "tipo no válido para la variable de iteración %qE"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de variable"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de parámetro"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de tipo"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de campo"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -49470,7 +49539,7 @@ msgstr "desbordamiento en la dimensión de la matriz"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
@@ -49649,7 +49718,7 @@ msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
 #  FIXME traducción
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
@@ -49868,878 +49937,878 @@ msgstr "se descarta el atributo"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "uso no válido de %<auto%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "calificado %<_Atomic%> el tipo de retorno de %qD"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "la función %<noreturn%> devuelve un valor que no es void"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores no válidos en el tipo de función que no es miembro"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "no se puede declarar que el parámetro %q+D sea del tipo abstracto %qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso no válido de %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto no válido"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "no se puede abrir %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es no válida para la función %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es no válida para la función %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "tipo de parámetro cualificado %<_Atomic%> %qT de %q+D"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor no válido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -50751,54 +50820,54 @@ msgstr "se refirió a %qT como un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT no válida"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
@@ -50806,43 +50875,43 @@ msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT no válido"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -50852,77 +50921,77 @@ msgstr "el tipo subyacente %<%T%> de %<%T%> debe ser un tipo integral"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -50964,7 +51033,7 @@ msgstr "no se puede borrar una función.  Solamente los punteros a objetos son a
 msgid "deleting %qT is undefined"
 msgstr "el borrado de %qT está indefinido"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "declaración plantilla de %q#D"
@@ -50974,7 +51043,7 @@ msgstr "declaración plantilla de %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "las listas de parámetro de plantilla proporcionadas no coinciden con los parámetros de plantilla de %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "se declaró el destructor %qD como una plantilla miembro"
@@ -51333,169 +51402,169 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "se usa %<typename%> fuera de la plantilla"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "sin argumentos"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los operadores de conversión explícita sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 #| msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los enums con ámbito sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los controles de anulación (override/final) sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los inicializadores de datos miembro que no son static sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las literales definidas por el usuario sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los constructores delegadores sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los constructores delegadores sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las literales definidas por el usuario sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "se utilizó el tipo incompleto %qT en un especificador de nombre anidado"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "la referencia a %<%T::%D%> es ambigua"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE; did you mean %qE?"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE; did you mean %qE?"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD no es un miembro de %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> no se ha declarado"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> no se ha declarado"
@@ -51686,359 +51755,359 @@ msgstr "inicialización por valor del tipo de referencia %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD se debe inicializar en la lista de inicialización de miembros"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D se inicializará después de"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT se inicializará después de"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  base %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  cuando se inicializó aquí"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "se dieron inicializaciones múltiples para %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "se dieron inicializaciones múltiples para la base %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "inicializaciones para múltiples miembros de %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la clase base %q#T debe ser inicializada explícitamente en la copia del constructor"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D es un dato miembro static; sólo se puede inicializar en su definición"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "inicializador sin nombre para %qT, el cual no tiene clases base"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "inicializador sin nombre para %qT, el cual usa herencia múltiple"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD es tanto una base directa como una base virtual indirecta"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "el tipo incompleto %qT no tiene al miembro %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "puntero no válido al campo de bits %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "uso no válido del dato miembro no static %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "desbordamiento entero en la expresión"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "no se permite cadenas con comillas dobles en expresiones #if"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "tipo %<void%> no válido para new"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const sin inicializar en %<new%> de %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "no se encontró un %qD adecuado en la clase %qT"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la petición para el miembro %qD es ambigua"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "inicializador entre paréntesis en la matriz new"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new no se puede aplicar a un tipo de referencia"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "el inicializador termina prematuramente"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "tamaño de matriz desconocida en delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase abstracta %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase polimórfica %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
@@ -52211,13 +52280,13 @@ msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "el miembro const %q#D que no es static, no puede usar el operador de asignación por defecto"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -52247,172 +52316,179 @@ msgstr "argumento de tipo erróneo para %s"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD debe tomar %<void%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+#| msgid "non-member function %qD cannot have cv-qualifier"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "la función que no es miembro %qD no puede tener calificador-cv"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD ya es un friend de %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot default compare union %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "no se puede crear un puntero al miembro referencia %qD"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "synthesized method %qD first required here "
 msgid "synthesized method %qD first required here"
 msgstr "se requirió primero el método sintetizado %qD aquí "
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "miembro union %q+D con %qD que no es trivial"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted constructor calls non-constexpr %q+D"
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "un constructor por defecto llama a %q+D que no es constexpr"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted constructor calls non-constexpr %q+D"
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "un constructor por defecto llama a %q+D que no es constexpr"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %q+#D is invalid"
 msgid "initializer for %q#D is invalid"
 msgstr "el inicializador para %q+#D es no válido"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted default constructor does not initialize %q+#D"
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "el constructor por defecto en efecto no inicializa %q+#D"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "el constructor por defecto en efecto no inicializa ningún dato miembro que no es static"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "un tipo de conclusión lambda tiene un constructor por defecto borrado"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "un tipo de conclusión lambda tiene un operador de asignación por copia borrado"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D se declara implícitamente como deleted porque %qT declara un constructor move o un operador de asignación move"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is implicitly deleted because the default definition would be ill-formed:"
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D es implícitamente deleted por que la definición por defecto estaría mal formada:"
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "no coincide la firma esperada %qD"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "expected signature: %qD"
 msgstr "no coincide la firma esperada %qD"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, fuzzy, gcc-internal-format
 #| msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "la función %q+D explícitamente por defecto no se puede declarar como constexpr porque la declaración implícita no es constexpr:"
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "una plantilla no se puede definir por defecto"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD no se puede definir por defecto"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "función definida por defecto %q+D con argumento por defecto"
@@ -52456,235 +52532,235 @@ msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la declaración de %q#D oscurece un parámetro"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "la declaración global %q+#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
 msgstr "genera un conflicto con la declaración previa %q+#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> nombra al destructor"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nombra al constructor en %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qE"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "using-declaration may not name namespace %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la declaración de %qD no está en un espacio de nombres alrededor de %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "calificación explícita en la declaración de %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D se declaró como friend"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD se debería declarar dentro de %qD"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "el atributo %qD no tiene signifcado porque los miembros del espacio de nombres anónimo tiene símbolos locales"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qD"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "límite máximo de %d espacios de nombres buscados para %qE"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "alternativa sugerida:"
 msgstr[1] "alternativas sugeridas:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not available for %s architecture"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%s no está disponible para la arquitectura %s"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D no se puede definir como %qE"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "se definió struct aquí"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "you can use an inline namespace instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' en %L es ambiguo"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "no se permite aquí el alias del espacio de nombres %qD, se asume que es %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "los atributos de método sólo se deben especificar al final"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entrando a pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -52711,7 +52787,7 @@ msgstr "el identificador %qE es una palabra clave en C++11"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -52737,7 +52813,7 @@ msgstr "%<::%E%> no se ha declarado"
 msgid "request for member %qE in non-class type %qT"
 msgstr "solicitud por el miembro %qE en el tipo %qT que no es clase"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> no se ha declarado"
@@ -52819,7 +52895,7 @@ msgstr "id-de-plantilla no válido"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "una literal de coma flotante no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "una conversión a un tipo diferente de un tipo integral o de enumeración no puede aparecer en una expresión constante"
@@ -52947,7 +53023,7 @@ msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu+
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
@@ -53077,7 +53153,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "no se puede encontrar un operador literal de cadena %qD con argumentos %qT, %qT"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "se esperaba una declaración"
@@ -53185,12 +53261,12 @@ msgstr "declaración de %<~%T%> como miembro de %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "se usa el nombre-de-definición-de-tipo %qD como un declarador de destructor"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD no es una plantilla"
@@ -53229,7 +53305,7 @@ msgstr "se esperaban especificadores de nombre anidados"
 msgid "expected nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "los tipos no se pueden definir en conversiones"
@@ -53245,7 +53321,7 @@ msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -53261,7 +53337,7 @@ msgstr "ISO C++ prohíbe las literales compuestas"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "uso no válido de %qD"
@@ -53286,995 +53362,1001 @@ msgstr "ISO C++ no permite %<alignof%> con algo que no es tipo"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<noexcept%>"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
 msgstr "no se pueden definir tipos en una expresión new"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+#| msgid "__builtin_thread_pointer is not supported on this target"
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "no se admite __builtin_thread_pointer en este objetivo"
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "no se pueden definir tipos en una expresión new"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "se prohíbe el límite de matriz después del id-de-tipo entre paréntesis"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Se esperaba un tipo de expresión"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "la expresión en el declarador-new debe tener un tipo integral o de enumeración"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "uso de conversión de estilo antiguo"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "el operador %<>>%> se tratará como dos en llaves en ángulo derechas en C++11"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "se sugieren paréntesis alrededor de la expresión %<>>%>"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ no permite ?: con el operando medio omitido"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, fuzzy, gcc-internal-format
 #| msgid "use of cast expressions as lvalues is deprecated"
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "el uso de expresiones de conversión como l-valores es obsoleto"
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "se esperaba el fin de la lista-de-captura"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %<this%> es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "ya se capturó %qD en la expresión lambda"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture %qE by reference"
 msgid "%<this%> cannot be captured by reference"
 msgstr "no se puede capturar %qE por referencia"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "capture of non-variable %qD "
 msgid "capture of non-variable %qE"
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
 msgstr "%q+#D se declaró aquí"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "captura de la variable %qD con duración de almacenamiento que no es automática"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %qD es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la captura por referencia explícita de %qD es redundate con la captura por referencia por defecto"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "se especificó un argumento por defecto para el parámetro lambda"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> duplicado"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "se esperaba una declaración etiquetada"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "la etiqueta case %qE no está dentro de una declaración switch"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "se necesita %<typename%> antes de %qE porque %qT es un ámbito dependiente"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nombra el constructor, no el tipo"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "el campo %qE se declaró como una función"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "no se pueden definir tipos en condiciones"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "se esperaba un inicializador"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "la expresión %<for%> basada en rango de tipo %qT es de tipo incompleto"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "<;%> extra"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label%> no está al inicio de un bloque"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "se prohíbe mezclar declaraciones y definiciones-de-función"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in range-based for loops"
 msgid "initializer in range-based %<for%> loop"
 msgstr "no se pueden definir tipos en bucles for basados en rango"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "declaraciones múltiples `%T' y `%T'"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "empty structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "se usó %<friend%> fuera de la clase"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> cambiará su significado en C++11; por favor bórrelo"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in %qT"
 msgid "%qD invalid in lambda"
 msgstr "%qD no válido en %qT"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "type-specifier invalid in lambda"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la definición de clase no se puede declarar como friend"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in an exception-specification"
 msgid "types may not be defined in explicit-specifier"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "especificación de enlace no válida"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<decltype%>"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "solamente los constructores toman inicializadores miembro"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "inicializador de clase base de estilo antiguo anacrónico"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (un inicializador de miembro calificado es implícitamente un tipo)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "falta un espacio entre %<\"\"%> y el identificador sufijo"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "se esperaba un identificador sufijo"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "se esperaba una cadena vacía después de la palabra clave %<operator%>"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operandos no válidos en la operación terniaria"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operador inesperado"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "parámetro de captura no válido"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros plantilla %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "los paquetes de parámetro de plantilla no pueden tener argumentos por defecto"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> no puede iniciar una lista de argumentos de plantilla"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> es una forma alternativa para %<[%>. Inserte espacios en blanco entre %<<%> y %<::%>"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-type template argument"
 msgid "invalid template-argument-list"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "error de decodificación en la lista de argumentos de plantilla"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "se esperaba un nombre de plantilla"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilice %<%T::template %D%> para indicar que es una plantilla"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<inline%>"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "especialización de plantilla con enlace C"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "se esperaba un specificador de tipo"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "se esperaba un id de plantilla para el tipo"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "se esperaba un nombre de tipo"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE no nombra a un tipo"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "se definió union aquí"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "se esperaba %<,%> o %<)%>"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, fuzzy, gcc-internal-format
 #| msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "el especificador de tipo elaborado para un ámbito enumerado no debe usar la palabra clave %<%D%>"
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la declaración %qD no declara nada"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "se descartan los atributos en un especificador de tipo elaborado que no es una declaración adelantada"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD es una plantilla de enumeración"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "se esperaba %<;%> o %<{%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "no se puede agregar una lista de enumerador a una instanciación de plantilla"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "la declaración de %qD en el espacio de nombres %qD el cual no incluye a %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "la declaración de %qD en %qD la cual no incluye a %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "no se permite la calificación extra"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "especificador enumerador opaco sin nombre"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "el especificador enumerador opaco debe usar un identificador simple"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qE no nombra a un tipo"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD no es un nombre-de-espacio-de-nombres"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace name required"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "El enumerador no puede tener atributos %C"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "varargs function cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "la función varargs no puede ser inline"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace %qD entered"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id-de-plantilla no puede aparecer en una declaración-using"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "las declaraciones access son obsoletas en favor de las declaraciones using: sugerencia: use la palabra clave %<using%>"
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "no se pueden definir tipos en declaraciones de plantilla alias"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT no es un espacio de nombres"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "se usó el parámetro %qD fuera del cuerpo de la función"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "una definición de función no se permite aquí"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "no se permite una especificación-asm en una definición-de-función"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "se esperaba un constructor, un destructor, o una conversión de tipo"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "se proporcionó un inicializador para la función"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "se redeclara la función %q+D como inline"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "el límite de la matriz no es una constante entera"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "no se puede definir el miembro de la definición de tipo dependiente %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> no es un tipo"
@@ -54283,461 +54365,461 @@ msgstr "%<%T::%E%> no es un tipo"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "declarador no válido"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "uso no válido del constructor como una plantilla"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "use %<%T::%D%> en lugar de %<%T::%D%> para nombrar el constructor en un nombre calificado"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "tipo no válido en la declaración"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "se esperaba un declarador"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD es un espacio de nombres"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "se esperaba un operador puntero"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource requiere -o"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "uso no válido de %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "no se pueden definir tipos en argumentos de plantilla"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "se esperaba un especificador de tipo"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "se esperaba %<,%> o %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "los argumentos por defecto sólo se permiten para parámetros de función"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros plantilla no puede tener un argumento por defecto"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ no permite inicializadores designados de C99"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "se esperaba un nombre de clase"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "se esperaba %<;%> después de la definición de struct"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "se esperaba %<{%> o %<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "no se puede especificar %<override%> para una clase"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la calificación global del nombre de clase es no válida"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "el nombre calificado no nombra una clase"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nombre de clase no válido en la declaración de %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "una especialización explícita se debe preceder con %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "no se puede resolver el tipo typename"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "definición previa de %q+#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03 se debe usar una llave-clase cuando se declara un friend"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for unnamed bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "campo de bits %qD con tipo no integral"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "especificador-pure en la definición-de-función"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "especificador pure no válido (sólo se permite %<= 0%>)"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "un inicializador dentro de llaves no se permite aquí"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "se especificó %<virtual%> más de una vez en la base especificada"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, fuzzy, gcc-internal-format
 #| msgid "more than one access specifier in base-specified"
 msgid "more than one access specifier in base-specifier"
 msgstr "más de un especificador de acceso en la base especificada"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (la clase base es implícitamente un tipo)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "las especificaciones de excepción dinámicas son obsoletas en C++0x; utilice %<noexcept%> en su lugar"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "El atributo %qE genera un conflicto con el atributo %s"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "se esperaba un identificador o %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "expression must be integral"
 msgid "expression must be enclosed in parentheses"
 msgstr "la expresión debe ser integral"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "asm template is not a string constant"
 msgid "result type is not a plain type-constraint"
 msgstr "la plantilla asm no es una cadena constante"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "la alineación solicitada no es una constante entera"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración no válida de %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -54746,575 +54828,575 @@ msgstr "faltan listas-de-parámetros-de-plantilla"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración no válida de plantilla miembro en la clase local"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita no válida"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "la declaración no declara nada"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso no válido de %qD en la especificación de enlace"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "se esperaba %<data%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "se esperaba %<@end%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as %q#D here"
 msgid "%qT first declared as %qs here"
 msgstr "  declarado inicialmente como %q#D aquí"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ no válido"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo no válido para la variable de de instancia"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo no válido para la propiedad"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "se esperaba una expresión entera"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
 #| msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, fuzzy, gcc-internal-format
 #| msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "tipo calificado const, volatile o restrict en %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD no es una función plantilla miembro"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "basura al final de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "no se permiten las conversiones estándar en este contexto"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -55608,7 +55690,7 @@ msgstr "el patrón de expansión %<%E%> no contiene paquetes de argumento"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "no se expanden los paquetes de parámetro con %<...%>"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -55637,94 +55719,94 @@ msgstr "la declaración de %q+D oscurece un parámetro"
 msgid "template parameter %qD declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "no se usan los parámetros de plantilla en la especialización parcial:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "demasiados argumentos para la función %qE"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template %qD"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qE debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qT debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "el tipo %qT del argumento de plantilla %qE depende de un parámetro de plantilla"
 msgstr[1] "el tipo %qT del argumento de plantilla %qE depende de parámetros de plantilla"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "especialización parcial de %qT después de la instanciación %qT"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "no hay un argumento por defecto para %qD"
@@ -55732,51 +55814,51 @@ msgstr "no hay un argumento por defecto para %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "el parámetro de paquete %qE debe estar al final de la lista de parámetros de plantilla"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en la re-declaración friend de la plantilla de función"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las declaraciones friend de la plantilla de función"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los argumentos de plantilla por defecto no se pueden usar en las plantillas de función sin -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las especializaciones parciales"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "template %qD declared"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "clase de plantilla sin nombre"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -55787,65 +55869,65 @@ msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "declaración de la plantilla de %qD no válida"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definición de plantilla de %q#D que no es plantilla"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "se esperaban %d niveles de parámetros de plantilla para %q#D, se obtuvieron %d"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  pero se requieren %d"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "los argumentos de plantilla para %qD no coinciden con la plantilla original %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilice template<> para una especialización explícita"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT no es un tipo plantilla"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "no se especificaron los especificadores de plantilla en la declaración de %qD"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "se redeclaró con %d parámetro de plantilla"
 msgstr[1] "se redeclaró con %d parámetros de plantilla"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -55854,138 +55936,138 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "la declaración previa de %q+#D usó %d parámetro de plantilla"
 msgstr[1] "la declaración previa de %q+#D usó %d parámetros de plantilla"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parámetro de plantilla %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "debe ser un puntero-a-miembro de la forma %<&X::Y%>"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  los tipos %qT y %qT tiene calificadores-cv incompatibles"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  no coinciden los tipos %qT y %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  el parámetro de plantilla %qD no es un paquete de parámetro, pero el argumento %qD sí"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  el argumento de plantilla %qE no coincide con la constante puntero-a-miembro %qE"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE no es equivalente a %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  se deducen tipos en conflicto para el parámetro %qT (%qT y %qT)"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  se deducen valores en conflicto para el parámetro %qE que no es tipo (%qE y %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -55994,323 +56076,323 @@ msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  no se puede convertir %qE (tipo %qT) al tipo %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT no es derivado de %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  los parámetros de plantilla de un argumento de plantilla plantilla son inconsistentes con otros argumentos de plantilla deducidos"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 #| msgid "  can't deduce a template for %qT from non-template type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  no se puede deducir una plantilla para %qT del tipo %qT que no es plantilla"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match %qD"
 msgid "  template argument %qE does not match %qE"
 msgstr "  el argumento de plantilla %qE no coincide con %qD"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qE no es una variable"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque las literales de cadena nunca se pueden usar en este contexto"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "in template argument for type %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso no válido del destructor %qE como un tipo"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es no válido"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "falla interna de consistencia"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "miembro de matriz flexible en union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a potential constant expression"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE no es una expresión constante potencial"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
@@ -56328,305 +56410,305 @@ msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT no válido"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "número erróneo de argumentos para %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -56639,149 +56721,149 @@ msgstr "especialización explícita de %qD después del primer uso"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT no es un espacio de nombres"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %qT in template argument"
@@ -57009,7 +57091,7 @@ msgstr "uso no válido de %<this%> en el nivel principal"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ámbito calificador no válido en el nombre del seudo-destructor"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificado %qT no coincide con el nombre del destructor ~%qT"
@@ -57060,7 +57142,7 @@ msgstr "especificación de clase base no válida"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
@@ -57166,7 +57248,7 @@ msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a trav
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -57209,7 +57291,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
@@ -57354,131 +57436,131 @@ msgstr "%qD aparece más de una vez en las cláusulas de datos"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "demasiadas cláusulas %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "decltype cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -57750,859 +57832,859 @@ msgstr "la conversión entre diferentes tipos de punteros-a-miembro %qT y %qT ca
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la expresión condicional entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "los tipos canónicos difieren para los tipos idénticos %T y %T"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "el mismo nodo de tipo canónico para los tipos diferentes %T y %T"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplicación no válida de %qs a una función miembro"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplicación no válida de %<sizeof%> a un campo de bits"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<sizeof%> a una expresión de tipo de función"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplicación no válida de %<__alignof%> a un campo de bits"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<__alignof%> a una expresión de tipo de función"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "se toma la dirección de la matriz temporal"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "solicitud por el miembro %qD en %qE, el cual es de tipo puntero %qT (¿ Tal vez quiso utilizar %<->%> ?)"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "solicitud por el miembro %qD en %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "uso no válido del dato miembro no static %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "acceso no válido a datos del miembro que no es static %qD  del objeto NULL"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "el tipo de objeto %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "el tipo que se destruye es %qT, pero el destructor se refiere a %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> no es un miembro de %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT no es una base de %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD no es una función plantilla miembro"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT no es de tipo puntero-a-objeto"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uso no válido del índice de matriz en puntero a miembro"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uso no válido del unario %<*%> en puntero a miembro"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uso no válido de la conversión implícita en puntero a miembro"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "se declaró el subíndice de la matriz como %<register%>"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "el valor indicado por el subíndice no es ni matriz ni puntero"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "falta un objeto en el uso de %qE"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ prohíbe la llamada %<::main%> dentro del mismo programa"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "se debe usar %<.*%> o %<->*%> en la llamada a la función puntero-a-miembro en %<%E (...)%>, p.e. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "faltan argumentos para el constructor %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "demasiados argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "faltan argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "demasiados argumentos para la función %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "faltan argumentos para la función %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "demasiados argumentos para el método %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "faltan argumentos para el método %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "demasiados argumentos para la función"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "faltan argumentos para la función"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "el parámetro %P de %qD tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "el parámetro %P tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "la dirección de %qD nunca debe ser NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "se asume la conversión al tipo %qT desde la función sobrecargada"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "se usó NULL en la aritmética"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ prohíbe la comparación entre puntero y entero"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "comparación sin orden en el argumento de coma no flotante"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operadores no válidos de tipos %qT y %qT para el binario %qO"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero de tipo %<void *%> en la sustracción"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a una función en la sustracción"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a un método en la sustracción"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "uso no válido de un puntero a un tipo incompleto en aritmética de punteros"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "se toma la dirección del constructor %qE"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "uso no válido de %qE para formar una función puntero a miembro"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  se requiere un id calificado"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "no se pueden usar paréntesis alrededor de %qE para formar una función-puntero-a-miembro"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro no estática sin calificar o entre paréntesis para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro limitada para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "se toma la dirección del temporal"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ prohíbe tomar la dirección de la función %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "no se puede crear un puntero al miembro referencia %qD"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "no se puede tomar la dirección del campo de bits %qD"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "se toma la dirección de la expresión de tipo %<id%>"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ prohíbe decrementar un enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "no se puede incrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "no se puede decrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe incrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe decrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, fuzzy, gcc-internal-format
 #| msgid "use of cast expressions as lvalues is deprecated"
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "el uso de expresiones de conversión como l-valores es obsoleto"
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "no se puede tomar la dirección de %<this%> que es una expresión r-valuada"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "se solicitó la dirección de la variable register explícita %qD"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "se solicitó la dirección de %qD, la cual se declaró como %<register%>"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "el inicializador de lista para el tipo que no es clase no debe estar entre paréntesis"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en en inicializador"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en el inicializador de memoria"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "se trata la lista de expresiones como una expresión compuesta en la conversión funcional"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "se trata la lista de expresiones como una expresión compuesta %s"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "no hay contexto para resolver el tipo de %qE"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "la conversión del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT usa el tipo local %qT"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "static_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "se convierte de %qT a %qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "la conversión de %qT a %qT pierde precisión"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "la comparación entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "la conversión de %qT a %qT incrementa la alineación requerida del tipo del destino"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ prohíbe la conversión entre puntero a función y puntero a objeto"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "conversión no válida del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "uso no válido de const_cast con tipo %qT, que no es puntero, referencia, ni un tipo puntero-a-datos-miembro"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "uso no válido de const_cast con tipo %qT, el cual es un puntero o referencia a un tipo de función"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "const_cast no válido de un valor-r de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "const_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ prohíbe la conversión a un tipo de matriz %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "conversión no válida al tipo de función %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  en la evaluación de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "se asigna a una matriz desde una lista de inicializador"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipos incompatible en la asignación de %qT a %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "se usó una matriz como inicializador"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "asignación de matriz no válida"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   en la conversión del puntero a función miembro"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "puntero a la conversión miembro a través de la base virtual %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   en la conversión del puntero a miembro"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversión no válida del tipo %qT a partir del tipo %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "no se puede convertir %qT a %qT en el argumento por defecto"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "no se puede convertir %qT a %qT en el paso de argumentos"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "no se puede convertir %qT a %qT en la devolución"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "no se puede convertir %qT a %qT en la asignación"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "el parámetro %qP de %qD puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "el parámetro puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "el objetivo de conversión puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "el objetivo de inicialización puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "al pasar el argumento %P de %q+D"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "se devolvió una referencia a la variable local %q+D"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "faltan valores en la declaración de devolución"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "se devuelve un valor de un destructor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "no se puede regresar de un manejador de una función-intenta-bloque de un constructor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "se devuelve un valor de un constructor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<lista inicializador dentro de llaves>"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "se deducen los tipos inconsistentes %qT y %qT para el tipo de devolución lambda"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> no debe regresar NULL a menos que se declare %<throw()%> (o -fcheck-new esté en efecto)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -58885,113 +58967,113 @@ msgstr "llaves alrededor del inicializador escalar"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -59232,10 +59314,10 @@ msgstr "La referencia a matriz en %C no puede tener más de %d dimensiones"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "La referencia a matriz en %C no puede tener más de %d dimensiones"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, fuzzy, gcc-internal-format
@@ -59417,7 +59499,7 @@ msgstr "Fortran 2003: Constructores de matriz de estilo [...] en %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003: Los constructores de matriz incluyen especificación de tipo en %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
@@ -59545,7 +59627,7 @@ msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "'I' en %L y 'J' en %L no pueden ser constantes literal BOZ al mismo tiempo"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -59593,7 +59675,7 @@ msgstr "Se esperaba la variable de comatriz como el argumento '%s' para el intr
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "El argumento 'a1' del intrínseco '%s' en %L debe ser INTEGER, REAL o CHARACTER"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
@@ -59611,7 +59693,7 @@ msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser REAL o COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER o PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -59755,190 +59837,190 @@ msgstr "Longitudes de caracteres desiguales (%ld/%ld) en %s en %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "Los argumentos '%s' y '%s' del intrínseco '%s' en %L deben tener el mismo tipo"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Different type kinds at %L"
 msgid "Different type kinds at %L"
 msgstr "Extensión: Diferentes tipos de géneros en %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "No se permite un puntero NULL en %L como un argumento de la función intrínseca '%s'"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser un POINTER"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser un puntero u objetivo VARIABLE o FUNCTION"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER or a TARGET"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser un POINTER o un TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "Una sección de matriz con un subíndice vector en %L no debe ser el objetivo de un puntero"
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "No se permite un puntero NULL en %L como un argumento de la función intrínseca '%s'"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "el argumento ATOM en %L para la función intrínseca %s debe ser un entero ATOMIC_INT_KIND o un lógico ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "El argumento ATOM en %L de la función intrínseca %s debe ser una comatriz o coíndice"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser del mismo tipo y género que '%s'"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "STAT= argument to %s at %L"
 msgstr "Demasiados argumentos para %s en %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "El argumento ATOM de la función intrínseca %s en %L debe ser definible"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "el argumento ATOM en %L para la función intrínseca %s debe ser un entero ATOMIC_INT_KIND o un lógico ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "El argumento VALUE de la función intrínseca %s en %L debe ser definible"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser %s"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "el argumento '%s' del intrínseco '%s' en %L no es un índice de dimensión válido"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "El argumento ATOM de la función intrínseca %s en %L debe ser definible"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "El argumento ATOM de la función intrínseca %s en %L debe ser definible"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "El argumento ATOM de la función intrínseca %s en %L debe ser definible"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Negative argument N at %L"
 msgid "Negative argument N at %L"
 msgstr "Extensión: Argumentos negativo N en %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be present if 'x' is COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe estar presente si 'x' es COMPLEX"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must have a type of either REAL or INTEGER"
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser de tipo REAL o INTEGER"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, fuzzy, gcc-internal-format
 #| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "Comatrices desactivadas en %C, use -fcoarray= para activar"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Support for entity at %L with deferred type parameter not yet implemented"
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr "Aún no se implementa el soporte para la entidad en %L con parámetro de tipo diferido"
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "OPERATOR argument at %L must be a PURE function"
@@ -59947,787 +60029,787 @@ msgstr "El argumento %s en %L debe ser de longitud uno"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic function '%s' at %L is not permitted in an initialization expression"
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "No se permite la función intrínseco '%s' en %L en una expresión de inicialización"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Fortran 2003:  Intrínseco '%s' con argumento KIND en %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "el argumento '%s' del intrínseco '%s' en %L tiene una forma no válida en la dimensión %d (%ld/%ld)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of intrinsic '%s' at %L of must have rank %d or be a scalar"
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe tener el rango %d o ser un escalar"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be numeric or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser numérico o LOGICAL"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "Formas diferentes para los argumentos '%s' y '%s' en %L para el intrínseco 'dot_product'"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser real por defecto"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser del mismo tipo y género que '%s'"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser %s"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "GNU extension: non-default INTEGER kind argument to %s intrinsic at %L"
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "Extensión de GNU: argumento de género que no es por defecto INTEGER para el intrínseco %s en %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: COMPLEX argument '%s' argument of '%s' intrinsic at %L"
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "Fortran 2008: El argumento COMPLEX '%s' argumento del intrínseco '%s' en %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "arguments 1 and 2 have different types"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "los argumentos 1 y 2 tienen tipos diferentes"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "El argumento %s en %L debe ser de longitud uno"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser del mismo género que '%s'"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "SIZE en %L debe ser positivo"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "El valor absoluto de SHIFT en %L debe ser menor o igual a SIZE en %L"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a variable"
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "'%s' en %C no es una variable"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser una constante"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "El intrínseco '%s' en %L debe tener al menos dos argumentos"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument to '%s' at %C"
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Faltan argumentos para '%s' en %C"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 #| msgid "arguments '%s' and '%s' for intrinsic %s"
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "argumentos '%s' y '%s' para el intrínseco %s"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "arguments '%s' and '%s' for intrinsic %s"
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "argumentos '%s' y '%s' para el intrínseco %s"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "El argumento 'a%d' del intrínseco '%s' en %L debe ser %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with CHARACTER argument at %L"
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "Fortran 2003: Intrínseco '%s' con argumento CHARACTER en %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 #| msgid "'a1' argument of '%s' intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "El argumento 'a1' del intrínseco '%s' en %L debe ser INTEGER, REAL o CHARACTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 #| msgid "Argument types of '%s' intrinsic at %L must match (%s/%s)"
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Los tipos de argumento del intrínseco '%s' en %L deben coincidir (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 #| msgid "Different shape on dimension 1 for arguments '%s' and '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "Formas diferentes en la dimensión 1 para los argumentos '%s' y '%s' en %L para el intrínseco matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 #| msgid "Different shape on dimension 2 for argument '%s' and dimension 1 for argument '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "Formas diferentes en la dimensión 2 para el argumento '%s' y en la dimensión 1 para el argumento '%s' en %L para el intrínseco matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser de rango 1 o 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be conformable with '%s' argument"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser conformable con el argumento '%s'"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "Los argumentos TO en MOVE_ALLOC en %L deben ser polimórficos si FROM es polimórfico"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "Los argumentos '%s' y '%s' del intrínseco '%s' en %L deben tener el mismo rango %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "Los argumentos '%s' y '%s' del intrínseco '%s' en %L deben tener el mismo rango %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "Argument 'S' of NEAREST at %L shall not be zero"
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "El argumento 'S' de NEAREST en %L no puede ser cero"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser POINTER, ALLOCATABLE o un puntero a procedimiento"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: NULL intrinsic with allocatable MOLD at %L"
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Fortran 2003: Intrínseco NULL con MOLD alojable en %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must provide at least as many elements as there are .TRUE. values in '%s' (%ld/%d)"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe proveer por lo menos tantos elementos como valores .TRUE. presentes en '%s' (%ld/%d)"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser de una variable dummy"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an OPTIONAL dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser de una variable dummy OPTIONAL"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be a subobject of '%s'"
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser un subobjeto de '%s'"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "El argumento del intrínseco RANK en %L debe ser objeto de datos"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "El argumento 'shape' del intrínseco 'reshape' en %L debe ser una matriz de tamaño constante"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is empty"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe estar vacío"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "El argumento 'shape' del intrínseco 'reshape' en %L tiene más de %d elementos"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has negative element (%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L tiene un elemento negativo (%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "El argumento complejo de LOG en %L no puede ser cero"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has wrong number of elements (%d/%d)"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L tiene el número erróneo de elementos (%d/%d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has out-of-range dimension (%d)"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "el argumento '%s' del intrínseco '%s' en %L tiene una dimensión fuera de rango (%d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has invalid permutation of dimensions (dimension '%d' duplicated)"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "el argumento '%s' del intrínseco '%s' en %L tiene una permutación no válida de dimensiones (dimensión '%d' duplicada)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Sin relleno, no hay suficientes elementos en el intrínseco RESHAPE fuente en %L para coincidir con la forma"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an extensible type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser un tipo extensible"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: SELECTED_REAL_KIND with neither 'P' nor 'R' argument at %L"
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "Fortran 2008: SELECTED_REAL_KIND sin un argumento 'P' ni 'R' en %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: '%s' intrinsic with RADIX argument at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Fortran 2008: Intrínseco '%s' con argumento RADIX en %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "El argumento 'source' del intrínseco 'shape' en %L no debe ser una matriz de tamaño asumido"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L may not be a procedure"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no puede ser un procedimiento"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "El argumento 'source' del intrínseco 'shape' en %L no debe ser una matriz de tamaño asumido"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be an interoperable data entity"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser una entidad de datos interoperables"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d of %qE must be a pointer type"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FIELD argument at %L of UNPACK must have the same rank as MASK or be a scalar"
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "El argumento FIELD en %L de UNPACK debe tener el mismo rango que MASK o ser un escalar"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L has no IMPLICIT type"
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "El resultado de la función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "El componente en %C debe tener el atributo POINTER"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument 'S' of NEAREST at %L shall not be zero"
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "El argumento 'S' de NEAREST en %L no puede ser cero"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "Array section at %L to C_LOC"
 msgstr "Sección de matriz en la llamada '%s' en %L"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "GNU extension: non double precision REAL argument to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Extensión de GNU: argumento de precisión REAL que no es doble para el intrínseco %s en %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser menor que el rango %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "el argumento '%s' del intrínseco '%s' en %L no es un índice de dimensión válido"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "El argumento %s para IMAGE_INDEX debe ser una matriz de rango uno en %L"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "El número de elementos de matriz del argumento SUB para IMAGE_INDEX en %L debe ser %d (corango) y no %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD argument to NULL required at %L"
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "se requiere el argumento MOLD para NULL en %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DIM argument without ARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "No se permite el argumento DIM sin un argumento ARRAY para el intrínseco THIS_IMAGE en %L"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Basura inesperada en la lista de argumentos formales en %C"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "El argumento 'MOLD' del intrínseco 'TRANSFER' en %L no debe ser %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "El argumento 'MOLD' del intrínseco 'TRANSFER' en %L no debe ser %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "El argumento 'MOLD' del intrínseco 'TRANSFER' en %L no debe ser %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "El TRANSFER intrínseco en %L tiene un resultado parcialmente indefinido: tamaño de la fuente %ld < tamaño del resultado %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must have the same rank as '%s' or be a scalar"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser del mismo rango que '%s' o ser un escalar"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have identical shape."
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Los argumentos '%s' y '%s' del intrínseco '%s' en %L deben tener forma idéntica."
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 #| msgid "Size of '%s' argument of '%s' intrinsic at %L too small (%i/%i)"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "El tamaño del argumento '%s' del intrínseco '%s' en %L es demasiado pequeño (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Demasiados argumentos para %s en %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser de un género que no sea más ancho que el género por defecto (%d)"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "El argumento ATOM en %L de la función intrínseca %s debe ser una comatriz o coíndice"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER o LOGICAL"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "Objetos o componentes polimórficos de tamaño asumido, tales como el que está en %C, aún no están implementados"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Se alcanzó el nivel de extensión máximo con el tipo '%s' en %L"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' of '%s' is PRIVATE at %L"
 msgid "%qs of %qs is PRIVATE at %L"
@@ -60946,303 +61028,303 @@ msgstr "Especificación INTENT errónea en %C"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: parámetro de tipo diferido en %C"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent feature: Old-style character length at %C"
 msgid "Old-style character length at %C"
 msgstr "Característica obsoleta: Longitud de carácter de estilo antiguo en %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Error sintáctico en la especificación de longitud de carácter en %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "El procedimiento '%s' en %C ya se había definido en %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "El procedimiento '%s' en %C ya se había definido en %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "El nombre '%s' en %C ya se definió como una interfaz genérica en %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "El procedimiento '%s' en %C tiene una interfaz explícita y no debe tener atributos declarados en %L"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L must have the BIND(C) attribute to be C interoperable"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "El procedimiento '%s' en %L debe tener el atributo BIND(C) para que sea interoperable con C"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a dummy argument to the BIND(C) procedure '%s' but is not C interoperable because derived type '%s' is not C interoperable"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "La variable '%s' en %L es un argumento dummy del procedimiento BIND(C) '%s' pero no es interoperable con C porque el tipo derivado '%s' no es interoperable con C"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a dummy argument to the BIND(C) procedure '%s' but is not C interoperable because it is polymorphic"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "La variable '%s' en %L es un argumento dummy del procedimiento BIND(C) '%s' pero puede no ser interoperable con C porque es polimórfica"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "La variable '%s' en %L es un parámetro del procedimiento BIND(C) '%s' pero puede no ser interoperable con C"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, fuzzy, gcc-internal-format
 #| msgid "Character argument '%s' at %L must be length 1 because procedure '%s' is BIND(C)"
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "El argumento de carácter '%s' en %L debe ser de longitud 1 porque el procedimiento '%s' es BIND(C)"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, fuzzy, gcc-internal-format
 #| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "TS29113: La variable '%s' en %L con atributo OPTIONAL en el procedimiento '%s' que es BIND(C)"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "TS29113: La variable '%s' en %L con atributo OPTIONAL en el procedimiento '%s' que es BIND(C)"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the OPTIONAL and the VALUE attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "La variable '%s' en %L no puede tener los atributos OPTIONAL y VALUE al mismo tiempo porque el procedimiento '%s' es BIND(C)"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "TS29113: La variable '%s' en %L con atributo OPTIONAL en el procedimiento '%s' que es BIND(C)"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape array '%s' at %L cannot be an argument to the procedure '%s' at %L because the procedure is BIND(C)"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "La matriz de forma asumida '%s' en %L no puede ser un argumento para el procedimiento '%s' en %L porque el procedimiento es BIND(C)"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "El símbolo '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "La variable '%s' en el bloque común '%s' en %C se debe declarar con un género interoperable con C porque el bloque común '%s' es BIND(C)"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "Longitudes de CHARACTER diferentes (%d/%d) en el constructor de matriz en %L"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "Se trunca la expresión CHARACTER en %L (%d/%d)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Los elementos CHARACTER del constructor de matriz en %L deben tener la misma longitud (%d/%d)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "No se permite un inicializador para el PARAMETER '%s' en %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Falta un inicializador para el PARAMETER en %L"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "La variable '%s' en %C con un inicializador ya aparecía en una declaración DATA"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't initialize implied-shape array at %L with scalar"
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "No se puede inicializar la matriz de tamaño implícito en %L con un escalar"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't initialize implied-shape array at %L with scalar"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "No se puede inicializar la matriz de tamaño implícito en %L con un escalar"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "El límite inferior no es constante en la declaración de forma implícita en %L"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "El componente en %C debe tener el atributo POINTER"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita o diferida"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "El componente '%s' en %C ya se había declarado en %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "El componente de matriz de puntero de la estructura en %C debe tener una forma diferida"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "El componente allocatable de la estructura en %C debe tener una forma diferida"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "una lista de parámetros con una elipsis no puede coincidir con una declaración de nombre de lista de parámetros vacía."
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "La inicialización NULL() en %C es ambigua"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "La inicialización NULL() en %C es ambigua"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de un puntero en %C en un procedimiento PURE"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Error en la inicialización de puntero en %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: non-NULL pointer initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2008: inicialización de puntero que no es NULL en %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, fuzzy, gcc-internal-format
 #| msgid "RETURN not allowed outside PROC"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "no se permite RETURN fuera de PROC"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "la función %qs no puede tener argumentos"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Carácter no válido en el nombre en %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 #| msgid "Non-PARAMETER symbol '%s' at %L can't be implied-shape"
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "El símbolo '%s' que no es PARAMETER en %L no puede ser de forma implícita"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Implied-shape array at %L"
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008: Matriz de forma implícita en %L"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Not yet implemented: LCOBOUND for coarray with non-constant cobounds at %L"
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Aún sin implementar: LCOBOUND para una comatriz con colímites que no son constantes en %L"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
@@ -61253,535 +61335,535 @@ msgstr "El dummy '%s' en %L no puede tener un inicializador"
 # como `apuntado'. cfuga
 # Referencia: http://gcc.gnu.org/onlinedocs/gfortran/Cray-pointers.html
 #
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Especificación de matriz duplicada para el apuntado Cray en %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "no se puede convertir a un tipo puntero"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Extensión: Inicialización de estilo antiguo en %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference type"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in pointer initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Error en la inicialización de puntero en %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "La inicialización en %C no es para una variable puntero"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "La inicialización de puntero en %C requiere '=>', no '='"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de una variable en %C en un procedimiento PURE"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "No se permite la inicialización del componente allocatable en %C"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of allocatable component at %C is not allowed"
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "No se permite la inicialización del componente allocatable en %C"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "El componente puntero '%s' de '%s' en %L es de un tipo que no se ha declarado"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "No se admite la declaración de tipo de estilo antiguo %s*%d en %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Declaración de tipo %s*%d no estándar en %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Falta el paréntesis derecho en %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización escalar en %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "No se admite el género %d para el tipo %s en %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "El parámetro de tipo de género C es para el tipo %s, pero el tipo en %L es %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Falta el paréntesis derecho o una coma en %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "No se admite el género %d para CHARACTER en %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "El parámetro de tipo de género para la entidad en %L difiere del parámetro de tipo de género de la especificación de tipo"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "el primer parámetro de %<operator new%> no puede tener un argumento por defecto"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "La expresión en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "La matriz '%s' en %L es una variable, lo cual no se reduce a una expresión constante"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "argumento de tipo derivado parametrizado"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Extensión: tipo BYTE en %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "El tipo BYTE usado en %C no está disponible en la máquina objetivo"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "El argumento por valor en %L no se permite en este contexto"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: TYPE with intrinsic-type-spec at %C"
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008: TYPE con especificación de tipo intrínseco en %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid type-spec at %C"
 msgid "Malformed type-spec at %C"
 msgstr "Especificación de tipo no válida en %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: DOUBLE COMPLEX at %C"
 msgid "DOUBLE COMPLEX at %C"
 msgstr "Extensión: DOUBLE COMPLEX en %C"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "El nombre de tipo '%s' en %C es ambiguo"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: CLASS statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003: Declaración CLASS en %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "El nombre de tipo '%s' en %C tiene conflictos con la entidad declarada previamente en %L, la cual tiene el mismo nombre"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Declaración IMPLICIT NONE duplicada en %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Falta el rango de carácter en IMPLICIT en %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Las letras debe estar en orden alfabético en la declaración IMPLICIT en %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "No se puede IMPORTar '%s' desde la unidad de ámbito del anfitrión en %C - no existe."
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' ya se IMPORTó desde la unidad de ámbito del anfitrión en %C."
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Error sintáctico en la declaración IMPORT en %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Falta la especificación de codimensión en %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Falta la especificación de dimensión en %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Atributo %s duplicado en %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL Iteration variable at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "La variable de iteración FORALL en %L debe ser INTEGER"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL Iteration variable at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "La variable de iteración FORALL en %L debe ser INTEGER"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "No se permite el atributo %s en %L fuera de la parte de especificación de un módulo"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS attribute at %C"
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003: Atributo ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS attribute at %C"
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008: Atributo CONTIGUOUS en %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "Sólo se permite PROTECTED en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: Atributo PROTECTED en %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: Atributo VALUE en %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: Atributo VOLATILE en %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Se proveen múltiples identificadores con un sólo especificador NAME= en %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La función implícitamente declarada BIND(C) '%s' en %L no puede ser interoperable con C"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable '%s' en el bloque común '%s' en %L no puede ser un género interoperable con C ya que el bloque común '%s' es BIND(C)"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La declaración de tipo '%s' en %L no es interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable '%s' en %L no es de un género interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable '%s' en el bloque común '%s' en %L no se puede declarar con BIND(C) porque no es un global"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "El tipo de devolución de la función BIND(C) '%s' en %L no puede ser una matriz"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
@@ -61789,1100 +61871,1100 @@ msgstr "El tipo de devolución de la función BIND(C) '%s' en %L no puede ser un
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "El símbolo '%s' en %L se marcó PRIVATE pero se le dio la etiqueta de asignación '%s'"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Se necesita una entidad o un nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Falta la entidad o el nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Falta el nombre"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "El tipo derivado en %C no se definió previamente y no puede aparecer en una definición de tipo derivado"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "MODULE PROCEDURE en %C debe estar en una interfaz genérica de módulo"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: IMPURE procedure at %C"
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008: Procedimiento IMPURE en %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "No deben aparecer PURE con IMPURE en %C"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A type parameter list is required at %C"
 msgstr "Se requiere paréntesis izquierdo después de %<*%>"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Se esperaba la etiqueta de devolución alterna en %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A parameter name is required at %C"
 msgstr "Se requiere paréntesis izquierdo después de %<*%>"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "El nombre '%s' en %C es el nombre del procedimiento"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Se esperaba otra dimensión en la declaración de matriz %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Basura inesperada en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate name '%s' in association at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Nombre '%s' duplicado en la asociación en %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Símbolo '%s' duplicado en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT en %C debe ser diferente que el nombre de la función"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Basura inesperada después de la declaración de la función en %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: El atributo BIND(C) en %L no se puede especificar para un procedimiento internal"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "El atributo BIND(C) en %C requiere una interfaz con BIND(C)"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "El procedimiento BIND(C) con NAME no debe tener atributo POINTER en %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "El procedimiento dummy en %C no puede tener atributo BIND(C) con NAME"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "El procedimiento '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Error sintáctico en la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Se esperaba '::' después de los atributos de enlazado en %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer component at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003: Procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Error sintáctico en el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE en %C debe estar en una interfaz genérica"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008: dos puntos dobles en la declaración MODULE PROCEDURE en %L"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: Declaración PROCEDURE en %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Se esperaba una lista de argumentos formales en la definición de la función en %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "El atributo BIND(C) en %L sólo se puede usar para variables o bloques comunes"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un PROGRAM"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un BLOCK DATA"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DERIVED TYPE"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque IF-THEN"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DO"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque FORALL"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque WHERE"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un subprograma contenido"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Faltan los paréntesis requeridos antes de BIND(C) en %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return cannot appear in operator interface at %L"
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "No puede aparecer una devolución alternativa en la interfaz de operador en %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nombre C no válido en el especificador NAME= en %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Error sintáctico en el especificador NAME= para la etiqueta de asignación %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Falta el paréntesis que cierra en la etiqueta de asignación en %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "No se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Para el procedimiento dummy %s, no se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "No se permite NAME en BIND(C) para ABSTRACT INTERFACE en %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: END statement instead of %s statement at %L"
 msgid "END statement instead of %s statement at %L"
 msgstr "Fortran 2008: Declaración END en lugar de una declaración %s en %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Se esperaba %s en la declaración en %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Se esperaba la declaración %s en %C"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Se esperaba el nombre de bloque de '%s' en la declaración %s en %C"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Se esperaba la etiqueta '%s' para la declaración %s en %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración DIMENSION"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Se especificarion dimensiones para %s en %L después de su inicialización"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración CODIMENSION"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La especificación de matriz se debe diferir en %L"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate POINTER attribute at %C"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Atributo POINTER duplicado en %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Carácter inesperado en la lista de variables en %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Se esperaba '(' en %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "se esperaba un nombre variable en %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "El puntero Cray en %C tiene %d bytes de precisión; las direcciones de memoria requieren %d bytes"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "no se puede convertir a un tipo puntero"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Se esperaba \")\" en %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Se esperaba \",\" o el final de la declaración en %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "No se permite INTENT dentro de BLOCK en %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "No se permite OPTIONAL dentro de BLOCK en %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "La declaración de punteros Cray en %C requiere la opción -fcray-pointer"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008: Declaración CONTIGUOUS en %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La especificación de acceso del operador %s en %C ya se había especificado"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La especificación de acceso del operador .%s. en %C ya se había especificado"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: Declaración PROTECTED en %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Se esperaba un nombre de variable en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Se esperaba un signo = en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Se esperaba una expresión en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Se inicializa una variable ya inicializada en %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caracteres inesperados en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Declaración SAVE incondicional en %C después de una declaración SAVE previa"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "No se permite VALUE dentro de BLOCK en %C"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: Declaración VALUE en %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Error sintáctico en la declaración VALUE en %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: Declaración VOLATILE en %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, fuzzy, gcc-internal-format
 #| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Se especifica VOLATILE para la variable de comatriz '%s' en %C, la cual es asociada a uso/anfitrión"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003: Declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Error sintáctico en la declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Basura después de la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE en %C debe estar en una interfaz genérica de módulo"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "El procedimiento intrínseco en %L no puede ser un MODULE PROCEDURE"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Símbolo ambiguo en la definición TYPE en %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' en la expresión EXTENDS en %C no es un tipo derivado"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' no se puede extender en %C porque es BIND(C)"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' no se puede extender en %C porque es un tipo SEQUENCE"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PRIVATE en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PUBLIC en la parte de especificación de un módulo"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "El tipo ABSTRACT '%s' se usa en %L"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Etiqueta construct '%s' duplicada en %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing structure name for outer structure definition at %0"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Falta el nombre de la estructura para la definición de la estructura externa en %0"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Se esperaba :: en la definición TYPE en %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "Mangled derived type definition at %C"
 msgstr "Fortran 2003: Bloque CONTAINS en una definición de tipo derivado en %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "El nombre de tipo derivado '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "El nombre de tipo derivado '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "El argumento dummy '%s' en %L no puede ser OPTIONAL"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "El Apuntado Cray en %C no puede ser una matriz de forma asumida"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM y ENUMERATOR en %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "El enumerador excede el tipo entero de C en %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L no se inicializó con una expresión entera"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Se esperaba una declaración de definición ENUM antes de %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Error sintáctico en la definición ENUMERATOR en %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Especificador de acceso duplicado en %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, NOPASS ilegal en %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, PASS ilegal en %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Atributo POINTER duplicado en %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE duplicado en %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED duplicado en %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Se esperaba un especificador de acceso en %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Se esperaba un atributo de enlace en %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "No pueden aparecer NON_OVERRIDABLE y DEFERRED al mismo tiempo en %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Se requiere el atributo POINTER para el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "Se esperaba ')' en %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Se debe especificar una interfaz para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) en %C se debe declarar DEFERRED"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Se esperaba un nombre de enlace en %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: PROCEDURE list at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008: Lista PROCEDURE en %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "'=> objetivo' es no válido para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "Se necesita '::' en el enlace PROCEDURE con objetivo explícito en %C"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Se esperaba un objetivo de enlace después de '=>' en %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "El tipo '%s' que contiene el enlace DEFERRED en %C no es ABSTRACT"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, fuzzy, gcc-internal-format
 #| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento con nombre de enlazado '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC en %C debe estar dentro de un tipo derivado CONTAINS"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Se esperaba '::' en %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Se esperaba un nombre genérico o un descriptor de operador en %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Forma no válida de la declaración PROGRAM en %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Se esperaba '=>' en %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento que no es genérico con el nombre de enlace '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "El enlace en %C debe tener el mismo acceso que el enlace '%s' que ya está definido"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Se esperaba un nombre de enlace específico en %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Ya se definió '%s' como un enlace específico para el genérico '%s' en %C"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Basura después del enlace GENERIC en %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La declaración FINAL en %C debe estar dentro de una sección de tipo derivado CONTAINS"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La declaración de tipo derivado con FINAL en %C debe estar en la parte de especificación de un MODULE"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vacío en %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Se esperaba un nombre de procedimiento de módulo en %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nombre de procedimiento \"%s\" desconocido en %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "¡'%s' en %C ya se había definido como un procedimiento FINAL!"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Atributo desconocido en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Error sintáctico en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Error sintáctico en el iterador FORALL en %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Error sintáctico en el iterador FORALL en %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Error sintáctico en el iterador FORALL en %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -63014,13 +63096,13 @@ msgstr "El índice en la dimensión %d está fuera de los límites en %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "LEN part_ref at %C"
 msgstr "Fortran 2003: Atributo VALUE en %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "KIND part_ref at %C"
@@ -63102,7 +63184,7 @@ msgstr "no se permite el intrínseco transformacional '%s' en %L en una expresi
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Extensión: Evaluación de una expresión de inicialización no estándar en %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -63404,7 +63486,7 @@ msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -63465,185 +63547,185 @@ msgstr "Fortran 2008: El objetivo de remapeo de rango no es rango 1 en %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "El objetivo de datos en %L no puede tener un coíndice"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %C must have the TARGET attribute"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es TARGET ni POINTER en %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Objetivo erróneo en la asignación de puntero en el procedimiento PURE en %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Asignación de puntero con subíndice vectorial del lado derecho en %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "El objetivo de asignación de puntero tiene atributo PROTECTED en %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "El objetivo de inicialización de puntero en %L no debe ser ALLOCATABLE"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %C must have the TARGET attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "El objetivo de inicialización de puntero en %L debe tener el atributo SAVE"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "El objetivo de inicialización de puntero a procedimiento en %L tal vez no es un puntero a procedimiento"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Funciones puntero en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expresión que no es variable en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "'%s' en el contexto de definición variable (%s) en %L no es una variable"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Uno que no es POINTER en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de definición de variable (%s) en %L"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable '%s' no puede aparecer en un contexto de definición variable (%s) en %L en el procedimiento PURE"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado al objetivo con índice vectorial en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "El nombre asociado '%s' no puede aparecer en un contexto de definición variable (%s) en %L porque su obtetivo en %L tampoco puede aparecer"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
@@ -63673,7 +63755,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63884,12 +63966,12 @@ msgstr "El primer argumento de la asignación definida en %L debe ser INTENT(OUT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -63966,683 +64048,683 @@ msgstr "Las interfaces '%s' y '%s' son ambiguas en %s en %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Aunque no esté referenciado, '%s' tiene interfaces ambiguas en %L"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a module procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "'%s' en %L no es un procedimiento de módulo"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (scalar and rank-%d)"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (escalar y rango %d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and scalar)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y escalar)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and rank-%d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y rango %d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (scalar and rank-%d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (escalar y rango %d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and scalar)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y escalar)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (rank-%d and rank-%d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "No coincide el rango en el argumento '%s' en %L (rango %d y rango %d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argumento de procedimiento no válido en %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to contiguous pointer dummy '%s' at %L must be simply contigous"
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "El argumento actual para el puntero dummy contiguo '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "El argumento actual INTENT(%s) en %L puede interferir con el argumento actual en %L."
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "No coincide el tipo en el argumento '%s' en %L; se pasa %s a %s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must have the same declared type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "El argumento actual para '%s' en %L debe tener el mismo tipo declarado"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 #| msgid "Corank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "No coincide el corango en el argumento '%s' en %L (%d y %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to '%s' at %L must be simply contiguous"
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "El argumento actual para '%s' en %L debe ser simplemente contiguo"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Argumento actual para el dummy que no es INTENT(OUT) '%s' en %L, el cual es LOCK_TYPE o tiene un componente LOCK_TYPE"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' has to be a pointer or assumed-shape array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "El argumento dummy '%s' tiene que ser un puntero o una matriz de tamaño asumida sin atributo CONTIGUOUS - porque el argumento actual en %L no es simplemente contiguo y ambos son ASYNCHRONOUS o VOLATILE"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument '%s'"
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Se pasa una comatriz en %L al argumento dummy INTENT(OUT) '%s', que no es comatriz, alojable"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, fuzzy, gcc-internal-format
 #| msgid "Passing coarray at %L to allocatable, noncoarray dummy argument '%s', which is invalid if the allocation status is modified"
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Se pasa una comatriz en %L al argumento dummy '%s' que no es comatriz, el cual es no válido si se modifica el estado de alojamiento"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic scalar passed to array dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Se pasó un escalar polimórfico al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Se pasó un elemento de forma asumida o puntero a matriz al argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extensión: Argumento actual CHARACTER de género diferente a C_CHAR, sin género por defecto escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argumento actual CHARACTER escalar con argumento dummy de matriz '%s' en %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "El argumento de palabra clave '%s' en %L no está en el procedimiento"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "El argumento de palabra clave '%s' en %L ya está asociado con otro argumento actual"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Más argumentos actuales que formales en la llamada a procedimento en %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Especificación de devolución alternativa inesperada en la llamada a subrutina en %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Null pointer at %L to non-pointer dummy '%s'"
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Puntero nulo en %L a un dummy '%s' que no es puntero"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy puntero o alojable '%s' en %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "No coincide la longitud de carácter (%ld/%ld) entre el argumento actual y el argumento dummy de forma asumida '%s' en %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L to allocatable or pointer dummy argument '%s' must have a deferred length type parameter if and only if the dummy has one"
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "El argumento actual en %L para el argumento alojable o dummy puntero '%s' debe tener un parámetro de tipo de longitud diferido si y sólo si el dummy tiene uno"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longitud del carácter del argumento actual es más corta que la del argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "El argumento actual contiene muy pocos elementos para el argumento dummy '%s' (%lu/%lu) en %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Se esperaba un puntero procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Falta un procedimiento para el argumento '%s' en %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "El argumento actual para '%s' no puede ser una matriz de tamaño asumido en %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy '%s'"
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: El argumento actual que no es puntero en %L para el puntero dummy '%s'"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to pointer dummy '%s'"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argumento actual coindizado en %L para el puntero dummy '%s'"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L to allocatable dummy '%s' requires INTENT(IN)"
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "El argumento actual coindizado en %L para el dummy alojable '%s' requiere INTENT(IN)"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy '%s' has neither ASYNCHRONOUS nor VOLATILE"
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "El argumento actual coindizado ASYNCHRONOUS o VOLATILE en %L requiere que el dummy '%s' no tenga ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy '%s' requires either VALUE or INTENT(IN)"
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "El argumento actual coindizado en %L con componente último alojable para el dummy '%s' requiere uno de VALUE o INTENT(IN)"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 #| msgid "Actual CLASS array argument for '%s' must be a full array at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "El argumento de la matriz CLASS actual para '%s' debe ser una matriz completa en %L"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "El argumento actual para '%s' debe ser ALLOCATABLE en %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "El argumento actual de sección de matriz con subíndices vectoriales en %L es incompatible con el atributo INTENT(OUT), INTENT(INOUT), VOLATILE o ASYNCHRONOUS del argumento dummy '%s'"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de forma asumida en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de sección de matriz en %L es incompatible con el argumento dummy de forma no asumida '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "El argumento actual de matriz de puntero en %L requiere un argumento dummy de forma asumida o matriz de puntero '%s' debido al atributo VOLATILE"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Falta la especificación de devolución alternativa en la llamada a subrutina en %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Falta el argumento actual para el argumento '%s' en %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "El mismo argumento actual está asociado con el argumento INTENT(%s) '%s' y el argumento INTENT(%s) '%s' en %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "El argumento del procedimiento en %L es local a un procedimiento PURE y tiene el atributo POINTER"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "El argumento coindizado en %L en un procedimiento PURE se pasa a un argumento INTENT(%s)"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "El argumento actual coindizado en %L es un procedimiento PURE se pasa a un argumento dummy POINTER"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument '%s'"
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "El argumento actual polimórfico coindizado en %L se pasa al argumento dummy polimórfico '%s'"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "El procedimiento '%s' que se llama en %L no tiene una interfaz explícita"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto puntero '%s' en %L debe tener una interfaz de función explícita o declrararse como matriz"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, fuzzy, gcc-internal-format
 #| msgid "The allocatable object '%s' at %L must have an explicit function interface or be declared as array"
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "El objeto allocatable '%s' en %L debe tener una interfaz de función explícita o declararse como matriz"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable function '%s' at %L must have an explicit function interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La función allocatable '%s' en %L debe tener una interfaz de función explícita"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "El argumento actual de LOCK_TYPE o con componente LOCK_TYPE en %L requiere una interfaz explícita para el procedimiento '%s'"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "se requiere el argumento MOLD para NULL en %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento '%s' en %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Se llamó al procedimiento de componente puntero '%s' con una interfaz implícita en %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "El argumento de palabra clave requiere una interfaz explícita para el procedimiento de componente puntero '%s' en %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "Se require MOLD= en un argumento NULL en %L: Ambigüedad entre las funciones específicas %s y %s "
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D es un alias del símbolo sin definir %qE"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "La entidad '%s' en %C ya está presente en la interfaz"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - too many interface type"
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "error interno - demasiados tipos de interfaz"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "No se puede sobreescribir el GENERIC '%s' en %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' en %L sobreescribe un enlace de procedimiento declarad como NON_OVERRIDABLE"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "'%s' en %L no debe ser DEFERRED porque sobreescribe un enlazado que no es DEFERRED"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' en %L sobreescribe un procedimiento PURE y también debe ser PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' en %L sobreescribe un procedimiento ELEMENTAL y también debe ser ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' en %L sobreeescribe un procedimiento que no es ELEMENTAL y tampoco debe ser ELEMENTAL"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' en %L sobreescribe una SUBROUTINE y también debe ser una SUBROUTINE"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' en %L sobreescribe una FUNCTION y también debe ser una FUNCTION"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' en %L sobreescribe un procedimiento PUBLIC y no debe ser PRIVATE"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "El argumento dummy '%s' de '%s' en %L se debe llamar '%s' para que coincida con el argumento correspondiente al procedimiento sobreescrito"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento '%s' que sobreescribe en %L: %s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' en %L debe tener el mismo nombre de argumentos formales que el procedimiento sobreeescrito"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' en %L sobreescribe un enlace NOPASS y también debe ser NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' en %L sobreescribe un enlace con PASS y también debe ser PASS"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "El argumento dummy del objeto pasado de '%s' en %L debe estar en la misma posición que el argumento dummy del objeto pasado del procedimiento sobreescrito"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "La etiqueta %s en %L debe ser de tipo %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "El argumento %s en %L debe ser de longitud uno"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued %s '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "La función %s valuada con carácter '%s' en %L no debe tener longitud asumida"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "No se permite la declaración DATA en %C en un procedimiento PURE"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL procedure '%s' at %L must have an explicit interface"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "El procedimiento ELEMENTAL '%s' en %L debe tener una interfaz explícita"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to procedure `%s'"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "faltan argumentos para el procedimiento `%s'"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to procedure `%s'"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -64763,83 +64845,83 @@ msgstr "No se permite ALTERNATE RETURN en %L"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "No coincide el tipo en el argumento '%s' en %L; se pasa %s a %s"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments for intrinsic `%A' at %0"
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "Demasiados argumentos para el intrínseco `%A' en %0"
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "init_arglist(): too many arguments"
 msgstr "demasiados argumentos"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid reference to intrinsic `%A' at %0"
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "Referencia no válida al intrínseco `%A' en %0"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' (is %s) is used at %L"
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "El intrínseco '%s' (es %s) se usa en %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Function '%s' as initialization expression at %L"
 msgid "Function %qs as initialization expression at %L"
 msgstr "Fortran 2003: La función '%s' como una expresión de inicialización en %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 #| msgid "transformational intrinsic '%s' at %L is not permitted in an initialization expression"
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "no se permite el intrínseco transformacional '%s' en %L en una expresión de inicialización"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003: Función elemental como expresión de inicialización con argumentos que no son enteros/carácter en %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque DO CONCURRENT en %L no es PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "La llamada de subrutina al intrínseco '%s' en %L no es PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Extensión: Conversión de %s a %s en %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Conversión de %s a %s en %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Posible cambio de valor en la conversión de %s a %s en %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Conversión de %s a %s en %L"
@@ -64847,25 +64929,25 @@ msgstr "Conversión de %s a %s en %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "No se puede convertir %s a %s en %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "No se puede convertir %s a %s en %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "'%s' declarado en %L puede oscurecer al intrínseco del mismo nombre. Para llamar al intrínsico, tal vez se requieran declaraciones INTRINSIC explícitas."
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
@@ -65255,13 +65337,13 @@ msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite ASYNCHRONOUS= en %C en Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite BLANK= en %C en Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -65273,7 +65355,7 @@ msgstr "Fortran 2003: no se permite DECIMAL= en %C en Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite ENCODING= en %C en Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -65323,7 +65405,7 @@ msgstr "La declaración CLOSE en %L requiere un número UNIT"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "El número UNIT en la declaración CLOSE en %L debe ser no negativo"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración %s en el procedimiento PURE en %C"
@@ -65426,7 +65508,7 @@ msgstr "NAMELIST '%s' en la declaración READ en %L contiene el símbolo '%s' el
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -65498,7 +65580,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Se esperaba una expresión en la declaración %s en %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Error sintáctico en la declaración %s en %C"
@@ -65515,89 +65597,89 @@ msgstr "Fortran 2003: Fichero interno en %L con lista de nombres"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "La unidad e/s en la declaración %s en %C debe ser un fichero interno en un procedimiento PURE"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite PAD= en %C en Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite DELIM= en %C en Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "La lista de nombres PRINT en %C es una extensión"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "No se permite la etiqueta END en %C en la declaración de salida"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Se esperaba una coma en la lista E/S en %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "No se permite la declaración PRINT en %C dentro un procedimiento PURE"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "No se permite la declaración INQUIRE en el procedimiento PURE en %C"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "La etiqueta IOLENGHT es no válida en la declaración INQUIRE en %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "La declaración INQUIRE en %L no puede contener especificadores FILE y UNIT al mismo tiempo"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "La declaración INQUIRE en %L requiere un especificador FILE o UNIT"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "El número UNIT en la declaración en %L debe ser no negativo"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "La declaración INQUIRE en %L requiere un especificador PENDING= con el especificador ID="
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite WAIT en %C en Fortran 95"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración WAIT en un procedimiento PURE en %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -65869,558 +65951,558 @@ msgstr "Basura después de la declaración ASSOCIATE en %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "El tipo derivado '%s' en %L no debe ser ABSTRACT"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Especificación de tipo no válida en %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Error sintáctico en el iterador FORALL en %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: DO CONCURRENT construct at %C"
 msgid "DO CONCURRENT construct at %C"
 msgstr "Fortran 2008: Constructor DO CONCURRENT en %C"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is unknown"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Se desconoce el nombre '%s' en la declaración %s en %C"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a construct name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "El nombre '%s' en la declaración %s en %C no es un nombre de constructor"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "La declaración %s en %C deja una construcción CRITICAL"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "La declaración %s en %C deja una construcción DO CONCURRENT"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "La declaración %s en %C no está dentro de una construcción"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within construct '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "La declaración %s en %C no está dentro de la construcción '%s'"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 #| msgid "CYCLE statement at %C is not applicable to non-loop construct '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "La declaración CYCLE en %C no se aplica a la construcción '%s' que no es bucle"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: EXIT statement with no do-construct-name at %C"
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Fortran 2008: Declaración EXIT sin nombre de constructor do en %C"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not applicable to construct '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "La declaración %s en %C no se aplica a la construcción '%s'"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "La declaración %s en %C deja un bloque estructurado OpenMP"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "La declaración %s en %C deja un bloque estructurado OpenMP"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "La declaración EXIT en %C termina el bucle !$OMP DO"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "La declaración CYCLE en %C para el bucle !$OMP DO colapsado que no es el más interno"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "La declaración CYCLE en %C para el bucle !$OMP DO colapsado que no es el más interno"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "La declaración EXIT en %C termina el bucle !$OMP DO"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "La declaración CYCLE en %C para el bucle !$OMP DO colapsado que no es el más interno"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "se requiere un l-valor en la declaración asm"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "STOP code at %C cannot be negative"
 msgstr "La especificación de forma en %L no puede ser negativa"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Image control statement %s at %C in PURE procedure"
 msgid "%s statement at %C in PURE procedure"
 msgstr "Declaración de control de imagen %s en %C en un procedimiento PURE"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "Declaración de control de imagen STOP en %C en el bloque CRITICAL"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen STOP en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "El código STOP en %L debe ser de tipo INTEGER o CHARACTER"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "El código STOP en %L debe ser un carácter por defecto KIND=%d"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "El código STOP en %L debe ser un entero por defecto KIND=%d"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Declaración CASE inesperada en %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: ERROR STOP statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "Fortran 2008: Declaración ERROR STOP en %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Image control statement %s at %C in PURE procedure"
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "Declaración de control de imagen %s en %C en un procedimiento PURE"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Image control statement %s at %C in CRITICAL block"
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "Declaración de control de imagen %s en %C en el bloque CRITICAL"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen %s en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant STAT tag found at %L "
 msgid "Redundant STAT tag found at %L"
 msgstr "Se encontró una etiqueta STAT redundante en %L "
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant ERRMSG tag found at %L "
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "Se encontró una etiqueta ERRMSG redundante en %L "
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant STAT tag found at %L "
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "Se encontró una etiqueta STAT redundante en %L "
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT POST statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT WAIT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "FAIL IMAGE statement at %C"
 msgstr "Fortran 2003: Declaración VALUE en %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "FORM TEAM statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: CLASS statement at %C"
 msgid "CHANGE TEAM statement at %C"
 msgstr "Fortran 2003: Declaración CLASS en %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "END TEAM statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: SYNC statement at %C"
 msgid "SYNC TEAM statement at %C"
 msgstr "Fortran 2008: Declaración SYNC en %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Declaración de control de imagen %s en %C en un procedimiento PURE"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Declaración de control de imagen %s en %C en el bloque CRITICAL"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen %s en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "Se encontró una etiqueta ACQUIRED_LOCK redundante en %L "
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: LOCK statement at %C"
 msgid "LOCK statement at %C"
 msgstr "Fortran 2008: Declaración LOCK en %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: UNLOCK statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "Fortran 2008: Declaración UNLOCK en %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Declaración de control de imagen SYNC en %C en un procedimiento PURE"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: SYNC statement at %C"
 msgid "SYNC statement at %C"
 msgstr "Fortran 2008: Declaración SYNC en %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "Declaración de control de imagen SYNC en %C en un bloque CRITICAL"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen SYNC en %C en un bloque DO CONCURRENT"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Característica eliminada: declaración ASSIGN en %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Característica eliminada: declaración GOTO asignada en %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "La lista de etiquetas de declaración en GOTO en %C no puede estar vacía"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent feature: Computed GOTO at %C"
 msgid "Computed GOTO at %C"
 msgstr "Característica obsoleta: GOTO computado en %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Error en la especificación de tipo en %L"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: typespec in ALLOCATE at %L"
 msgid "typespec in ALLOCATE at %L"
 msgstr "Fortran 2003: Especificación de tipo en ALLOCATE en %L"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "Declaración %s inesperada en %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Objeto de alojamiento erróneo en %C para un procedimiento PURE"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal allocate-object at %C for a PURE procedure"
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "Objeto de alojamiento ilegal en %C para un procedimiento PURE"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE de comatriz en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE de comatriz en %C en el bloque CRITICAL"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocate-object at %L is not a nonprocedure pointer or an allocatable variable"
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "El objeto de alojamiento en %L no es un puntero que no es procedimiento o una variable de alojamiento"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la especificación de tipo"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "El parámetro de tipo de género para la entidad en %L difiere del parámetro de tipo de género de la especificación de tipo"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Especificación de forma para el escalar asignable en %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "STAT tag at %L cannot be a constant"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ERRMSG tag at %L"
 msgid "ERRMSG tag at %L"
 msgstr "Fortran 2003: Etiqueta ERRMSG en %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: SOURCE tag at %L"
 msgid "SOURCE tag at %L"
 msgstr "Fortran 2003: Etiqueta SOURCE en %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant SOURCE tag found at %L "
 msgid "Redundant SOURCE tag found at %L"
 msgstr "Se encontró una etiqueta SOURCE redundante en %L "
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "La etiqueta SOURCE en %L tiene conflictos con la especificación de tipo en %L"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: SOURCE tag at %L with more than a single allocate object"
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "Fortran 2008: Etiqueta SOURCE en %L con más de un objeto de alojamiento sencillo"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: MOLD tag at %L"
 msgid "MOLD tag at %L"
 msgstr "Fortran 2008: Etiqueta MOLD en %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant MOLD tag found at %L "
 msgid "Redundant MOLD tag found at %L"
 msgstr "Se encontró una etiqueta MOLD redundante en %L "
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la especificación de tipo en %L"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "El objeto de alojamiento en %L con un parámetro de tipo diferido requiere una especificación de tipo o una etiqueta SOURCE o una etiqueta MOLD"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "El objeto de alojamiento en %L con un parámetro de tipo diferido requiere una especificación de tipo o una etiqueta SOURCE o una etiqueta MOLD"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Objeto de alojamiento ilegal en %C para un procedimiento PURE"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE de comatriz en %C en el bloque DO CONCURRENT"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE de comatriz en %C en el bloque CRITICAL"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocate-object at %C is not a nonprocedure pointer or an allocatable variable"
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "El objeto de alojamiento en %C no es un puntero que no es procedimiento o una variable de alojamiento"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ERRMSG at %L"
 msgid "ERRMSG at %L"
 msgstr "Fortran 2003: ERRMSG en %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "Declaración de control de imagen RETURN en %C en un bloque CRITICAL"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "Declaración de control de imagen RETURN en %C en un bloque DO CRITICAL"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "La declaración RETURN alternativa en %C sólo se permite dentro de una SUBROUTINE"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Extensión: declaración RETURN en el programa principal en %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Se esperaba una referencia de componente en %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Basura después de CALL en %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Se esperaba un procedimiento enlazado a tipo o un procedimiento de componente puntero en %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Error sintáctico en el nombre de bloque común en %C"
@@ -66428,241 +66510,241 @@ msgstr "Error sintáctico en el nombre de bloque común en %C"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "La variable '%s' en %L en el bloque común '%s' en %C se debe declarar con género interoperable con C porque el bloque común '%s' es bind(c)"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "La variable '%s' en el bloque común '%s' en %C no puede ser bind(c) porque no es global"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "El símbolo '%s' en %C ya está en un bloque COMMON"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "El símbolo inicializado '%s' en %C sólo puede ser COMMON en BLOCK DATA"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "La especificación de matriz para el símbolo '%s' en COMMON en %C debe ser explícita"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "El símbolo '%s' en COMMON en %C no puede ser una matriz POINTER"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "El símbolo '%s', en el bloque COMMON '%s' en %C está siendo indirectamente equivalente a otro bloque COMMON '%s'"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "BLOCK DATA construct at %L"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "El nombre de grupo de lista de nombres '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "El nombre de grupo de lista de nombres '%s' en %C ya está asociado con USE y no se puede reespecificar."
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %C"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "El componente de tipo derivado %C no es un miembro EQUIVALENCE permitido"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "La referencia a matriz en EQUIVALENCE en %C no puede ser una sección de matriz"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "El EQUIVALENCE en %C requiere dos o más objetos"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Se intentó sobreescribir indirectamente los bloques COMMON %s y %s con EQUIVALENCE en %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Se esperaba una coma en EQUIVALENCE en %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "EQUIVALENCE statement at %C"
 msgstr "Fortran 2003: Declaración VALUE en %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "La función de declaración en %L es recursiva"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "La función de declaración '%s' en %L no se permite como un argumento actual"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In statement function"
 msgid "Statement function at %C"
 msgstr "En la declaración de la función"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be scalar"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Se esperaba la inicialización de la expresión en CASE en %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name '%s' of SELECT construct at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Se esperaba el nombre de bloque '%s' de la construcción SELECT en %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un subprograma contenido"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "El selector en SELECT TYPE en %C no es una variable nombrada; use nombre-asociado =>"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: LOCK statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "Fortran 2008: Declaración LOCK en %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Declaración CASE inesperada en %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Error sintáctico en la especificación CASE en %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Declaración TYPE IS inesperada en %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Error sintáctico en la especificación TYPE IS en %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Error sintáctico en la especificación CLASS IS en %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Error sintáctico en la especificación CASE en %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "La declaración ELSEWHERE en %C no está dentro de un bloque WHERE"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -66706,12 +66788,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -67454,8 +67536,8 @@ msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
@@ -68998,195 +69080,195 @@ msgstr "Carácter inesperado en la lista de variables en %C"
 msgid "Expected structure component name at %C"
 msgstr "Se esperaba un nombre de componente de estructura en %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Se esperaba una lista de argumentos en %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "El parámetro KIND de %s en %L debe ser una expresión de inicialización"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "El componente de procedimiento puntero '%s' requiere una lista de argumentos en %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forming reference to reference type %qT"
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Componente de procedimiento puntero con coíndice en %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of references"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "se crea la matriz de referencias"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Structure constructor with missing optional arguments at %C"
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Fortran 2003: Constructor de estructura con argumentos opcionales faltantes en %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 #| msgid "No initializer for component '%s' given in the structure constructor at %C!"
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "¡No existe un inicializador dado para el componente '%s' en el constructor de estructura en %C!"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "No initializer for component '%s' given in the structure constructor at %C!"
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "¡No existe un inicializador dado para el componente '%s' en el constructor de estructura en %C!"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 #| msgid "Can't construct ABSTRACT type '%s' at %L"
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "No se puede construir el tipo ABSTRACT '%s' en %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Structure constructor with named arguments at %C"
 msgid "Structure constructor with named arguments at %C"
 msgstr "Fortran 2003: Constructor de estructura con argumentos nombrados en %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component initializer without name after component named %s at %L!"
 msgid "Component initializer without name after component named %s at %L"
 msgstr "¡Inicializador de componente sin nombre después del componente nombrado %s en %L!"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many components in structure constructor at %L!"
 msgid "Too many components in structure constructor at %L"
 msgstr "¡Demasiados componentes en el constructor de estructura en %L!"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' is initialized twice in the structure constructor at %L!"
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "¡El componente '%s' se inicializa dos veces en el constructor de estructura en %L!"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "Coindexed expression to pointer component '%s' in structure constructor at %L!"
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "¡Expresión con coíndice en el componente puntero '%s' en el constructor de estructura en %L!"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "component '%s' at %L has already been set by a parent derived type constructor"
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "El componente '%s' en %L ya se había definido por un constructor padre de tipo derivado"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "'%s' en %C es el nombre de una función recursiva y por lo tanto se refiere a la variable de resultado. Use una variable RESULT explícita para recursión directa (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "El símbolo en %C no es apropiado para una expresión"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected use of subroutine name '%s' at %C"
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Uso inesperado del nombre de subrutina '%s' en %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs requires argument list at %C"
 msgstr "La función de declaración '%s' requiere una lista de argumentos en %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Function %qs requires an argument list at %C"
 msgstr "La función '%s' requiere una lista de argumentos en %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument to '%s' at %C"
 msgid "Missing argument to %qs at %C"
 msgstr "Faltan argumentos para '%s' en %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Missing argument list in function %qs at %C"
 msgstr "Faltan la lista de argumentos en la función '%s' en %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "El nombre '%s' no se puede usar como un operador definido en %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "La constante nombrada en %C en un EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a variable"
 msgid "%qs at %C is not a variable"
@@ -69572,544 +69654,544 @@ msgstr "'%s' en %L es ambiguo"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento GENERIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 #| msgid "Type specified for intrinsic function '%s' at %L is ignored"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Se descarta el tipo para la función intrínseca '%s' en %L"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "La subrutina intrínseca '%s' en %L no debe tener un especificador de tipo"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared INTRINSIC at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "No existe '%s' declarado como INTRINSIC en %L"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "The intrinsic '%s' declared INTRINSIC at %L is not available in the current standard settings but %s.  Use an appropriate -std=* option or enable -fall-intrinsics in order to use it."
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "El intrínseco '%s' declarado como INTRINSIC en %L no está disponible en la configuración actual de estándares pero %s.  Use una opción -std=* apropiada o active -fall-intrinsics para poder usarlo."
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, fuzzy, gcc-internal-format
 #| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Internal procedure '%s' is used as actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Fortran 2008: Se usa el procedimiento interno '%s' como un argumento actual en %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "La función de declaración '%s' en %L no se permite como un argumento actual"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "El intrínseco '%s' en %L no se permite como un argumento actual"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Internal procedure '%s' is used as actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Fortran 2008: Se usa el procedimiento interno '%s' como un argumento actual en %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento ELEMENTAL que no es INTRINSIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "No se puede encontrar un procedimiento INTRINSIC específico para la referencia '%s' en %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "El símbolo '%s' en %L es ambiguo"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "El argumento por valor en %L no es de tipo numérico"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "El argumento por valor en %L no puede ser una matriz o una sección de matriz"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "El argumento por valor en %L no se permite en este contexto"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "No se permite el paso del procedimiento interno en %L por ubicación"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "El procedimiento ELEMENTAL que no es INTRINSIC '%s' no se permite como un argumento actual en %L"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Argumento actual coindizado en %L con componente puntero último"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "'%s' en %L es una matriz y OPTIONAL; SI FALTA, no puede ser el argumento actual de un procedimiento ELEMENTAL a menos que exista un argumento que no sea opcional con el mismo rango (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "El argumento actual en %L para el dummy INTENT(%s) '%s' de la subrutina ELEMENTAL '%s' es un escalar, pero otro argumento actual es una matriz"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 #| msgid "Return type mismatch of function '%s' at %L (%s/%s)"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "No coincide el tiop de devolución de la función '%s' en %L (%s/%s)"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "La interfaz no coincide en el procedimiento dummy '%s' en %L: %s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "No hay una función específica para el genérico '%s' en %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "La función genérica '%s' en %L no es consistente con una interfaz intrínseca específica"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La función '%s' en %L es INTRINSIC pero no es compatible con un intrínseco"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "No se puede resolver la función específica '%s' en %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un FORALL %s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a DO CONCURRENT %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un DO CONCURRENT %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "La referencia a la función '%s' que no es PURE en %L está dentro de un FORALL %s"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after NOWAIT clause at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Basura inesperada después de la cláusula NOWAIT en %C"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "La ABSTRACT INTERFACE '%s' no se debe referenciar en %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "La función '%s' se declara CHARACTER(*) y no se puede usar en %L ya que no es un argumento de prueba"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "La función definida por el usuario '%s' que no es ELEMENTAL en %L no se permite en la construcción WORKSHARE"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY '%s' en %L no se puede llamar recursivamente, porque la función '%s' no es RECURSIVE"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "La función '%s' en %L no se puede llamar recursivamente, porque no es RECURSIVE"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque FORALL en %L no es PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en el bloque DO CONCURRENT en %L no es PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "La llamada a subrutina a '%s' en %L no es PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "No hay una subrutina específica para el genérico '%s' en %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "La subrutina genérica '%s' en %L no es consistente con una interfaz de subrutina intrínseca"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La subrutina '%s' en %L es INTRINSIC pero no es compatible con un intrínseco"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "No se puede resolver la subrutina específica '%s' en %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' en %L tiene un tipo, el cual no es consistente con CALL en %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY '%s' en %L no se puede llamar recursivamente, porque la subrutina '%s' no es RECURSIVE"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE '%s' en %L no se puede llamar recursivamente, porque no es RECURSIVE"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Las formas para los operandos en %L y %L no son conformables"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "always_inline function might not be inlinable"
 msgid "Impure function at %L might not be evaluated"
 msgstr "una función always_inline tal vez no se puede incluir en línea"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "El argumento por valor en %L no puede ser una matriz o una sección de matriz"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tranco ilegal de cero en %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "No se especificó el límite superior a la derecha de la sección de matriz de tamaño asumido en %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango de coíndice no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "El coíndice en la codimensión %d debe ser un escalar en %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "El índice de matriz en %L debe ser escalar"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "El índice de matriz en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Extensión: índice de matriz REAL en %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "El argumento dim en %L debe ser escalar"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "El índice de matriz en %L es una matriz de rango %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "El índice de inicio de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "El índice de inicio de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "El índice de inicio de la subcadena en %L es menor a uno"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "El índice de final de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "El índice de final de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "El índice de final de la subcadena en %L excede la longitud de la cadena"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "El índice de final de la subcadena en %L es demasiado grande"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo POINTER en %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo ALLOCATABLE en %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "No se deben especificar dos o más referencias de parte con rango que no es cero en %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -70119,12 +70201,12 @@ msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -70134,301 +70216,301 @@ msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' at %L with BIND(C) attribute must have an explicit interface"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "El procedimiento '%s' en %L con atributo BIND(C) debe tener una interfaz explícita"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s', usada en una expresión de especificación, se referencía en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s' se usa en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Subobjecto polimórfico de un objeto coindizado en %L"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Error en la especificación de tipo en %L"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -70437,303 +70519,303 @@ msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "El nombre '%s' no se puede usar como un operador definido en %C"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -70741,196 +70823,197 @@ msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la et
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero."
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -70938,7 +71021,7 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -70947,66 +71030,66 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: SAVE implícito para la variable de módulo '%s' en %L, se necesita por la inicialización por defecto"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -71014,1031 +71097,1031 @@ msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "El argumento de ICHAR en %L debe ser de longitud uno"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Especificaciones de control de E/S en conflicto en %0 y %1"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Longitudes de carácter diferentes en la asignación de puntero en %L"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -72771,175 +72854,175 @@ msgstr "'%s' en %L tiene atributos especificados fuera de su cuerpo INTERFACE"
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "El símbolo '%s' en %L genera conflictos con el símbolo del módulo '%s' asociado a uso en %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "El símbolo '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "El procedimiento '%s' en %L no puede tener el tipo básico de %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "El símbolo '%s' en %L no puede tener un tipo"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "El componente '%s' en %C ya estaba en el tipo padre en %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "El símbolo '%s' en %C es ambiguo"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "El tipo derivado '%s' en %C se está usando antes de ser definido"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "El componente '%s' en %C es un componente PRIVATE de '%s'"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Declaración de etiqueta %d duplicada en %L y %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "La etiqueta %d en %C ya se referenció como objetivo de ramificación"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "La etiqueta %d en %C ya se referenció como etiqueta de formato"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "La etiqueta %d en %C se utilizó previamente como una etiqueta FORMAT"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "La etiqueta %d en %C se utilizó previamente como objetivo de ramificación"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: LOCK statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Fortran 2008: Declaración LOCK en %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' del módulo '%s'"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' de la unidad de programa actual"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "El tipo derivado '%s' declarado en %L debe tener el atributo BIND para ser interoperable con C"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "El tipo derivado '%s' con atributo BIND(C) en %L está vacío, y puede ser inaccesible para el procesador acompañante de C"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo POINTER porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "El procedimiento de componente puntero '%s' en %L no puede ser un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo ALLOCATABLE porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C, aún cuando el tipo derivado '%s' es BIND(C)"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "El tipo derivado '%s' en %L no puede tener el atributo SEQUENCE porque es BIND(C)"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -72980,94 +73063,94 @@ msgstr "Se sobreescriben los inicializadores desiguales en EQUIVALENCE en %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Se crea una matriz temporal en %L para el argumento '%s'"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipo de expresión errónea durante la caminata (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "El bloque COMMON nombrado '%s' en %L debe ser del mismo tamaño como en elsewhere (%lu vs %lu bytes)"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "la posición solicitada no es una constante entera"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Tipo de referencia ilegal en %L como un objeto EQUIVALENCE"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Reglas de equivalencia inconsistentes que involucran a '%s' en %L y a '%s' en %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, fuzzy, gcc-internal-format
 #| msgid "The equivalence set for variable '%s' declared at %L violates alignment requirements"
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "El conjunto de equivalencia para la variable '%s' declarado en %L viola los requerimientos de alineación"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "Equivalence for '%s' does not match ordering of COMMON '%s' at %L"
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "La equivalencia para '%s' no coincide con el orden del COMMON '%s' en %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, fuzzy, gcc-internal-format
 #| msgid "The equivalence set for '%s' cause an invalid extension to COMMON '%s' at %L"
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "El conjunto de equivalencia para '%s' causa una extensión no válida al COMMON '%s' en %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L; reorder elements or use -fno-align-commons"
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Se requiere el relleno de %d bytes antes de '%s' en el COMMON '%s' en %L; reordene los elementos o use -fno-align-commons"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON at %L; reorder elements or use -fno-align-commons"
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Se requiere el relleno de %d bytes antes de '%s' en COMMON en %L; reordene los elementos o use -fno-align-commons"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L does not exist"
 msgid "COMMON %qs at %L does not exist"
 msgstr "El COMMON '%s' en %L no existe"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L requires %d bytes of padding; reorder elements or use -fno-align-commons"
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "El COMMON '%s' en %L requiere %d bytes de relleno; reordene los elementos o use -fno-align-commons"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON at %L requires %d bytes of padding; reorder elements or use -fno-align-commons"
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
@@ -73088,83 +73171,83 @@ msgstr "expresión de inicialización que no es constante en %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variable intrínseca que no es un procedimiento"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return value of function %qs at %L not set"
 msgstr "No se define el valor de devolución de la función '%s' en %L"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Aún no se admite un parámetro de tipo diferido"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "ya existe la declaración del extremo trasero para la variable de módulo %s"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Se declaró la variable '%s' sin uso en %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "El argumento dummy '%s' en %L se declaró INTENT(OUT) pero no se estableció"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type dummy argument '%s' at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "El argumento dummy de tipo derivado '%s' en %L se declaró INTENT(OUT) pero no se estableció y no tiene un inicializador por defecto"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "Unused dummy argument '%s' at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argumento dummy sin uso '%s' en %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 #| msgid "Unused module variable '%s' which has been explicitly imported at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Variable de módulo '%s' sin uso la cual se importó explícitamente en %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Se declaró la variable '%s' sin uso en %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Se declaró el parámetro '%s' sin uso en %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' which has been explicitly imported at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Parámetro '%s' sin uso el cual se importó explícitamente en %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "Return value '%s' of function '%s' declared at %L not set"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "No se define el valor de devolución '%s' de la función '%s' declarada en %L"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -73180,29 +73263,29 @@ msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Operador intrínseco desconocido"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Lista de argumentos de función desconocida en %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -73242,25 +73325,25 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr "Tipo base ES erróneo (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "implicit mapping of assumed size array %qD"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "optional argument"
 msgid "optional class parameter"
 msgstr "argumento opcional"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "unhandled derived-type component"
 msgstr "argumento de tipo derivado parametrizado"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Código de declaración erróneo"
@@ -73386,86 +73469,86 @@ msgstr "no coinciden los argumentos"
 msgid "unable to open file"
 msgstr "no se puede abrir el fichero '%s'"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "flujo de bytecode: basura al final de la sección de símbolos"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "no se puede decodificar el número hexadecimal"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "nombre de fichero inesperado %s en el fichero de resolución de enlace. Se esperaba %s"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "no se puede abrir el fichero de desplazamiento"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "desplazamiento inesperado"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "línea no válida en el fichero de resolución"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "resolución no válida en el fichero de resolución"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "resolution sub id %x not in object file"
 msgid "resolution sub id %wx not in object file"
 msgstr "el sub id de resolución %x no está en el fichero objeto"
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, fuzzy, gcc-internal-format
 #| msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "flujo de bytecode en el fichero %qs generado con LTO versión %d.%d en lugar de la versión esperada %d.%d"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "cannot read LTO decls from %s"
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "no se pueden leer las decls LTO de %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "No se puede abrir %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "No se puede mapear %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "No se puede leer %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "no se puede abrir el fichero de resolución de símbolos: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "errores durante la mezcla de unidades de traducción"
@@ -74625,7 +74708,7 @@ msgstr "falta el nombre de macro después de %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "falta un nombre de fichero después de %qs"
@@ -74829,17 +74912,17 @@ msgstr "algoritmo %qs de reordenación de bloque básico desconocido"
 msgid "unknown TLS model %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "modelo %qs de coste de vectorizador desconocido"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "no se reconoce el valor de visibilidad %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "prioridad %qs de inicialización de verificación de vtable desconocida."
@@ -74847,12 +74930,22 @@ msgstr "prioridad %qs de inicialización de verificación de vtable desconocida.
 #~ msgid "Same as %s.  Use the latter option instead."
 #~ msgstr "Igual que %s.  Utilice, en cambio, la última opción."
 
+#, fuzzy
+#~| msgid "Warn about variables which are initialized to themselves."
+#~ msgid "Warn about code paths in which an initialized value is used."
+#~ msgstr "Avisa sobre variables que se inicialicen ellas mismas."
+
 #~ msgid "-msim   Use simulator runtime."
 #~ msgstr "-msim   Usa el simulador de tiempo de ejecución."
 
 #~ msgid "-mlong-double-[64,128]\tSpecify size of long double."
 #~ msgstr "-mlong-double-[64,128]\tEspecifica el tamaño de long double."
 
+#, fuzzy
+#~| msgid "BMX instructions are only supported with R2 architecture"
+#~ msgid "Use instructions for a future architecture."
+#~ msgstr "las instrucciones BMX solo se admiten con la arquitectura R2"
+
 #, fuzzy
 #~| msgid "%<constexpr%> cannot appear in a typedef declaration"
 #~ msgid "%<constinit%> cannot appear in a typedef declaration"
diff --git a/gcc/po/fi.po b/gcc/po/fi.po
index eb7ed258b8f..dfc51cc1426 100644
--- a/gcc/po/fi.po
+++ b/gcc/po/fi.po
@@ -32,7 +32,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1-b20200322\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2020-03-26 11:07+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -1956,86 +1956,86 @@ msgstr "pituusmääre strfmon-muotoilussa"
 msgid "<command-line>"
 msgstr "<komentorivi>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "puuttuva operandi"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "virheellinen etuliite ”0b” liukulukuvakiolle"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "virheellinen %%G-tila"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2051,18 +2051,18 @@ msgid "invalid %%r value"
 msgstr "virheellinen %%r-arvo"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "virheellinen %%R-arvo"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
@@ -2092,7 +2092,7 @@ msgstr "virheellinen %%M-arvo"
 msgid "invalid %%U value"
 msgstr "virheellinen %%U-arvo"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
@@ -2102,7 +2102,7 @@ msgstr "virheellinen %%s-arvo"
 msgid "invalid %%C value"
 msgstr "virheellinen %%C-arvo"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
@@ -2112,10 +2112,10 @@ msgstr "virheellinen %%E-arvo"
 msgid "unknown relocation unspec"
 msgstr "uudelleensijoitusvirhe"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "virheellinen %%xn-koodi"
@@ -2198,35 +2198,35 @@ msgstr "virheellinen lauseke kohdemuuttujana"
 msgid "unrecognized supposed constant"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Virheellinen käsky"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2234,13 +2234,13 @@ msgstr "fr30_print_operand: tuntematon koodi"
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
@@ -2376,7 +2376,7 @@ msgstr "odottamaton siirros"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2630,25 +2630,25 @@ msgstr "virheellinen const_double-operandi"
 msgid "bad output_condmove_single operand"
 msgstr "Yksi"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 msgid "invalid operand %%xn code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 msgid "invalid fp constant"
 msgstr "virheellinen rotate-käsky"
@@ -2796,7 +2796,7 @@ msgstr "Virheellinen operaatiokoodi"
 msgid "invalid %%P operand"
 msgstr "virheellinen %%P-operandi"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -2855,7 +2855,7 @@ msgid "post-increment address is not a register"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -2910,8 +2910,8 @@ msgstr "Nolla ei ole kelvollinen lausekenimiö kohdassa %C"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
@@ -3052,177 +3052,223 @@ msgstr "Pinotila loppui.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Älä käytä laitteistoliukulukuja"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Poista käytöstä POSIX ACLs -tuki"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 #, fuzzy
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "Tuota little-endian-koodia"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "virheellinen %%J-arvo"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "virheellinen %%D-arvo"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "virheellinen vektoripermutaatiovakio"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Älä luo #line-direktiivejä"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "virheellinen muunnos gimple-kutsussa"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "virheellinen muunnos gimple-kutsussa"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3233,91 +3279,91 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "tyypit eroavat etumerkillisyyden osalta"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 #, fuzzy
 msgid "binary operator does not support two vector bool operands"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 #, fuzzy
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "kohdemuoto ei tue äärettömyyttä"
@@ -3593,8 +3639,8 @@ msgstr "({nimetön})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "”)” oli odotus"
@@ -3614,7 +3660,7 @@ msgstr "”)” oli odotus"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "”)” oli odotus"
@@ -3622,7 +3668,7 @@ msgstr "”)” oli odotus"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "”)” oli odotus"
@@ -3641,21 +3687,21 @@ msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "”)” oli odotus"
@@ -3666,12 +3712,12 @@ msgstr "”)” oli odotus"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -3680,7 +3726,7 @@ msgstr "odotettiin %<,%> tai %<;%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "”)” oli odotus"
@@ -3690,18 +3736,18 @@ msgstr "”)” oli odotus"
 msgid "expected %<.%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -3709,19 +3755,19 @@ msgstr "odotettiin %<,%> tai %<;%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
@@ -3730,7 +3776,7 @@ msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "”)” oli odotus"
@@ -3741,35 +3787,35 @@ msgstr "”)” oli odotus"
 msgid "expected label"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 msgid "candidate:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "Ota käyttöön käyttäjän määrittelemät käskyt"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
 msgstr[1] "ehdokkaat ovat:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "ehdokas 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "hyppy nimiöön %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "hyppy case-nimiöön"
 
@@ -3866,7 +3912,7 @@ msgstr "jäsennysvirhe malliargumenttien luettelossa"
 msgid "<statement>"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<tuntematon>"
@@ -4049,52 +4095,52 @@ msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 msgid "source type is not polymorphic"
 msgstr "lähde ei ole osoitin"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bittikomplementille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "konjugaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "unaariselle huutomerkille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
@@ -4142,17 +4188,17 @@ msgstr "Virheellinen merkki BOZ-vakiossa kohdassa %C"
 msgid "elemental binary operation"
 msgstr "  -b, --binary            lue binäärimuodossa\n"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, fuzzy, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "liian vähän (%d) argumentteja funktiolle ”%s”"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, fuzzy, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, fuzzy, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
@@ -4232,7 +4278,7 @@ msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 msgid "Driving:"
 msgstr "Varoitus:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4248,7 +4294,7 @@ msgstr "<sisäinen>"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "<tunnistevirhe>"
@@ -4374,12 +4420,12 @@ msgstr "lohkolaite"
 msgid "implied END DO"
 msgstr "syötteen loppu"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 #, fuzzy
 msgid "assignment"
 msgstr "Eri tyypit osoitinsijoituksessa kohdassa %L; yritettiin tyypin %s sijoitusta tyyppiin %s"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 #, fuzzy
 msgid "pointer assignment"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
@@ -4398,224 +4444,224 @@ msgstr ""
 "                  muuten yksinkertaisia\n"
 "  never, simple   tee aina yksinkertaisia varmuuskopioita\n"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 #, fuzzy
 msgid "elemental procedure"
 msgstr "RPC: Proseduuri ei ole käytettävissä"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 msgid "allocatable argument"
 msgstr "Virheellinen argumentti"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "ei argumentteja"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "valinnainen argumentti"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "osoitinargumentti"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "kohdeargumentti"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "arvoargumentti"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 msgid "volatile argument"
 msgstr "ylimääräinen %<volatile%>"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 msgid "coarray argument"
 msgstr "Virheellinen argumentti"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "Virheellinen argumentti"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 #, fuzzy
 msgid "NO_ARG_CHECK attribute"
 msgstr "liian pitkä riviargumentti"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 #, fuzzy
 msgid "array result"
 msgstr "MD5-tulos on:\n"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "tulosta ei voi kirjoittaa: %s"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, fuzzy, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, fuzzy, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, fuzzy, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, fuzzy, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, fuzzy, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, fuzzy, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, fuzzy, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, fuzzy, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Silmukkamuuttuja"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 msgid "iterator variable"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "Ennenaikainen säännöllisen lausekkeen loppu"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 #, fuzzy
 msgid "STAT variable"
 msgstr "tiedoston tilan lukeminen epäonnistui"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 #, fuzzy
 msgid "item in READ"
 msgstr "Soita numero"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "uutta arkistoa ei voi lukita"
@@ -4629,27 +4675,27 @@ msgstr "Odotettiin PARAMETER-symbolia kompleksivakiossa kohdassa %C"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, fuzzy, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, fuzzy, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, fuzzy, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "virheellinen taulukkosijoitus"
@@ -4729,7 +4775,7 @@ msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 msgid "Assigned label is not a target label"
 msgstr "ei-paikallinen nimiö "
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5193,7 +5239,7 @@ msgstr "Varoita laskutoimituksista funktio-osoittimilla"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ei tee mitään. Säilytetty yhteensopivuuden vuoksi."
@@ -5775,8 +5821,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ei tee mitään. Säilytetty yhteensopivuuden vuoksi."
@@ -8222,106 +8268,101 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "Varoita löytyneistä PCH-tiedostoista, joita ei käytetä"
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Varoita muuttujista, jotka alustetaan omalla arvollaan."
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12760,8 +12801,8 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-msgid "Use instructions for a future architecture."
-msgstr "ISO C kieltää sisäkkäiset funktiot"
+msgid "Use instructions added in ISA 3.1."
+msgstr "Käytä AltiVec-käskyjä"
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -12773,6 +12814,11 @@ msgstr "Käytä AltiVec-käskyjä"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Älä luo #line-direktiivejä"
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Käytä AltiVec-käskyjä"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17735,7 +17781,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18378,367 +18424,367 @@ msgstr "continue-lause silmukan ulkopuolella"
 msgid "Perform loop unrolling for all loops."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Käytä poikkeustenkäsittelyä"
 
-#: common.opt:2896
+#: common.opt:2900
 #, fuzzy, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 msgid "Perform variable tracking."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, fuzzy, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2959
+#: common.opt:2963
 #, fuzzy, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:2963
+#: common.opt:2967
 #, fuzzy, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, fuzzy, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, fuzzy, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:3040
+#: common.opt:3044
 #, fuzzy, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Tuota vianjäljitystietoja oletusmuodossa."
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, fuzzy, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3132
+#: common.opt:3136
 #, fuzzy, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3136
+#: common.opt:3140
 #, fuzzy, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa."
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3209
+#: common.opt:3213
 #, fuzzy, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Tuota isel-käskyjä"
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Ota käyttöön funktioprofilointi."
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Ota käyttöön yksityiskohtainen tuloste."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Näytä kääntäjän versio."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Vaienna varoitukset."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Luo jaettu kirjasto."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Älä luo dynaamisesti linkitettyä paikkariippumatonta suoritettavaa tiedostoa."
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19888,8 +19934,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "laskettua arvoa ei käytetä"
@@ -19915,7 +19961,7 @@ msgid "expected boolean type"
 msgstr "odotettiin totuusarvotyyppiä"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "odotettiin kokonaislukua"
@@ -19989,7 +20035,7 @@ msgstr "liian vähän argumentteja"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "liian monta argumenttia"
@@ -20399,7 +20445,7 @@ msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -20483,12 +20529,12 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20506,8 +20552,8 @@ msgstr "%qE-attribuuttia ei huomioida"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -20626,7 +20672,7 @@ msgstr "%qD esitelty ei-parametrina"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "siirros vakiomerkkijonon rajojen ulkopuolelle"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE esitelty täällä"
@@ -20913,7 +20959,7 @@ msgstr "polku puuttuu %qs:n jälkeen"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
@@ -21203,12 +21249,12 @@ msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21718,302 +21764,302 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "polku puuttuu %qs:n jälkeen"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, fuzzy, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "%s: kenttä ”%s” ei saa olla määritelty"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "bittikentän %qs leveys on negatiivinen"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Ei ole tuettu"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, fuzzy, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Stmt-sisäkkäistysvirhe."
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "tyhjä esittely"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, fuzzy, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "symtab_node::verify epäonnistui"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: osaa ”%.*s” ei tunneta"
@@ -22099,12 +22145,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "nimike %q+D määritelty mutta käyttämättä"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
@@ -22256,7 +22302,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "Hakemistoa %s ei voi avata"
@@ -22583,22 +22629,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, fuzzy, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "<%s> ja <%s> ovat virheellisiä nimiä välille"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, fuzzy, gcc-internal-format
 msgid "shared rtx"
 msgstr "jaettu muistiobjekti"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, fuzzy, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "Sähkökatko"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22658,7 +22704,7 @@ msgstr "oikealle siirron lukumäärä on negatiivinen"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "tiedoston %s avaaminen epäonnistui"
@@ -22688,12 +22734,12 @@ msgstr "Käänteinen jä_rjestys"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivirheellä: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivaroituksella: %s"
@@ -22708,7 +22754,7 @@ msgstr "argumentti %qd ei ole vakio"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
@@ -22728,37 +22774,37 @@ msgstr "suuri kokonaisluku implisiittisesti katkaistu etumerkittömäksi tyypiks
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, fuzzy, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "looginen"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "looginen"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23381,13 +23427,13 @@ msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 msgid "function returns address of local variable"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "esitelty täällä"
@@ -24006,10 +24052,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "Arvo sallitun välin ulkopuolella."
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -24181,7 +24227,7 @@ msgstr "%qs määritelty parametrille %qE"
 msgid "enclosing %<target%>"
 msgstr "# Ei kohde:"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
@@ -24231,13 +24277,13 @@ msgstr "muuttuja %qD esitelty uudelleen funktiona"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -24247,149 +24293,149 @@ msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "odotettiin %<operator%>"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, fuzzy, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "%qD ei ole malli"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, fuzzy, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, fuzzy, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, fuzzy, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, fuzzy, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, fuzzy, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 " EPÄONNISTUI\n"
 "\n"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT muunnetaan tyypiksi %qT, kun se viedään %<...%>:n läpi"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(eli kannattaisi antaa %qT eikä %qT funktiolle %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jos tämä koodi saavutetaan, ohjelma keskeytyy"
@@ -24464,7 +24510,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -24736,54 +24782,54 @@ msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 msgid "the extra base is defined here"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24813,37 +24859,37 @@ msgstr "funktio voi olla ehdokas %<%s%>-attribuutille jos sen tiedetään palaav
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr "verifiointi epäonnistui: %s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24893,57 +24939,57 @@ msgstr "virheellinen lvalue asm-tulosteessa %d"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Kumoamistoimintojen enimmäismäärä"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "”%s” ei ole oikea profiilidatatiedosto ”%s”:lle"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "lähdetiedostoa %s ei löydy"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Taulukkotyyppi      : %s\n"
@@ -25195,52 +25241,52 @@ msgstr "argumenttien määrä ei vastaa prototyyppiä"
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr "viimeksi käytetty täällä"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "switch alkaa tästä"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25461,52 +25507,52 @@ msgstr "%qs-attribuutin virheellinen argumentti"
 msgid "invalid branch to/from %s structured block"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, fuzzy, gcc-internal-format
 msgid "containing loop here"
 msgstr "jätä pois CACHEDIR.TAGin sisältävät hakemistot"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, fuzzy, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -26831,132 +26877,132 @@ msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, fuzzy, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr ""
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, fuzzy, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, fuzzy, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "Profilointiajastin vanhentunut"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, fuzzy, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "%s: Virhe kirjoitettaessa %s\n"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, fuzzy, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "virhe suljettaessa laitetta %s"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "Muodostin %qs"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, fuzzy, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "Muodostin %qs"
@@ -27051,122 +27097,122 @@ msgstr "%Jvanhanmallinen funktiomäärittely"
 msgid "ignoring loop annotation"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "Virheellinen taulukkoviitemuoto kohdassa %C"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr "pyydetty muuntoa ei-skalaarityypiksi"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "virheellinen %%r-arvo"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "%qD:n virheellinen käyttö"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
@@ -27180,52 +27226,52 @@ msgstr ""
 "                  muuten yksinkertaisia\n"
 "  never, simple   tee aina yksinkertaisia varmuuskopioita\n"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, fuzzy, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, fuzzy, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, fuzzy, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr "%<noreturn%>-funktio palaa"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -27236,509 +27282,509 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "ehdotetaan sulkeita vertailun ympärille %<|%>:n operandissa"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "epäkelpo totuusarvolauseke"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, fuzzy, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr "virheelliset tyypit nop-muunnokselle"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "virheelliset tyypit nop-muunnokselle"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "virheellisiä tyyppejä muunnoksessa kokonaisluvuksi"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, fuzzy, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "virheellisiä tyyppejä muunnoksessa liukuluvuksi"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "virheellisiä tyyppejä muunnoksessa liukuluvuksi"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "virheellisiä tyyppejä muunnoksessa kokonaisluvuksi"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "Taulukkotyyppi      : %s\n"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "Ei ole hakemisto"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "virheellinen %%r-arvo"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, fuzzy, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto-kohde ei ole nimiö eikä osoitin"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "bittikenttä %+q#D ei ole kokonaislukutyyppinen"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, fuzzy, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "Ensimmäinen/seuraava ketju rikki"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, fuzzy, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "virheellinen versionumero ”%s”"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "MD5-tulos on:\n"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "puuttuva ”]”"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "Virheellinen argumentti"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple epäonnistui"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, fuzzy, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) on asetettu väärään peruslohkoon"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, fuzzy, gcc-internal-format
 msgid "PHI node with location"
 msgstr "symtab_node::verify epäonnistui"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, fuzzy, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 "Vihje: %s\n"
 "\n"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) on asetettu väärään peruslohkoon"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple epäonnistui"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "ei-paikallinen nimiö "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "nimiö "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "vuonohjauskäsky peruslohkon sisällä"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "useita default-nimikkeitä samassa switch-lauseessa"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "ylimääräisiä tyyppimääreitä muotoiluargumentissa (argumentti %d)"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "”I”-lippu"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-funktio palaa"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "ei-void-tyyppisen funktion loppu saavutettu"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "attribuutilla warn_unused_result esitellyn funktion paluuarvoa ei huomioida"
@@ -27753,47 +27799,47 @@ msgstr "%qs-makron määrittelyssä"
 msgid "in expansion of macro %qs"
 msgstr "%qs-makron lavennuksessa"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "fr30_print_operand: tunnistamaton %%b-koodi"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "fr30_print_operand: tunnistamaton %%b-koodi"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "”I”-lippu"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "fr30_print_operand: tunnistamaton %%b-koodi"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
@@ -28316,12 +28362,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr "verify_gimple epäonnistui"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, fuzzy, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "sulkumerkkien käyttö laskulausekkeen ympärillä on suositeltavaa |-operandissa"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, fuzzy, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
@@ -28386,7 +28432,7 @@ msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28396,27 +28442,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "union määritelty täällä"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen ulkopuolella"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen ulkopuolella"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen ulkopuolella"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen alapuolella"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
@@ -28491,32 +28537,32 @@ msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD on vanhentunut: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD on vanhentunut"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE on vanhentunut: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "tyyppi on vanhentunut: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tyyppi on vanhentunut"
@@ -28541,232 +28587,232 @@ msgstr "tyyppi on vanhentunut"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "Tiedoston tyyppi eroaa"
 
-#: tree.c:13924
+#: tree.c:13935
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13926
+#: tree.c:13937
 #, fuzzy, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13928
+#: tree.c:13939
 #, fuzzy, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13951
+#: tree.c:13962
 #, fuzzy, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: tree.c:13964
+#: tree.c:13975
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: tree.c:14000
+#: tree.c:14011
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14002
+#: tree.c:14013
 #, fuzzy, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14004
+#: tree.c:14015
 #, fuzzy, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14043
+#: tree.c:14054
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: tree.c:14045
+#: tree.c:14056
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: tree.c:14047
+#: tree.c:14058
 #, fuzzy, gcc-internal-format
 msgid "and field"
 msgstr "kentän leveys"
 
-#: tree.c:14064
+#: tree.c:14075
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, fuzzy, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, fuzzy, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "”%s” on määrittelemättä"
 
-#: tree.c:14392
+#: tree.c:14403
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:14404
+#: tree.c:14415
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:14423
+#: tree.c:14434
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:14431
+#: tree.c:14442
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:14437
+#: tree.c:14448
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: tree.c:14473
+#: tree.c:14484
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:14494
+#: tree.c:14505
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:14500
+#: tree.c:14511
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:14511
+#: tree.c:14522
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:14522
+#: tree.c:14533
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:14540
+#: tree.c:14551
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree.c:14547
+#: tree.c:14558
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.c:14554
+#: tree.c:14565
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
@@ -28891,82 +28937,82 @@ msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 msgid "storage size of %q+D isn%'t known"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, fuzzy, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "alustin liukulukuarvolle ei ole liukulukuvakio"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "alustin liukulukuarvolle ei ole liukulukuvakio"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "virheellinen alkuarvo jäsenelle %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%qs:n esittely taulukollisena funktioita"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "esittelyssä %q+D"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, fuzzy, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "%qs ei ole tuettu tällä kohteella"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "Rinnakkaiset työt (-j) eivät ole tuettuja tällä alustalla."
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
@@ -29546,7 +29592,7 @@ msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 msgid "type was previously declared %qE"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
@@ -29566,7 +29612,7 @@ msgstr "%qD ei ole %qD:n jäsen"
 msgid "%qE argument is not a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
@@ -29938,12 +29984,12 @@ msgstr "lueteltu tyyppi määritelty täällä"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "ehdotetaan sulkeita totuusarvona käytetyn sijoituksen ympärille"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
@@ -30099,12 +30145,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -30205,7 +30251,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "taulukon koko on liian suuri"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
@@ -30215,124 +30261,124 @@ msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Arvo sallitun välin ulkopuolella."
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "taulukon koko on negatiivinen"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, fuzzy, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30395,510 +30441,510 @@ msgstr "%qE on tunnistamaton muotofunktiotyyppi"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "muotomerkkijonoargumentti seuraa muotoiltavia argumentteja"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "funktio %qD voi olla ehdokas %qs-muotoiluattribuutille"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "$-operandinumero puuttuu muotoilussa"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s ei tue %%n$-operandinumeromuotoilua"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "muotoiluargumentti %d käytössä useammin kuin kerran %s-muotoilussa"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$-operandinumeroa käytetty operandinumerottoman muotoilun jälkeen"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "muotoiluargumentti %d käyttämätön ennen käytettyä argumenttia %d $-tyylisessä muotoilussa"
 
 # XXX
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "muotoilu ei ole merkkijonoliteraali, muotoilumerkkijonoa ei tarkisteta"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "muotoilu ei ole merkkijonoliteraali eikä muotoiluargumentteja"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "muotoilu ei ole merkkijonoliteraali, argumenttityyppejä ei tarkisteta"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "liian monta argumenttia muotoilulle"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr "käyttämättömiä argumentteja $-tyylisessä muotoilussa"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "%s-muotoilumerkkijonon pituus on nolla"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "muotoilu on leveämerkkinen merkkijono"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "muotomerkkijonoargumentti seuraa muotoiltavia argumentteja"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "päättämätön muotoilumerkkijono"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, fuzzy, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
 # XXX
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "toistettu %s muotoilussa"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "täytemerkki puuttuu strfmon-muotoilun lopusta"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "%s-muotoilun leveys on nolla"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "%s-muotoilussa vasen tarkkuus on tyhjä"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "%s-muotoilussa tarkkuus on tyhjä"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, fuzzy, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "väärinmuodostettu %<#pragma %s%>, jätetään huomiotta"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, fuzzy, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "muotoilussa %3$s käytetään lippuja %1$s ja %2$s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "muotoilussa %3$s käytetään lippuja %1$s ja %2$s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> antaa vain vuoden kaksi viimeistä numeroa joissakin maa-asetustoissa"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> antaa vain vuoden kaksi viimeistä numeroa"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "%<%%[%>-muotoilua ei ole suljettu %<]%>:lla"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "pituusmääreen %qs käyttö tyyppimerkillä %qc"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
 # XXX
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "operandinumero annettu vaiennetulla sijoituksella"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "operandinumero annettu muotoilulle, joka ei ota argumentteja"
 
 # XXX
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "toistettu %s muotoilussa"
 
 # XXX
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "toistettu %s muotoilussa"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "sulautettu %<\\0%> muotoilussa"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 msgid "use %qs instead"
 msgstr "käytä #includea sen sijaan"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr "funktio voi olla ehdokas %<%s%>-attribuutille"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr "vääränlainen seuraava %<%%%> muotoilussa"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "vääränlainen seuraava %<%%%> muotoilussa"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
 # XXX
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr "toistettu %s muotoilussa"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
 # XXX
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr "toistettu %s muotoilussa"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
 # XXX
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr "toistettu %s muotoilussa"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "vääränlainen seuraava %<%%%> muotoilussa"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "vääränlainen seuraava %<%%%> muotoilussa"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "monimerkkinen sarkain %s"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr "päättämätön muotoilumerkkijono"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "muotoilussa on tuntematon muunnostyyppimerkki %qc"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "vääränlainen seuraava %<%%%> muotoilussa"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "muunnoksen tyyppi puuttuu muotoilun lopusta"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "Älä luo #line-direktiivejä"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, fuzzy, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr "päättämätön muotoilumerkkijono"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, fuzzy, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr "päättämättömät assembly-murrevaihtoehdot"
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "sulautettu %<\\0%> muotoilussa"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 msgid "unterminated color directive"
 msgstr "päättämättömät assembly-murrevaihtoehdot"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "kirjoitetaan nollaosoittimen läpi (argumentti %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "luetaan nollaosoittimen läpi (argumentti %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "kirjoitetaan vakio-objektiin (argumentti %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "ylimääräisiä tyyppimääreitä muotoiluargumentissa (argumentti %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "muotoilu %q.*s odottaa tyyppiä %<%s%s%>, mutta %d. argumentin tyyppi on %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "muotoilu %q.*s odottaa %<%T%s%>-tyyppiä, mutta %d. argumentin tyyppi on %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, fuzzy, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, fuzzy, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<%T::%E%> ei ole tyyppi"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, fuzzy, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, fuzzy, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr "muotoiltavat argumentit eivät ole %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
@@ -31059,7 +31105,7 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -31074,17 +31120,17 @@ msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "’(’ puuttuu predikaatin jäljestä"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
@@ -31094,7 +31140,7 @@ msgstr "puuttuva kasvatuslauseke"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -31690,7 +31736,7 @@ msgid "wrong type argument to %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
@@ -32371,7 +32417,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
@@ -32448,7 +32494,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "sijoitus hylkää kohdeosoitintyypin määreitä"
 msgstr[1] "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -32468,7 +32514,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "union määritelty täällä"
@@ -32488,7 +32534,7 @@ msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 msgid "too many input files"
 msgstr "liikaa syötetiedostoja"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "tuntematon cc_attr-arvo"
@@ -32519,14 +32565,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "tuntematon komentorivivalitsin %qs"
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "kelvolliset argumentit ovat: %s; tarkoititko %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "kelvolliset argumentit ovat: %s"
@@ -33043,395 +33089,402 @@ msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 msgid "profiler support for VxWorks"
 msgstr "profilointituki VxWorksille"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, fuzzy, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "%s ei tue %%n$-operandinumeromuotoilua"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "odotettiin 64-bittistä osoitetta, mutta argumentti 1 on %d-bittinen"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "odotettiin 64-bittistä osoitetta, mutta argumentti 2 on %d-bittinen"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> ei ole merkkijono eikä luku"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "tuntematon #pragma GCC coprocessor %E"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%s %qs"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%s %qs"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "Älä varoita Microsoft-laajennosten käytöstä"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "virheellinen %%h-arvo"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "tuntematon valitsin -%s"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Funktio %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "Kelvolliset argumentit:"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "tuntematon konetila %qs"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s ei tue %%n$-operandinumeromuotoilua"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, fuzzy, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, fuzzy, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, fuzzy, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, fuzzy, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, fuzzy, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "tuntematon värimoodi"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
@@ -33612,17 +33665,17 @@ msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33772,12 +33825,12 @@ msgstr "Funktio %qs"
 msgid "invalid type for %<asm%> flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "[käytössä]"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, fuzzy, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
@@ -33785,194 +33838,194 @@ msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "Ei ole tuettu"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s odottaa kokonaislukuliteraalia väliltä [%d, %d]."
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "mountin käyttöön vaaditaan pääkäyttäjän oikeudet"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "PEITE"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33982,283 +34035,283 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "typeid:tä ei voi käyttää -fno-rtti-valitsimen kanssa"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "Muodostin %qs"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "Muodostin %qs"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check on yhteensopimaton valitsimen -mno-apcs-frame kanssa"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic ja -mapcs-reent ovat yhteensopimattomat"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, fuzzy, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "C++-jäsennin ei tue -dy-valitsinta, jätetään se huomiotta"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "Muodostin %qs"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "Tiedostoa ”%s” ei löytynyt."
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS ei tue valitsinta -mcallee-super-interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, fuzzy, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, fuzzy, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
@@ -34266,22 +34319,22 @@ msgstr "epäkelpo vektorityyppi attribuutille %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "<tuntematon>"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -34360,17 +34413,17 @@ msgstr "%<-fpie%> ei ole tuettu"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> ei ole tuettu"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "valitsimet %s ja %s ovat toisensa poissulkevat"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
@@ -34632,7 +34685,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "virheellinen sisäinen makro ”%s”"
@@ -34963,52 +35016,52 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "Käytä liukulukurekistereitä"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr "Valitettavasti et ole root\n"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr "Valitettavasti et ole root\n"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, fuzzy, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr "syntaksivirhe: näennäismuisti on myös lopussa"
@@ -35142,134 +35195,134 @@ msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 msgid "parameter to builtin not valid: %s"
 msgstr "SISÄÄNRAKENNETTU CD %s\n"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "<%s> ja <%s> ovat virheellisiä nimiä välille"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "<%s> ja <%s> ovat virheellisiä nimiä välille"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 "Vihje: %s\n"
 "\n"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
@@ -35651,144 +35704,144 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
@@ -36234,7 +36287,7 @@ msgstr "%J%qD määritelty sekä tavallisesti että aliaksena"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -37307,52 +37360,52 @@ msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, fuzzy, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -37468,323 +37521,324 @@ msgstr "luvun on oltava 0 tai 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "%d. argumentti funktiolle %qE hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "virheellinen parametri %qs"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "Profilointiajastin vanhentunut"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr "%s: kenttä ”%s” ei saa olla tyhjä"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr "%s: kenttä ”%s” ei saa olla tyhjä"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, fuzzy, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "<sisäänrakennettu>"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
@@ -37804,219 +37858,224 @@ msgstr "%qs käyttää rekisteriä r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 vaatii PowerPC64-suorittimen, otetaan käyttöön"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "valitsin -mstring ei ole tuettu little-endian-järjestelmissä"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%s %qs"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "<tuntematon>"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, fuzzy, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "<tuntematon>"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "<tuntematon>"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "Funktio %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Vanhentunut. Tämä valitsin ei vaikuta mihinkään"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, fuzzy, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, fuzzy, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, fuzzy, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s on virheellinen"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
@@ -38337,139 +38396,139 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, fuzzy, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-fPIC ei ole tuettu"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, fuzzy, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "blocks-argumentti on liian suuri, maksimi on %llu"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -38888,8 +38947,8 @@ msgstr "attribuutti %qs soveltuu vain taulukkotyyppeihin"
 msgid "could not read the BRIG file"
 msgstr "Tiedoston ”%s” palauttaminen epäonnistui."
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
@@ -39166,7 +39225,7 @@ msgstr "%J%qD:n esittely varjostaa edellistä paikallista"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
@@ -39236,7 +39295,7 @@ msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Jokaisesta esittelemättömästä tunnisteesta ilmoitetaan vain"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qD ei ole määritelty funktion näkyvyysalueen ulkopuolella"
@@ -39266,7 +39325,7 @@ msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 msgid "duplicate label declaration %qE"
 msgstr "%qE-nimiön kaksoisesittely"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
@@ -39476,7 +39535,7 @@ msgstr "ei voi laittaa volatile-kenttäistä objektia rekisteriin"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, fuzzy, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%qE nimiavaruudessa %qE ei nimeä tyyppiä"
@@ -39816,7 +39875,7 @@ msgstr "tyyppinimi esitelty taulukon palauttavan funktiona"
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääritteet jätetään huomiotta funktion paluutyypissä"
@@ -40123,7 +40182,7 @@ msgstr "sisäkkäinen %<struct %E%>:n uudelleenmäärittely"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
@@ -40173,7 +40232,7 @@ msgstr "structilla ei ole nimettyjä jäseniä"
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
@@ -40209,7 +40268,7 @@ msgstr "sisäkkäinen %<enum %E%>:n uudelleenmäärittely"
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
@@ -40239,7 +40298,7 @@ msgstr "ylivuoto luetellun tyypin arvoissa"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
@@ -40269,7 +40328,7 @@ msgstr "%qD:lle ei ole edellistä prototyyppiä"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -40384,12 +40443,12 @@ msgstr "argumentti %qD ei vastaa sisäistä prototyyppiä"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
@@ -40397,258 +40456,258 @@ msgstr "parametri %qD on alustettu"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "käytä valitsinta -std=c99 tai -std=gnu99 koodisi kääntämiseen"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "staattisen muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
 # XXX: alkuesittely
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE:n kaksoiskappale"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "käytetty %<__thread%> ennen %<static%>:a"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "fetchmail: säie nukkuu %d sekuntia.\n"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "käytetty sekä %<__thread%> että %<auto&>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "negatiivisen arvon siirto vasemmalle"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
@@ -40668,7 +40727,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "toinen täsmäävyys on täällä"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
@@ -40714,7 +40773,7 @@ msgid "unknown type name %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
@@ -40734,7 +40793,7 @@ msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
@@ -40749,8 +40808,8 @@ msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 msgid "unexpected attribute"
 msgstr "Odottamattomat argumentit"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
@@ -40788,7 +40847,7 @@ msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -40816,7 +40875,7 @@ msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "odotettiin merkkijonoliteraalia"
@@ -40846,7 +40905,7 @@ msgstr "ei-vakio ehto staattiselle väitteelle"
 msgid "static assertion failed: %E"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "staattinen väite epäonnistui: %s"
@@ -40891,14 +40950,14 @@ msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "luetellun tyypin luettelon lopussa on pilkku"
@@ -40983,7 +41042,7 @@ msgstr "useita tallennusluokkia esittelymääritteissä"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
@@ -40993,7 +41052,7 @@ msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, fuzzy, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
@@ -41053,7 +41112,7 @@ msgstr "ISO C90 kieltää esittelyjen ja koodin sekoittamisen"
 msgid "expected %<}%> before %<else%>"
 msgstr "#else #else:n jälkeen"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ilman edeltävää %<if%>:iä"
@@ -41068,7 +41127,7 @@ msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
@@ -41093,17 +41152,17 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr "odotettiin tunnistetta tai %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<if%>-lauseessa"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<else%>-lauseessa"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "ehdotetaan aaltosulkeita epäselvän %<else%>:n välttämiseksi"
@@ -41123,12 +41182,12 @@ msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -41143,8 +41202,8 @@ msgstr "lopetusalkio puuttuu funktiokutsusta"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "cv-määreen kaksoiskappale"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
 msgid "first seen here"
 msgstr "struct määritelty täällä"
@@ -41171,12 +41230,12 @@ msgstr "ISO C kieltää ?:-lausekkeen ilman keskimmäistä termiä"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%Jviimeksi käytetty täällä"
@@ -41569,61 +41628,61 @@ msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "kuori on annettava polkuineen"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
@@ -41633,18 +41692,18 @@ msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%s: liian monta arvoa"
@@ -41664,53 +41723,53 @@ msgstr "odotettiin %<,%> tai %<;%>"
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41732,12 +41791,12 @@ msgstr "%<num_threads%>-arvon on oltava positiivinen"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
@@ -41747,22 +41806,22 @@ msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 msgid "expected constant integer expression"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> tai %<max%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "%s: Liian monta argumenttia\n"
@@ -41777,52 +41836,52 @@ msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "%s: liian monta argumenttia\n"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "sekä %<long%> että %<void%> esittelymääritteissä"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -41832,7 +41891,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
@@ -41867,22 +41926,22 @@ msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "virheellinen const_double-operandi"
@@ -41897,77 +41956,77 @@ msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "Funktio %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, fuzzy, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, fuzzy, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -41982,7 +42041,7 @@ msgstr "%qE on esittelemättä"
 msgid "expected function name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
@@ -41992,67 +42051,67 @@ msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -42062,57 +42121,57 @@ msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, fuzzy, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -42122,73 +42181,73 @@ msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 msgid "not enough perfectly nested loops"
 msgstr "liian vähän argumentteja"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "liian vähän argumentteja"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 # XXXXXXX
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -42203,57 +42262,57 @@ msgstr "%Jvanhanmallinen funktiomäärittely"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "  siirtyy catch-lohkoon"
@@ -42263,12 +42322,12 @@ msgstr "  siirtyy catch-lohkoon"
 msgid "variant %qD is not a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -42278,32 +42337,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "# Ei kohde:"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
@@ -42358,42 +42417,42 @@ msgstr "odotettiin luokan nimeä"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "-pipe ei ole tuettu"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -42408,27 +42467,27 @@ msgstr "käytetään muuttuvapituista taulukkoa"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -42438,7 +42497,7 @@ msgstr "odotettiin %<,%> tai %<;%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "Käyttö: %s <transaktiotiedosto> <tiedostojärjestelmä>\n"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -42453,7 +42512,7 @@ msgstr "          %s"
 msgid "%qD has an incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
@@ -42574,7 +42633,7 @@ msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "taulukon indeksi ei ole kokonaisluku"
@@ -42599,7 +42658,7 @@ msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 msgid "enum constant defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42712,17 +42771,17 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "vertailu merkkijonoliteraalin kanssa aiheuttaa määrittelemätöntä toimintaa"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "osoittimen ja kokonaisluvun välinen vertailu"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
@@ -42748,7 +42807,7 @@ msgstr "vähennyslaskussa käytetty osoitinta funktioon"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
@@ -42998,7 +43057,7 @@ msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "tyyppimuunnos %qT-tyyppisestä funktiokutsusta yhteensopimattomaan tyyppiin %qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "tyyppimuunnos erikokoisesta kokonaisluvusta osoittimeksi"
@@ -43170,7 +43229,7 @@ msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
@@ -43330,7 +43389,7 @@ msgstr "alustus yhteensopimattomasta osoitintyypistä"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "sopimattomasta tyypistä koostuva taulukko alustetaan merkkijonovakiosta"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
@@ -43361,7 +43420,7 @@ msgstr "alustusalkiota ei pystytä laskemaan latausajankohtana"
 msgid "invalid initializer"
 msgstr "epäkelpo alustin"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
@@ -43506,7 +43565,7 @@ msgstr "ylimääräisiä alkioita skalaarialustimessa"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C90 kieltää yhdysliteraalit"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
@@ -43546,7 +43605,7 @@ msgstr "%<long%>-tyyppistä switch-lauseketta ei muunneta %<int%>-tyyppiin ISO C
 msgid "case label is not an integer constant expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, fuzzy, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -43556,17 +43615,17 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 msgid "%<default%> label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -43581,7 +43640,7 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "lauseella ei ole vaikutusta"
@@ -43591,22 +43650,22 @@ msgstr "lauseella ei ole vaikutusta"
 msgid "expression statement has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "liukulukujen vertailu operaattoreilla == ja != on epävarmaa"
@@ -43657,7 +43716,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
@@ -43687,51 +43746,51 @@ msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 msgid "used vector type where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "odotettiin %<operator%>"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs määritelty parametrille %qE"
@@ -43741,8 +43800,8 @@ msgstr "%qs määritelty parametrille %qE"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
@@ -43910,12 +43969,12 @@ msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, fuzzy, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
@@ -43940,8 +43999,8 @@ msgstr "muuttuja %qD esitelty uudelleen funktiona"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs määritelty parametrille %qE"
@@ -43956,19 +44015,19 @@ msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 msgid "%qE appears more than once in data clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
@@ -44038,116 +44097,116 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "lähde ei ole osoitin"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, fuzzy, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, fuzzy, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, fuzzy, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, fuzzy, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%>-funktion ensimmäinen argumentti ei ole tyyppiä %<va_list%>"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -44330,811 +44389,811 @@ msgstr "odotettiin %<,%> tai %<;%>"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 msgid "  no known conversion from %qH to %qI"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "Käyttö: %s [-r] [-t]\n"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "virheellinen sisäinen makro ”%s”"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr "Virhe lukuarvon jäsentämisessä lähellä kohtaa ”%s”"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr "poistettu funktio %q+D"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr "poistettu funktio %q+D"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s %d"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 msgid "  inherited here"
 msgstr "  tässä alustuksessa"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 #, fuzzy
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "operaatioita semop-kutsua kohden enintään = %d\n"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Ei vastaavuutta"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Virheellinen järjestelmäkutsu"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "moniselitteinen argumentti %s %s:lle"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "Ei vastaavuutta"
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, fuzzy, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E::%E%> ei ole luokka eikä nimiavaruus"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "<tuntematon operaattori>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E::%E%> ei ole tyyppi"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%s %E%> esitelty parametriluettelon sisällä"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ kieltää ?:-lausekkeen käytön ilman keskimmäistä termiä"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, fuzzy, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "ehtolausekkeessa etumerkkinen ja etumerkitön tyyppi"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, fuzzy, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "Funktio %qs:"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "Funktio %qs:"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "esitelty täällä"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "muunnetaan %<false%> osoitintyyppiksi %2$qD:n argumentissa %1$P"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "liikaa aaltosulkeita %qT:n alustimen ympärillä"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi välittää %<...%>:n kautta"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
 # XXX
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD tyhjentää ei-triviaalintyyppisen objektin %#qT%s"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; käytä kopiosijoitusta sen sijaan"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; käytä kopioalustusta sen sijaan"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD kirjoittaa ei-triviaalisti-kopioitavaan tyyppiin %#qT%s"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, fuzzy, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT esitelty täällä"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Kopiomuodostin %qs"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "%s: valitsin on moniselitteinen; vaihtoehdot:"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "arvon palautus hajottimesta"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, fuzzy, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ehdokas 1: %q+#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ehdokas 2: %q+#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
@@ -45174,522 +45233,522 @@ msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, fuzzy, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, fuzzy, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%q+D esitelty täällä"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (paluutyypissään)"
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "esitelty täällä"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (tyypissään)"
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, fuzzy, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (paluutyypissään)"
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, fuzzy, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qD perii %E-ABI-tunnisteen, jota %qT käyttää (paluutyypissään)"
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, fuzzy, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q+D esitelty täällä"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%Jnimike %qD määritelty, mutta ei käytetty"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "Näytä _piilotetut"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "nimellä %qD"
 
 # semi-fuzzy
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "Varoita perittyjen metodien puuttuvista toteutuksista"
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bittikenttä %+q#D ei ole kokonaislukutyyppinen"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bittikentän %q+D leveys ei ole kokonaislukuvakio"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bittikentän %q+D leveys negatiivinen"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bittikentän %q+D leveys nolla"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D on liian pieni sisältämään %q#T:n kaikkia arvoja"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "ei argumentteja"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "ei argumentteja"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "ei argumentteja"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D ei voi olla staattinen koska se on unionin jäsen"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "liikaa argumentteja metodille %qE"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%q+D-funktion paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT on sulkeumatyyppi, joka on literaali vasta C++17:stä alkaen"
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "esittely ei esittele mitään"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "tyhjästä luokasta %qT perittyjen luokkien rakenne saattaa muuttua GCC:n tulevissa versioissa"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, fuzzy, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Kieli:"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, fuzzy, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "liian vähän argumentteja"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
@@ -45769,7 +45828,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "%q+E is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
@@ -45825,7 +45884,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "%qD:n esittely ei-funktiona"
@@ -45880,369 +45939,368 @@ msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "esitelty täällä"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "odotettiin %<template%>"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, fuzzy, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "virheellinen %%s-arvo"
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Jako nollalla kohdassa %L"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "          %s"
@@ -46288,7 +46346,7 @@ msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
@@ -46328,292 +46386,292 @@ msgstr "%qs odottaa vakioargumenttia"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "pyydetty muuntoa ei-skalaarityypiksi"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "kutsuttu täältä"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "epäkelpo %qs:n soveltaminen vaillinaiseen tyyppiin %qT "
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "epäkelpo %qs:n soveltaminen vaillinaiseen tyyppiin %qT "
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti funktiolle %qs"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti funktiolle %qs"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti funktiolle %qs"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "lause on vaikutukseton"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "puuttuva kasvatuslauseke"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "ei-yksiselitteinen oletustyyppimuunnos tyypistä %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -46678,7 +46736,7 @@ msgstr "edellisestä esittelystä %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "edellinen esittely %q+D"
@@ -46859,12 +46917,12 @@ msgstr "%q+D:n edellinen esittely oli täällä"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD uudelleenesitellään tarpeettomasti samalla näkyvyysalueella"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "%qD:n poistettu määrittely"
@@ -46877,44 +46935,44 @@ msgstr "%qD:n poistettu määrittely"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -46922,841 +46980,841 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "säiekohtainen esittely %q#D seuraa ei-säiekohtaista esittelyä"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ei-säiekohtainen esittely %q#D seuraa säiekohtaista esittelyä"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, fuzzy, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "edellinen esittely"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  täältä"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  siirtyy try-lohkoon"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, fuzzy, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ei ole luokka"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nimeää %q#T:n, joka ei ole tyyppi"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T:n attribuutin on oltava %qs-avainsanan perässä"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "useita tyyppejä yhdessä esittelyssä"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ kieltää nimettömät structit"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "muuttujalla %q#D on alustin, mutta vaillinaista tyyppiä"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, fuzzy, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD:n koko muistissa ei ole tunnettu"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD:n koko muistissa ei ole vakio"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  voit kiertää tämän poistamalla alustimen"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "muuttuvakokoinen yhdysliteraali"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D on vaillinaista tyyppiä"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalaariobjekti %qD vaatii yhden alkion alustimeensa"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "taulukko %qD alustettu sulkujen sisällä olevalla merkkijonoliteraalilla %qE"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, fuzzy, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, fuzzy, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-tallennusluokkamääritteen käyttö"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "%q+D:n edellinen esittely"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE-attribuutti soveltuu vain muuttujiin ja funktioihin"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "parametri %qD esitelty void-tyyppisenä"
@@ -48027,7 +48085,7 @@ msgstr "taulukon koon ylivuoto"
 msgid "%qD declared as array of %qT"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
@@ -48192,7 +48250,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
@@ -48393,810 +48451,810 @@ msgstr "attribuuttia ei huomioida"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "tarpeettomat sulkeet %qs:n esittelyssä"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%>-funktio palauttaa ei-void-arvon"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "muodostin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "muodostimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, fuzzy, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ylimääräinen kvalifiointi %<%T::%> jäsenelle %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "tiedostoa %s ei voi avata"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, fuzzy, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, fuzzy, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, fuzzy, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, fuzzy, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, fuzzy, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, fuzzy, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "lueteltu tyyppi määritelty täällä"
@@ -49208,95 +49266,95 @@ msgstr "lueteltu tyyppi määritelty täällä"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "on ristiriidassa %q+#D:n edellisen esittelyn kanssa"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT määritelty monella suoralla kannoalla"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT määritelty suoralla virtuaalisella kannalla"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
@@ -49305,72 +49363,72 @@ msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -49410,7 +49468,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malliesittelylle %q+D"
@@ -49420,7 +49478,7 @@ msgstr "malliesittelylle %q+D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
@@ -49746,147 +49804,147 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "poistettu funktio %q+D"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 msgid "(no argument)"
 msgstr "ei argumentteja"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[...]"
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, fuzzy, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%E%> on esittelemättä"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%E%> on esittelemättä"
@@ -50067,338 +50125,338 @@ msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekke
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD tulee alustaa jäsenten alustuslistassa"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "parametri %qD on alustettu"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD alustetaan jäljempänä kuin"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  kanta %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  tässä alustuksessa"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "kantaluokka %q#T pitäisi alustaa eksplisiittisesti kopiomuodostimessa"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, fuzzy, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, fuzzy, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, fuzzy, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, fuzzy, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, fuzzy, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, fuzzy, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, fuzzy, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, fuzzy, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "muotoilu %s päättyy %%:iin"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, fuzzy, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, fuzzy, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
@@ -50558,12 +50616,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
@@ -50588,158 +50646,163 @@ msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD:n esittely %qT:n jäsenenä"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "alustamaton const %qD"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "%qT ei ole malli"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
 # XXX
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
@@ -50779,210 +50842,210 @@ msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "on ristiriidassa %q+#D:n edellisen esittelyn kanssa"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-esittely %qD paikallisessa luokassa ilman edeltävää esittelyä"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, fuzzy, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%<fast_interrupt%>-attribuuttidirektiivi jätetty huomiotta"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "ehdotettu vaihtoehto:"
 msgstr[1] "ehdotetut vaihtoehdot:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%qE on vanhentunut"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "struct määritelty täällä"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -51007,7 +51070,7 @@ msgstr "tunniste %qE on ristiriidassa C++:n varatun sanan kanssa"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
@@ -51032,7 +51095,7 @@ msgstr "%<::%E%> on esittelemättä"
 msgid "request for member %qE in non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> on esittelemättä"
@@ -51112,7 +51175,7 @@ msgstr "muodostimen virheellinen käyttö mallina"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
@@ -51233,7 +51296,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -51353,7 +51416,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -51453,12 +51516,12 @@ msgstr "%<~%T%>:n esittely %qT:n jäsenenä"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ID"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ei ole malli"
@@ -51493,7 +51556,7 @@ msgstr "useita tallennuspaikkoja esittelymääritteissä"
 msgid "expected nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
@@ -51508,7 +51571,7 @@ msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -51523,7 +51586,7 @@ msgstr "ISO C++ kieltää yhdysliteraalit"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD:n virheellinen käyttö"
@@ -51548,912 +51611,917 @@ msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, fuzzy, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, fuzzy, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "vanhanmallisen tyyppimuunnoksen käyttö"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "suosittellaan sulkumerkkejä %<>>%>-lausekkeen ympärille"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, fuzzy, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "versioviitetaulukolle ei voi varata muistia"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, fuzzy, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D esitelty täällä"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "poistettu funktio %q+D"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> ei ole lohkon alussa"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> saa uuden merkityksen C++11:ssä; poista se"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "%s: virheellinen kenttämääritys %s"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "odotettiin %<operator%>"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Avainsana %s on tuntematon tai sillä ei vielä ole toteutusta"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(G++ hyväksyy koodin -fpermissive-valitsimella)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "odotettiin %<template%>"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, fuzzy, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "Odotettu nimi"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "union määritelty täällä"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, fuzzy, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, fuzzy, gcc-internal-format
 msgid "namespace name required"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "siirryttiin %qD-nimiavaruuteen"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "tyyppimääritteet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT ei ole nimiavaruus"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "poistettu funktio %q+D"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Varoita kun kaikki muodostimet ja hajottimet ovat yksityisiä"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
@@ -52462,430 +52530,430 @@ msgstr "%<%T::%E%> ei ole tyyppi"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "id="
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, fuzzy, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "odotettiin %<,%> tai %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C90 ei tue joustavia taulukkojäseniä"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, fuzzy, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ei löydetä luokkaa %qE"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ sallii bittikenttien määritteet vain ennen %<:%>-merkkiä"
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bittikenttä %+q#D ei ole kokonaislukutyyppinen"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-tarkenne funktiomäärittelyssä"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "ylimääräinen %<;%> luokansisäisen funktiomäärittelyn perässä"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 ei salli dynaamisia poikkeusmäärittelyitä"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynaamiset poikkeusmäärittelyt ovat vanhentuneita C++11:ssä"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "vakio tai tunniste odotettu"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, fuzzy, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, fuzzy, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -52894,545 +52962,545 @@ msgstr "%J%qD:n edellinen esittely oli täällä"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "    Ei ilmaistuja epäjäseniä\n"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "%<sizeof...%>-argumentti on ympäröitävä sulkeilla"
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %<const%>"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "nimiö "
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "Taso 2 ei ole synkronoitu"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "odotettiin %<:%> tai %<...%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs määritelty parametrille %qE"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "esitelty täällä"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "C++98:ssa %<template%> (selventimenä) on sallittu vain malleissa"
 
 # XXX
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, fuzzy, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, fuzzy, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "%qE ei ole Objective-C-luokkanimi eikä -alias"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "ylimääräinen %qs Objective-C++-metodien välissä"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "mahdollisia ikisilmukoita ei voi optimoida"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, fuzzy, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, fuzzy, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, fuzzy, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, fuzzy, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "_Peru"
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "Käyttö: %s <transaktiotiedosto> <tiedostojärjestelmä>\n"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53703,7 +53771,7 @@ msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -53728,84 +53796,84 @@ msgstr "malliesittelylle %q+D"
 msgid "template parameter %qD declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "ensiö"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, fuzzy, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "ensiö"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 msgstr[1] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -53813,47 +53881,47 @@ msgstr "%qD:lla ei voi olla oletusargumentteja"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "%qD-malli esitelty"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
@@ -53863,493 +53931,493 @@ msgstr "useita tallennuspaikkoja esittelymääritteissä"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "Vaaditaan todennus.\n"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "varjostunut esittely on täällä"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "edellinen määrittely oli täällä"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "nimellä %qD"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, fuzzy, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
@@ -54367,212 +54435,212 @@ msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 msgid "%s %#qS"
 msgstr ""
@@ -54580,82 +54648,82 @@ msgstr ""
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "%q+D:n edellinen esittely oli täällä"
@@ -54667,132 +54735,132 @@ msgstr "%q+D:n edellinen esittely oli täällä"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, fuzzy, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -54997,7 +55065,7 @@ msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, fuzzy, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
@@ -55047,7 +55115,7 @@ msgstr "perustyypin %qT kaksoiskappale virheellinen"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
@@ -55146,7 +55214,7 @@ msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -55186,7 +55254,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
@@ -55311,117 +55379,117 @@ msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, fuzzy, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%s:n arvon on oltava kokonaisluku"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
@@ -55661,817 +55729,817 @@ msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu t
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen bittikenttään"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "%<__alignof%>-avainsanaa sovellettu bittikenttään"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "nimikkeen osoitteen ottaminen ei ole standardia"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "vanhentunut tyyppimuunnos merkkijonovakiosta tyyppiin %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "vanhentunut tyyppimuunnos merkkijonovakiosta tyyppiin %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
 # semi-fuzzy
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, fuzzy, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, fuzzy, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ kieltää %<::main%>-funktion kutsumisen ohjelmasta"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "liikaa argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "liian vähän argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "liikaa argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "liikaa argumentteja metodille %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "liikaa argumentteja funktiolle"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "liian vähän argumentteja funktiolle"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kääntäjä voi olettaa, että %qD:n osoite ei koskaan ole NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL-arvon käyttö laskutoimituksessa"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ kieltää osoittimen ja kokonaisluvun vertailun"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ kieltää %<void *%>-tyyppisen osoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ kieltää funktio-osoittimen käytön vähennyslaskussa"
 
 # semi-fuzzy; onko metodi tässä luokan jäsenfunktio ja yllä muu funktio?
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "muodostimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, fuzzy, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "id="
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "väliaikaismuuttujan osoitteen ottaminen"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ kieltää %<::main%>-funktion osoitteen ottamisen"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "odotettiin lauseketta"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, fuzzy, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ kieltää enumin vähentämisen"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen kasvattamisen"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen vähentämisen"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, fuzzy, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "halutaan globaalin rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "esittely ei esittele mitään"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "tyyppimuunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "tarpeeton tyyppimuunnos tyyppiin %qT"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 #, fuzzy
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "muunnos epäyhteensopivien jäsenosoitintyyppien %qH ja %qI välillä"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "muunnos tyypistä %qT tyyppiin %qT kasvattaa kohdetyypin vaadittua kohdistusta"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "tyyppimuunnos funktio-osoittimen ja olio-osoittimen välillä on ehdollisesti tuettu"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ kieltää tyyppimuunnoksen taulukkotyyppiin %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, fuzzy, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "ei-vakio taulukon indeksi alustimessa"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "taulukkoa käytetty alustimena"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "virheellinen taulukkosijoitus"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "poista %<std::move%>-kutsu"
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "%s: liian monta arvoa"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "arvon palautus hajottimesta"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "arvon palautus muodostimesta"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "taulukon palauttava funktio"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> ei saa palauttaa NULLia ellei esittely ole %<throw()%> (tai -fcheck-new ole voimassa)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "virheellinen %%s-arvo"
@@ -56732,107 +56800,107 @@ msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, fuzzy, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, fuzzy, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "PRINT_OPERAND null-osoitin"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, fuzzy, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "sijoitus yhteensopimattomasta osoitintyypistä"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
@@ -57056,10 +57124,10 @@ msgstr "Taulukkoviitteellä kohdassa %C ei voi olla yli %d ulottuvuutta"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "Taulukkoviitteellä kohdassa %C ei voi olla yli %d ulottuvuutta"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -57226,7 +57294,7 @@ msgstr "Odotettiin taulukkoindeksiä kohdassa %C"
 msgid "Array constructor including type specification at %C"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
@@ -57345,7 +57413,7 @@ msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava vakio"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "epäkelpo osoitintila %qs"
@@ -57386,7 +57454,7 @@ msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "kääntäjänsisäisen ”%s”-funktion ”al” kohdassa %L on oltava INTEGER, REAL tai CHARACTER"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava numeerinen tyyppi"
@@ -57401,7 +57469,7 @@ msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdass
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava INTEGER tai PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava vakio"
@@ -57521,167 +57589,167 @@ msgstr "Erisuuret merkkipituudet (%ld/%ld) merkkijonossa %s kohdassa %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "kääntäjänsisäisen ”%3$s”-funktion argumenttien ”%1$s” ja ”%2$s” kohdassa %4$L on oltava samaa tyyppiä"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava osoitin tai VARIABLE tai FUNCTION"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER tai TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava saman tyyppinen ja kaltainen kuin ”%4$s”"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei ole kelvollinen ulottuvuusindeksi"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei saa olla läsnä, jos ”x” on COMPLEX-tyyppinen "
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava joko REAL tai INTEGER"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
@@ -57689,697 +57757,697 @@ msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on virheellinen ulottuvuuksia permutaatio (ulottuvuus ”%4$d” kahteen kertaan)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava tasoa %d tai sen on oltava skalaari"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava numeerinen tai LOGICAL"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava oletusreaaliluku"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava saman tyyppinen ja kaltainen kuin ”%4$s”"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava merkkijonon ”%4$s” kaltainen"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava vakio"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Puuttuva argumentti kohteelle ”%s” kohdassa %C"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”a%1$d” kohdassa %3$L on oltava %4$s(%5$d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "kääntäjänsisäisen ”%s”-funktion ”al” kohdassa %L on oltava INTEGER, REAL tai CHARACTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Kääntäjänsisäisen ”%s”-funktion argumenttityyppien kohdassa %L on täsmättävä (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion ”%1$s”-argumentin kohdassa %3$L on oltava tasoa 1 tai 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava saman tyyppinen ja kaltainen kuin ”%4$s”"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava OPTIONAL-valemuuttuja"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ”ei saa olla ”%4$s”:n aliobjekti"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "kääntäjänsisäisen ”reshape”-funktion argumentti ”shape” kohdassa %L ei saa olla vakiokokoinen taulukko"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on tyhjä"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentilla ”%1$s” kohdassa %3$L on negatiivinen alkio (%4$d)"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentilla ”%1$s” kohdassa %3$L on negatiivinen alkio (%4$d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on väärä määrä alkioita (%4$d/%5$d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on lukualueen ulkopuolinen ulottuvuus (%4$d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on virheellinen ulottuvuuksia permutaatio (ulottuvuus ”%4$d” kahteen kertaan)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava laajennettavaa tyyppiä"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "kääntäjänsisäisen ”shape”-funktion argumentti ”source” kohdassa %L ei saa olla oletetun kokoinen taulukko"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "kääntäjänsisäisen ”shape”-funktion argumentti ”source” kohdassa %L ei saa olla oletetun kokoinen taulukko"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$d tasoa"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei ole kelvollinen ulottuvuusindeksi"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "kääntäjänsisäisen ”TRANSFER”-funktion argumentti ”MOLD” kohdassa %L ei saa olla %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "kääntäjänsisäisen ”TRANSFER”-funktion argumentti ”MOLD” kohdassa %L ei saa olla %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "kääntäjänsisäisen ”TRANSFER”-funktion argumentti ”MOLD” kohdassa %L ei saa olla %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava samaa tasoa kuin ”%4$s” tai sen on oltava skalaari"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "kääntäjänsisäisen ”%3$s”-funktion argumenttien ”%1$s” ja ”%2$s” kohdassa %4$L on oltava muodoltaan identtisiä."
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” koko kohdassa %3$L on liian pieni (%4$i/%5$i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, fuzzy, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "Sarakkeiden määrä   : %d\n"
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "Sarakkeiden määrä   : %d\n"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$d:n kaltainen"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava INTEGER tai LOGICAL"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, fuzzy, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "Muodostin %qs"
@@ -58574,1756 +58642,1756 @@ msgstr "Kaksoiskappale %s-spesifikaatio kohdassa %C"
 msgid "deferred type parameter at %C"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Proseduurilla ”%s” kohdassa %C on eksplisiittinen rajapinta ja sillä ei saa olla attribuutteja, jotka on esitelty kohdassa %L"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "Odotettiin PARAMETER-symbolia kompleksivakiossa kohdassa %C"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "%s: paniikki: Virheellinen ”l_value” %d\n"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER kohdassa %L on ilman alustinta"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Alkio %s-taulukkomuodostimessa kohdassa %L on %s"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "Alkio %s-taulukkomuodostimessa kohdassa %L on %s"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, fuzzy, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-alustus kohdassa %C on moniselitteinen"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-alustus kohdassa %C on moniselitteinen"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "NULL()-alustus kohdassa %C on moniselitteinen"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, fuzzy, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Virheellinen merkki nimessä kohdassa %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Alkio %s-taulukkomuodostimessa kohdassa %L on %s"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Kaksoiskappalemuotospesifikaatio kohdassa %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Ei-vakio tyyppiesittely %s*%d kohdassa %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, fuzzy, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, fuzzy, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "loppumerkki %c puuttuu"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Kaksoiskappele %s attribuutti kohdassa %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, fuzzy, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribuutti kohdassa %L ei ole sallittu moduulin spesifikaatio-osan ulkopuolella"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "yhtenäistä dataa"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Useita tunnisteita tarjottu yhdellä NAME= tarkenteella kohdassa %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Virheellinen alustin %s Data-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Virheellinen alustin %s Data-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "symboli ”%s”"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Odotettiin vaihtoehtoista paluunimiötä kohdassa %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Kaksoiskappalesymboli ”%s” muodollisessa argumenttiluettelossa paikassa %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-muuttujan paikassa %C on oltava erilainen kuin funktionimen"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaksivirhe proseduuriosoitinkomponentissa kohdassa %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, fuzzy, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Puuttuva muotonimiö kohdassa %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Odotettiin ”%s”-lohkonimeä %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Odotettiin päättävää nimeä kohdassa %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "tyhjä esittely"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Odottamaton merkki muuttujaluettelossa kohdassa %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-osoittimen kohdassa %C on oltava kokonaisluku"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-osoittimella kohdassa %C on %d-tavun tarkkuus; muistiosoitteet vaativat %d tavua"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Odotettiin ”)” kohdassa %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Odotettiin muuttujanimeä kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Odotettiin lauseketta kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Alustetaan jo alustettu muuttuja kohdassa %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Odottamattomia merkkejä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, fuzzy, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "abstrakti metodi ei-abstraktissa luokassa"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "%s: Tulostetiedoston %s sulkeminen epäonnistui\n"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, fuzzy, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei saa olla OPTIONAL"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumeraattori ylittää C-kokonaislukutyypin kohdassa %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaksivirhe ENUMERATOR-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Roskaa CALL-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Tuntematon attribuutti !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
@@ -60448,12 +60516,12 @@ msgstr "Arvo sallitun välin ulkopuolella."
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
@@ -60528,7 +60596,7 @@ msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -60794,7 +60862,7 @@ msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
@@ -60852,167 +60920,167 @@ msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -61038,7 +61106,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -61229,12 +61297,12 @@ msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
@@ -61304,582 +61372,582 @@ msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L on jo liitetty toiseen varsinaiseen argumenttiin"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Odotettiin proseduuriosoitinta argumentille ”%s” kohdassa %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, fuzzy, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "ei voi emuloida %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, fuzzy, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei saa olla OPTIONAL"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "tyhjä esittely"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
@@ -61984,73 +62052,73 @@ msgstr "Odotettiin vaihtoehtoista paluunimiötä kohdassa %C"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, fuzzy, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, fuzzy, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "liikaa argumentteja funktiolle"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, fuzzy, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "virheellinen parametri %qs"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Laajennus: Muunnos tyypistä %s tyypiksi %s kohdassa %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
@@ -62058,22 +62126,22 @@ msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -62419,12 +62487,12 @@ msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
@@ -62434,7 +62502,7 @@ msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
@@ -62479,7 +62547,7 @@ msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
@@ -62574,7 +62642,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -62640,7 +62708,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaksivirhe %s-lauseessa kohdassa %C"
@@ -62655,83 +62723,83 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "Kokonaisluvun ylivuoto"
@@ -62976,505 +63044,505 @@ msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "toistorakenne [c*] ei saa esiintyä merkkijono1:ssä"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "Tauko"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Nolla ei ole kelvollinen lausekenimiö kohdassa %C"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "<tyyppivirhe>"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "nimitietueelle ei voi varata muistia"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Odotettiin komponenttiviitettä kohdassa %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Roskaa CALL-lauseen jälkeen kohdassa %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Syntaksivirhe IF-lauseessa kohdassa %C"
@@ -63482,217 +63550,217 @@ msgstr "Syntaksivirhe IF-lauseessa kohdassa %C"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Taulukkoviitteellä kohdassa %C ei voi olla yli %d ulottuvuutta"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Odotettiin alustuslauseketta CASE-lauseessa kohdassa %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "%qD on jo määritelty"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Odottamaton TYPE IS -lause kohdassa %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaksivirhe TYPE IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaksvirhe CLASS IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Nimiö ”%s” kohdassa %C ei täsmää IF nimiön ”%s” kanssa"
@@ -63733,12 +63801,12 @@ msgstr "  eikä %<operator=(const %T&)%>"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, fuzzy, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -64419,8 +64487,8 @@ msgstr "tyhjä esittely"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
@@ -65826,172 +65894,172 @@ msgstr "tyhjä esittely"
 msgid "Expected structure component name at %C"
 msgstr "Odotettiin komponenttiviitettä kohdassa %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: fortran/primary.c:2366
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Syntaksivirhe proseduuriosoitinkomponentissa kohdassa %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, fuzzy, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "attribuutti %qE pätee vain muuttujiin"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, fuzzy, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "attribuutti %qE pätee vain muuttujiin"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, fuzzy, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Symboli kohdassa %C ei sovellu lausekkeeseen"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Odottamaton alirutiininimen ”%s” käyttö kohdassa %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Käskyfunktio ”%s” vaatii argumenttiluettelon kohdassa %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "”%s” ei ole kelvollinen makron nimi, sillä se on C++:n operaattori"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
@@ -66318,493 +66386,493 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT-tyyppiä ”%s” käytetty kohdassa %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Odottamaton vaihtoehtoinen paluumäärittely alirutiinikutsussa kohdassa %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktiota ”%s” kohdassa %L ei voida kutsua rekursiivisesti, koska se ei ole RECURSIVE"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, fuzzy, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, fuzzy, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Arvo sallitun välin ulkopuolella."
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -66813,12 +66881,12 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -66827,283 +66895,283 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "<tyyppivirhe>"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "tulosta ei voi kirjoittaa: %s"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
@@ -67112,284 +67180,284 @@ msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABL
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "”%s” ei ole kelvollinen makron nimi, sillä se on C++:n operaattori"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -67397,187 +67465,187 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -67585,114 +67653,114 @@ msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
@@ -67700,842 +67768,842 @@ msgstr ""
 "  tai:  %s -l [SIGNAALI]...\n"
 "  tai:  %s -t [SIGNAALI]...\n"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, fuzzy, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Proseduurilla ”%s” kohdassa %C on eksplisiittinen rajapinta ja sillä ei saa olla attribuutteja, jotka on esitelty kohdassa %L"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
@@ -69221,153 +69289,153 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Nimiö ”%s” kohdassa %C ei täsmää IF nimiön ”%s” kanssa"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Odotettiin päättävää nimeä kohdassa %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbolia ”%s” käytetään ennen kuin sille määritellään tyyppi kohdassa %L"
@@ -69404,83 +69472,83 @@ msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, fuzzy, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Taulukkoviite rajojen ulkopuolella"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -69500,72 +69568,72 @@ msgstr "ei-vakio alustuslauseke kohdassa %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, fuzzy, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, fuzzy, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "%Jmuuttuja %qD esitelty %<inline%>:ksi"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Käyttämätön muuttuja ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Käyttämätön parameteri ”%s” esitelty kohdassa %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -69580,27 +69648,27 @@ msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "last-op"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -69636,22 +69704,22 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr "%s: rivi %d: virheellinen komento ”%s”\n"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 msgid "optional class parameter"
 msgstr "valinnainen argumentti"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "lauseella ei ole vaikutusta"
@@ -69761,82 +69829,82 @@ msgstr "täsmäämättömät argumentit"
 msgid "unable to open file"
 msgstr "tiedoston avaaminen ei onnistu"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "ei voitu luoda uutta ELF-lohkoa: %s"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "ei voitu jäsentää heksadesimaalinumeroa"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "ei voitu jäsentää tiedostosiirrosta"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "odottamaton siirros"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "tiedoston ”%s” otsaketta ei voi lukea"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Tiedostoa %s ei voi avata"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "arkiston otsaketta ei voi kartoittaa"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "tietokantaa %s ei voi lukea"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
@@ -70962,7 +71030,7 @@ msgstr "makron nimi puuttuu %qs:n jälkeen"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
@@ -71162,17 +71230,17 @@ msgstr "Funktio %qs"
 msgid "unknown TLS model %qs"
 msgstr "tls_model-argumentti ei ole merkkijono"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs:n alustuksen lähistöllä)"
@@ -71180,6 +71248,14 @@ msgstr "(%qs:n alustuksen lähistöllä)"
 #~ msgid "Same as %s.  Use the latter option instead."
 #~ msgstr "Sama kuin %s. Käytä tätä valitsinta ensimmäisen sijaan."
 
+#, fuzzy
+#~ msgid "Warn about code paths in which an uninitialized value is used."
+#~ msgstr "Varoita muuttujista, jotka alustetaan omalla arvollaan."
+
+#, fuzzy
+#~ msgid "Use instructions for a future architecture."
+#~ msgstr "ISO C kieltää sisäkkäiset funktiot"
+
 #, fuzzy
 #~ msgid "ASYNCHRONOUS= specifier at %L must be of default CHARACTER kind"
 #~ msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
diff --git a/gcc/po/fr.po b/gcc/po/fr.po
index fb7df47bb98..86d15e0a798 100644
--- a/gcc/po/fr.po
+++ b/gcc/po/fr.po
@@ -95,10 +95,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 10.1.0\n"
+"Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
-"PO-Revision-Date: 2020-05-09 08:27+0200\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
+"PO-Revision-Date: 2020-07-24 08:48+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
 "Language: fr\n"
@@ -1983,83 +1983,83 @@ msgstr "modificateur de longueur dans le format de strfmon"
 msgid "<command-line>"
 msgstr "<ligne-de-commande>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "opérande non supporté pour le code « %c »"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "opérande invalide pour « %%%c »"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante vecteur invalide"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "opérande en virgule flottante ou registre vecteur incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "opérande de registre incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "opérande manquant"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "constante invalide"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "opérande invalide"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "préfixe d'opérande invalide « %%%c »"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr "mode d'adresse invalide"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversion invalide depuis le type %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversion invalide vers le type %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "opération non permise sur le type %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "impossible de combiner les vecteurs GNU et SVE dans l'opération binaire"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "« %%& » utilisé sans référence à un TLS dynamique local"
@@ -2075,18 +2075,18 @@ msgid "invalid %%r value"
 msgstr "valeur %%r invalide"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "valeur %%R invalide"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
@@ -2116,7 +2116,7 @@ msgstr "valeur %%M invalide"
 msgid "invalid %%U value"
 msgstr "valeur %%U invalide"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
@@ -2126,7 +2126,7 @@ msgstr "valeur %%s invalide"
 msgid "invalid %%C value"
 msgstr "valeur %%C invalide"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
@@ -2136,10 +2136,10 @@ msgstr "valeur %%E invalide"
 msgid "unknown relocation unspec"
 msgstr "relocalisation unspec inconnue"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "valeur %%xn invalide"
@@ -2221,35 +2221,35 @@ msgstr "UNSPEC invalide comme opérande : %d"
 msgid "unrecognized supposed constant"
 msgstr "constante supposée non reconnue"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "opérande shift invalide"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruction Thumb établie"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruction établie dans la séquence conditionnelle"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Opérande non supporté pour le code « %c »"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2257,13 +2257,13 @@ msgstr "Opérande non supporté pour le code « %c »"
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "instruction jamais exécutée"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "code de format Maverick « %c » obsolète"
@@ -2385,7 +2385,7 @@ msgstr "opérande non supporté"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2602,25 +2602,25 @@ msgstr "mauvais opérande output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "mauvais opérande output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr "adresse ADDR_SPACE_GLOBAL invalide"
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, c-format
 msgid "invalid operand %%xn code"
 msgstr "code d'opérande %%xn invalide"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr "code %%xn d'opérande invalide pour QImode"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, c-format
 msgid "invalid fp constant"
 msgstr "constante en virgule flottante invalide"
@@ -2764,7 +2764,7 @@ msgstr "opération invalide sur %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "opérande %%P invalide"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -2818,7 +2818,7 @@ msgid "post-increment address is not a register"
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -2870,8 +2870,8 @@ msgstr "« %%%c » n'est pas un préfixe d'opérande valide"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "utilisation invalide de « %%%c »"
@@ -3002,165 +3002,202 @@ msgstr "Manque d'espace sur la pile.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Essayez d'exécuter « %s » dans le shell pour augmenter sa limite.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> nécessite une unité matérielle en virgule flottante"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> nécessite l'adressage indexé"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> et %<-mno-altivec%> sont incompatibles"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> désactive vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> n'est pas disponible en mode petit-boutiste"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, c-format
+msgid "invalid %%A value"
+msgstr "valeur %%A invalide"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "valeur %%D invalide"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, c-format
 msgid "invalid %%t value"
 msgstr "valeur %%t invalide"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "valeur %%V invalide"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "valeur %%z invalide"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 et __ibm128 ne peuvent pas être utilisés dans la même expression"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
+#: config/rs6000/rs6000.c:26740
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "conversion invalide depuis le type %<__vector_quad%>"
+
+#: config/rs6000/rs6000.c:26742
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "conversion invalide vers le type %<__vector_quad%>"
+
+#: config/rs6000/rs6000.c:26744
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "conversion invalide depuis le type %<__vector_pair%>"
+
+#: config/rs6000/rs6000.c:26746
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "conversion invalide vers le type %<__vector_pair%>"
+
+#: config/rs6000/rs6000.c:26754
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "conversion invalide depuis le type %<* __vector_quad%>"
+
+#: config/rs6000/rs6000.c:26757
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "conversion invalide vers le type %<* __vector_quad%>"
+
+#: config/rs6000/rs6000.c:26760
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "conversion invalide depuis le type %<* __vector_pair%>"
+
+#: config/rs6000/rs6000.c:26763
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "conversion invalide vers le type %<* __vector_pair%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3171,88 +3208,88 @@ msgstr "les références mémoire symboliques sont uniquement supportées sur z1
 msgid "cannot decompose address"
 msgstr "adresse indécomposable"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "opérateur de comparaison invalide pour le modificateur de sortie « E »"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "référence invalide pour le modificateur de sortie « J »"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « O »"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « R »"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "référence mémoire attendue pour le modificateur de sortie « S »"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « S »"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « N »"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « M »"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vecteur constant invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expression invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expression invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr "vecteur passé en argument à une fonction sans prototype"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "les types diffèrent sur le type signé/non-signé"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr "l'opérateur binaire ne supporte pas deux opérandes booléens vectoriels"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr "l'opérateur binaire ne supporte pas l'opérande booléen vectoriel"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "l'opérateur binaire ne supporte pas le mélange d'un booléen vectoriel avec un vecteur en virgule flottante"
 
@@ -3515,8 +3552,8 @@ msgstr "({anonyme})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
@@ -3536,7 +3573,7 @@ msgstr "%<;%> attendu"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -3544,7 +3581,7 @@ msgstr "%<)%> attendu"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -3562,21 +3599,21 @@ msgstr "%<;%>, %<,%> ou %<)%> attendu"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -3587,12 +3624,12 @@ msgstr "%<{%> attendu"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
@@ -3601,7 +3638,7 @@ msgstr "%<while%> attendu"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -3610,18 +3647,18 @@ msgstr "%<,%> attendu"
 msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> ou %<)%> attendu"
@@ -3629,19 +3666,19 @@ msgstr "%<,%> ou %<)%> attendu"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> ou %<}%> attendu"
@@ -3650,7 +3687,7 @@ msgstr "%<#pragma omp section%> ou %<}%> attendu"
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> attendu"
@@ -3661,33 +3698,33 @@ msgstr "%<<%> attendu"
 msgid "expected label"
 msgstr "étiquette attendue"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr "candidat :"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 msgid "  after user-defined conversion:"
 msgstr "  après la conversion définie par l'utilisateur :"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
 msgstr[1] "les candidats sont :"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "candidat 1 :"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "candidat 2 :"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "saut à l'étiquette %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "saut à l'étiquette du « case »"
 
@@ -3776,7 +3813,7 @@ msgstr "<erreur de paramètre du patron>"
 msgid "<statement>"
 msgstr "<déclaration>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<inconnu>"
@@ -3942,48 +3979,48 @@ msgstr "la conversion supprime l'attribut « const »"
 msgid "source type is not polymorphic"
 msgstr "le type source n'est pas polymorphique"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "type d'argument erroné pour le moins unaire"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "type d'argument erroné pour le plus unaire"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "type d'argument erroné pour le complément de bit"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "type d'argument erroné pour abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "type d'argument erroné pour la conjugaison"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "dans l'argument d'un unaire !"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "pas d'opérateur de pré-incrémentation pour le type"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "pas d'opérateur de post-incrémentation pour le type"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "pas d'opérateur de pré-décrémentation pour le type"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "pas d'opérateur de post-décrémentation pour le type"
 
@@ -4023,17 +4060,17 @@ msgstr "Type illégal dans la concaténation de caractère à %L"
 msgid "elemental binary operation"
 msgstr "opération binaire élémentaire"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "arguments « a%d » et « a%d » pour l'intrinsèque « %s »"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "arguments « %s » et « %s » pour l'intrinsèque %s"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "arguments « %s » et « %s » pour l'intrinsèque « %s »"
@@ -4112,7 +4149,7 @@ msgstr "Désaccord de la limite du tableau pour la dimension 2 du tableau (%ld/%
 msgid "Driving:"
 msgstr "Pilotage:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argument effectif de INTENT = OUT/INOUT"
 
@@ -4127,7 +4164,7 @@ msgstr "unité interne dans WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "étiquette %s avec INQUIRE"
@@ -4233,11 +4270,11 @@ msgstr "bloc IF"
 msgid "implied END DO"
 msgstr "END DO implicite"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
@@ -4245,199 +4282,199 @@ msgstr "affectation de pointeur"
 msgid "simple IF"
 msgstr "IF simple"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "procédure élémentaire"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr "argument qui peut être alloué"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr "argument asynchrone"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "argument optionnel"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "argument pointeur"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "argument cible"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "argument valeur"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr "argument volatile"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr "argument de forme tacite (assumed-shape)"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr "argument de rang tacite (assumed-rank)"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr "argument co-tableau"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr "argument de type dérivé paramétrisé"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr "argument polymorphique"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "attribut NO_ARG_CHECK "
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr "argument de type tacite (assumed-type)"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "résultat tableau"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr "résultat pointeur ou allouable"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr "résultat avec une longueur de caractères non constante"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr "procédure bind(c)"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Contexte invalide pour un pointeur NULL() à %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur numérique unaire %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Entités de type dérivé inattendues dans l'opérateur numérique intrinsèque binaire %%<%s%%> à %%L"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur numérique binaire %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de concaténation de chaînes à %%L sont %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur logique %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "L'opérande de l'opérateur .not. à %%L est %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Les quantités COMPLEX ne peuvent pas être comparées à %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Les valeurs logiques à %%L doivent être comparées avec %s au lieu de %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de comparaison %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Opérateur %%<%s%%> inconnu à %%L; vouliez-vous utiliser « %s » ?"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Opérateur %%<%s%%> inconnu à %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur utilisateur %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur utilisateur %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangs inconsistant pour l'opérateur à %%L et %%L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr "variable d'itérateur"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "Expression de départ dans la boucle DO"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "Expression de fin dans la boucle DO"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "Expression de pas dans la boucle DO"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "objet ALLOCATE"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -4450,27 +4487,27 @@ msgstr "Longueurs de CHARACTER différentes (%ld/%ld) dans le constructeur de ta
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Débordement d'entier en calculant la quantité de mémoire à allouer"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "La valeur du paramètre PDT LEN « %s » n'est pas en accord avec celle dans la déclaration fictive"
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne ne correspond pas à celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne est plus courte que celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "La cible du remappage de rang est trop petite (%ld < %ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr "Assignation d'un scalaire à un tableau non alloué"
 
@@ -4545,7 +4582,7 @@ msgstr "Le numéro d'unité dans l'expression E/S est trop grand"
 msgid "Assigned label is not a target label"
 msgstr "L'étiquette assignée n'est pas une étiquette cible"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Numéro d'image %d invalide dans SYNC IMAGES"
@@ -4968,7 +5005,7 @@ msgstr "Avertir à propos de la création de temporaires de tableaux."
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ne fait rien. Préservé pour rétro-compatibilité."
@@ -5550,8 +5587,8 @@ msgstr "Ajouter un souligné aux noms visibles depuis l'extérieur."
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ne fait rien. Préservé pour rétro-compatibilité."
@@ -7993,105 +8030,100 @@ msgstr "Avertir à propos de chemins dans le code où un pointeur vers une pile
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Avertir à propos de chemins dans le code où une valeur non initialisée est utilisée."
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr "Avertir si le code est trop compliqué pour que l'analyseur réussisse à l'explorer entièrement."
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr "Restreindre l'analyseur à l'exécution du seul vérificateur nommé."
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr "Éviter de combiner plusieurs instructions dans une arrête éclatée."
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr "Émettre une note quand les doublons dans les diagnostiques sont supprimés"
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr "Purger les états non utilisés durant l'analyse."
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr "Fusionner des états suffisamment similaires durant l'analyse."
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr "Activer la transitivité des contraintes durant l'analyse."
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr "Approximer l'effet des appels de fonctions pour simplifier l'analyse."
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr "Produire des descriptions plus verbeuses du flux de contrôle dans les diagnostiques."
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr "Produire de description plus verbeuse des changements d'états dans les diagnostiques."
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr "Contrôler quels événements sont affichés dans les chemins de diagnostiques."
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "Vidanger divers détails internes de l'analyseur dans FICHIERSRC.analyzer.txt."
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr "Vidanger divers détails internes de l'analyseur vers stderr."
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr "Vidanger des informations du graphe d'appel spécifiques à l'analyseur dans un fichier FICHIERSRC.callgraph.dot."
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr "Vidanger le graphe éclaté de l'analyseur dans un fichier FICHIERSRC.eg.dot."
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr "Produire des diagnostiques montrant l'emplacement des nœuds dans le graphe éclaté."
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr "Vidanger une représentation textuelle du graphe éclaté dans FICHIERSRC.eg.txt."
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr "Vidanger une représentation textuelle du graphe éclaté dans FICHIERSRC.eg-ID.txt."
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr "Vidanger les informations de la purge d'états dans un fichier FICHIERSRC.state-purge.dot."
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr "Vidanger le supergraphe de l'analyseur dans un fichier FICHIERSRC.supergraph.dot."
@@ -12526,8 +12558,8 @@ msgstr "Activer les conversions par défaut entre __float128 et long double."
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
-msgstr "Utiliser les instructions pour une architecture future."
+msgid "Use instructions added in ISA 3.1."
+msgstr "Utiliser les instructions ajoutées dans l'ISA 3.1."
 
 #: config/rs6000/rs6000.opt:576
 #, no-c-format
@@ -12539,6 +12571,11 @@ msgstr "Générer (ne pas générer) les instructions mémoire préfixées."
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Générer (ne pas générer) d'adressage mémoire relatif au PC."
 
+#: config/rs6000/rs6000.opt:584
+#, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Générer (ne pas générer) les instructions MMA."
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17486,7 +17523,7 @@ msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tNiveau de c
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr "Supprimer le préfixe du chemin absolu avant de dégrader le nom pour -fprofile-generate= et -fprofile-use=."
 
 #: common.opt:2217
@@ -18130,367 +18167,367 @@ msgstr "Dérouler les boucles quand le nombre d'itérations est connu."
 msgid "Perform loop unrolling for all loops."
 msgstr "Dérouler toutes les boucles."
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Autoriser l'optimisation de l'arithmétique en virgule flottante qui peut changer le résultat de l'opération à cause de l'arrondi."
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Identique à -fassociative-math pour les expressions contenant des divisions."
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Permettre les optimisations mathématiques qui peuvent violer les standards IEEE ou ISO."
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Déplacer les boucles à l'intérieur des branchements quand c'est possible."
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Scinder les boucles pour éliminer des conditions qui sont constantes sur une plage de la boucle (Loop Splitting)."
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr "Décliner les versions des boucles basées sur le fait que les indices ont un pas de un."
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Générer uniquement les tables de retour en arrière pour la gestion des exceptions."
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens bfd au lieu de l'éditeur par défaut."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens gold au lieu de l'éditeur par défaut."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens lld de LLVM au lieu de l'éditeur par défaut."
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Réaliser le pistage des variables."
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Réaliser le pistage des variables en annotant les affectations."
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Basculer -fvar-tracking-assignments."
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Réaliser le pistage des variables et aussi étiqueter les variables qui ne sont pas initialisées."
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Activer la vectorisation sur les arbres."
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Activer la vectorisation des boucles sur les arbres."
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Activer la vectorisation des blocs de base (SLP) sur les arbres."
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpécifie le modèle de coût pour la vectorisation."
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpécifier le modèle de coût de la vectorisation pour du code marqué par la directive simd."
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Activer le modèle de coût du vectoriseur dynamique. Préservé pour rétro-compatibilité."
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activer la propagation par copie des informations sur l'évolution scalaire."
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Ajouter des commentaires additionnels à la sortie de l'assembleur."
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tDéfinir la visibilité par défaut des symboles."
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Valider les pointeurs dans la vtable avant de les utiliser."
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Sortir les compteurs de vérifications des vtables."
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Sortir les informations sur les ensembles de pointeurs pour la vérification des vtables."
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Utiliser les profils des valeurs des expressions dans les optimisations."
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Construire une toile et séparer les utilisations sans relations d'une variable seule."
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Activer l'élimination conditionnelle du code mort pour les appels internes."
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Réaliser les optimisations sur tout le programme."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Supposer que le débordement de pointeur revient au départ."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Supposer que le débordement de l'arithmétique signée boucle sur la plage accessible."
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Placer des données initialisées à zéros dans la section bss."
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Générer les informations de débogage dans le format par défaut."
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Supposer que l'assembleur supporte les directives .loc (DWARF2+)."
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Supposer que l'assembleur supporte les vues dans les directives .loc (DWARF2+)."
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Enregistrer DW_AT_decl_column et DW_AT_call_column dans DWARF."
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Générer les informations de débogage dans la version par défaut du format DWARF."
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Générer les informations de débogage dans le format DWARF v2 (ou ultérieur)."
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Générer les informations de débogage dans le format étendu par défaut."
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Générer des information étendues pour les points d'entrées des fonctions en ligne."
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr "Calculer les points de réinitialisation locview sur base des estimations des longueurs des insns."
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Ne pas générer les sections DWARF pubnames et pubtypes."
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Générer les sections DWARF pubnames et pubtypes."
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Générer les sections DWARF pubnames et pubtypes avec les extensions GNU."
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Enregistrer les options de la ligne de commande de gcc dans DW_AT_producer de DWARF."
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Générer les informations de débogage dans des fichiers .dwo séparés."
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Générer les informations de débogage dans le format STABS."
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Générer les informations de débogage dans le format STABS étendu."
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Émettre des emplacements de points d'arrêt progressifs recommandés"
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Ne pas produire les suppléments DWARF au delà de la version sélectionnée."
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr "Ajouter les attributs de description à certains DIEs DWARF qui n'ont pas d'attribut de nom."
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Inverser l'option actuelle de génération des informations de débogage."
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr "Augmenter les listes de positions de variables avec des vues progressives."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Générer les informations de débogage dans le format VMS."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Générer les informations de débogage dans le format XCOFF."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Générer les informations de débogage dans le format XCOFF étendu."
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Générer des sections de débogage compressées."
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tGénérer les sections de débogage compressées dans le format <format>."
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<répertoire>\tDéfinir le <répertoire> comme étant le répertoire par défaut des modules externes."
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <répertoire>\tDéfinir le <répertoire> comme étant le sous-répertoire d'inclusion multiarch."
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fichier>\tPlacer la sortie dans le <fichier>."
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Autoriser le profilage des fonctions."
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Comme -pedantic mais les avertissements sont rapportés comme des erreurs."
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Ne pas afficher les fonctions compilées ni le temps écoulé."
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Activer la sortie en mode bavard."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Afficher la version du compilateur."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Supprimer les avertissements."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Créer une bibliothèque partagée."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Ne pas créer un exécutable indépendant de la position dynamiquement lié."
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Créer un exécutable indépendant de la position dynamiquement lié."
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Créer un exécutable statique indépendant de la position."
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Faire sauvegarder les registres par l'appelant au travers des appels si possible."
@@ -19641,8 +19678,8 @@ msgstr "Limite sur le nombre de vérifications à l'exécution pour détecter le
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Limite sur le nombre de vérifications à l'exécution de l'alignement que le code qui décline les versions des boucles vectorisées doit insérer."
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "la valeur calculée n'est pas utilisée"
@@ -19668,7 +19705,7 @@ msgid "expected boolean type"
 msgstr "type booléen attendu"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "entier attendu"
@@ -19732,7 +19769,7 @@ msgstr "pas assez d'arguments"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "trop d'arguments"
@@ -20087,7 +20124,7 @@ msgstr "l'attribut %qE est ignoré car il est en conflit avec l'attribut %qs"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20171,12 +20208,12 @@ msgstr "les attributs de type sont ignorés après que le type ait déjà été
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20194,8 +20231,8 @@ msgstr "attribut %qE ignoré"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "attribut %<target%> manquant pour %qD avec plusieurs versions"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "déclaration précédente de %qD"
@@ -20314,7 +20351,7 @@ msgstr "l'argument référencé est déclaré ici"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "le décalage %qwi est hors des limites de la chaîne constante"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE déclaré ici"
@@ -20601,7 +20638,7 @@ msgstr "argument 0 invalide pour %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack ()%>"
@@ -20891,12 +20928,12 @@ msgstr "l'écrasement %<asm%> entre en conflit avec l'opérande de sortie"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "l'écrasement %<asm%> entre en conflit avec l'opérande d'entrée"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "la protection de la pile ne protège pas les variables locales: tampon de longueur variable"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "la protection de la pile ne protège pas la fonction: tous les tableaux locaux font moins de %d octets de longueur"
@@ -21407,302 +21444,302 @@ msgstr "les blocs de base n'ont pas été disposés consécutivement"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "le nombre d'annotations des bb dans la chaîne des insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "le nombre d'arêtes de l'appelant est invalide"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr "appel indirect manquant dans la séquence d'appel spéculative"
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr "l'appel indirect dans la séquence d'appel spéculative n'a pas le fanion spéculatif"
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr "les arrêtes spéculatives ne sont pas adjacentes"
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr "l'appel direct à %s dans la séquence d'appel spéculative n'a pas de fanion spéculatif"
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr "l'appel direct à %s dans une séquence d'appel spéculative a speculative_id %i hors limites"
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr "appel direct dupliqué pour %s dans la séquence d'appel spéculative avec speculative_id %i"
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr "le hachage de l'instruction d'appel ne pointe pas vers la première arrête directe de la séquence d'appel spéculative"
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr "référence %s dupliquée dans la séquence d'appel spéculative avec speculative_id %i"
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "appel direct manquant pour la spéculation %i"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "référence manquante pour la spéculation %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr "le nombre de cibles spéculatives %i est en désaccord avec num_speculative_call_targets %i"
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "champ aux défini pour l'arête %s->%s"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "décompte cgraph invalide"
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "clone en ligne dans la même liste du groupe comdat"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "le nombre de clones en ligne n'est pas compatible"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "tp_first_run doit être non négatif"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "les symboles locaux doivent être définis"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clone en ligne visible depuis l'extérieur"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clone en ligne avec l'adresse prise"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "le clone en ligne est forcé à sortir"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr "calls_comdat_local est défini en dehors d'un groupe comdat"
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr "fanion calls_comdat_local invalide"
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "l'attribut malloc devrait être utilisé pour une fonction qui retourne un pointeur"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "champ aux défini pour une arête indirecte depuis %s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "le décompte d'arêtes n'est pas compatible avec le décompte de fonction"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Une arête indirecte depuis %s n'est pas marquée comme indirecte ou a un indirect_info associé, l'instruction correspondante est: "
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr "l'arête a, à la fois, call_stmt et lto_stmt_uid définis"
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "la fonction locale comdat est appelée par %s en dehors de son comdat"
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "le pointeur inlined_to est faux"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "appelants en ligne multiples"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "pointeur inlined_to défini pour des appelants pas en ligne"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "le décompte des arêtes de l'appelant ne correspond pas au décompte du BB"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "le décompte des appels indirects ne correspond pas au décompte du BB"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr "la référence a, à la fois, stmt et lto_stmt_uid définis"
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "le pointeur inlined_to est défini mais aucun prédécesseur trouvé"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "le pointeur inlined_to fait référence à lui même"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "le cgraph_node a un mauvais clone_of"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "le cgraph_node a une mauvaise liste de clones"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "le cgraph_node est dans la liste des clones mais il n'est pas un clone"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "le cgraph_node a un mauvais pointeur prev_clone"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "la liste doublement liée des clones est corrompue"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "L'alias a des arêtes d'appel"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "L'alias a une référence qui n'est pas un alias"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "L'alias a plus d'une référence alias"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "L'alias analysé n'a pas de référence"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Pas d'arête hors du nœud du fragment"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Plus d'une arête sortante hors du nœud du fragment"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Le fragment n'est pas supposé avoir un contenu"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt partagé:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "l'arête pointe vers la mauvaise déclaration:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "une arête indirecte avec un appelé inconnu correspondant à un call_stmt avec une déclaration connue:"
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "arête callgraph manquante pour l'appel stmt:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "référence à une instruction morte"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "l'arête %s->%s n'a pas de call_stmt correspondant"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "une arête indirecte depuis %s n'a pas de call_stmt correspondant"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr "origine manquante pour un nœud dans une liste imbriquée"
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "l'origine pointe vers un parent différent"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node a échoué"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s: la section %s.%d est manquante"
@@ -21788,12 +21825,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "l'attribut %<weakref%> est ignoré car la variable est initialisée"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F utilisé mais jamais défini"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F déclaré %<static%> mais jamais défini"
@@ -21945,7 +21982,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "le support LTO n'a pas été activé dans cette configuration"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "ne peut ouvrir %s: %m"
@@ -22275,22 +22312,22 @@ msgstr "%<-gdwarf-6%> est émis sous la version 5 avec des incompatibilités"
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "UNSPEC non délégitimisé %s (%d) trouvé à l'emplacement de la variable"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "partage rtl invalide repéré dans l'insn"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "rtx partagé"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "défaut d'inconsistance interne"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn utilisé là où emit_jump_insn est attendu :\n"
@@ -22350,7 +22387,7 @@ msgstr "%<region_array%> ne correspond pas à %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> ne correspond pas à %<region_tree%>"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs a échoué"
@@ -22380,12 +22417,12 @@ msgstr "ordre de stockage inverse pour le mode %s"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "écriture de %wu bits de données hors des limites de l'objet de destination, les données ont été tronquées dans %wu bits"
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kappel à %qs déclaré avec une erreur d'attribut: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kappel à %qs déclaré avec un avertissement d'attribut: %s"
@@ -22400,7 +22437,7 @@ msgstr "argument %qs invalide pour %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "la taille de trame de %wu octets est plus grande que %wu octets"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "n'a pu ouvrir le fichier de vidange des insn finales %qs: %m"
@@ -22420,37 +22457,37 @@ msgstr "la constante de grande taille en virgule fixe a été tronquée implicit
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "comparaison est toujours %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de tests de non égalités non appariés est toujours 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de tests d'égalités mutuellement exclusifs est toujours 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque la constante dans la comparaison est réduite"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque des constantes sont combinées autour d'une comparaison"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vérification fold: arbre originale modifié par fold"
@@ -23070,13 +23107,13 @@ msgstr "la fonction peut retourner l'adresse d'une variable locale"
 msgid "function returns address of local variable"
 msgstr "la fonction retourne l'adresse d'une variable locale"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "déclaré ici"
@@ -23644,10 +23681,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "%G%qD le décalage %s est hors des limites de l'objet %qD avec le type %qT"
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -23815,7 +23852,7 @@ msgstr "%qE non spécifié dans le %<target%> englobant"
 msgid "enclosing %<target%>"
 msgstr "%<target%> englobant"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE est déclarée dans une région %<host_data%> englobante"
@@ -23865,13 +23902,13 @@ msgstr "variable non scalaire %qD dans la clause %<lastprivate%> conditionnelle"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr "modificateur de réduction %<task%> sur une construction avec une clause %<nowait%>"
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr "modificateur de réduction %<task%> invalide sur une construction autre que %<parallel%>, %<for%> ou %<sections%>"
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "clause %<inscan%> %<reduction%> sur la construction %qs"
@@ -23881,148 +23918,148 @@ msgstr "clause %<inscan%> %<reduction%> sur la construction %qs"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "la clause %<linear%> pour une variable autre qu'un itérateur de boucle est spécifiée sur une construction combinée avec %<distribute%>"
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "champ de correspondance %qE d'une structure de longueur variable"
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE apparaît plus d'une fois dans la clause de correspondance (map)"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable « copyprivate » %qE n'est pas « threadprivate » ou privée dans le contexte extérieur"
 
 # le %s est remplacé par des mots-clé non traduits tels que « firstprivate », « lastprivate »,…
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable « %s » %qE est privée dans le contexte extérieur"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "modificateur de clause %qs %<if%> attendu au lieu de %qs"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr "%qD est spécifié dans la clause %qs mais pas dans la clause %<inscan%> %<reduction%> sur la construction contenante"
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<map%>"
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "la même variable est utilisée dans les clauses %<firstprivate%> et %<lastprivate%> dans la construction %<distribute%>"
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "clause de données avec réduction sur %qE incompatible; promu en %<present_or_copy%>"
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr "%qD spécifié dans la clause %<inscan%> %<reduction%> mais dans dans la clause directive %<scan%>"
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "réduction privée invalide sur %qE"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "la clause %<inscan%> %<reduction%> est utilisée avec la clause %<linear%> pour une variable autre qu'un itérateur de boucle"
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "type %<mutexinoutset%> dans la clause %<depend%> sur un constructeur %<taskwait%>"
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "le %<lastprivate%> conditionnel sur l'itérateur de boucle %qD est ignoré"
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "la clause %<bind%> n'est pas spécifiée sur une construction %<loop%> pas imbriquée dans une autre construction OpenMP"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<bind(parallel)%> sur une construction %<loop%> imbriquée dans une construction %<simd%>"
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "%<bind(team)%> sur une région %<loop%> pas strictement imbriquée dans une région %<team%>"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "la clause %<lastprivate%> sur une construction %<loop%> fait référence à une variable %qD qui n'est pas l'itérateur de boucle"
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "une construction %<ordered%> avec une clause %<depend%> doit être étroitement imbriquée dans une boucle avec une clause %<ordered%> avec un paramètre"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE n'est pas une itération de la boucle %d la plus à l'extérieur, %qE attendu"
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "le nombre de variables dans la clause %<depend%> avec le modificateur %<sink%> ne correspond pas au nombre de variables d'itérations"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "plus d'une clause %<depend%> avec le modificateur %<source%> sur une construction %<ordered%>"
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "une clause %<depend%> avec le modificateur %<source%> a été spécifiée avec des clauses %<depend%> avec le modificateur %<sink%> sur la même construction"
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "la gimplification a échoué"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT a été promu en %qT lors du passage à travers %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(vous devriez donc passer %qT et non %qT à %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si ce code est atteint, le programme s'arrêtera"
@@ -24097,7 +24134,7 @@ msgstr "le jeton %u a %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "le jeton %u a %<y-location == %u%>"
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "utilisation invalide de l'attribut %<fallthrough%>"
@@ -24369,54 +24406,54 @@ msgstr "désaccord dans la disposition de la mémoire"
 msgid "the extra base is defined here"
 msgstr "la base supplémentaire est définie ici"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appel"
 msgstr[1] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appels"
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appel exécuté %lli fois"
 msgstr[1] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appels exécutés %lli fois"
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appel"
 msgstr[1] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appels"
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] "La déclaration de la méthode %qD comme étant finale permettrait la dévirtualisation de %i appel"
 msgstr[1] "La déclaration de la méthode %qD comme étant finale permettrait la dévirtualisation de %i appels"
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appel exécuté %lli fois"
 msgstr[1] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appels exécutés %lli fois"
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "La déclaration de la méthode %qD comme étant finale permettrait la dévirtualisation de %i appel exécuté %lli fois"
 msgstr[1] "La déclaration de la méthode %qD comme étant finale permettrait la dévirtualisation de %i appels exécutés %lli fois"
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "fnsummary invalide dans un flux LTO"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "le résumé en ligne ipa est manquant dans le fichier d'entrée"
@@ -24446,37 +24483,37 @@ msgstr "la fonction pourrait être une candidate pour l'attribut %qs si elle est
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "le résumé de référence ipa est manquant dans l'unité ltrans"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr "Décalage d'accès avant le décalage parent"
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr "Taille d'accès plus grande ou égale à la taille de son parent"
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr "L'accès se termine en dehors de son parent"
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr "L'accès chevauche un de ses semblables"
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr "La vérification d'accès IPA-SRA a échoué"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr "Fonction %qs, paramètre %u, a des accès IPA-SRA qui se chevauchent"
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr "Fonction %s, paramètre %u, est utilisée mais n'a pas certains accès IPA-SRA"
@@ -24526,57 +24563,57 @@ msgstr "contraintes d'opérande inconsistantes dans un %<asm%>"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "le nombre maximum d'insns de rechargement générées par insn est atteint (%d)"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr "la fonction %qs a été référencée dans du code déchargé mais n'a pas été marquée comme devant être incluse dans le code déchargé"
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr "la variable %qs a été référencée dans du code déchargé mais n'a pas été marquée comme devant être incluse dans le code déchargé"
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "flux bytecode: plusieurs instances trouvées pour le nœud cgraph avec le uid %d"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "flux bytecode: aucun appelant trouvé en lisant l'arête"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "flux bytecode: aucun appelé trouvé en lisant l'arête"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "flux bytecode: nœud cgraph vide rencontré"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Un maximum de %i exécutions d'un profile est supporté. Le profile est peut-être corrompu ?"
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Les informations de profile dans %s sont corrompues"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "impossible de trouver le cgraph LTO dans %s"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "impossible de trouver les références des sections LTO dans %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "table de délestage invalide dans %s"
@@ -24828,53 +24865,53 @@ msgstr "la clause %<depend%> avec le modificateur %<sink%> attend une itération
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr "la clause %<depend%> avec le modificateur %<sink%> fait référence à une itération qui n'est jamais dans l'espace d'itération"
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr "%qs spécifie un niveau de parallélisme conflictuel"
 
 # ce message fait référence à une valeur (dans c-common.c) ou une condition (c-warn.c), d'où le féminin
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr "… avec la clause %qs précédente ici"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr "impossible d'appliquer %<%s%> à %qD, qui a aussi été marqué avec une directive OpenMP « declare target »"
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr "clause %qs incompatible en appliquant %<%s%> à %qD, qui a déjà été marqué avec une directive « routine » de OpenACC"
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr "clause %qs manquante en appliquant %<%s%> à %qD, qui a déjà été marqué avec une directive « routine » de OpenACC"
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "… avec la clause %qs ici"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr "… sans la clause %qs proche d'ici"
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> écrase d'autres spécificateurs de boucle de OpenACC"
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> entre en conflit avec d'autres spécificateurs de boucle de OpenACC"
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "la boucle intérieure utilise le même parallélisme OpenACC que la boucle qui la contient"
@@ -25095,52 +25132,52 @@ msgstr "entrée invalide dans le bloc structuré %s"
 msgid "invalid branch to/from %s structured block"
 msgstr "branchement invalide vers/depuis le bloc structuré %s"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr "l'opérande %<-fopenacc-dim%> est mal formé à %qs"
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr "l'appel de routine utilise le même parallélisme OpenACC que la boucle qui la contient"
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr "la boucle contenante est ici"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr "l'appel de routine utilise un parallélisme OpenACC interdit par la routine contenante"
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr "la boucle utilise un parallélisme OpenACC interdit par la routine contenante"
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "la routine %qD est déclarée ici"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr "parallélisme de boucle OpenACC incorrectement imbriqué"
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr "partitionnement insuffisant pour paralléliser la boucle des éléments"
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr "partitionnement disponible insuffisant pour paralléliser la boucle découpée en blocs"
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr "partitionnement disponible insuffisant pour paralléliser la boucle"
@@ -26473,132 +26510,132 @@ msgstr "%<-fcf-protection=return%> n'est pas supporté pour cette cible"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> n'est plus supporté"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "l'ordonnancement d'instructions n'est pas supporté sur cette machine cible"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "cette machine cible n'a pas de branchements différés"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "%<-f%sleading-underscore%> n'est pas supporté sur cette machine cible"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "impossible de fermer le fichier de vidange des insn mises à zéro %qs: %m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "le système cible ne supporte par le format de débogage %qs"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "le pistage des variables a été demandé mais il est inutile sans produire d'informations de débogage"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "le pistage des variables a été demandé mais il n'est pas supporté par ce format de débogage"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments change l'ordonnancement sélectif"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr "sans %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> est équivalent à %<-gvariable-location-views%>"
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr "%<-ginternal-reset-location-views%> est forcé désactivé sans %<-gvariable-location-views%>"
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr "%<-ginline-points%> est forcé désactivé sans %<-gstatement-frontiers%>"
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "%<-ffunction-sections%> n'est pas supporté pour cette cible"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "%<-fdata-sections%> n'est pas supporté pour cette cible"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "%<-fprefetch-loop-arrays%> n'est pas supporté pour cette cible"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "%<-fprefetch-loop-arrays%> n'est pas supporté pour cette cible (essayez les options %<-march%>)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "%<-fprefetch-loop-arrays%> n'est pas supporté avec %<-Os%>"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "%<-fassociative-math%> désactivé; d'autres options prennent le pas"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr "%<-fstack-clash-protection%> n'est pas supporté sur des cibles où la pile grandi depuis les adresses basses vers les adresses hautes"
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr "%<-fstack-check=%> et %<-fstack-clash_protection%> sont mutuellement exclusives; %<-fstack-check=%> est désactivée"
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "%<-fstack-protector%> n'est pas supporté pour cette cible"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "%<-fsanitize=address%> et %<-fsanitize=kernel-address%> ne sont pas supportés pour cette cible"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "erreur d'écriture dans %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "erreur de fermeture de %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr "mpfr n'est pas configuré pour gérer tous les modes en virgule flottante"
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "auto-tests incompatibles avec %<-E%>"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "les auto-tests ne sont pas activés dans cet exécutable"
@@ -26693,172 +26730,172 @@ msgstr "%K%<asm%> pas permis dans une fonction %<transaction_safe%>"
 msgid "ignoring loop annotation"
 msgstr "ignore l'annotation de boucle"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "la constante n'a pas été recalculée quand %<ADDR_EXPR%> a changé"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "les effets de bords n'ont pas été recalculés quand %<ADDR_EXPR%> a changé"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "%<DECL_GIMPLE_REG_P%> est défini sur une variable dont l'adresse est prise"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "l'adresse est prise mais le bit %<TREE_ADDRESSABLE%> n'est pas défini"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "expression invalide pour la l-valeur min"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "opérande invalide dans la référence indirecte"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr "%qs non scalaire"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "position ou opérande de taille invalide pour %qs"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr "la précision du type résultant intégral ne correspond pas à la taille du champ de %qs"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "la taille du mode du résultat non intégral ne correspond pas à la taille du champ de %qs"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "%qs dans un opérande non-mode-precision"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "la position plus la taille dépasse la taille de l'objet référencé dans %qs"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr "désaccord de type dans la référence %qs"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr "%qs pas au plus haut niveau"
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "opérande invalide pour %qs"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "désaccord de type dans %qs"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "opérande de décalage %qs invalide"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "conversion d'un %qs dans le membre de gauche de %qs"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "conversion d'un registre vers une taille différente dans %qs"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "opérande d'adresse invalide dans %qs"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "opérande de décalage invalide dans %qs"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "clique invalide dans %qs"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "%qs dans IL gimple"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "l'appel gimple a deux cibles"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "l'appel gimple n'a pas de cible"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "fonction invalide dans l'appel gimple"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "non fonction dans un appel gimple"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "type const pure invalide pour la fonction"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "membre de gauche invalide dans un appel gimple"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr "membre de gauche dans un appel %<noreturn%>"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "conversion invalide dans un appel gimple"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "chaîne statique invalide dans un appel gimple"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "chaîne statique avec une fonction qui n'en utilise pas"
@@ -26869,507 +26906,507 @@ msgstr "chaîne statique avec une fonction qui n'en utilise pas"
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "appel %<__builtin_unreachable%> ou %<__builtin_trap%> avec des arguments"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "argument invalide dans un appel gimple"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "opérandes invalides dans une comparaison gimple"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "types d'opérandes de comparaison non concordants"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "opération ou type non supporté pour une comparaison vectorielle retournant un booléen"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "opérandes non vectoriels dans une comparaison vectorielle"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "type invalide comme résultat d'une comparaison vectorielle"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "type foireux pour le résultat d'une comparaison"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "non registre comme membre de gauche d'une opération unaire"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "opérande invalide dans l'opération unaire"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr "types vectoriels invalides dans une conversion nop"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "types invalides dans une conversion nop"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "types invalides dans une conversion d'espace d'adresse"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "types invalides dans une conversion en virgule fixe"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "types invalides dans une conversion vers une virgule flottante"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "types invalides dans une conversion vers un entier"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "désaccord de type dans l'expression %qs"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "types invalides pour %qs"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr "%qs devrait provenir d'un scalaire vers un vecteur similaire"
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "conversion non triviale dans une opération unaire"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "non registre comme membre de gauche d'une opération binaire"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "opérandes invalides dans l'opération binaire"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "opérandes non vectoriels invalides pour %qs"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr "opérandes (pointeurs) %qs invalides"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "types vectoriels attendus dans %qs"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "désaccord de type dans une expression binaire"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "non registre comme membre de gauche dans une opération ternaire"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "opérandes invalides dans l'opération ternaire"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "le premier argument d'un %qs doit être d'un type vectoriel booléen du même nombre d'éléments que le résultat"
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "types vectoriels attendus dans %qs"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "des vecteurs avec un nombre d'éléments différents ont été trouvés dans %qs"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "type de masque invalide dans %qs"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "combinaison de types pas permise dans %qs"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "position ou taille invalide dans %qs"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs dans un opérande non-mode-precision"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "insertion hors limites dans %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs pas à la frontière d'un élément"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "conversion non triviale dans %qs"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "membre de gauche de %qs dans une instruction écrasée"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "opérande invalide dans %qs"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "membre de droite invalide pour un stockage mémoire gimple : %qs"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "type incorrect pour les éléments d'un vecteur %qs"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "nombre incorrect pour les éléments d'un vecteur %qs"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "type incorrect pour les éléments d'un vecteur CONSTRUCTOR"
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "vecteur %qs avec un index d'élément non nul"
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "l'élément d'un vecteur %qs n'est pas une valeur GIMPLE"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "non vecteur %qs avec des éléments"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "%qs avec une condition toujours fausse"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "opérande invalide dans l'instruction de retour"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "conversion invalide dans une instruction de retour"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "la destination du « goto » n'est ni une étiquette ni un pointeur"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "opérande invalide pour l'instruction « switch »"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "instruction « switch » avec un type non entier"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "étiquette invalide pour le « case » par défaut dans l'instruction « switch »"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "%<CASE_CHAIN%> invalide"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "étiquette invalide pour un « case » dans l'instruction « switch »"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "plage du « case » invalide dans l'instruction « switch »"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "désaccord de type pour l'étiquette du « case » dans l'instruction « switch »"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "désaccord dans la précision du type dans l'instruction « switch »"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "les « case » ne sont pas triés dans l'instruction « switch »"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "le contexte de l%'étiquette n'est pas la déclaration de la fonction actuelle"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "entrée incorrecte dans %<label_to_block_map%>"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "configuration incorrecte pour le numéro de la zone d'atterrissage des exceptions (landing pad)"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "code de comparaison invalide dans la condition gimple"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "étiquettes invalides dans la condition gimple"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "résultat %<PHI%> invalide"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "définition %<PHI%> manquante"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "argument %<PHI%> invalide"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "types incompatibles dans l'argument %<PHI%> %u"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "%<verify_gimple%> a échoué"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "instruction sans effet dans la table EH"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "le bloc des références vers les emplacements n'est pas dans l'arbre des blocs"
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "déclaration locale depuis une fonction différente"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) est défini avec un mauvais bloc de base"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "nœud PHI avec emplacement"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "partage incorrect des nœuds de l'arbre"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "PHI virtuel avec des emplacements d'arguments"
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) est défini avec un mauvais bloc de base"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "l'instruction est marquée comme produisant une exception mais elle ne le fait pas"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "une instruction est marquée comme produisant une exception au milieu du bloc"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple a échoué"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK a un nœud dans le langage intermédiaire (IL) qui lui est associé"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK a un nœud dans le langage intermédiaire (IL) qui lui est associé"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru pour sortir du bloc de base %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "étiquette non locale "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "étiquette de la zone d'atterrissage du gestionnaire d'exceptions "
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "étiquette"
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "contrôle de flux au milieu du bloc de base %d"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "arête fallthru après une instruction de contrôle dans le bb %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "arête vrai/faux après un non GIMPLE_COND dans le bb %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "mauvais fanions d'une arête sortante à la fin du bb %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "« goto » explicite à la fin du bb %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "l'arête de retour ne pointe pas vers la sortie dans le bb %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "« case » par défaut rencontré mais pas au début du vecteur des « case »"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "étiquettes « case » pas triées: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "arête sortante supplémentaire %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "arête manquante %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "une fonction avec %<noreturn%> retourne une valeur"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "le contrôle a atteint la fin d'une fonction non « void »"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "la valeur retournée par %qD est ignorée alors qu'elle est déclarée avec l'attribut %<warn_unused_result%>"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "la valeur retournée est ignorée pour une fonction déclarée avec l'attribut %<warn_unused_result%>"
@@ -27384,47 +27421,47 @@ msgstr "dans la définition de la macro %qs"
 msgid "in expansion of macro %qs"
 msgstr "dans l'expansion de la macro %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "le BB %i a plusieurs arêtes de gestion des exceptions"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "le BB %i ne peut pas produire d'exception mais il a une arête pour la gestion des exceptions"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "la dernière instruction du BB %i a défini incorrectement la zone d'atterrissage des exceptions"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "le BB %i n'a pas d'arête de gestion des exceptions"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "arête incorrecte de gestions des exceptions %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "il manque une arête dans le BB %i"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "le BB %i a trop d'arêtes falltrhu"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "le BB %i a une arête incorrecte"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "le BB %i a une arête fallthru incorrecte"
@@ -27932,12 +27969,12 @@ msgstr "instruction (%p) marquée comme modifiée après l'étape d'optimisation
 msgid "verify_ssa failed"
 msgstr "verify_ssa a échoué"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "le code de la fonction intégrée indépendant de la machine est hors limite"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "la fonction intégrée spécifique à la cible n'est pas disponible"
@@ -28002,7 +28039,7 @@ msgstr "l'indice %E du tableau est hors des limites d'un tableau de taille inté
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "l'indice %qE du tableau est hors des limites d'un tableau de taille intérieure nulle %qT"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr "en référençant %qD"
@@ -28012,27 +28049,27 @@ msgstr "en référençant %qD"
 msgid "defined here %qD"
 msgstr "défini ici %qD"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "l'indice du tableau %wi est en dehors des limites de %qT"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "l'indice du tableau [%wi, %wi] est en dehors des limites de %qT"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "l'indice intermédiaire du tableau %wi est en dehors des limites de %qT"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "l'indice du tableau %wi est en dessous des limites de %qT"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "l'indice du tableau %wu est au delà des limites de %qT"
@@ -28107,32 +28144,32 @@ msgstr "vérification de l'arbre: opérande accédé %d de %s avec %d opérandes
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de %<omp_clause %s%> avec %d opérandes dans %s, à %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD est obsolète: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD est obsolète"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE est obsolète: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE est obsolète"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "le type est obsolète: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "le type est obsolète"
@@ -28157,232 +28194,232 @@ msgstr "le type est obsolète"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "la variante du type diffère sur %s"
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "la variante du type a un %<TYPE_SIZE_UNIT%> différent"
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "%<TYPE_SIZE_UNIT%> de la variante du type"
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "%<TYPE_SIZE_UNIT%> du type"
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "variante du type avec %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "la variante du type a un %<TYPE_VFIELD%> différent"
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "la variante du type a un %<TYPE_BINFO%> différent"
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "%<TYPE_BINFO%> de la variante du type"
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "%<TYPE_BINFO%> du type"
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "la variante du type a un %<TYPE_FIELDS%> différent"
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "le premier désaccord est le champ"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr "et le champ"
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "la variante du type a un %<TREE_TYPE%> différent"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "%<TREE_TYPE%> de la variante du type"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "%<TREE_TYPE%> du type"
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "le type n'est pas compatible avec sa variante"
 
-#: tree.c:14387
+#: tree.c:14398
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "la variante principale n'est pas définie"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_MAIN_VARIANT%> a un %<TYPE_MAIN_VARIANT%> différent"
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "%<TYPE_CANONICAL%> a un %<TYPE_CANONICAL%> différent"
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_CANONICAL%> n'est pas compatible"
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "le %<TYPE_MODE%> de %<TYPE_CANONICAL%> n'est pas compatible"
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "le %<TYPE_CANONICAL%> de la variante principale n'est pas la variante principale"
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "%<TYPE_VFIELD%> n'est pas %<FIELD_DECL%> ni %<TREE_LIST%>"
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "%<TYPE_NEXT_PTR_TO%> n'est pas %<POINTER_TYPE%>"
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "%<TYPE_NEXT_REF_TO%> n'est pas %<REFERENCE_TYPE%>"
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "%<TYPE_BINFO%> n'est pas %<TREE_BINFO%>"
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "le type %<TYPE_BINFO%> n'est pas %<TYPE_MAIN_VARIANT%>"
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_METHOD_BASETYPE%> n'est pas un enregistrement ni une union"
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_OFFSET_BASETYPE%> n'est pas un enregistrement ni une union"
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "%<TYPE_ARRAY_MAX_SIZE%> pas %<INTEGER_CST%>"
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "%<TYPE_MAX_VALUE_RAW%> non NULL"
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "le champ %<TYPE_LANG_SLOT_1 (binfo)%> est non NULL"
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "la valeur de l'enum n'est pas %<CONST_DECL%> ou %<INTEGER_CST%>"
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "le type de la valeur de l'enum n'est pas %<INTEGER_TYPE%> et n'est pas convertible en l'enum"
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "le nom de la valeur de l'enum n'est pas %<IDENTIFIER_NODE%>"
 
-#: tree.c:14596
+#: tree.c:14607
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "le %<TYPE_DOMAIN%> du tableau n'est pas d'un type entier"
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%<TYPE_FIELDS%> défini dans un type incomplet"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "arbre erroné dans la liste %<TYPE_FIELDS%>"
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "%<TYPE_CACHED_VALUES_P%> est %i tandis que %<TYPE_CACHED_VALUES%> est %p"
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "%<TYPE_CACHED_VALUES%> n'est pas %<TREE_VEC%>"
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "mauvaise entrée %<TYPE_CACHED_VALUES%>"
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "%<TREE_PURPOSE%> n'est pas NULL dans la liste %<TYPE_ARG_TYPES%>"
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "entrée erronée dans la liste %<TYPE_ARG_TYPES%>"
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "le champ %<TYPE_VALUES_RAW%> n'est pas NULL"
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "%<TYPE_CACHED_VALUES_P%> est défini alors qu'il ne le devrait pas"
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "%<TYPE_METHOD_BASETYPE%> n'est pas la variante principale"
@@ -28508,82 +28545,82 @@ msgstr "l'alignement requis pour %q+D est plus grand que l'alignement implément
 msgid "storage size of %q+D isn%'t known"
 msgstr "la taille de stockage de %q+D est inconnue"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "l'initialiseur pour les valeurs entières/virgules fixes est trop compliqué"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "l'initialiseur pour une valeur en virgule flottante n'est pas une constante en virgule flottante"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "valeur initiale invalide pour le membre %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD déclaré faible après avoir été utilisé"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "la déclaration faible de %q+D est appliquée à une définition statique qui existe déjà"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "la déclaration faible de %q+D doit être publique"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "la déclaration faible de %q+D n'est pas supportée"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "seulement les alias faibles sont supportés dans cette configuration"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "« weakref » n'est pas supporté par cette configuration"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "%qs n'est pas supporté sur cette cible"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "symver est uniquement supporté sur les plateformes ELF"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "le symbole %qs %q+D pointe vers lui-même en fin de compte"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "le symbole %qs %q+D doit avoir une classe de liaison statique"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "les définitions d'alias ne sont pas supportées dans cette configuration"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "%qs n'est pas supporté par cette configuration"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "l'attribut de visibilité n'est pas supporté dans cette configuration; ignoré"
@@ -29166,7 +29203,7 @@ msgstr "l'attribut %qE suit %qE"
 msgid "type was previously declared %qE"
 msgstr "le type a été précédemment déclaré %qE"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> ne peut être spécifié que pour une fonction virtuelle"
@@ -29186,7 +29223,7 @@ msgstr "%qD n'est pas compatible avec %qD"
 msgid "%qE argument is not a function"
 msgstr "l'argument de %qE n'est pas une fonction"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "le message déprécié n'est pas une chaîne"
@@ -29557,12 +29594,12 @@ msgstr "%<?:%> utilisant des constantes entières dans un contexte booléen"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "le compilateur peut supposer que l'adresse de %qD sera toujours évaluée à %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "parenthèses suggérées autour de l'affectation utilisée comme valeur dans une condition"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "usage de %<restrict%> invalide"
@@ -29719,12 +29756,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "l'attribut %<fallthrough%> est spécifié avec un paramètre"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "trop peu d'arguments pour la fonction %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -29825,7 +29862,7 @@ msgstr "l'index %E désigne un offset plus grand que la taille de %qT"
 msgid "size of array is too large"
 msgstr "la taille du tableau est trop grande"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "le type %qT de l'opérande est incompatible avec l'argument %d de %qE"
@@ -29835,124 +29872,124 @@ msgstr "le type %qT de l'opérande est incompatible avec l'argument %d de %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "argument de type pointeur ou de type entier attendu pour l'argument 1"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "les deux arguments doivent être compatibles"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "nombre d'arguments incorrect pour la fonction %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "l'argument 1 de %qE doit être un type pointeur non void"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un type ayant une taille constante"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un objet de taille non nulle"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "l'argument %d de %qE doit être un type pointeur"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "l'argument %d de %qE doit être un pointeur vers un type ayant une taille constante"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "l'argument %d de %qE doit être un pointeur vers une fonction"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "désaccord de taille dans l'argument %d de %qE"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "modèle mémoire non entier pour l'argument %d de %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "modèle mémoire invalide pour l'argument %d de %qE"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "cette cible ne défini pas de barrière de spéculation; votre programme s'exécutera quand même correctement mais des spéculations incorrectes pourraient ne pas être restreintes"
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "la valeur de l'index est hors limites"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "la conversion du scalaire %qT vers le vecteur %qT implique une troncature"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "la fonction interne %qE doit être appelée directement"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "la taille du tableau %qE n'est pas une expression constante"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "la taille du tableau n'est pas une expression constante"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "la taille %qE du tableau %qE est négative"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "la taille %qE du tableau est négative"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "la taille %qE du tableau %qE excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "la taille %qE du tableau excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "la taille du tableau %qE excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "la taille du tableau excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "la variable d'environnement %s doit fournir un entier non négatif plus petit que ou égal à %wd"
@@ -30007,502 +30044,502 @@ msgstr "%qE est un type non reconnu de fonction avec format"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "l'argument de la chaîne de format suit les arguments devant être formatés"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "la fonction %qD pourrait peut-être être candidate pour l'attribut de format %qs"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "numéro de l'opérande $ manquant dans le format"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s ne supporte pas les numéros d'opérandes %%n$ dans le format"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "le numéro d'opérande est hors limites dans le format"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "l'argument de format %d est utilisé plus d'une fois dans le format %s"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr "un numéro d'opérande %<$%> est utilisé après un format sans numéro d'opérande"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "l'argument de format %d est inutilisé et se trouve avant l'argument %d qui est utilisé avec un numéro d'argument %<$%>"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "le format n'est pas une chaîne littérale, le format n'est pas vérifié"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "le format n'est pas une chaîne littérale et il n'y a pas d'arguments de format"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "le format n'est pas une chaîne littérale, les types des arguments ne sont pas vérifiés"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "trop d'arguments pour le format"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr "arguments inutilisés dans le format avec le style %<$%>"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "chaîne de format %s de longueur nulle"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "le format est une chaîne de caractères larges"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "la chaîne de format n'est pas un tableau de type %qs"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "chaîne de format non terminée"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s utilisé avec le format %<%%%c%> %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s ne supporte pas %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s ne supporte pas %s avec le format %<%%%c%> %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr "%s utilisé dans une séquence entre guillemets"
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr "conversion %qc utilisée sans guillemets"
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "%s répété dans le format"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "caractère de remplissage manquant à la fin du format de strfmon"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "largeur zéro dans le format %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "précision à gauche vide dans le format %s"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "précision vide dans le format %s"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s ne supporte pas %qs %s comme modificateur de longueur"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "caractère de type de conversion %qc inconnu dans le format"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s ne supporte par le format %<%%%c%> %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s ignoré avec %s et le format %<%%%c%> %s"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s ignoré avec %s dans le format %s"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "utilisation de %s et de %s ensemble dans le format %<%%%c%> %s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "utilisation de %s et de %s ensemble dans le format %s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> laisse seulement les 2 derniers chiffres de l'année dans certaines configurations linguistiques"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> laisse seulement les 2 derniers chiffres de l'année"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "pas de %<]%> fermant pour le format %<%%[%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "l'utilisation du modificateur de longueur %qs avec le type de caractère %qc a soit aucun effet ou soit un comportement indéfini"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s ne supporte pas le format %<%%%s%c%> %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "numéro d'opérande spécifié avec une affectation supprimée"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "numéro d'opérande spécifié pour un format n'acceptant aucun argument"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "nom de type %<%.*s%> sans guillemets dans le format"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "opérateur %<%.*s%> sans guillemets dans le format"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "mot clé %<%.*s%> sans guillemets dans le format"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr "utilisez %qs à la place"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr "attribut sans guillemets dans le format"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "nom de fonction interne %<%.*s%> sans guillemets dans le format"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr "identificateur ou mot clé %<%.*s%> sans guillemets dans le format"
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr "terme %<%.*s%> mal orthographié dans le format; utilisez plutôt %<%s%s%>"
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr "directive %qs avec guillemets dans le format; utilisez plutôt %qs"
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr "contraction %<%.*s%> dans le format; utilisez plutôt %qs"
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr "caractère blanc %qc sans guillemets dans le format"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr "des caractères blancs douteux traînent à la fin du format"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "majuscules incohérentes dans le format"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "séquence de %i espaces consécutifs sans guillemets dans le format"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "caractères de contrôle sans guillemets dans le format"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "caractère de contrôle %qc sans guillemets dans le format"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "nom d'option %<%.*s%> dans guillemets dans le format"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr "caractère de ponctuation %qc non équilibré dans le format"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr "directive du pré-processeur %<%.*s%> sans guillemets dans le format"
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr "apostrophe %<'%> isolée dans le format"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr "s'il n'est pas possible d'éviter l'apostrophe, entourez la dans une paire de directives %qs et %qs"
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr "accent grave %<`%> dans le format"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr "utilisez plutôt la directive apostrophe %qs"
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr "espace suivie d'un caractère de ponctuation %<%c%>"
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr "directive %qs entre guillemets dans le format"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr "si l'utilisation de %qs n'est pas possible, utilisez plutôt %qs"
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "séquence de ponctuation %<%.*s%> douteuse au début du format"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "séquence de ponctuation %<%.*s%> douteuse à la fin du format"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr "séquence de %i caractères de ponctuation %q.*s consécutifs sans guillemets dans le format"
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "caractères non graphiques sans guillemets dans le format"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "caractère non graphique %qc sans guillemets dans le format"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "caractère de ponctuation %<%c%> déséquilibré dans le format"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr "directive de mise entre guillemets non terminée"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "caractère guillemet %<%c%> non terminé dans le format"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "des caractères %<%%%> douteux traînent dans le format"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "il manque le type dans la conversion à la fin du format"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "directive imbriquée de mise entre guillemets"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr "directive de mise entre guillemets non concordante"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr "directive %qc redondante après une occurrence précédente du même"
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr "directive de réinitialisation de couleur sans concordante"
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr "conversion %qc utilisée dans une séquence entre guillemets"
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "%<\\0%> inclus à l'intérieur du format"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr "directive de couleur non terminée"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "écriture à travers un pointeur nul (argument %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "lecture à travers un pointeur nul (argument %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "écriture dans un objet constant (argument %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "qualificatif de type supplémentaire dans l'argument du format (argument %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> attend un argument de type %<%s%s%> mais l'argument %d a le type %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> attend un argument %<%s%s%> correspondant"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> attend un argument de type %<%T%s%> mais l'argument %d a le type %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> attend un argument %<%T%s%> correspondant"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> n'est pas défini comme %<long%> ou %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "%qs n'est pas défini comme un type"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> n'est pas défini comme un type pointeur"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr "les arguments devant être formatés ne sont pas %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "les formats de strftime ne peuvent pas formater d'arguments"
@@ -30664,7 +30701,7 @@ msgstr "type de dépendance %<depobj%> spécifié dans la clause %<depend%> d'un
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "le modificateur %<iterator%> ne peut pas être spécifié sur une construction %<depobj%>"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "type invalide pour la variable d'itération %qE"
@@ -30679,17 +30716,17 @@ msgstr "variable d'itération %<_Atomic%> %qE"
 msgid "%qE is not initialized"
 msgstr "%qE n'est pas initialisé"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "prédicat de contrôle manquant"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "prédicat de contrôle invalide"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "expression d'incrémentation manquante"
@@ -30699,7 +30736,7 @@ msgstr "expression d'incrémentation manquante"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "l'incrément n'est pas la constante 1 ou -1 pour la condition %<!=%>"
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expression d'incrémentation invalide"
@@ -31295,7 +31332,7 @@ msgid "wrong type argument to %s"
 msgstr "argument de type erroné pour %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "débordement dans l'expression constante"
@@ -31971,7 +32008,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr "%<memset%> utilisé avec une longueur égale au nombre d'éléments sans être multiplié par la taille des éléments"
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparaison entre les types %qT et %qT"
@@ -32047,7 +32084,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "passage de l'argument %i aux alias qualifiés avec %qs avec l'argument %Z"
 msgstr[1] "passage de l'argument %i aux alias qualifiés avec %qs avec les arguments %Z"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "cette condition a des branches identiques"
@@ -32067,7 +32104,7 @@ msgstr "certaines parties de l'expansion de la macro ne sont pas protégées par
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr "convertir un pointeur %qT compacté (alignement %d) vers un pointeur %qT (alignement %d) peut résulter en une valeur de pointeur non alignée"
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr "défini ici"
@@ -32087,7 +32124,7 @@ msgstr "%qs n'est pas une option valide pour le préprocesseur"
 msgid "too many input files"
 msgstr "trop de fichiers d'entrée"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "valeur %qs inconnue pour %<-mcpu%>"
@@ -32118,14 +32155,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "option non reconnue passée à %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "les arguments valides sont: %s; vouliez-vous utiliser %qs ?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "les arguments valables sont: %s"
@@ -32642,391 +32679,398 @@ msgstr "les définitions d'alias ne sont pas supportées avec Mach-O; ignoré"
 msgid "profiler support for VxWorks"
 msgstr "support du profilage pour VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kl'argument %d doit être une constante immédiate"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kl'index de l'avenue doit être une constante immédiate"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "%Kla taille totale et la taille de l'élément doivent être des constantes immédiates non nulles"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%Kl'argument doit être une constante immédiate de 16 bits"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "L'extension Memory Tagging ne supporte pas %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "%Kl'argument %d doit être une constante immédiate dans l'intervalle [0,15]"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "adresse sur 64 bits attendue mais l'argument 1 a %d bits"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "adresse sur 64 bits attendue mais l'argument 2 a %d bits"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> existe une chaîne en paramètre"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "option %qs inconnue pour %<#pragma GCC aarch64%>"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "l'attribut %qE ne peut pas être appliqué à un type de fonction SVE"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<%s%> inattendu après %<%s%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs est incompatible avec l'utilisation de types en virgule flottante"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs est incompatible avec l'utilisation de types vectoriels"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "le modificateur de fonctionnalité %qs est incompatible avec l'utilisation de types en virgule flottante"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "le modificateur de fonctionnalité %qs est incompatible avec l'utilisation de types vectoriels"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "cette opération requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "vous pouvez activer SVE en utilisant l'option %<-march%> sur la ligne de commande ou en utilisant l'attribut ou le pragma %<target%>"
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "l'argument de type %qT requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "le type SVE %qT ne peut pas être passé en argument à une fonction sans prototype"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 9.1"
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE requiert l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "les appels à des fonctions de type %qT requièrent l'extension de l'ISA SVE"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "sondes de pile pour les trames SVE"
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "fanion inconnu passé à %<-moverride=%s%> (%s)"
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "chaîne %s mal formée\n"
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "format invalide pour sve_width"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "valeur invalide pour sve_width: %d"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "chaîne d'ajustement manquante dans l'option (%s)"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "option d'ajustement inconnue (%s)"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "%<-mstack-protector-guard=global%> et %<-mstack-protector-guard-offset=%qs%> incompatibles"
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "%<-mstack-protector-guard-offset%> et %<-mstack-protector-guard-reg%> doivent être utilisés tous les deux avec %<-mstack-protector-guard=sysreg%>"
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "spécifie un registre système avec une chaîne de courte longueur."
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs n'est pas un décalage valide dans %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "seules les valeurs 12 (4 ko) et 16 (64 ko) sont supportées pour la taille de garde. La valeur %d donnée (%llu ko) est hors limites"
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "la taille %<%d%> de la sécurité anti-collision de la pile doit être égale à l'intervalle de sondage %<%d%>"
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "les arguments valables sont: %s;"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "nom de processeur manquant dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "modificateur de fonctionnalité %qs invalide dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "argument %<%s%> invalide pour %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argument manquant pour %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "nom d'architecture manquant dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "valeur %qs inconnue pour %<-march%>"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "modificateur de fonctionnalité %qs invalide dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "nom de processeur manquant dans %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "valeur %qs inconnue pour %<-mtune%>"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "l'option %<-mcpu=%s%> est en conflit avec l'option %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "l'assembleur ne supporte pas %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "la signature de l'adresse de retour n'est supportée qu'avec %<-mabi=lp64%>"
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "modèle de code %qs avec %<-f%s%>"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode ilp32"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "modificateur de fonctionnalité %s invalide avec la valeur (\"%s\") dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "argument manquant dans le pragma ou l'attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "type de protection (\"%s\") invalide dans le pragma ou l'attribut %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "valeur manquante dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target()%> est mal composé"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'accepte pas d'argument"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'autorise pas de forme négative"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s=%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> est mal composé"
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
-msgstr "le passage par paramètre pour l'argument de type %qT quand C++17 est activé a changé pour correspondre à C++14 dans GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr "le passage de paramètre pour l'argument de type %qT avec des membres %<[[no_unique_address]]%> a changé dans %{GCC 10.1%}"
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr "le passage par paramètre pour l'argument de type %qT quand C++17 est activé a changé pour correspondre à C++14 %{dans GCC 10.1%}"
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kl'avenue %wd est hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "avenue %wd hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d non supportée"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas les types de tailles mélangés pour les fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas le type de retour %qT pour les fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "type de retour %qT non supporté pour des fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC ne supporte actuellement pas un argument de type %qT pour des fonctions %<simd%>"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr "GCC ne supporte actuellement pas simdlen %d pour le type %qT"
@@ -33207,17 +33251,17 @@ msgstr "l'argument de l'attribut %qE n'est pas « ilink1 » ni « ilink2 »"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "l'argument de l'attribut %qE n'est pas « ilink » ni « firq »"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33367,12 +33411,12 @@ msgstr "sortie du fanion %<asm%> %qs inconnue"
 msgid "invalid type for %<asm%> flag output"
 msgstr "type invalide pour la sortie du fanion %<asm%>"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "%Kle coprocesseur %d n'est pas activé avec +cdecp%d"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr "%Kle coproc doit être une constante immédiate dans la plage [0-%d] activé avec +cdecp<N>"
@@ -33380,194 +33424,194 @@ msgstr "%Kle coproc doit être une constante immédiate dans la plage [0-%d] act
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%Kl'argument %d de %qE doit être une constante immédiate dans l'intervalle [0-%d]"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "cette fonction interne n'est pas supportée pour cette cible"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%Kla plage du bit de saturation doit être dans la plage [%wd, %wd]"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "%Kla plage du bit de saturation doit être une constante immédiate"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr "Vous devez activer les instructions MVE pour utiliser ces intrinsèques"
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr "Vous devez activer les instructions NEON (par ex. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) pour utiliser ces intrinsèques."
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Vous devez activer les instructions VFP pour utiliser ces intrinsèques."
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr "Vous devez activer les instructions crypto (par ex. inclure %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) pour utiliser ces intrinsèques."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "sélecteur doit être un immédiat"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "la plage du sélecteur doit être entre 0 et 7"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "la plage du sélecteur doit être entre 0 et 3"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "la plage du sélecteur doit être entre 0 et 1"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "le masque doit être un immédiat"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "la plage du masque doit être entre 0 et 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_rori_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_ror_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_si64 dans le code"
@@ -33577,283 +33621,283 @@ msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr "l'argument %u de la fonction %qE est du type %qT qui n'est pas connu comme ayant 128 bits"
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt et NEON sont incompatibles"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "le processeur cible ne supporte pas ARM"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "activer le support de la trace de débogage n'a de sens qu'en compilant pour le Thumb"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "activer le support pour l'interopérabilité de l'appelé n'a de sens qu'en compilant pour le Thumb"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "%<-g%> avec %<-mno-apcs-frame%> peut ne pas donner un débogage pertinent"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt non supporté en mode Thumb"
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "%<-mtp=cp15%> ne peut pas être utilisé avec un Thumb 16 bits"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC est incompatible avec Thumb"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr "%s ne supporte que du code non pic sur les cibles M-profile avec l'instruction MOVT"
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr "%s ne supporte que du code non pic sur les cibles M-profile"
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "%s est incompatible avec %<-mword-relocations%>"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "le processeur cible ne supporte pas les instructions THUMB"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "le processeur cible ne supporte pas les accès non alignés"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "%<-mapcs-stack-check%> incompatible avec %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "%<-fpic%> et %<-mapcs-reent%> sont incompatibles"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "Le code réentrant APCS n'est pas supporté.  Ignoré"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr "l'option %<-mstructure-size-boundary%> est dépréciée"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "la frontière de la taille de la structure peut seulement être 8, 32 ou 64"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "la frontière de la taille de la structure peut seulement être 8 ou 32"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC est incompatible avec %<-msingle-pic-base%>"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "le mode FDPIC n'est pas supporté en mode Thumb-1"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "%<-mpic-register=%> est inutile sans %<-fpic%>"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "incapable d'utiliser %qs pour un registre PIC"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> n'est pas supporté sur cette architecture"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "les options fp16 sélectionnées sont incompatibles"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt exige une ABI compatible AAPCS pour fonctionner correctement"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "l'abi iwmmxt requiert un processeur avec iwmmxt"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "le processeur cible ne supporte pas l'interopérabilité"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS ne supporte pas %<-mcaller-super-interworking%>"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS ne supporte pas %<-mcallee-super-interworking%>"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 et pas de ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "le processeur cible ne supporte pas les extensions de sécurité ARMv8-M"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "Les extensions de sécurité ARMv8-M sont incompatibles avec le FPU sélectionné"
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "%<-mfloat-abi=hard%>: le processeur sélectionné n'a pas de FPU"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "%<-mfloat-abi=hard%> et VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "variante PCS qui n'est pas dérivée de AAPCS"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "les fonctions variadiques doivent utiliser la variante du AAPCS de base"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "variante PCS"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "ABI VFP en virgule flottante matérielle du Thumb-1"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr "argument de type %qT pas permis avec -mgeneral-regs-only"
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 7.1"
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions avec des arguments passés sur la pile"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions avec un nombre variable d'arguments"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions qui retournent une valeur sur la pile"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "l'attribut %qE est ignoré sans l'option %<-mcmse%>."
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "l'attribut %qE n'a pas d'effet sur les fonctions statiques"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "l'attribut %qE ne s'applique qu'au type de base d'un pointeur vers une fonction"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "l'accès à un stockage local au thread n'est actuellement pas supporté avec %<-mpure-code%> ou %<-mslow-flash-data%>"
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "incapable de calculer la position réelle des paramètres sur la pile"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Saut lointain thumb1 inattendu"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "pas de registre bas disponible pour dépiler les registres hauts"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "les routines du service d'interruption ne peuvent pas être codées en mode Thumb"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> pour Thumb-1"
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
@@ -33861,22 +33905,22 @@ msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "la sélection automatique du fpu n'est actuellement pas permise ici"
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "architecture invalide pour l'attribut ou le pragma cible %qs"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "attribut ou pragma cible %qs inconnu"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "fanions asm non supportés en mode thumb1"
@@ -33955,17 +33999,17 @@ msgstr "%<-fpie%> n'est pas supporté"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> n'est pas supporté"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "les attributs de fonction %qs et %qs sont mutuellement exclusifs"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la fonction avec l'attribut %qs ne peut pas avoir d'argument"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la fonction avec l'attribut %qs ne peut pas retourner une valeur"
@@ -34230,7 +34274,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "appel indirect dans une fonction, ceci n'est pas supporté par eBPF"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "argument invalide pour la fonction interne"
@@ -34561,52 +34605,52 @@ msgstr "spécificateur de paramètre %s dupliqué dans l'attribut amdgpu_hsa_ker
 msgid "too many arguments passed in sgpr registers"
 msgstr "trop d'arguments passés dans les registres sgpr"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr "Un ensemble qui n'est pas par défaut de valeurs initiales a été demandé, ceci viole l'ABI !"
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "type d'argument erroné pour %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "trampolines de fonctions imbriquées pas supportés sur GCN5 à cause des piles non exécutables"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr "TLS n'est pas implémenté pour GCN."
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr "Fonction interne non implémentée"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr "utilisation de vector_length (64), %d est ignoré"
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr "utilisation de vector_length (64), le paramètre à l'exécution est ignoré"
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "utilisation de num_workers (%d), %d est ignoré"
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "dimension de déchargement hors limites (%d)"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr "mémoire de partage de données locale épuisée"
@@ -34740,132 +34784,132 @@ msgstr "le paramètre à une fonction interne doit être une chaîne sous forme
 msgid "parameter to builtin not valid: %s"
 msgstr "le paramètre à la fonction interne n'est pas valable: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "une routine de service d%'interruption ne peut pas être appelée directement"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 2 bits"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "le cinquième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "le troisième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 3 bits"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "l'avant dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "le troisième argument doit être une constante de comparaison"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "mode de comparaison incorrect"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "opérande d'arrondi incorrect"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 32 bits"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "le sélecteur doit être une constante entière dans la plage [0, %wi]"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE a besoin d'une option isa inconnue"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE a besoin de l'option isa %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "le dernier argument doit être une valeur immédiate"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "le dernier argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "le quatrième argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "opérande d'indice incorrect"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "l'argument de l'intrinsèque %<xabort%> doit être une valeur immédiate sur 8 bits"
@@ -35245,144 +35289,144 @@ msgstr "seul le format de débogage DWARF est supporté pour les routines de ser
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service exception"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service d'interruption"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l%'attribut %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "les attributs %qs et %qs sont incompatibles"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante chaîne de caractères"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la routine de service d'interruption devrait avoir %qs comme deuxième argument"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "la routine de service d'interruption doit retourner %<void%>"
@@ -35827,7 +35871,7 @@ msgstr "%qE ne peut pas avoir les deux attributs %qs et %qs en même temps"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE redéclaré avec les attributs conflictuels %qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "l'attribut %qE requiert une chaîne comme argument"
@@ -36905,52 +36949,52 @@ msgstr "%<__delay_cycles%> n'accepte que des décomptes de cycles non négatifs"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "%<__delay_cycles%> est limité à des décomptes de boucles sur 32 bits"
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "processeur %qs inconnu pour %<-mtune%>"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "l'ABI pour des structures aplaties avec un champ de bits d'une taille non nulle a changé dans GCC 10"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "l'argument de l'attribut %qE n'est pas « user », « supervisor » ou « machine »"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> requiert %<-march%> pour incorporer l'extension %<M%>"
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "l'ABI demandée requiert %<-march%> pour incorporer l'extension %qc"
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e requiert l'ABI ilp32e"
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "l'ABI requiert %<-march=rv%d%>"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> doit être entre %d et %d"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "l'attribut RISC-V ELF %<-mriscv-attribute%> requiert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "la fonction %qs ne peut pas avoir un type d'interruption différent"
@@ -37066,323 +37110,324 @@ msgstr "le nombre doit être 0 ou 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "rebut à la fin de %<#pragma longcall%>"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "la fonction interne %qs n'accepte que 2 arguments"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "la fonction interne %qs n'accepte que 3 arguments"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "la fonction interne %qs n'accepte qu'un argument"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "passer l'argument %d de %qE abandonne les qualificatifs du type cible du pointeur"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "l'interne %qs requiert l'interne %qs"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs n'est pas supporté dans cette configuration du compilateur"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinaison invalide de paramètres pour l'intrinsèque Altivec %qs"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC retourné par référence: extension ABI non standard sans aucune garantie de compatibilité"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "la valeur ne peut être retournée dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez %qs pour les autoriser"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats avec un alignement sur %d octets a changé avec GCC 5"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "l'argument ne peut pas être passé dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez %qs pour les autoriser"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats de %<float%> homogènes a changé avec GCC 5"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC passé par référence: extension ABI non standard sans aucune garantie de compatibilité"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "erreur interne: fonction interne %qs déjà traitée"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_mffsl%> n'est pas supporté avec %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "l'argument 1 doit être une valeur de champ sur 8 bits"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_mtfsb0%> et %<__builtin_mtfsb1%> ne sont pas supportés avec %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr "L'argument doit être une constante entre 0 et 31."
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_set_fpscr_rn%> n'est pas supporté avec %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr "L'argument doit être une valeur entre 0 et 3."
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "%<__builtin_set_fpscr_drn%> n'est pas supporté en mode 32 bits"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_set_fpscr_drn%> n'est pas supporté avec %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr "L'argument doit être une valeur entre 0 et 7."
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "l'argument 1 doit être un littéral signé de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 3 bits"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 4 bits"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 6 bits"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 7 bits"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "l'argument 1 de %qs doit être une constante"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "l'argument 1 de %qs est hors limite"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "la fonction interne %qs est uniquement valable en mode 64 bits"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "l'argument %d doit être un littéral non signé"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "l'argument %d est un littéral non signé qui est hors limite"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "la fonction interne %qs est uniquement valable en mode 64 bits"
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "la fonction interne %qs n'accepte qu'une chaîne comme argument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "le processeur %qs est un argument invalide pour la fonction interne %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs est un argument invalide pour la fonction interne %qs"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "la fonction interne %qs requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "l'argument 1 doit être 0 ou 2"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 6 bits"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "l'argument 1 doit être 0 ou 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "l'argument 3 doit être dans la plage [0, 15]"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "l'argument de %qs doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "surcharge non résolue pour la fonction Altivec interne %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr "le deuxième argument de %qs doit être [0, 12]"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "le troisième argument de %qs doit être [0, 12]"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "%qs est uniquement valable pour le processeur cell"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "%qs requiert l'option %qs"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "%qs requiert les options %qs et %qs"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "%qs requiert l'ISA 3.0 en virgule flottante IEEE 128 bits"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "%qs requiert les options %qs (ou plus récente) et %qs ou %qs"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "%qs n'est pas supportée avec les options actuelles"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "erreur interne: la fonction interne %qs a un type de retour %qs inattendu"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "erreur interne: pour la fonction interne %qs, l'argument %d a le type %qs inattendu"
@@ -37403,219 +37448,224 @@ msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Une trame de pile plus grande que 2G n'est pas supportée par %<-fsplit-stack%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs requiert %qs ou %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs requiert une architecture PowerPC64, elle est maintenant activée"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs n'est pas supporté sur Darwin 64 bits; il est incompatible avec les bibliothèques C et C++ installées"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec pas supporté par cette cible"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs n'est pas supporté sur des systèmes petits boutistes"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "l'option de la cible power9 est incompatible avec %<%s=<xxx>%> pour <xxx> inférieur à power9"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs est incompatible avec les options explicitement désactivées"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs requiert %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "l'attribut cible ou le pragma change la taille du %<long double%>"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs requiert le support ISA 2.06 complet"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Utilisation du %<long double%> en précision étendue de IEEE"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Utilisation du %<long double%> en précision étendue de IBM"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs requiert le support VSX"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "L'option %<-mfloat128%> peut ne pas être totalement supportée"
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs requiert le support ISA 3.0 complet"
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "type d'ABI de la bibliothèque de vectorisation (%qs) inconnu pour l'option %qs"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI AltiVec"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI darwin64"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs n'est pas un nombre valide dans %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs n'est pas un registre de base valable dans %qs"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs a besoin d'un registre de base valable"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "option inconnue pour %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs est déprécié et recommandé dans aucune circonstance"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "l'agencement des agrégats contenant des vecteurs alignés sur %d octets a changé avec GCC 5"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr "%qs est un type opaque et vous ne pouvez pas le remplacer avec d'autres valeurs."
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option %qs"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans %qs"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "processeur %qs invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> désactive %<-m%s%>"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "l'attribut %<target_clones%> requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "les versions multiples requièrent ifunc qui n'est pas supporté sur cette cible"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
@@ -37936,139 +37986,139 @@ msgstr "l'attribut %qE demandé n'est pas une paire de constantes entières non
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "la taille totale des variables locales excède la limite de l'architecture"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "la taille de la trame de la fonction %qs est de %wd octets. Elle dépasse la limite de %d octets de la pile fournie par l'utilisateur. Un déroutement inconditionnel est ajouté."
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "la taille de la trame de la fonction %qs est de %wd octets. C'est plus que la moitié de la taille de la pile. Le contrôle dynamique ne serait pas fiable. Aucun contrôle n'est généré pour cette fonction."
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "la taille de la trame de %qs est de %wd octets"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utilise l'allocation de pile dynamique"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "les fonctions imbriquées ne savent pas être profilées avec %<-mfentry%> sur un s390"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "l'ABI 64 bits n'est pas supportée en mode ESA/390"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline est uniquement supporté avec %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "le support des vecteurs matériels n'est pas disponible sur %s"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "le support des vecteurs matériels n'est pas disponible avec %<-msoft-float%>"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles sur %s"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles en mode ESA/390"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> ne peut être utilisé en conjonction avec %<-msoft-float%>"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> ne sont pas supportés en combinaison"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "la taille de la pile doit être plus grande que la valeur de la protection de la pile"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "la taille de la pile ne peut pas être plus grande que 64k"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> implique l'utilisation de %<-mstack-size%>"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-check requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-target requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-check requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-target requiert un entier dans la plage 0..4095"
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> est supporté uniquement sur des processeurs 64 bits"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "les arguments de %qs doivent être des entiers non négatifs"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "l'argument de %qs est trop grand (max. %d)"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> ne peut pas être utilisé sans %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) est inconnu"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "la valeur %qs n'est pas supportée par l'attribut %<target%>"
@@ -38486,8 +38536,8 @@ msgstr "l'attribut %qs s'applique seulement aux types tableaux"
 msgid "could not read the BRIG file"
 msgstr "n'a pu lire le fichier BRIG"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "la valeur void n'a pas été ignorée comme elle aurait dû l'être"
@@ -38764,7 +38814,7 @@ msgstr "la déclaration de %q+D masque la déclaration précédente de quelque c
 msgid "declaration of %qD shadows a parameter"
 msgstr "la déclaration de %qD masque un paramètre"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la déclaration de %qD masque une déclaration globale"
@@ -38834,7 +38884,7 @@ msgstr "%qE non déclaré (première utilisation dans cette fonction)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "chaque identificateur non déclaré est rapporté une seule fois pour chaque fonction dans laquelle il apparaît"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "l'étiquette %qE est référencée à l'extérieur de toute fonction"
@@ -38864,7 +38914,7 @@ msgstr "saut dans l'expression d'une instruction"
 msgid "duplicate label declaration %qE"
 msgstr "déclaration de l'étiquette %qE en double"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "étiquette %qD dupliquée"
@@ -39072,7 +39122,7 @@ msgstr "impossible de mettre un objet avec un champ volatile dans un registre"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "%<const %qD%> non initialisé est invalide en C++"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
@@ -39411,7 +39461,7 @@ msgstr "nom de type déclaré comme une fonction retournant un tableau"
 msgid "function definition has qualified void return type"
 msgstr "la définition de la fonction a un type de retour « void » qualifié"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "les qualificatifs de type sont ignorés sur le type retourné par la fonction"
@@ -39719,7 +39769,7 @@ msgstr "redéfinition imbriquée de %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "définir le type dans l'expression %qs est invalide en C++"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la déclaration ne déclare rien du tout"
@@ -39769,7 +39819,7 @@ msgstr "la structure n'a aucun membre nommé"
 msgid "struct has no members"
 msgstr "la structure n'a aucun membre"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "tableau flexible comme membre de l'union"
@@ -39805,7 +39855,7 @@ msgstr "redéfinition imbriquée de %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "redéclaration de %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "le mode spécifié est trop petit pour les valeurs énumérées"
@@ -39835,7 +39885,7 @@ msgstr "débordement dans les valeurs de l'énumération"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "le C ISO restreint les valeurs de l'énumérateur à la plage d'un %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "la fonction à mettre en ligne %qD a reçu l'attribut %qs"
@@ -39865,7 +39915,7 @@ msgstr "aucun prototype précédent pour %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour %qD"
@@ -39980,12 +40030,12 @@ msgstr "l'argument %qD ne concorde pas avec le prototype interne"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "le paramètre %qD est défini mais pas utilisé"
@@ -39993,257 +40043,257 @@ msgstr "le paramètre %qD est défini mais pas utilisé"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "les déclarations initiales de boucles %<for%> ne sont permises qu'en mode C99 et C11"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "utilisez l'option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> ou %<-std=gnu11%> pour compiler votre code"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "le C90 ISO ne supporte pas les déclarations initiales de la boucle %<for%>"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable statique %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable %<extern%> %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de %qD (qui n'est pas une variable) dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "les qualificatifs d'espace d'adresses %qs et %qs sont incompatibles"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "spécificateur de déclaration %qE dupliqué"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans le spécificateur de déclaration"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> est trop long pour GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "le C90 ISO ne supporte pas %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "le C90 ISO ne supporte pas les types « complex »"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "le C ISO ne supporte pas les types saturants"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE dupliqué"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "le C ISO ne supporte pas les types %<__int%d%>"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "le C90 ISO ne supporte pas les types booléens"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "le C ISO ne supporte pas le type %<_Float%d%s%>"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "le C ISO ne supporte pas les virgules flottantes décimales avant C2X"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "les types en virgule fixe ne sont pas supportés pour cette cible"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "le C ISO ne supporte pas les types en virgule fixe"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la recherche de %qD par le C++ retournerait un champ, pas un type"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE échoue a être un typedef ou un type interne"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE n'est pas au début de la déclaration"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE utilisé avec %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE utilisé avec %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE utilisé avec %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "le C99 ISO ne supporte pas %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "le C90 ISO ne supporte pas %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> avant %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> avant %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> ou %<__thread%> dupliqué"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "classes de stockage multiples dans les spécificateurs de la déclaration"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs utilisé avec %qE"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> est utilisé sans %<_Fract%> ou %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C ISO ne supporte pas un simple %<complex%> signifiant %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> suivi des attributs %<[[]]%>"
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "le C ISO interdit les types entiers complexes"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "le combinateur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "l'initialiseur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "décalage vers la gauche d'une valeur négative"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "le compteur de décalages vers la gauche est négatif"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "le compteur de décalages vers la droite est négatif"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "compteur de décalages vers la gauche >= à la largeur du type"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "compteur de décalages vers la droite >= à la largeur du type"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "compteur de décalages vers la gauche >= à la largeur de l'élément du vecteur"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "compteur de décalages vers la droite >= à la largeur de l'élément du vecteur"
@@ -40263,7 +40313,7 @@ msgstr "marqueur de conflit de contrôle de version dans le fichier"
 msgid "to match this %qs"
 msgstr "pour correspondre à ce %qs"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -40309,7 +40359,7 @@ msgid "unknown type name %qE"
 msgstr "nom de type %qE inconnu"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "spécificateurs de déclaration attendus"
@@ -40329,7 +40379,7 @@ msgstr "attribut %<fallthrough%> au plus haut niveau"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identificateur ou %<(%> attendu"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "les attributs de préfixes sont ignorés pour les méthodes"
@@ -40344,8 +40394,8 @@ msgstr "les attributs de préfixes sont ignorés pour les implémentations"
 msgid "unexpected attribute"
 msgstr "attribut inattendu"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "l'attribut %<fallthrough%> n'est pas suivi par %<;%>"
@@ -40383,7 +40433,7 @@ msgstr "%<__auto_type%> requiert une déclaration de donnée initialisée"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> peut uniquement être utilisé avec un seul déclarateur"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> ou %<;%> attendu"
@@ -40411,7 +40461,7 @@ msgstr "le C99 ISO ne supporte pas %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "le C90 ISO ne supporte pas %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "chaîne littérale attendue"
@@ -40441,7 +40491,7 @@ msgstr "l'expression dans l'assertion statique n'est pas une constante"
 msgid "static assertion failed: %E"
 msgstr "échec de l'assertion statique: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "l'assertion statique a échoué"
@@ -40486,14 +40536,14 @@ msgstr "un enum vide est invalide"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identificateur attendu"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "virgule à la fin de la liste d'énumerateurs"
@@ -40578,7 +40628,7 @@ msgstr "spécificateurs de déclaration ou %<...%> attendu"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "les parenthèses doivent être omises si la liste des arguments de l'attribut est vide"
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "l'attribut %qE ne prend pas d'argument"
@@ -40588,7 +40638,7 @@ msgstr "l'attribut %qE ne prend pas d'argument"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "le C ISO ne supporte pas les attributs %<[[]]%> avant C2X"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<deprecated%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
@@ -40648,7 +40698,7 @@ msgstr "le C90 ISO interdit les mélanges de déclarations et de code"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> attendu avant %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sans %<if%> précédent"
@@ -40663,7 +40713,7 @@ msgstr "étiquette à la fin d'une déclaration composée"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "instruction attendue"
@@ -40688,17 +40738,17 @@ msgstr "une étiquette peut uniquement faire partie d'une instruction or une dé
 msgid "expected identifier or %<*%>"
 msgstr "identificateur ou %<*%> attendu"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<if%>"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<else%>"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "des accolades explicites sont suggérées pour éviter toute ambiguïté sur le %<else%>"
@@ -40718,12 +40768,12 @@ msgstr "variables d'itération multiples dans l'énumération rapide"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable d'itération invalide dans l'énumération rapide"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC ivdep%>"
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC unroll%>"
@@ -40738,8 +40788,8 @@ msgstr "collection manquante dans l'énumération rapide"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "qualificatif %<asm%> %qE dupliqué"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "vu pour la première fois ici"
@@ -40766,12 +40816,12 @@ msgstr "le C ISO interdit l'omission du terme central de l'expression %<?:%>"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la division %<sizeof (%T) / sizeof (%T)%> ne calcule pas le nombre d'éléments dans le tableau"
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "le premier opérande %<sizeof%> a été déclaré ici"
@@ -41162,61 +41212,61 @@ msgstr "une déclaration de méthode objective-c est attendue"
 msgid "no type or storage class may be specified here,"
 msgstr "aucun type ni classe de stockage ne peut être spécifié ici,"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribut de propriété inconnu"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<getter%>)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<setter%>)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "l'attribut %<setter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "le nom du « setter » doit être terminé par %<:%>"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "l'attribut %<getter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiert une expression d'affectation qui est évaluée en une constante entière non négative plus petite que %u"
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> ne peut être utilisé que dans des instructions composées"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> doit être dans la portée au niveau du fichier"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> ne peut être utilisé que dans une construction de boucle avec la clause %<inscan%> %<reduction%>"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction %<#pragma omp sections%>"
@@ -41226,18 +41276,18 @@ msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> peut uniquement être utilisé dans la portée du fichier"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "instruction « for », « while » ou « do » attendue"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> doit être le premier"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "trop de clauses %qs"
@@ -41257,53 +41307,53 @@ msgstr "%<)%> ou %<,%> attendu"
 msgid "%qD is not a variable"
 msgstr "%qD n'est pas une variable"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD n'est pas une variable pointeur"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'argument « collapse » a besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> ou %<present%> attendu"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> ou %<shared%> attendu"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> ou %<exit%> attendu"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> attendu"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "trop de %<if%> avec le modificateur %qs"
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "trop de clauses %<if%>"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "trop de clauses %<if%> sans modificateur"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si une clause %<if%> a un modificateur, alors toutes les clauses %<if%> doivent utiliser un modificateur"
@@ -41325,12 +41375,12 @@ msgstr "la valeur de %<num_threads%> doit être positive"
 msgid "%<num_tasks%> value must be positive"
 msgstr "la valeur de %<num_tasks%> doit être positive"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "la valeur de %<grainsize%> doit être positive"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "la valeur de %<priority%> doit être positive ou nulle"
@@ -41340,22 +41390,22 @@ msgstr "la valeur de %<priority%> doit être positive ou nulle"
 msgid "expected constant integer expression"
 msgstr "expression entière constante attendue"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> ou %<default%> attendu"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<scalar%>, %<aggregate%> ou %<pointer%> attendu"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "trop de clauses %<defaultmap%> avec la catégorie %qs"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "trop de clauses %<defaultmap%> avec une catégorie non spécifiée"
@@ -41370,52 +41420,52 @@ msgstr "l'expression %qs doit être un entier"
 msgid "%qs value must be positive"
 msgstr "la valeur de %qs doit être positive"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "trop d'arguments pour %<static%>"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argument inattendu"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "l'argument %<tile%> a besoin d'une constante entière positive"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> attendu"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<team%>, %<parallel%> ou %<thread%> attendu"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "les arguments ordonnés ont besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> ou identificateur attendu"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "les deux modificateurs %<monotonic%> et %<nonmonotonic%> sont spécifiés"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<runtime%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
@@ -41425,7 +41475,7 @@ msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
 msgid "chunk size value must be positive"
 msgstr "la taille du fragment doit être positive"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "type d'ordonnancement invalide"
@@ -41460,22 +41510,22 @@ msgstr "l'expression %<safelen%> doit être une expression entière constante po
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'expression %<simdlen%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "le modificateur %<iterator%> est incompatible avec %qs"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "type de « depend » invalide"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "type de « map » invalide"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "type de « dist_schedule » invalide"
@@ -41490,77 +41540,77 @@ msgstr "type de « proc_bind » invalide"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> ou %<any%> attendu"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "clause %<#pragma acc%> attendue"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs n'est pas valide pour %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "les clauses dans un trait %<simd%> devraient être séparées par des %<,%>"
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs doit être la première clause de %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "clause %<#pragma omp%> attendue"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "pas de clause valide spécifiée dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "section de tableau dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD doit être une variable globale dans %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "clause OpenACC invalide au niveau global du fichier"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<extern%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<global%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD doit être une variable déclarée dans la même portée que %<#pragma acc declare%>"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variable %qD utilisée plus d'une fois avec %<#pragma acc declare%>"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> attendu après %<#pragma acc %s%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> n'a pas clause de mouvement de données"
@@ -41575,7 +41625,7 @@ msgstr "%qE n'a pas été déclaré"
 msgid "expected function name"
 msgstr "nom de fonction attendu"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD ne fait pas référence à une fonction"
@@ -41585,67 +41635,67 @@ msgstr "%qD ne fait pas référence à une fonction"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une déclaration ou d'une définition de fonction"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> doit être appliqué avant l'utilisation"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> doit être appliqué avant la définition"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%>"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "clause %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> ou %<hint%> attendue"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "trop de clauses atomiques"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "trop de clauses d'ordre de mémoire"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp atomic read%> est incompatible avec les clauses %<acq_rel%> ou %<release%>"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic write%> est incompatible avec les clauses %<acq_rel%> ou %<acquire%>"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic update%> est incompatible avec les clauses %<acq_rel%> ou %<acquire%>"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forme invalide de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pour la mémoire"
@@ -41655,57 +41705,57 @@ msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pou
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> ou fin de ligne attendue"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "l'expression %<depobj%> n'est pas une expression l-valeur"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%> ou %<mutexinoutset%> attendu"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "clause %<depend%>, %<destroy%> ou %<update%> attendue"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<acq_rel%>, %<release%> ou %<acquire%> attendu"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "liste %<flush%> spécifiée avec une clause d'ordre de mémoire"
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<inclusive%> ou %<exclusive%> attendu"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> attendu"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "le paramètre de la clause %<ordered%> est plus petit que %<collapse%>"
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la clause %<linear%> ne peut pas être spécifiée avec la clause %<ordered%> comportant un paramètre"
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "instruction « for » attendue"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "déclaration ou initialisation d'itération attendue"
@@ -41715,72 +41765,72 @@ msgstr "déclaration ou initialisation d'itération attendue"
 msgid "not enough perfectly nested loops"
 msgstr "pas assez de boucles parfaitement imbriquées"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "boucles coalescées imparfaitement imbriquées"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la clause %<ordered%> avec un paramètre ne devrait pas être spécifiée sur la construction %qs"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> avec une clause %<depend%> peut uniquement être utilisé dans des instructions composées"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> attendu après %qs"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> attendu"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur un clause %<map%>"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> doit contenir au moins une clause %<map%>, %<use_device_ptr%> ou %<use_device_addr%>"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> doit contenir au moins une clause %<from%> ou %<to%>"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> avec un type avec correspondance autre que %<to%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> avec un type « map » autre que %<from%>, %<release%> ou %<delete%> sur une clause %<map%>"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
@@ -41795,57 +41845,57 @@ msgstr "%<#pragma omp declare %s%> doit être suivi d'une déclaration ou une d
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> doit être suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "nom de sélecteur de trait attendu"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "sélecteur %qs pas permis pour l'ensemble %qs du sélecteur de contexte"
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "le sélecteur %qs n'accepte aucune propriété"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "l'argument du score doit être une expression entière constante"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "l'argument du score doit être non négatif"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "la propriété doit être une expression entière constante ou une chaîne littérale"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "identificateur ou chaîne littérale attendus"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "la propriété doit être une expression entière constante"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "les propriétés pour le sélecteur %<simd%> ne peuvent pas être spécifiées dans %<metadirective%>"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<construct%>, %<device%>, %<implementation%> ou %<user%> attendu"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> attendu"
@@ -41855,12 +41905,12 @@ msgstr "%<match%> attendu"
 msgid "variant %qD is not a function"
 msgstr "le variant %qD n'est pas une fonction"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "le variant %qD et la base %qD ont des types incompatibles"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "le variant %qD est interne"
@@ -41870,32 +41920,32 @@ msgstr "le variant %qD est interne"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi par une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %<to%>"
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr "la directive avec uniquement des clauses %<device_type%> est ignorée"
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> attendu"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> attendu"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sans %<#pragma omp declare target%> correspondant"
@@ -41950,42 +42000,42 @@ msgstr "nom de fonction %<(%> attendu"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<&omp_priv%>"
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> ou %<variant%> attendu"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<seq_cst%>, %<relaxed%> ou %<acq_rel%> attendu"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "clause %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> ou %<atomic_default_mem_order%> attendue"
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "la clause %qs sur la directive %<requires%> n'est pas encore supportée"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "clause %qs utilisée lexicalement après la construction de la première cible ou l'API de déchargement"
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "plus d'une clause %<atomic_default_mem_order%> dans une même unité de compilation"
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "clause %<atomic_default_mem_order%> utilisée lexicalement après la première construction %<atomic%> sans clause d'ordre de mémoire"
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> requiert au moins une clause"
@@ -42000,27 +42050,27 @@ msgstr "type %qT de taille nulle dans la clause %<reduction%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "type %qT de taille variable dans la clause %<reduction%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE est déclaré %<threadprivate%> après la première utilisation"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automatique %qE ne peut être %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE a un type incomplet"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
@@ -42030,7 +42080,7 @@ msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas dans un %<__transaction_atomic%> extérieur ou une fonction %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> pas à l'intérieur de %<__transaction_atomic%>"
@@ -42045,7 +42095,7 @@ msgstr "pas d'accolade fermante"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD a un type incomplet %qT"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "utilisation invalide de l'expression void"
@@ -42166,7 +42216,7 @@ msgstr "déréférencement d'un pointeur %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "la valeur de l'indice n'est ni un tableau ni un pointeur ni un vecteur"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "l'indice du tableau n'est pas un entier"
@@ -42191,7 +42241,7 @@ msgstr "le C90 ISO interdit d'accéder à un tableau par un indice si le tableau
 msgid "enum constant defined here"
 msgstr "constante enum définie ici"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sur le tableau %qE en paramètre de fonction retournera la taille de %qT"
@@ -42304,17 +42354,17 @@ msgstr "conversion implicite de %qT en %qT lors du passage de l'argument à la f
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "trop peu d'arguments pour la fonction interne %qE %u attendus"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "une comparaison avec une chaîne littérale produit un résultat non spécifié"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "comparaison entre un pointeur et la constante caractère zéro"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "vouliez-vous déréférencer le pointeur ?"
@@ -42339,7 +42389,7 @@ msgstr "pointeur vers une fonction utilisé dans une soustraction"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "arithmétique sur un pointeur vers un type incomplet"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "arithmétique sur un pointeur vers un agrégat vide"
@@ -42587,7 +42637,7 @@ msgstr "transtypage d'un pointeur vers un entier de taille différente"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "transtypage d'un appel de fonction de type %qT vers le type %qT ne correspondant pas"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "transtypage vers un pointeur depuis un entier de taille différente"
@@ -42754,7 +42804,7 @@ msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'initialisation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "le type de retour pourrait être un candidat pour un attribut de format"
@@ -42914,7 +42964,7 @@ msgstr "impossible d'initialiser un tableau de %qT depuis une chaîne de caract
 msgid "array of inappropriate type initialized from string constant"
 msgstr "tableau d'un type inapproprié initialisé avec une chaîne constante"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "utilisation invalide d'un tableau n'étant pas une l-valeur"
@@ -42945,7 +42995,7 @@ msgstr "un élément de l'initialisation n'est pas évaluable lors du chargement
 msgid "invalid initializer"
 msgstr "initialisation invalide"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
@@ -43090,7 +43140,7 @@ msgstr "trop d'éléments dans l'initialisation d'un scalaire"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "le C ISO interdit %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la fonction est déclarée avec %<noreturn%> mais elle utilise l'instruction %<return%>"
@@ -43130,7 +43180,7 @@ msgstr "l'expression %<long%> du « switch » n'est pas convertie en %<int%> a
 msgid "case label is not an integer constant expression"
 msgstr "l'étiquette du « case » doit être une expression constante entière"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "étiquette « case » en dehors de tout « switch »"
@@ -43140,17 +43190,17 @@ msgstr "étiquette « case » en dehors de tout « switch »"
 msgid "%<default%> label not within a switch statement"
 msgstr "étiquette %<default%> en dehors de tout « switch »"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "mot-clé « break » à l'extérieur de toute boucle ou « switch »"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "mot-clé « continue » à l'extérieur de toute boucle"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "mot-clé « break » utilisé dans une boucle OpenMP"
@@ -43165,7 +43215,7 @@ msgstr "mot-clé « break » à l'intérieur du corps d'une boucle %<#pragma s
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "mot-clé « continue » à l'intérieur du corps d'une boucle %<#pragma simd%>"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "déclaration sans effet"
@@ -43175,22 +43225,22 @@ msgstr "déclaration sans effet"
 msgid "expression statement has incomplete type"
 msgstr "l'instruction de l'expression a un type incomplet"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "comparaison de vecteurs avec des types d'éléments différents"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "comparaison de vecteurs avec des nombres d'éléments différents"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "n'a pu trouver un type entier de la même taille que %qT"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "comparer des nombres flottants à l'aide de %<==%> ou %<!=%> n'est pas sûr"
@@ -43241,7 +43291,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "comparaison ordonnée d'un pointeur avec un pointeur nul"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparaison ordonnée d'un pointeur avec un zéro entier"
@@ -43271,51 +43321,51 @@ msgstr "valeur de type « union » utilisée là où un scalaire est requis"
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « vector » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "modificateur de clause %<cancel%> %<if%> attendus"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE dans la clause %qs"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "champ de bits %qE dans la clause %qs"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE est un membre d'une union"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "impossible de déréférencer %qE dans la clause %qs"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE n'est pas une variable dans la clause %qs"
@@ -43325,8 +43375,8 @@ msgstr "%qE n'est pas une variable dans la clause %qs"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD dans la clause %qs"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD est une variable « threadprivate » dans la clause %qs"
@@ -43494,12 +43544,12 @@ msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "type d'élément de longueur variable dans la table de la clause %<reduction%>"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la clause %<nowait%> ne doit pas être utilisée avec %<copyprivate%>"
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE doit être %<threadprivate%> pour %<copyin%>"
@@ -43524,8 +43574,8 @@ msgstr "%<_Atomic%> %qD dans la clause %<linear%>"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "le pas %qE de la clause %<linear%> n'est ni une constante ni un paramètre"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE n'est pas une variable dans la clause %qs"
@@ -43540,19 +43590,19 @@ msgstr "%qD apparaît plus d'une fois dans les clauses de réduction"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE apparaît plus d'une fois dans les clauses de données"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de données"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD apparaît à la fois dans les clauses « data » et « map »"
@@ -43622,117 +43672,117 @@ msgstr "%qE ne devrait pas avoir le type %<omp_depend_t%> dans la clause %<depen
 msgid "array section does not have mappable type in %qs clause"
 msgstr "la section du tableau n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de mouvement"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses « map »"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD n'a pas un type pour lequel la correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE n'est ni une variable ni un nom de fonction dans la clause %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE apparaît plus d'une fois dans la même directive %<declare target%>"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "la variable %qs n'est pas un pointeur"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "la clause %<order%> ne doit pas être utilisée avec %<ordered%>"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la clause %<inbranch%> est incompatible avec %<notinbranch%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE est prédéterminé %qs pour %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%qE qualifié avec %<const%> peut uniquement apparaître dans les clauses %<shared%> ou %<firstprivate%>"
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "la valeur de la clause %<simdlen%> est plus grande que la valeur de la clause %<safelen%>"
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "modificateur d'ordonnancement %<nonmonotonic%> spécifié en même temps que la clause %<ordered%>"
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "clause %qs spécifiée en même temps que la clause %<inscan%> %<reduction%>"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "le pas de la clause %<linear%> est un paramètre %qD pas spécifié dans la clause %<uniform%>"
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "la clause %<nogroup%> ne doit pas être utilisée avec la clause %<reduction%>"
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "impossible d'utiliser %<va_arg%> avec un ordre de stockage inversé"
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "le deuxième argument de %<va_arg%> est du type incompatible %qT"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "le C++ exige un type promu, pas un type enum, dans %<va_arg%>"
@@ -43914,778 +43964,778 @@ msgid "expected case label"
 msgstr "étiquette de « case » attendue"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "  passer %qT comme argument %<this%> élimine les qualificatifs"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  pas de conversion connue de %qH vers %qI pour le paramètre implicite %<this%>"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  la conversion de l'argument %d serait mal formée:"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr "  pas de conversion connue pour convertir %qH en %qI"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  pas de conversion connue pour convertir l'argument %d depuis %qH vers %qI"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  le candidat attend %d argument, %d fourni(s)"
 msgstr[1] "  le candidat attend %d arguments, %d fourni(s)"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T, %T)%> (fonction interne)"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T)%> (fonction interne)"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%<%D(%T)%> (fonction interne)"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr "%s%qT (conversion)"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr "%s%#qD (concordance proche)"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr "%s%#qD (supprimé)"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr "%s%#qD (inversé)"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr "%s%#qD (réécrit)"
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s%#qD"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr "  hérité ici"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  le type de retour %qT de la fonction de conversion explicite ne peut pas être converti en %qT avec une conversion qualifiée"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  la conversion depuis le type de retour %qT de la spécialisation de la fonction de conversion du patron vers %qT n'est pas une correspondance exacte"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  la substitution des arguments du patron déduit a provoqué les erreurs vues plus haut"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  la déduction/substitution de l'argument du patron a échoué:"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  un constructeur acceptant un unique argument de son propre type de classe est invalide"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  un constructeur hérité n'est pas un candidat pour une initialisation depuis une expression du même type ou d'un type dérivé"
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "la conversion de %qH vers %qI est ambiguë"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "initialiser %qH avec %qI dans une expression constante convertie n'est pas liée directement"
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversion de %qH vers %qI dans une expression constante convertie"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr "impossible de convertir %qE de %qH vers %qI"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "pas de fonction correspondant à l'appel %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%D(%A)%>"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "le pointeur vers la fonction membre %qE ne peut être appelé sans un objet; utilisez %<.*%> ou %<->*%>"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "pas de concordance pour l'appel à %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "l'appel à %<(%T) (%A)%> est ambigu"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "surcharge ambiguë pour "
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr "pas de concordance pour "
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (les types des opérandes sont %qT, %qT et %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (les types des opérandes sont %qT et %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (le type de l'opérande est %qT)"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "%<operator?:%> ternaire"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<operator?:%> ternaire dans %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> dans %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> dans %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs dans %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> dans %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> dans %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> dans %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "le C++ ISO interdit l'omission du terme au milieu de l'expression %<?:%>"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "le type scalaire inféré %qT n'est pas un type entier ou en virgule flottante de la même taille que %qT"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "la conversion du scalaire %qH vers le vecteur %qI implique une troncature"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types vectoriels incompatibles dans l'expression conditionnelle: %qT, %qT et %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "le deuxième opérande de l'opérateur conditionnel a le type %<void%> mais le troisième opérande n'est ni une expression qui génère une exception ni le type %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "le troisième opérande de l'opérateur conditionnel a le type %<void%> mais le deuxième opérande n'est ni une expression qui génère une exception ni le type %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "les opérandes de %<?:%> ont les types différents %qT et %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  et chaque type peut être converti en l'autre"
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "conversion implicite depuis %qH vers %qI pour correspondre à d'autres résultats de la condition"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "non concordance dans les énumérés de l'expression conditionnelle: %qT vs %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "type énuméré et non énuméré dans l'expression conditionnelle"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs, on essaie avec l'opérateur préfixé à la place"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "en C++20, cette comparaison appelle la fonction actuelle récursivement avec les arguments inversés"
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "le type de retour de %qD n'est pas %qs"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "utilisé comme candidat réécrit pour la comparaison de %qT et %qT"
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparaison entre %q#T et %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "le nettoyage pendant une exception pour cet opérateur « new » avec placement sélectionne %<operator delete%> sans placement"
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement) en C++14 (ou avec %<-fsized-deallocation%>)"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement)"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "pas de fonction de désallocation correspondante pour %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "pas de %<operator %s%> adapté pour %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D est privé dans ce contexte"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "déclaré privé ici"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D est protégé dans ce contexte"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "déclaré protégé ici"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D est inaccessible dans ce contexte"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "passage de NULL pour l'argument non pointeur %P de %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  déclaré ici"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "conversion vers un type non pointeur %qT à partir de NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "conversion de %<false%> vers un type pointeur pour l'argument %P de %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "conversion de %<false%> vers le type pointeur %qT"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initialisation de l'argument %P de %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les conversions vers des tableaux aux limites inconnues sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "trop d'accolades autour de l'initialiseur pour %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "la conversion vers %qH depuis %qI requiert une initialisation directe"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "la conversion définie par l'utilisateur de %qH vers %qI est invalide"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversion invalide de %qH vers %qI"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversion de la liste d'initialisation vers %qT utiliserait le constructeur explicite %qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "en C++11 et au delà, un constructeur par défaut peut être explicite"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "impossible de lier la référence d'une r-valeur de type %qH à une l-valeur de type %qI"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une r-valeur de type %qI"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "impossible de lier la référence de type %qH vers %qI à cause des limites différentes des tableaux"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "lier la référence du type %qH à %qI abandonne les qualificatifs"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ne peut lier le champ de bits %qE avec %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ne peut lier le champs empaqueté %qE avec %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ne peut lier la r-valeur %qE avec %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversion implicite de %qH en %qI lors du passage de l'argument à la fonction"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "l'énumération %qT dans une portée limitée est passée au travers de %<...%> en tant que %qT avant %<-fabi-version=6%> et en tant que %qT après"
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "le passage d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "impossible de recevoir le type référencé %qT au travers de %<...%>"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la réception d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "évaluation récursive de l'argument par défaut pour %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "l'appel à %qD utilise l'argument par défaut du paramètre %P qui n'est pas encore défini"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "l'argument de l'appel de fonction pourrait être un candidat pour un attribut de format"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "utilisation d'une fonction ayant plusieurs versions sans version par défaut"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "le passage de %qT comme argument %<this%> abandonne les qualificatifs"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dans l'appel de %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT n'est pas une base accessible de %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "passage des arguments à l'élision du constructeur hérité %qD"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "l'affectation depuis le %<initializer_list%> temporaire n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "écriture %qD vers un objet de type %#qT sans affectation par copie triviale"
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "écriture %qD vers un objet de type non trivial %#qT%s"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "écriture %qD vers un objet de type %#qT avec le membre %qs de %qD"
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "écriture %qD vers un objet de type %#qT contenant un pointeur vers le membre de donnée%s"
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; utilisez plutôt une affectation ou une initialisation par valeur"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; utilisez plutôt une affectation"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; utilisez plutôt une initialisation par valeur"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD effacement d'un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD effacement d'un objet du type non trivial %#qT%s"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD effacement d'un objet de type %#qT contenant un pointeur vers un membre%s"
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; utilisez plutôt une affectation par copie ou une initialisation par copie"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; utilisez plutôt une affectation par copie"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; utilisez plutôt une initialisation par copie"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD écriture dans un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD écriture dans un objet du type non trivialement copiable %#qT%s"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD écriture dans un objet avec un constructeur par copie supprimé"
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD copie un objet du type non trivial %#qT depuis un tableau de %#qT"
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD copie un objet de type %#qT avec le membre %qs de %qD depuis un tableau de %#qT; utilisez plutôt une affectation ou une initialisation par copie"
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octets inchangés"
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octet inchangé"
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet du type non trivialement copiable %#qT; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet de type %#qT avec un constructeur par copie supprimé; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD déplacement d'un objet de type %#qT avec un destructeur supprimé"
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD déplacement d'un objet du type non trivial %#qT et de taille %E dans une région de taille %E"
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT déclaré ici"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "le constructeur délègue à lui-même"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr "ne peut convertir %qH en %qI"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "pour un transtypage de style « fonction », enlevez le %<::%D%> redondant"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de %<%s(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%s(%A)%>"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "appel à %q#D qui est pur virtuel depuis un initialisateur qui n'est pas un membre statique"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le constructeur"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le destructeur"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "impossible d'appeler la fonction membre %qD sans objet"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "le passage de %qT choisi %qT au lieu de %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "choix de %qD à la place de %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 msgid "  for conversion from %qH to %qI"
 msgstr "  pour la conversion de %qH vers %qI"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  parce que la séquence de conversion pour l'argument est meilleure"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "désaccord dans l'argument par défaut lors de la résolution de la surcharge"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidat 1: %q#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidat 2: %q#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "le C++ ISO indique que ceux-ci sont ambigus même si la plus mauvaise conversion pour le premier est meilleures que la plus mauvaise conversion pour le second:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "une limite temporaire sur %qD existe uniquement jusqu'à la sortie du constructeur"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "initialisation invalide pour une référence non constante du type %qH à partir d'une r-valeur de type %qI"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "initialisation invalide pour une référence du type %qH à partir d'une expression de type %qI"
 
@@ -44715,520 +44765,520 @@ msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "impossible de convertir depuis %qT vers la classe de base %qT car %qT est incomplet"
 
 # ce message apparaît juste après le %q#D ci-dessus
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D est en conflit avec la version héritée de %qT"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "la version héritée de %qT est déclarée ici"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D ne peut pas être surchargé par %q#D"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "déclaration précédente de %q#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "spécifications d'accès conflictuelles pour la méthode %q+D, ignoré"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "spécifications d'accès conflictuelles pour le champ %qE, ignoré"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "%qD invalide dans %q#T à cause de la méthode locale %q#D avec le même nom"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "méthode locale %q#D, déclarée ici"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "%qD invalide dans %q#T à cause du membre local %q#D avec le même nom"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "membre local %q#D déclaré ici"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD hérite de l'étiquette de l'ABI %E que %qT (utilisé dans son type de retour) a déjà"
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT déclaré ici"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD hérite de l'étiquette de l'ABI %E que %qT (utilisé dans son type) a déjà"
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT n'a pas l'étiquette de l'ABI %E que la classe de base %qT a"
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT ne possède pas l'étiquette de l'ABI %E que %qT (utilisé dans le type de %qD) possède"
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "impossible de dériver de la classe de base %<final%> %qT dans le type dérivé %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "toutes les fonctions membre de la classe %qT sont privées"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T définit uniquement un destructeur privé et n'a pas d'amis"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T définit uniquement des constructeurs privés et n'a pas d'amis"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D est public mais requiert un objet %q#T existant"
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "pas de redéfinition finale unique pour %qD dans %qT"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD peut être marqué « override »"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D est marqué %<override%> mais il ne redéfini rien"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D est marqué %<final%> mais il n'est pas virtuel"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD était caché"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  par %qD"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données publiques non statiques"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "cette flexibilité est dépréciée et sera supprimée"
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "l'élision dans %qD n'est pas héritée"
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "champ de bits %q#D avec le type non entier %qT"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la largeur du champ de bits %q+D n'est pas une constante entière"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "largeur négative dans le champ de bits %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "largeur nulle pour le champ de bits %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "la largeur de %qD dépasse celle de son type"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD est trop petit pour contenir toutes les valeurs de %q#T"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "le membre %q+#D avec destructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "le membre %q#D avec un opérateur d’affectation par copie n'est pas permis dans l'union"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les unions sans restrictions sont disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "en C++98, %q+D ne peut pas être statique parce qu'il est un membre d'une union"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "le membre de donnée non statique %q+D dans une union ne peut pas avoir le type référencé %qT"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "le membre de données %q+D est incorrectement déclaré avec le type d'une fonction"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "le membre de données %q+D est incorrectement déclaré comme type de méthode"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "attribut « packed » ignoré à cause du champ non POD non empaqueté %q#D"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "le membre %q+D ne peut pas être déclaré comme une référence %<mutable%>"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "le membre %q+D ne peut pas être déclaré à la fois %<const%> et %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "champs multiples initialisés dans l'union %qT"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "le membre %q+D initialisé est déclaré ici"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "champ %q#D avec le même nom que la classe"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T a des membres de données qui sont des pointeurs"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  mais il ne déclare pas %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ou %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  mais il ne déclare pas %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "membre pointeur %q+D déclaré ici"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "l'alignement de %qD a augmenté avec %<-fabi-version=9%> (GCC 5.2)"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "l'alignement de %qD augmentera avec %<-fabi-version=9%>"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initialisation spécifiée pour une méthode non virtuelle %q+D"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "le destructeur pour %qT est ambigu"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "la méthode redéfini à la fois les méthodes %<transaction_pure%> et %qE"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "la méthode déclarée %qE redéfini la méthode %qE"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "la classe englobant la fonction membre non statique %<constexpr%> %q+#D n'est pas un type littéral"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T n'est pas littéral à cause de:"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT est un type de fermeture qui n'est un littéral qu'à partir du C++17"
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T a un destructeur non trivial"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T n'a pas de destructeur %<constexpr%>"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T n'est pas un agrégat, n'a pas de constructeur par défaut trivial et n'a pas de constructeur %<constexpr%> qui n'est pas un constructeur de copie ou par déplacement"
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la classe de base %qT de %q+T n'est pas littérale"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  le membre de donnée non statique %qD a un type non littéral"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  le membre de donnée non statique %qD a un type volatile"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la classe de base %q#T a un destructeur non virtuel accessible"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "la référence non statique %q#D dans la classe sans un constructeur"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "le membre constant non statique %q#D dans la classe sans un constructeur"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base directe %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base virtuelle %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "le décalage relatif de %qD n'est pas compatible avec l'ABI et peut changer dans une version future de GCC"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "la taille du type %qT est trop grande (%qE octets)"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "utilisation invalide de %q#T avec un tableau de taille nulle dans %q#D"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "utilisation invalide de %q#T avec un membre sous forme de tableau flexible dans %q#T"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "membre tableau %q#D déclaré ici"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "membre tableau de taille nulle %qD pas à la fin de %q#T"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau de taille nulle %qD dans un %q#T par ailleurs vide"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "dans la définition de %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "le membre tableau flexible %qD n'est pas à la fin de %q#T"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau flexible %qD dans %q#T par ailleurs vide"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T a des fonctions virtuelles et un destructeur non virtuel accessible"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "le type transparent %q#T n'a aucun champ"
 
 # un type transparent est un type qui est passé comme le type qu'elle manipule, par ex decimal32
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la classe de type transparent %qT a des classes de base"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la classe de type transparent %qT a des fonctions virtuelles"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "le type transparent %q#T ne peut être rendu transparent car le type du premier champ a une ABI différente de la classe générale"
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "la définition de %qD ne correspond pas à %<#include <initializer_list>%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "la tentative de terminer la struct a été stoppée nette en raison des erreurs précédentes dans l'analyse syntaxique"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "la chaîne de langage %<\"%E\"%> n'est pas reconnue"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ne peut résoudre la fonction surchargée %qD basé sur la conversion vers le type %qT"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "pas de correspondance pour convertir la fonction %qD vers le type %q#T"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversion de la fonction surchargée %qD vers le type %q#T est ambiguë"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "on suppose un pointeur vers le membre %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un pointeur vers un membre peut seulement être formé avec %<&%E%>)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "pas assez d'informations sur le type"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "impossible de convertir %qE du type %qT vers le type %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "la déclaration de %q#D change la signification de %qD"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD déclaré ici comme %q#D"
@@ -45308,7 +45358,7 @@ msgstr "l'appel %<constexpr%> déborde au delà de la fin de la fonction"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E n'est pas une expression constante"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "appel à la fonction interne %qE"
@@ -45364,7 +45414,7 @@ msgstr "désallocation d'un stockage déjà désalloué"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "désallocation d'un stockage qui n'a pas été précédemment alloué"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "appel à la fonction non %<constexpr%> %qD"
@@ -45419,370 +45469,369 @@ msgstr "l'expression de décalage %q+E déborde"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "arithmétique impliquant un pointeur nul dans %qE"
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau %qD du type %qT"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec le tableau %qD de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau de type %qT"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec un tableau de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "accès à un élément non initialisé du tableau"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "déréférencement d'un pointeur nul dans %qE"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE n'est pas une expression constante"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "le mutable %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "accès au membre non initialisé %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "accès au membre %qD au lieu du membre initialisé %qD dans l'expression constante"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "déréférencement d'un pointeur nul"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "accès à la valeur de %qE au travers d'une gl-valeur %qT dans une expression constante"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "le contenu d'un stockage non initialisé n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "alloué ici"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "utilisation d'un stockage alloué après sa désallocation dans une expression constante"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "la valeur de %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD utilisé dans sa propre initialisation"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D n'est pas const"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D est volatile"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD n'a pas été initialisé par une expression constante"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD n'a pas été déclaré %<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD n'a pas un type entier ou énuméré"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "la modification de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "changement du membre actif d'une union de %qD à %qD"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "changement du membre actif d'une union de %qD à %qD durant l'initialisation"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "l'instruction n'est pas une expression constante"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "le décompte des itérations de la boucle %<constexpr%> dépasse la limite permise %d (utilisez %<-fconstexpr-loop-limit=%> pour augmenter la limite)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "l'assembleur en ligne n'est pas une expression constante"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr "seul de l'assembleur en ligne non évalué est autorisé dans une fonction %<constexpr%> en C++2a"
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "la valeur %qE du type %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "le décompte des opérations d'évaluation de %<constexpr%> dépasse la limite permise %wd (utilisez %<-fconstexpr-ops-limit=%> pour augmenter la limite)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporaire du type %qT non littéral dans une expression constante"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "un %<reinterpret_cast%> n'est pas une expression constante"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "la conversion du pointeur nul %qT vers %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> n'est pas une expression constante"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "l'expression %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "template-id %qE inattendu"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "un concept de fonction doit être appelé"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "l'expression %qE du sous-type %s est inattendue"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE n'est pas une expression constante car il fait référence aux sous-objets mutables de %qT"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE n'est pas une expression constante car il fait référence à une variable incomplètement initialisée"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE n'est pas une expression constante car il fait référence à un résultat de %<operator new%>"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE n'est pas une expression constante car le stockage alloué n'a pas été désalloué"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "l'évaluation immédiate retourne l'adresse de la fonction immédiate %qD"
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversion depuis le type pointeur %qT vers le type arithmétique %qT dans une expression constante"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversion l-valeur vers r-valeur d'une l-valeur volatile %qE avec le type %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la capture lambda de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "car il est utilisé comme gl-valeur"
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> d'un entier vers un pointeur"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "prendre l'adresse avec address-of d'un objet %qE qui est local au thread ou a un stockage automatique n'est pas une expression constante"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "utilisation de %<this%> dans une expression constante"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "expression lambda dans une expression constante avant C++17"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "les fonctions virtuelles ne peuvent pas être %<constexpr%> avant C++2a"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "l'expression %<typeid%> n'est pas une expression constante car %qE est un type polymorphique"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "transtypage vers le type non entier %qT dans une expression constante"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD déclaré %<static%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD déclaré %<thread_local%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "la division par zéro n'est pas une expression constante"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> n'est pas une expression constante"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "initialisation d'un tableau non constant"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> n'est pas une expression constante"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr "les deux branches de l'instruction %<if%> sont marquées comme %qs"
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> appellera toujours %<terminate%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "en C++11, les destructeurs sont %<noexcept%> par défaut"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "en C++11, ce %<throw%> appellera %<terminate%> car les destructeurs sont %<noexcept%> par défaut"
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "l'attribut %qE est ignoré après un %qE antérieur"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD n'est pas un type"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD n'est pas un type de classe"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD n'a pas le type %<const char *%>"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD n'a pas un type entier"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> ne contient pas uniquement que des membres de données non-statiques %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> et %<_M_column%>"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "évaluation de %qs"
@@ -45823,7 +45872,7 @@ msgstr "conversion vers le type référencé non const %q#T depuis une r-valeur
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversion depuis %qH vers %qI écarte les qualificatifs"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "le transtypage de %qT vers %qT ne déréférence pas le pointeur"
@@ -45861,292 +45910,292 @@ msgstr "%q#T utilisé là où une valeur en virgule flottante était attendue"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "conversion de %qH vers le type non scalaire %qI demandée"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "la valeur de retour de %qD est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%> : %<%s%>"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "la valeur de retour de %qD est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%>%s"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "la valeur de retour de type %qT est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%> : %<%s%>"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "la valeur de retour de type %qT est ignorée alors qu'elle est déclarée avec l'attribut %<nodiscard%>%s"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "dans l'appel à %qD, déclaré ici"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "la valeur retournée par %qD est ignorée alors qu'elle est déclarée avec l'attribut %<warn_unused_result%>"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "le pseudo-destructeur n'est pas appelé"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet de type incomplet %qT"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'instruction"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet du type %qT"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'instruction"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet du type non trivialement copiable %qT"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'instruction"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet %qE du type incomplet %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'instruction"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "la conversion vers void ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "le deuxième opérande de l'expression conditionnelle ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "le troisième opérande de l'expression conditionnelle ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "l'opérande de droite de l'opérateur virgule ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "l'opérande de gauche de l'opérateur virgule ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "l'instruction ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "l'expression d'incrémentation de « for » ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "le deuxième opérande de l'expression conditionnelle est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "le troisième opérande de l'expression conditionnelle est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "l'opérande de droite de l'opérateur virgule est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "l'opérande de gauche de l'opérateur virgule est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "l'instruction est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "l'expression d'incrémentation de « for » est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "le deuxième opérande de l'expression conditionnelle n'a pas d'effet"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "le troisième opérande de l'expression conditionnelle n'a pas d'effet"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "l'opérande de droite de l'opérateur virgule n'a pas d'effet"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "l'opérande de gauche de l'opérateur virgule n'a pas d'effet"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "l'instruction n'a pas d'effet"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "l'expression d'incrémentation de « for » n'a pas d'effet"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "conversion d'un NULL vers un type non pointeur"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "la conversion du type par défaut ne peut déduire l%'argument du patron pour %qD"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "la conversion du type par défaut est ambiguë à partir de %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  les conversions candidates incluent %qD et %qD"
@@ -46211,7 +46260,7 @@ msgstr "par rapport à la déclaration précédente de %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redéclaration de %qD diffère de %qs dans la déclaration précédente"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "déclaration précédente de %qD"
@@ -46392,12 +46441,12 @@ msgstr "la déclaration précédente de %qD est ici"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "fonction %qD déclarée %<[[noreturn]]%> mais sa première déclaration ne l'était pas"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "déclaration redondante de %qD dans la même étendue"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "définition supprimée de %qD"
@@ -46410,44 +46459,44 @@ msgstr "définition supprimée de %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spécialisation explicite de %qD après la première utilisation"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: attribut de visibilité ignoré car il est en conflit avec la déclaration précédente"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redéfinition de %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD est en conflit avec la fonction utilisée"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D pas déclaré dans une classe"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne avec l'attribut %<gnu_inline%>"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne sans l'attribut %<gnu_inline%>"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "l'opérateur de comparaison %q+D est remis au défaut après sa première déclaration"
@@ -46455,842 +46504,842 @@ msgstr "l'opérateur de comparaison %q+D est remis au défaut après sa premièr
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redéclaration de l'ami %q#D ne peut pas avoir d'arguments de patron par défaut"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "la déclaration locale au thread de %q#D suit la déclaration non locale au thread"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "la déclaration non locale au thread de %q#D suit la déclaration locale au thread"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redéclaration de %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redéclaration redondante du membre statique %<constexpr%> %qD"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "l'étiquette locale %qE est en conflit avec l'étiquette existante"
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr "étiquette précédente"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  à partir d'ici"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sort du block structuré OpenMP"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  croise l'initialisation de %q#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  entre dans la portée de %q#D qui a un destructeur non trivial"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  entre dans le bloc %<try%>"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  entre dans le bloc %<catch%>"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entre dans le bloc structuré OpenMP"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  entre dans l'instruction synchronisée ou atomique"
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  entre dans l'instruction %<constexpr if%>"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  passe outre l'initialisation de %q#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  entre dans la portée de %q#D qui a un destructeur non trivial"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "sortie invalide du bloc structuré OpenMP"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD utilisé sans arguments du patron"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T n'est pas une classe"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "pas de patron de classe nommé %q#T dans %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "pas de type nommé %q#T dans %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la recherche de %qT dans %qT est ambigüe"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un patron de classe"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un type"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "les paramètres du patron ne correspondent pas au patron %qD"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> n'est pas une puissance de deux"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un destructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un opérateur d'affectation par copie n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoré dans la déclaration de %q#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "l'attribut pour %q#T doit suivre le mot-clé %qs"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "types multiples dans une déclaration"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redéclaration du type interne C++ %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> peut seulement être spécifié pour des déclarations de variables ou de fonctions"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nom de type manquant dans la déclaration typedef"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "le C++ ISO interdit les structures anonymes"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> peut seulement être spécifié à l'intérieur d'une classe"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> peut seulement être spécifié pour des constructeurs"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "une classe de stockage peut seulement être spécifiée pour des objets et des fonctions"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> a été ignoré dans cette déclaration"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs ne peut pas être utilisé pour des déclarations de types"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoré dans l'instanciation explicite de %q#T"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "aucun attribut peut être appliqué à une instanciation explicite"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "les attributs sont ignorés s'ils sont appliqués à la classe de type %qT en dehors de la définition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "attributs ignorés car ils sont appliqués au type dépendent %qT sans déclaration associée"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD est initialisé (utilisez plutôt %qs)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la déclaration de %q#D est %<extern%> et est initialisée"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la définition de %q#D est marquée %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D n'est pas un membre de donnée statique de %q#T"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "la déclaration du patron non membre de %qD"
 
 # le message ci-dessous est la suite de celui juste ci-dessus
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ne correspond pas à la déclaration du patron membre ici"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "le C++ ISO ne permet pas que %<%T::%D%> soit défini comme %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "initialisation en double de %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la déclaration de %q#D en dehors de la classe n'est pas une définition"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD déclaré %<thread_local%> dans une fonction %qs"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD déclaré %<static%> dans une fonction %qs"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D a un initialiseur mais a un type incomplet"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "les éléments du tableau %q#D ont un type incomplet"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "l'agrégat %q#D a un type incomplet et ne peut être défini"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD est déclaré comme référence mais n'est pas initialisé"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nom utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nom %qD utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "les initialisations par désignation non triviales ne sont pas supportées"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "le champ désigné par l'indicateur C99 %qE n'est pas une expression constante entière"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "l'initialisation n'a pu déterminer la taille de %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "taille de tableau manquante dans %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "tableau %qD de taille zéro"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "la taille de stockage de %qD n'est pas connue"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "la taille de stockage de %qD n'est pas constante"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la variable en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la fonction statique en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "vous pouvez contourner cela en enlevant l'initialiseur"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "%<const %D%> non initialisé"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable %qD non initialisée dans une fonction %<constexpr%>"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "variable %qD non initialisée dans un contexte %<constexpr%>"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T n'a pas de constructeur par défaut fourni par l'utilisateur"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "le constructeur n'est pas défini par l'utilisateur car le constructeur par défaut est explicitement demandé dans le corps de la classe"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "et le constructeur implicitement défini n'initialise pas %q#D"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "type %qT invalide pour initialiser un vecteur de type %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "l'initialisation de %qT doit être entre accolades"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> utilisé dans une initialisation par désignation dans le style GNU pour la classe %qT"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT n'a pas de membre de données non statique nommé %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "initialisation invalide pour %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "le champ désigné par l'indicateur C99 %qE est hors de l'initialisation de l'agrégat"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "trop d'éléments d'initialisation pour %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "trop d'accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades manquantes autour de l'initialisation pour %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "les éléments du tableau %q#T ont un type incomplet"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "littéral composé de taille variable"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D a un type incomplet"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "l'objet scalaire %qD requiert un élément dans l'initialisation"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98, %qD doit être initialisé par un constructeur et non par %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "le tableau %qD est initialisé par la chaîne littérale entre parenthèses %qE"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initialisation invalide pour un membre statique avec constructeur"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique pas en ligne %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(une initialisation en dehors de la classe est requise)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "la référence %qD est initialisée avec elle-même"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "n'a pu trouver la déclaration du variant"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> sur le constructeur %qD"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> sur le destructeur %qD"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> sur %qD par défaut"
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> sur %qD supprimé"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> sur %qD virtuel"
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (pas une initialisation) dans la déclaration"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "le C++17 ISO n'autorise pas le spécificateur de classe de stockage %<register%>"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "spécificateur de classe de stockage %<register%> utilisé"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "l'initialisation pour %<decltype(auto) %D%> a un type fonction (avez-vous oublié les %<()%> ?)"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "le concept de variable n'a pas d'initialisation"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "masque la déclaration précédente du type de %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> peut uniquement être appliqué à une variable avec une durée de stockage statique ou au niveau du thread"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la fonction %q#D est initialisée comme une variable"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une structure anonyme comme membre"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une union anonyme comme membre"
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "impossible de décomposer le membre inaccessible %qD de %qT"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: lui et sa classe de base %qT ont des membres de données non statiques"
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: ses classes de base %qT et %qT ont des membres de données non statiques"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "la liaison structurée fait référence au type incomplet %qT"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "impossible de décomposer le tableau de longueur variable %qT"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u nom fourni pour la liaison structurée"
 msgstr[1] "%u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "seulement %u nom fourni pour la liaison structurée"
 msgstr[1] "seulement %u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "alors que %qT se décompose en %wu élément"
 msgstr[1] "alors que %qT se décompose en %wu éléments"
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "impossible de décomposer le vecteur de longueur variable %qT"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> n'est pas une expression constante entière"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "alors que %qT se décompose en %E éléments"
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dans l'initialisation de la variable de liaison structurée %qD"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "impossible de décomposer le type union %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "impossible de décomposer le type %qT qui n'est ni une classe ni un tableau"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "impossible de décomposer le type de fermeture lambda %qT"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "la liaison structurée fait référence au type de classe incomplet %qT"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "impossible de décomposer le type de classe %qT sans membre de donnée non statique"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "la variable non locale %qD déclarée %<__thread%> a besoin d'une initialisation dynamique"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "la variable non locale %qD déclarée %<__thread%> a un destructeur non trivial"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> en C++11 permet l'initialisation et la destruction dynamique"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de %qT"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taille du tableau manquante dans %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "tableau %qT de taille zéro"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "le destructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "le constructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD est déclaré comme une variable %<virtual%>"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de variable"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD déclaré comme un paramètre %<virtual%>"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD déclaré comme un paramètre %<inline%>"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de paramètre"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD déclaré comme un type %<virtual%>"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD déclaré comme un type %<inline%>"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de type"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD déclaré comme un champ %<virtual%>"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD déclaré comme un champ %<inline%>"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de champ"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D déclaré comme un ami"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D déclaré avec une spécification d'exception"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la définition de %qD n'est pas dans l'espace de noms incluant %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la fonction membre statique %q#D est déclarée avec des qualificatifs de type"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "le concept %q#D est déclaré avec des paramètres de fonction"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "le concept %q#D est déclaré avec un type de retour déduit"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "le concept %q#D a le type de retour %qT qui n'est pas %<bool%>"
@@ -47560,7 +47609,7 @@ msgstr "débordement dans la dimension du tableau"
 msgid "%qD declared as array of %qT"
 msgstr "%qD est déclaré comme tableau de %qT"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
@@ -47725,7 +47774,7 @@ msgstr "declarator-id manquant; utilisation du mot réservé %qD"
 msgid "function definition does not declare parameters"
 msgstr "la définition de fonction ne déclare aucun paramètre"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de %qD comme non fonction"
@@ -47926,810 +47975,810 @@ msgstr "attribut ignoré"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un attribut qui appartient à un spécificateur de type est ignoré"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "parenthèses inutiles dans la déclaration de %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "clause « requires » sur le type de retour"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la fonction %qs utilise le spécificateur de type %<auto%> sans type de retour à la fin"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "le type de retour déduit est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "une fonction virtuelle ne peut pas avoir un type de retour déduit"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %qT comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %<decltype(auto)%> comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "utilisation invalide de %<decltype(auto)%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "type de classe %qD déduit dans le type de retour de la fonction"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "le guide de déduction pour %qT doit avoir un type de retour à la fin"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "le type de retour %qT à la fin du guide de déduction n'est pas une spécialisation de %qT"
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "le type de retour à la fin est uniquement disponible avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "la fonction %qs avec le type de retour à la fin n'est pas déclarée avec le spécificateur de type %<auto%>"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "le type de retour qualifié avec %<volatile%> est déprécié"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "le type de retour %<constinit%> pour une fonction n'est pas permis"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "les constructeurs ne peuvent pas être déclarés %<virtual%>"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "les fonctions virtuelles ne peuvent pas être amies"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la déclaration amie n'est pas dans la définition de la classe"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "ne peut définir la fonction amie %qs dans une définition de classe locale"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "la définition de la fonction amie %qs ne peut pas avoir son nom qualifié avec %<::%>"
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "la définition de la fonction amie %qs ne pas avoir son nom qualifié avec %<%D::%>"
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "une fonction de conversion ne peut pas avoir de type de retour à la fin"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre %q#T"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut déclarer une référence vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "ne peut déclarer une référence vers %q#T qui n'est pas un typedef ou un argument vers un type d'un patron"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD utilisé comme un déclarateur"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amies de leur classe"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification %<%T::%> additionnelle sur le membre %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "ne peut définir la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "ne peut déclarer la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "le non paramètre %qs ne peut pas être un paquet de paramètres"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "les membres de données ne peuvent pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "le paramètre ne peut pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> en dehors de la déclaration de la classe"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> dans une déclaration amie"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs et les opérateurs de conversion peuvent être %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "le membre non objet %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la fonction %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la référence %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef ne peut pas être une définition de fonction"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef ne peut pas être une définition de fonction membre"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> n'est pas autorisé dans une déclaration de synonyme"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef déclaré %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "clause « requires » sur un typedef"
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "le nom du typedef ne peut pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "le C++ ISO interdit le type imbriqué %qD avec le même nom que la classe englobante"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "les paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre amie la classe %qT au niveau de la portée globale"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificatifs invalides sur un type de fonction non membre"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "clause « requires » sur type-id"
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstraite %qT utilisée comme déclaration"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "clause « requires » dans la déclaration du type non fonction %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser %<::%> dans la déclaration d'un paramètre"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ne peut déclarer un paramètre avec %<decltype(auto)%>"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "le paramètre %<auto%> n'est pas permis dans ce contexte"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "membre de donnée non statique déclaré avec %qT comme type à remplacer"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "le C++ ISO interdit le membre tableau flexible %qs"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "le C++ ISO interdit les tableaux flexibles comme membres"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction %qD dans un contexte invalide"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fonction %qD déclarée %<virtual%> à l'intérieur d'une union"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD ne peut pas être déclaré %<virtual%> puisqu'il est toujours statique"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie du destructeur %qD"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de %qD comme membre de %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "un destructeur ne peut pas être %qs"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les destructeurs %<constexpr%> sont uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie pour le constructeur %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "un constructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "un concept ne peut être une fonction membre"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD ne peut pas être %qs"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation du patron de variable %qD déclaré comme une fonction"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "le patron de variable a été déclaré ici"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "le champ %qD a le type incomplet %qT"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "le nom %qT a un type incomplet"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "le champ sans nom n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "membre de donnée statique %qE déclaré %qs"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "le membre statique %<constexpr%> %qD doit avoir une initialisation"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "le membre de donnée non statique %qE est déclaré %qs"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la classe de stockage %<auto%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la classe de stockage %<register%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la classe de stockage %<__thread%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la classe de stockage %<thread_local%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "le spécificateur de type « virt-specifier » sur %qs n'est pas permis en dehors d'une définition de classe"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<static%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<inline%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "fonction non classe virtuelle %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs défini en dehors d'un contexte de classe"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs déclaré en dehors d'un contexte de classe"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "ne peut déclarer la fonction membre %qD comme ayant une classe de liaison statique"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> ne peut pas être utilisé lors de la définition (contrairement à la déclaration) d'un membre de donnée statique"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "membre statique %qD déclaré %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre %q#D comme ayant une classe de liaison externe"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la déclaration de la variable %<constexpr%> %qD n'est pas une définition"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "une variable ne peut pas être déclarée %<consteval%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la déclaration de %q#D n'est pas initialisée"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisé et déclaré %<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs a, à la fois, %<extern%> et une initialisation"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "l'argument par défaut %qE utilise %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "l'argument par défaut %qE utilise la variable locale %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide du type %qT qualifié CV dans la déclaration du paramètre"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du type %<void%> dans la déclaration du paramètre"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "le paramètre qualifié avec %<volatile%> est obsolète"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "le paramètre %qD est incorrectement déclaré comme type de méthode"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut un pointeur vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut une référence vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement utiliser %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD ne peut pas être déclaré dans un espace de noms"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD ne peut pas être déclaré statique"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD doit être une fonction membre non statique"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD doit être soit une fonction membre non statique ou une fonction non membre"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD doit avoir un argument de type classe ou énuméré"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "le C++ ISO interdit la surcharge de %<operator ?:%>"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD ne doit pas avoir un nombre variables d'arguments"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD doit avoir zéro ou un argument"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD doit avoir un ou deux arguments"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qD suffixé doit avoir %<int%> comme argument"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qD suffixé doit avoir %<int%> comme second argument"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD ne doit avoir aucun argument"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD doit avoir exactement un argument"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD doit avoir exactement deux arguments"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD ne peut avoir d'arguments par défaut"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversion de %qT vers %<void%> n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "%qD défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "%qD préfixé devrait retourner %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "%qD suffixé devrait retourner %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD devrait retourner par valeur"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation du paramètre du type de patron %qT après %qs"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "utilisation de la spécialisation du patron d'alias %qT après %qs"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation du nom de typedef %qD après %qs"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD a une déclaration précédente ici"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT référé en tant que %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT a une déclaration précédente ici"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "il est fait référence à %qT comme un enum"
@@ -48741,95 +48790,95 @@ msgstr "il est fait référence à %qT comme un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron requis pour %<%s %T%>"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de l'enum %q#D sans déclaration précédente"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de %qT sous une forme qui n'est pas un patron"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "l'union dérivée %qT est invalide"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT est défini avec des bases directes multiples"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT est défini avec des bases virtuelles directes"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "le type de base %qT n'est pas un « struct » ou une « class »"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "type récursif %qT non défini"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "le type de base dupliqué %qT est invalide"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "désaccord dans le type sous-jacent de l'enum %q#T"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "types sous-jacents différents dans l'enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "le type sous-jacent %qT de %qT doit être un type entier"
@@ -48838,72 +48887,72 @@ msgstr "le type sous-jacent %qT de %qT doit être un type entier"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier ne peut représenter toutes les valeurs de l'énumération pour %qT"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "les valeurs énumérées de %qD doivent être de type entier ou une énumération simple (donc, pas fortement typée)"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "la valeur de l'énumération pour %qD n'est pas une constante entière"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<unsigned long%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<long%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "la valeur de l'énumération %qE est en dehors de la plage du type sous-jacent %qT"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD est déjà défini dans la classe %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "utilisation de %qD avant la déduction de %<auto%>"
@@ -48943,7 +48992,7 @@ msgstr "ne peut détruire une fonction.  Seuls les pointeurs vers des objets son
 msgid "deleting %qT is undefined"
 msgstr "la destruction de %qT est non définie"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "déclaration du patron de %q#D"
@@ -48953,7 +49002,7 @@ msgstr "déclaration du patron de %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "la liste des paramètres du patron fournie ne correspond pas aux paramètres du patron de %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "le destructeur %qD est déclaré en tant que patron membre"
@@ -49278,147 +49327,147 @@ msgstr "car %qT a un %qD fourni par l'utilisateur"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "conversion d'une fonction lambda qui utilise %<...%> en pointeur de fonction"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "utilisation de la fonction supprimée %qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "utilisation de la fonction %qD avec des contraintes non satisfaites"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "utilisation du paquet de paramètres intégré %qD en dehors d'un patron"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(pas d'argument)"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[...]"
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les listes d'initialisation étendues sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les opérateurs de conversion explicites sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les patrons variadiques sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les expressions lambda sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "le auto du C++11 est uniquement disponible avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les enums fortement typés sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les fonctions par défaut ou supprimées sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les espaces de noms en ligne sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "le contrôle de la redéfinition (override/final) est uniquement disponible avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les initialisations de membres de données non statiques sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les littéraux définis par l'utilisateur sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les constructeurs délégués sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les constructeurs hérités sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les attributs c++11 sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les qualificatifs de références sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "type %qT incomplet utilisé dans un spécificateur de noms imbriqué"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "la référence à %<%T::%D%> est ambiguë"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD n'est pas un membre de %qT; vouliez-vous employer %qs ?"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD n'est pas un membre de %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD n'est pas un membre de %qD; vouliez-vous employer %qs ?"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD n'est pas un membre de %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> n'a pas été déclaré; vouliez-vous employer %qs ?"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> n'a pas été déclaré"
@@ -49599,338 +49648,338 @@ msgstr "initialisation par valeur du type référencé %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "instanciation récursive de l'initialisation du membre par défaut pour %qD"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "l'initialisation du membre par défaut pour %qD est requise avant la fin de sa classe englobante"
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initialisation pour le membre tableau flexible %q#D"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr "initialiser %qD depuis %qE n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD devrait être initialisé dans la liste d'initialisation du membre"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD est initialisé avec lui-même"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "initialisation invalide pour le membre tableau %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "membre constant non initialisé dans %q#T"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D devrait être initialisé"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "membre par référence non initialisé dans %q#T"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sera initialisé après"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT sera initialisée après"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  la base %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  quand elle est initialisée ici"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "initialisations multiples données pour %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "initialisations multiples données pour la base %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initialisations pour des membres multiples de %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la classe de base %q#T devrait être explicitement initialisée dans le constructeur par copie"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la classe %qT n'a aucun champ nommé %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D est un membre de donnée statique; il peut seulement être initialisé lors de sa définition"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D n'est pas un membre de donnée non statique de %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "initialisation sans nom pour %qT, lequel n'a pas de classe de base"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "initialisation sans nom pour %qT, lequel utilise de multiples héritages"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD est à la fois une base directe et une base virtuelle indirecte"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "le type %qT n'est pas une base directe ou virtuelle de %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "le type %qT n'est pas une base directe de %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT n'est pas un type de classe"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "le type incomplet %qT n'a pas de membre %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "pointeur invalide vers le champ de bits %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "utilisation invalide de la fonction membre non statique %qD"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "utilisation invalide du membre de donnée non statique %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "membre de référence non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "membre constant non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %<%T [%wu]%> et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un tableau d'objets de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "débordement d'entier dans la taille du tableau"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "la taille du tableau dans l'expression « new » doit être une constante"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "le type modifié par une variable n'est pas permis dans l'expression « new »"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée directement, pas par un %<typedef%>"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée sans parenthèses autour du id de type"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "type %<void%> invalide pour %<new%>"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "%<new%> de %<initializer_list%> n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "constante non initialisée dans %<new%> de %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "pas de %qD convenable dans la classe %qT"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la requête pour le membre %qD est ambiguë"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> de type %qT avec l'alignement étendu %d"
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "utilisation de %qD qui n'a pas de paramètre d'alignement"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "utilisez %<-faligned-new%> pour activer le support du « new » sur-aligné du C++17"
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initialisation entre parenthèses dans le « new » du tableau"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "la taille du tableau dans « new » doit avoir un type entier"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "« new » ne peut pas être appliqué à un type référencé"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "« new » ne peut être appliqué à un type de fonction"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "problème possible détecté dans l'invocation de l'opérateur %<delete []%>"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur %<delete[]%> spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "fin prématurée de l'initialisation"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taille du tableau inconnue dans delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "problème possible détecté dans l'invocation de %<operator delete%>"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni %<operator delete%> spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "la destruction d'un objet de la classe abstraite %qT qui a un destructeur non virtuel provoquera un comportement indéfini"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "la destruction d'un objet de la classe polymorphique %qT qui a un destructeur non virtuel pourrait produire un comportement indéfini"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "le type passé au delete vectoriel n'est ni un pointeur ni un type tableau"
@@ -50090,12 +50139,12 @@ msgstr "le nom décoré de %qD change entre %<-fabi-version=%d%> et %<-fabi-vers
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "le nom décoré de la variable de protection de l'initialisation pour %qD change entre %<-fabi-version=%d%> et %<-fabi-version=%d%>"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "le membre constant non statique %q#D ne peut utiliser l'opérateur d'affectation par défaut"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "le membre par référence non statique %q#D ne peut utiliser l'opérateur d'affectation par défaut"
@@ -50120,157 +50169,162 @@ msgstr "formation du type de %qs"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%qD par défaut est uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "l'opérateur de comparaison à trois voies peut uniquement être remis au défaut dans la définition d'une classe"
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "l'opérateur de comparaison par égalité peut uniquement être remis au défaut dans la définition d'une classe"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr "%qD par défaut doit retourner %<bool%>"
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, gcc-internal-format
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD par défaut doit être %<const%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "%qD par défaut ne peut pas avoir de qualificatif de référence %<&&%>"
+
+#: cp/method.c:1155
+#, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD par défaut n'est pas un ami de %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr "le membre par défaut %qD doit avoir le type de paramètre %<const %T&%>"
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr "%qD par défaut doit avoir les paramètres de type %<const %T&%> ou %qT"
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr "%qD par défaut doit avoir les paramètres de type %<const %T&%> ou %qT mais pas les deux"
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "impossible de comparer par défaut l'union %qT"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "impossible de comparer par défaut le membre de référence %qD"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "impossible de comparer par défaut un membre anonyme d'une union"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr "la comparaison à trois voies de %qD a le type %qT qui n'est pas un type dans la catégorie des comparaisons"
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr "la méthode synthétisée %qD est requise ici pour la première fois"
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "membre d'union %q+D avec un %qD non trivial"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "le destructeur par défaut appelle %qD qui n'est pas %<constexpr%>"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "le constructeur par défaut appelle %qD qui n'est pas %<constexpr%>"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "l'initialisation pour %q#D est invalide"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "le constructeur par défaut imposé par défaut n'initialise pas %q#D"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "copie du membre de donnée non statique %q#D du type de référence d'une r-valeur"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "le constructeur par défaut imposé par défaut n'initialise aucun membre de donnée non statique"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "l'affectation par déplacement imposée par défaut pour %qT appelle l'opérateur d'affectation par déplacement non trivial de la base virtuelle %qT"
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "un type de fermeture lambda a un constructeur par défaut supprimé"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "un type de fermeture lambda a un opérateur d'affectation par copie supprimé"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D est implicitement déclaré comme supprimé car %qT déclare un constructeur par déplacement ou un opérateur d'affectation par déplacement"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D hérite depuis plusieurs sous-objets de base"
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D est implicitement supprimé car la définition par défaut serait mal formée:"
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F est implicitement supprimé car sa spécification d'exception ne correspond pas à la spécification d'exception implicite %qX"
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "la déclaration par défaut %q+D ne correspond pas à la signature attendue"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "signature attendue: %qD"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "la fonction %q+D explicitement par défaut ne peut pas être déclarée %qs car la déclaration implicite n'est pas %qs :"
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "un patron ne peut pas être imposé par défaut"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD ne peut pas être imposé par défaut"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "fonction %q+D imposée par défaut avec un argument par défaut"
@@ -50310,211 +50364,211 @@ msgstr "le paramètre lambda %qD a été déclaré précédemment comme une capt
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la déclaration de %q#D masque un paramètre"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "la déclaration de %qD masque un membre de %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "déclaration externe locale de %q#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "ne correspond pas à la déclaration précédente %q#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "déclaration amie %qD dans la classe locale sans déclaration locale antérieure"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "déclaration « using » pour un non membre au niveau de la portée de la classe"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "la déclaration « using » ne peut pas nommer l'énumérateur %<%E::%D%>"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "déclaration « using » pour un membre en dehors de la portée de la classe"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> nomme le destructeur"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nomme le constructeur dans %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "impossible d'hériter des constructeurs depuis la base indirecte %qT"
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "%qD n'a pas été déclaré dans %qE"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "la déclaration « using » ne peut pas nommer l'espace de nom %qD"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la déclaration de %qD n'est pas dans l'espace de noms entourant %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "qualificatifs explicites dans la déclaration de %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD n'a pas été déclaré dans %qD"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "uniquement ici comme un %<friend%>"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD aurait dû être déclaré à l'intérieur de %qD"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "l'attribut %qD requiert un seul argument NTBS"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "l'attribut %qD n'a pas de signification puisque les membres de l'espace de noms anonyme obtiennent des symboles locaux"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms anonyme"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms pas en ligne"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "la directive d'attribut %qD est ignorée"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "limite maximale de %d espaces de noms recherchés pour %qE"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "alternative suggérée:"
 msgstr[1] "alternatives suggérées:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> est défini dans l'en-tête %qs ; avez-vous oublié %<#include %s%> ?"
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> est uniquement disponible à partir de %s"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "la macro %qs n'a pas encore été définie"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "elle a été définie ici plus tard"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "la déclaration de %<std::initializer_list%> ne correspond pas à %<#include <initializer_list>%> et n%'est pas un patron"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "la directive « using » %<strong%> n'est plus supportée"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "vous pouvez utiliser un espace de noms en ligne à la place"
 
 # %qs est le nom d'une procédure d'où le féminin
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> est ambigu"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "l'alias de l'espace de noms %qD n'est pas permis ici, on suppose %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "impossible d'imbriquer plus de %d espaces de noms"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "un espace de nom en ligne doit être spécifié à la définition initiale"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD défini ici"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entre dans %<pop_everything ()%>"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX quitte %<pop_everything ()%>"
@@ -50539,7 +50593,7 @@ msgstr "l'identificateur %qE est un mot clé en C++20"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> n'est pas défini à vrai"
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi par une déclaration ou une définition de fonction"
@@ -50564,7 +50618,7 @@ msgstr "%<::%E%> n'a pas été déclaré"
 msgid "request for member %qE in non-class type %qT"
 msgstr "requête du membre %qE dans le type %qT qui n'est pas une classe"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> n'a pas été déclaré"
@@ -50644,7 +50698,7 @@ msgstr "template-id invalide"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "le C++ ISO interdit l'utilisation d'un littéral en virgule flottante dans une expression constante"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "un transtypage vers un type autre qu'un entier ou une énumération ne peut pas apparaître dans une expression constante"
@@ -50765,7 +50819,7 @@ msgstr "le %<constinit%> du C++20 est uniquement disponible avec %<-std=c++2a%>
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<concept%> uniquement disponible avec %<-std=c++2a%> ou %<-fconcepts%>"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<requires%> uniquement disponible avec %<-std=c++2a%> ou %<-fconcepts%>"
@@ -50885,7 +50939,7 @@ msgstr "utilisez %<-fext-numeric-literals%> pour activer plus de suffixes intern
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "impossible de trouver l'opérateur littéral de chaîne %qD avec les arguments %qT, %qT"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "déclaration attendue"
@@ -50986,12 +51040,12 @@ msgstr "déclaration de %<~%T%> comme membre de %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "nom du typedef %qD utilisé comme déclaration de destructeur"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualified-id attendu"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD n'est pas un patron"
@@ -51026,7 +51080,7 @@ msgstr "template-id de la variable %qD dans le spécificateur de nom imbriqué"
 msgid "expected nested-name-specifier"
 msgstr "spécificateur de nom imbriqué attendu"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "les types ne peuvent pas être définis dans les transtypages"
@@ -51041,7 +51095,7 @@ msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
@@ -51056,7 +51110,7 @@ msgstr "le C++ ISO interdit les littéraux composés"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "deux %<[%> consécutifs n'introduiront qu'un attribut"
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "utilisation invalide de %qD"
@@ -51081,913 +51135,918 @@ msgstr "le C++ ISO ne permet pas %<alignof%> avec un non type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "les types ne peuvent pas être définis dans des expressions %<noexcept%>"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "les types ne peuvent pas être définis dans une expression %qs"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "%<__builtin_has_attribute%> avec un argument dépendant n'est pas encore supporté"
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "les types ne peuvent pas être définis dans une expression « new »"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "les limites de tableau sont interdites après un type-id entre parenthèses"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "essayez d'enlever les parenthèses autour du type-id"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "l'initialisation de l'expression « new » pour le type %<auto%> exige exactement un élément"
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "liste-expression ou type-id attendu"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "les types ne peuvent pas être définis dans un new-type-id"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "l'expression dans la déclaration « new » doit être un type entier ou un type énuméré"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "utilisation d'un vieux style de transtypage vers %q#T"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "l'opérateur %<>>%> est traité comme deux caractères > en C++11"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "parenthèses suggérées autour de l'expression %<>>%>"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "le C++ ISO ne permet pas d'omettre l'opérande du milieu de %<?:%>"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "une expression avec une virgule au plus haut niveau dans l'indice d'un tableau est déprécié"
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "des types ne peuvent pas être définis dans %<__builtin_offsetof%>"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les expressions lambda dans un contexte non évalué sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les expressions lambda dans un argument de patron sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "une expression lambda non locale ne peut pas avoir de capture par défaut"
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "fin de liste de capture attendue"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %<this%> est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "%qD déjà capturé dans l'expression lambda"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "la capture de %<*this%> est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "ne peut capturer %<this%> par référence"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les captures d'initialisation compactes ne sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr "%<&%> devrait apparaître avant %<...%>"
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "les initialisations par capture des fonctions lambda sont uniquement disponibles avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "initialisation vide pour la capture par initialisation d'une fonction lambda"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "capture de %qE qui n'est pas une variable"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D déclaré ici"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture de la variable %qD avec une durée de stockage non automatique"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "trop de %<...%> dans la capture lambda"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %qD est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la capture par référence explicite de %qD est redondante avec la capture par référence par défaut"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "les patrons lambda sont uniquement disponibles avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les patrons lambda sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argument par défaut spécifié pour un paramètre lambda"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "%<mutable%> dupliqué"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les lambda %<constexpr%> sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "les attributs au début d'une instruction sont ignorés"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "instruction étiquetée attendue"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "le « case » %qE n'est pas à l'intérieur de l'instruction « switch »"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> doit être utilisé avant %qE car %qT est une portée dépendante"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nomme le constructeur, pas le type"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "instruction composée dans une fonction %<constexpr%>"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<if constexpr%> uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'instruction init dans des instructions de sélection est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "instruction de sélection attendue"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr "la condition déclare un tableau"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "la condition déclare une fonction"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "des types ne peuvent pas être définis dans des conditions"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initialisation attendue"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "l'expression %<for%> parcourant une plage de type %qT a un type incompatible"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "types différents pour « begin » et « end » de l'instruction %<for%> parcourant une plage: %qT et %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "instruction d'itération attendue"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les boucles %<for%> parcourant une plage avec un initialiseur sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les boucles %<for%> parcourant une plage sont uniquement disponibles avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> dans une fonction %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "le C++ ISO interdit les gotos calculés"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "instruction de saut attendue"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> superflu"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> pas au début du bloc"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "non variable %qD dans la déclaration avec plus d'une déclaration contenant un type à remplacer"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "déduction incohérente pour %qT: %qT et puis %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "mélanger des déclarations et des définitions de fonctions est interdit"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "des types ne peuvent pas être définis dans la déclaration d'une instruction « for » parcourant une plage"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initialisation dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "déclarations multiples dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les liaisons structurées sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "déclaration de liaison structurée vide"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "initialisation invalide pour la déclaration de liaison structurée"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> utilisé en dehors d'une classe"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "le mot-clé %<bool%> n'est pas permis dans une définition de concept en C++20"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr "la syntaxe de définition d'un concept en C++20 est %<concept <name> = <expr>%>"
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> a changé de signification en C++11; retirez-le"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%<decl-specifier%> invalide dans une condition"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD est invalide dans une lambda"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "spécificateur de type invalide dans une lambda"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la définition de classe ne peut pas être déclarée comme amie"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "les patrons ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "les types ne peuvent pas être définis dans une spécification explicite"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<explicit(bool)%> est uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "spécification de classe de liaison invalide"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "un %<static_assert%> sans message est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "les types ne peuvent pas être définis dans les expressions %<decltype%>"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "les types ne peuvent pas être définis dans un conversion-type-id"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "utilisation invalide de %<auto%> dans un opérateur de conversion"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "un %<auto%> dans un opérateur de conversion d'un patron membre ne peut jamais être déduit"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "seuls les constructeurs prennent des initialisions membres"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "impossible de développer l'initialisation du membre %qD"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "ancien style anachronique d'initialisation de classe de base"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (une initialisation de membre qualifiée est implicitement un type)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "mot-clé inattendu; enlevez l'espace entre les guillemets et l'identificateur du suffixe"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "identificateur de suffixe attendu"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "une chaîne vide était attendue après le mot-clé %<operator%>"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "préfixe d'encodage invalide dans l'opérateur littéral"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "opérateur attendu"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "le mot-clé %<export%> n'est pas implémenté et sera ignoré"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "paramètre de type contraint invalide"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "paramètre de type qualifié avec CV"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "utilisation invalide de %<auto%> dans l'argument par défaut du patron"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "les paquets de paramètres des patrons ne peuvent pas avoir d'arguments par défaut"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "template-id attendu"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> ne peut pas être au début d'une liste d'arguments d'un patron"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> est une écriture alternative pour %<[%>. Insérer un espace entre %<<%> et %<::%>"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si vous utilisez %<-fpermissive%> ou %<-std=c++11%> ou %<-std=gnu++11%> G++ acceptera votre code)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "liste d'arguments de patron invalide"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr "un nom de fonction comme opérande dans le membre de gauche de %<<%> est toujours mal formé en C++2a; incluez le nom de la fonction dans %<()%>"
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<(%> attendu après la liste d'arguments de patron"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "erreur d'analyse dans la liste des arguments du patron"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "nom de patron attendu"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD n'est pas un patron mais il est utilisé comme patron"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilisez %<%T::template %D%> pour indiquer que c'est un patron"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "paquet de paramètres attendu avant %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "argument de patron attendu"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argument de patron invalide car ce n'est pas un type"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<inline%>"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<constexpr%>"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<consteval%>"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "spécialisation de patron avec édition de liens C"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "spécificateur du type attendu"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "l'utilisation de %<auto%> dans la déclaration d'un paramètre lambda est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec %<-fconcepts-ts%>"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "template-id attendu pour le type"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE ne contraint pas un type"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr "concept défini ici"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<auto%> ou %<decltype(auto)%> attendu après %qE"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "type à remplacer (« placeholder ») inattendu dans le type de retour contraint"
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "un spécificateur de type élaboré pour un enum fortement typé ne peut pas utiliser le mot-clé %qD"
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%<template%> doit suivre un nom de spécificateur imbriqué"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la déclaration %qD ne déclare rien du tout"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributs ignorés sur un type non instancié"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attributs ignorés sur une instanciation de patron"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attributs ignorés sur un spécificateur de type élaboré qui n'est pas une déclaration anticipée"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD est un patron d'énumération"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD ne nomme pas une énumération dans %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "un enum fortement typé sans nom n'est pas permis"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> ou %<{%> attendu"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "impossible d'ajouter une liste d'énumération à l'instanciation d'un patron"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "le spécificateur de nom imbriqué %qT pour la déclaration d'un enum ne nomme pas une classe ou un espace de noms"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans l'espace de noms %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "qualification supplémentaire pas permise"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "le C++ ISO interdit un enum vide et sans nom"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "spécificateur enum opaque sans nom"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "un spécificateur enum opaque doit utiliser un simple identificateur"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD n'est pas un nom d'espace de nom; vouliez-vous utiliser %qs ?"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD n'est pas un espace de noms"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "espace de noms attendu"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les définitions d'espace de noms imbriqués en ligne sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr "les attributs standards sur les espaces de noms doivent précéder le nom de l'espace de noms"
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les définitions d'espace de noms imbriqués sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nom d'espace de nom imbriqué attendu"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "nom d'espace de nom attendu"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "une définition d'espace de noms imbriqué ne peut pas avoir d'attribut"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "une définition d'un espace de noms imbriqué ne peut pas être « inline »"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "entrée dans l'espace de noms %qD"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la définition %<namespace%> n'est pas permise ici"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'expansion de paquets dans une déclaration « using » est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un template-id ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "une liste séparée par des virgules dans une déclaration « using » est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "les déclarations d'accès sont dépréciées en faveur des déclarations « using »; suggestion: ajoutez le mot-clé %<using%>"
 
 # alias template est un patron appliqué à un alias == patron d'alias
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "les types ne peuvent pas être définis dans des déclarations de patrons d'alias"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<asm%> dans une fonction %<constexpr%> uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "qualificatif %<asm%> %qT dupliqué"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "le qualificatif %<asm%> %qT est ignoré en dehors du corps d'une fonction"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT n'est pas un qualificatif %<asm%>"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "qualificatif %<asm%> en dehors du corps de la fonction"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "une définition de fonction n'est pas permise ici"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "une spécification %<asm%> n'est pas permise dans une définition de fonction"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "des attributs ne sont pas permis dans une définition de fonction"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "constructeur, destructeur ou conversion de type attendu"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initialisation fournie pour une fonction"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "les attributs après l'initialisation entre parenthèses sont ignorés"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "la non fonction %qD est déclarée comme un patron implicite"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "la limite du tableau n'est pas une constante entière"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "impossible de définir le membre du typedef dépendant %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> n'est pas un type"
@@ -51996,431 +52055,431 @@ msgstr "%<%T::%E%> n'est pas un type"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "déclarateur invalide"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "utilisation invalide du constructeur comme patron"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "utilisez %<%T::%D%> au lieu de %<%T::%D%> pour nommer le constructeur dans un nom qualifié"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id dans une déclaration"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "déclarateur attendu"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD est un espace de noms"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "impossible de former un pointeur vers un membre de la non classe %q#T"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "opérateur pointeur attendu"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "qualificatif CV dupliqué"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "qualificatifs de référence multiples"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE requiert %<-fgnu-tm%>"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "spécificateurs virtuels (virt-specifier) multiples"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "arguments de patron manquants après %qT"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "utilisation invalide de %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "les types ne peuvent pas être définis dans les arguments du patron"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "utilisation invalide de %<auto%> dans un argument de patron"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "spécificateur de type attendu"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> ou %<...%> attendu"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "des types ne peuvent pas être définis dans des types de paramètres"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "des arguments par défaut sont uniquement permis pour des paramètres de fonction"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "le corps d'un function-try-block d'un constructeur %<constexpr%> est uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "le corps du function-try-block de la fonction %<constexpr%> est uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les initialisations désignées du C++ sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation de GNU"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation du C99"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "soit toutes les instructions d'initialisation devraient être désignées ou aucune ne devrait l'être"
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> pas permis dans une liste d'initialisation par désignation"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "désignateur %<.%s%> utilisé plusieurs fois dans la même liste d'initialiseurs"
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "nom de classe attendu"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> attendu après la définition de la classe"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> attendu après la définition de la structure"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> attendu après la définition de l'union"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> ou %<:%> attendu"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ne peut spécifier %<override%> pour une classe"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la qualification globale du nom de la classe est invalide"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "le nom qualifié ne nomme pas une classe"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "le mot-clé %<template%> n'est pas permis dans class-head-name (NdT: nom de classe)"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nom de classe invalide dans la déclaration de %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "une spécialisation explicite doit être précédée par %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "le patron de fonction %qD est redéclaré comme un patron de classe"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "impossible de résoudre le type de typename"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "définition précédente de %q#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "mot-clé de type classe (class ou struct) attendu"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "le C++ ISO interdit le mot-clé typename dans un paramètre de patron qui est un patron; utilisez %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> ou %<typename%> attendu"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03, le mot-clé class (ou struct) doit être utilisé lors de la déclaration d'un ami"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "une classe de stockage sur un agrégat anonyme dans une classe n'est pas permis"
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les initialiseurs de membre par défaut pour les champs de bits sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "initialiseur d'un membre par défaut pour un champ de bits sans nom"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "le C++ ISO autorise les attributs de champs de bits uniquement avant l'élément %<:%>"
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "champ de bits %qD a le type non entier %qT"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "spécificateur pur sur une définition de fonction"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%<;%> supplémentaire après la définition dans la classe"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<,%> égarée à la fin de la déclaration du membre"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> attendu à la fin de la déclaration du membre"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "spécificateur pur invalide (seul %<= 0%> est autorisé)"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "une initialisation entre accolades n'est par permise ici"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> spécifié plus d'une fois dans le spécificateur de base"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "plus d'un spécificateur d'accès dans le spécificateur de base"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "le mot-clé %<typename%> n'est pas permis en dehors des patrons"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (la classe de base est implicitement un type)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "les types ne peuvent pas être définis dans une spécification d'exception"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "le C++17 ISO n'autorise pas la spécification dynamique des exceptions"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "les spécifications dynamiques d'exceptions sont dépréciées en C++11"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "utilisation invalide de %<auto%> dans une spécification d'exception"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<try%> dans une fonction %<constexpr%> uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "des types ne peuvent pas être définis dans une déclaration d'exception"
 
 # Je ne suis pas sûr du tout de la signification de « scoped attribute token »…
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "l'attribut de préfixe « using » est utilisé en même temps qu'un élément d'attribut agissant sur une portée"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "un identificateur est attendu pour le nom d'attribut"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr "les parenthèses doivent être omises si la liste d'arguments d'attributs %qE est vide"
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<noreturn%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<nodiscard%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut attendu avant %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'attribut de préfixe « using » est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "l'expression doit être comprise entre parenthèses"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "%<requires%> additionnel manquant pour démarrer une expression « requires »"
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "le type de résultat n'est pas un contrainte de type simple"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "l'exigence sur le type de retour n'est pas une contrainte de type"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "la syntaxe %<template<>%> est requise pour spécialiser %<%T::%E%>"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "déclaration invalide de %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de listes de paramètres pour le patron"
@@ -52429,543 +52488,543 @@ msgstr "trop peu de listes de paramètres pour le patron"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de listes de paramètres pour le patron"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "les valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "le C++ ISO n'a pas adopté les patrons d'opérateurs de chaînes littérales prenant un paquet d'arguments de caractères"
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet de paramètres de type non patron %<<char...>%> ou un unique paramètre non-type de type class"
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet de paramètres de type non patron tel que %<<char...>%>"
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr "les introductions de patrons ne font pas partie des concepts C++20 [-fconcepts-ts]"
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "pas de concept correspondant pour l'introduction du patron"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron membre dans la classe locale"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite invalide"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration de patron de %<typedef%>"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "une déclaration de patron de classe ne doit rien déclarer d'autre"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "une spécialisation explicite de patron ne peut pas avoir une classe de stockage"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> devrait être %<> >%> à l'intérieur d'une liste d'arguments de patron imbriqués"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "le %<>>%> est faux, utilisez %<>%> pour terminer la liste d'arguments du patron"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "l'argument %<sizeof...%> doit être entouré de parenthèses"
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "utilisation invalide de %qD dans la spécification de la classe de liaison"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "le C++ ISO 1998 ne permet pas %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "%<__thread%> et %<thread_local%> sont tous les deux spécifiés"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qD dupliqué"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs dupliqué"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> attendu"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> attendu"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> attendu"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> attendu"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> attendu"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> attendu"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> attendu"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> attendu"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> attendu"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> attendu"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> attendu"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> attendu"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> attendu"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> attendu"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> attendu"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> attendu"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> attendu"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> attendu"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> attendu"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> attendu"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> attendu"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> attendu"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> attendu"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> attendu"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> attendu"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> attendu"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> attendu"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> ou %<::%> attendu"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> ou %<template%> attendu"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "clé d'énumération redondante dans %<enum%s%> en référence à %q#T"
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette %qs utilisée en nommant %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T a été précédemment déclaré ici"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "clé de classe %qs redondante en référence à %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT est déclaré avec clé de classe %qs non concordante"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "retirez la clé de classe ou remplacez là par %qs"
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "remplacez la clé de classe avec %qs"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT est défini en tant que %qs ici"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT déclaré en tant que %qs pour la première fois ici"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD redéclaré avec un accès différent"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "en C++98, %<template%> (afin de lever une ambigüité) est seulement permis à l'intérieur des patrons"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construction Objective-C++ %<@%D%> mal placée"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "récepteur de message objective-c++ attendu"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "un ou des argument(s) de message objective-c++ est/sont attendu(s)"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> doit spécifier un type comme un argument"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nom de sélecteur Objective-C++ invalide"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "une déclaration de méthode objective-c++ est attendue"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "les attributs de méthodes doivent être spécifiés à la fin"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs égaré entre des méthodes Objective-C++"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "type invalide pour la variable d'instance"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identificateur attendu après %<@protocol%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "des attributs ne peuvent pas être spécifiés avant le mot-clé %<@%D%> en Objective-C++"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "les attributs de préfixes sont ignorés avant %<@%D%>"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "type invalide pour une propriété"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "liste d'expressions entières attendue"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "l'expression %<wait%> doit être un nombre entier"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "identificateur de réduction invalide"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "des types ne peuvent pas être définis dans des types d'itérateurs"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle %<for%> de OpenMP"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "clause %<ordered%> avec un paramètre sur une boucle %<for%> basée sur une portée"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "pas assez de boucles « for » à combiner"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> suivi de %<#pragma omp declare %s%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "clause d'initialisation invalide"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "expression id (arguments) attendue"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<omp_priv%> ou %<&omp_priv%>"
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "des types ne peuvent pas être définis dans une liste de types de réductions"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique %qT prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "type tableau ou fonction %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "type référence %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "un qualificatif %<const%>, %<volatile%> ou %<__restrict%> est appliqué au type %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> nomme un ensemble de surcharges"
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD ne fait pas référence à une fonction à l'intérieur de l'espace de noms"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas à l'intérieur d'un %<__transaction_atomic%> extérieur"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  ou une fonction %<transaction_may_cancel_outer%>"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rebut à la fin de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp require%> peut uniquement être utilisé dans la portée du fichier ou de l'espace de noms"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "les optimisations inter-modules ne sont pas implémentées pour le C++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "les types à remplacer ne sont pas permis dans ce contexte"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "les patrons implicites ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "édition de liens %<extern \"C\"%> démarrée ici"
@@ -53236,7 +53295,7 @@ msgstr "le motif d'expansion %qE ne contient pas de paquet de paramètres"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "les paquets de paramètres ne sont pas étendus avec %<...%>"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -53261,84 +53320,84 @@ msgstr "la déclaration de %q+#D masque un paramètre de patron"
 msgid "template parameter %qD declared here"
 msgstr "le paramètre de patron %qD est déclaré ici"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "spécialisation du concept de variable %q#D"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "les paramètres du patron ne peuvent pas être déduits dans la spécialisation partielle:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron et n'a pas plus de contrainte que le patron primaire; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "le patron primaire ici"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "la spécialisation partielle n'est pas plus spécialisée que le patron primaire car elle remplace des paramètres multiples par une expansion d'un paquet"
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "trop d'arguments pour la spécialisation partielle %qT"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la spécialisation partielle de %qD n'est pas plus spécialisée que"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "le patron primaire %qD"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "l'argument %qE du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "l'argument %qT du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "l'argument %qE du patron implique des paramètres du patron"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "le type %qT de l'argument %qE du patron dépend d'un paramètre du patron"
 msgstr[1] "le type %qT de l'argument %qE du patron dépend de paramètres du patron"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "la déclaration de %qD rend ambigüe l'instanciation précédente du patron pour %qD"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spécialisation partielle de %qD après l'instanciation de %qD"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "pas d'argument par défaut pour %qD"
@@ -53346,47 +53405,47 @@ msgstr "pas d'argument par défaut pour %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "le paquet de paramètres %q+D doit être à la fin de la liste des paramètres du patron"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans la redéclaration d'un ami d'un patron d'une fonction"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans les déclarations d'un ami d'un patron"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des patrons de fonctions sans %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des spécialisations partielles"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argument par défaut pour le paramètre de patron pour la classe englobant %qD"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "patron %qD déclaré"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "patron de classe sans nom"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (virt-specifier)"
@@ -53396,493 +53455,493 @@ msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (vir
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "déclaration de patron %qD invalide"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "définition de patron d'un non patron %q#D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "on attendait %d niveaux de paramètres du patron pour %q#D mais on en a obtenu %d"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "a obtenu %d paramètres de patron pour %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "a obtenu %d paramètres de patron pour %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mais %d son requis"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "les arguments du patron %qD ne correspondent pas à ceux du patron original %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilisez %<template<>%> pour une spécialisation explicite"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT n'est pas un type de patron"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "spécificateurs de patron pas spécifiés dans la déclaration de %qD"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redéclaré avec %d paramètre dans le patron"
 msgstr[1] "redéclaré avec %d paramètres dans le patron"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "la déclaration précédente %qD utilisait %d paramètre dans le patron"
 msgstr[1] "la déclaration précédente %qD utilisait %d paramètres dans le patron"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "paramètre %q+#D du patron"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redéclaré ici comme %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "déclaration du paramètre de patron %q+#D avec des contraintes différentes"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "la déclaration originale apparaît ici"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redéfinition de l'argument par défaut pour %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la définition originale apparaît ici"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "redéclaration de %q#D avec des contraintes différentes"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE n'est pas un argument de patron valide pour le type %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "il doit être le nom d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison externe"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "il doit être un pointeur vers un membre de la forme %<&X::Y%>"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "car il est un membre de %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  n%'a pu déduire le paramètre %qD du patron"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  les types %qT et %qT ont des qualificatifs CV incompatibles"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  types %qT et %qT non concordants"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  le paramètre %qD du patron n'est pas un paquet de paramètres mais l'argument %qD en est un"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  l'argument %qE du patron ne correspond pas à la constante %qE qui est un pointeur vers un membre"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE n'est pas équivalent à %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  déduction du paquet de paramètres inconsistante entre %qT et %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  types déduits conflictuels pour le paramètre %qT (%qT et %qT)"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  valeurs déduites conflictuelles pour le paramètre non type %qE (%qE et %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  le type tableau %qT dimensionné par une variable n'est pas un argument de patron valable"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  le type fonction membre %qT n'est pas un argument de patron valable"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  le candidat attend au moins %d argument, %d fourni(s)"
 msgstr[1] "  le candidat attend au moins %d arguments, %d fourni(s)"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  ne peut convertir %qE (type %qT) vers le type %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT est une classe de base ambigüe de %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT n'est pas dérivé de %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  les paramètres du patron d'un argument de patron qui est lui-même un patron sont inconsistants avec les autres arguments déduits pour le patron"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  impossible de déduire un patron pour %qT depuis le type non patron %qT"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  l'argument de patron %qE ne correspond pas à %qE"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qE n'est pas une variable"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable de type %qT en C++98 car %qD n'a pas une classe de liaison externe"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "l'adresse du sous-objet %qT de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable car elle n'a pas une durée de stockage statique"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD n'est pas un argument de patron valable car %qD est une variable, pas une adresse d'une variable"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE n'est pas un argument de patron valable pour %qT car ce n'est pas l'adresse d'une variable"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car les chaînes littérales ne peuvent jamais être utilisées dans ce contexte"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "dans l'argument de patron pour le type %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "l'argument de patron %qE pour le type %qT n'est pas un entier constant"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT à cause de conflits dans les qualificatifs CV"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas une l-valeur"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D n'est pas un argument de patron valable pour le type %qT car une variable de référence n'a pas une adresse constante"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est un pointeur"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "essayez d'utiliser %qE à la place"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est du type %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "les attributs sur l'argument %qT du patron sont ignorés"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "les attributs dans l'argument %qE du patron sont ignorés"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nom de classe injecté %qD utilisé comme argument de patron qui est lui-même un patron"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "utilisation invalide du destructeur %qE comme un type"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour faire référence à un membre type d'un paramètre de patron, utilisez %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  on attendait une constante de type %qT, on a obtenu %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  l'argument de patron ambigu pour le paramètre de patron non type est traité comme un type fonction"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  on attendait un patron de classe, on a obtenu %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  on attendait un type, on a obtenu %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  on attendait un type, on a obtenu %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  on attendait un patron de classe, on a obtenu %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  on attendait un patron de type %qD, on a obtenu %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "désaccord de contrainte à l'argument %d dans la liste des paramètres du patron pour %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  on attendait %qD, on a obtenu %qD"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "impossible de convertir l'argument %qE du patron de %qT vers %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "l'argument %d du patron est invalide"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être au moins %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "fournis pour %qD"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du patron d'alias %qD"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du concept %qD"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "ainsi, toute instanciation avec un paquet de paramètres non vide serait mal formée"
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D n'est pas un patron de fonction"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "type non patron %qT utilisé comme un patron"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "échec de la contrainte du patron pour %qD"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "utilisation du patron de variable invalide %qE"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum qui est %d (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "membre tableau flexible %qD dans l'union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "repli de l'expansion vide sur %O"
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE n'est pas le motif entier de l'expansion du paquet"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qT"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qE"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  lors de l'instanciation de l'argument par défaut pour l'appel à %qD"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT"
@@ -53900,291 +53959,291 @@ msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD a un type fonction"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "type de paramètre %qT invalide"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fonction retournant un tableau"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD est instancié pour un paquet vide"
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "l'initialiseur pour %q#D est développé en une liste vide d'expressions"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_convertvector%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instanciation explicite du concept de variable %q#D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciation explicite du concept de fonction %q#D"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "la spécification d'exception %qD dépend d'elle-même"
@@ -54196,132 +54255,132 @@ msgstr "la spécification d'exception %qD dépend d'elle-même"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les paramètres de patrons non typés du type classe déduit sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "les paramètres de patrons non typés du type classe sont uniquement disponibles avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT n'est pas un type valide pour un paramètre non type du patron car il n'est pas structurel"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "le mot-clé %<template%> n'est pas permis dans declarator-id"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "un concept ne peut être contraint"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "le concept %qE n'est pas dans la portée de l'espace de noms"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert %<#include <initializer_list>%>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "le patron %qT ne peut être déduit et il est utilisé sans arguments de patron"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "la déduction du patron synonyme est uniquement disponible avec %<-std=c++2a%> ou %<-std=gnu++2a%>"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "impossible de déduire les arguments du patron de %qT car il n'a pas de guides de déduction viables"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les contraintes sur le type à remplacer ne sont pas satisfaites"
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "utilisation invalide de %qT dans un argument de patron"
@@ -54526,7 +54585,7 @@ msgstr "utilisation invalide de %<this%> hors de toute fonction"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "étendue de qualification invalide dans le nom du pseudo-destructeur"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne concorde pas avec le nom du destructeur ~%qT"
@@ -54576,7 +54635,7 @@ msgstr "spécification de classe de base invalide"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
@@ -54675,7 +54734,7 @@ msgstr "l'utilisation de %<offsetof%> à l'intérieur du type %qT (qui ne respec
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> est autorisé dans OpenMP uniquement dans les clauses %<declare simd%>"
@@ -54715,7 +54774,7 @@ msgstr "clause linéaire appliquée à la variable non entière non pointeur aya
 msgid "linear step expression must be integral"
 msgstr "l'expression du pas de « linear » doit être un entier"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD n'est pas une variable dans la clause %qs"
@@ -54840,118 +54899,118 @@ msgstr "%qD apparaît plus d'une fois dans les clauses %<nontemporal%>"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD n'est pas une expression l-valeur ni une section de tableau dans une clause %<depend%>"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "patron %qE dans la clause %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "nom de fonction surchargée %qE dans la clause %qs"
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "l'expression de %<grainsize%> doit être un entier"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "l'expression de %<priority%> doit être un entier"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "l'expression %<hint%> doit être un nombre entier"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "l'expression %<hint%> doit être une expression entière constante"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "la variable %qs n'est ni un pointeur ni une référence à un pointeur"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau ni une référence à un pointeur ou un tableau"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "l'argument de %<tile%> doit être de type entier"
 
 # Cette traduction aurait du sens si on pouvait changer l'ordre des %. Je n'arrive pas à savoir si c'est possible.
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%> qualifiant %qE sans membre %<mutable%> ne peut apparaître que dans les clauses %<shared%> ou %<firstprivate%>"
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD n'est pas un fichier, un espace de noms ou une variable déclarée dans un bloc"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directive %<threadprivate%> %qE n'est pas dans la définition de %qT"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la différence entre %qE et %qD n'est pas un type entier"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> utilisé avec la variable d'itération de classe %qE"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> utilise deux expressions différentes pour la mémoire"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "l'assertion statique a échoué: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condition non constante pour l'assertion statique"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "l'argument de %<decltype%> doit être une expression"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> ne sait pas résoudre l'adresse d'une fonction surchargée"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
@@ -55191,797 +55250,797 @@ msgstr "la conversion entre des pointeurs vers des membres de types distincts %q
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "l'expression conditionnelle entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "les types canoniques diffèrent pour les types identiques %qT et %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "nœud de type canonique identique pour les types différents %qT et %qT"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "application invalide de %qs à une fonction membre"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "application invalide de %<sizeof%> sur un champ de bits"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<sizeof%> à une expression d'un type de fonction"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "application invalide de %<__alignof%> sur un champ de bits"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<__alignof%> à une expression d'un type de fonction"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "l'argument de %<alignas%> a le type non entier %qT"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "utilisation invalide de la fonction membre non statique de type %qT"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "prise de l'adresse d'un tableau temporaire"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "le C++ ISO interdit la conversion d'une chaîne constante vers %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversion obsolète de la chaîne constante vers %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "requête du membre %qD dans %qE, lequel est le type pointeur %qT (vous avez peut-être oublié d'utiliser %<->%> ?)"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "requête du membre %qD dans %qE, lequel est de type non classe %qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "utilisation invalide du membre de donnée non statique %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "accès invalide au membre de donnée non statique %qD dans la base virtuelle d'un objet NULL"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "l'objet de type %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "le type devant être détruit est %qT, mais le destructeur réfère à %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "le champ %q#D peut être accessible via %q#D"
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T n'a pas de membre nommé %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %q#D ? (accessible via %q#D)"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %q#D ? (pas accessible depuis ce contexte)"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %qE ?"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> n'est pas un membre de %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT n'est pas une base de %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD n'est pas une fonction patron membre"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT n'est pas un type pointeur vers un objet"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "utilisation invalide de l'indexation de tableau sur un pointeur vers un membre"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "utilisation invalide du %<*%> unaire sur un pointeur vers un membre"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "utilisation invalide de la conversion implicite d'un pointeur vers un membre"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "l'opérande de gauche de %<->*%> doit être un pointeur vers une classe mais il est un pointeur vers un membre du type %qT"
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indice manquant dans la référence du tableau"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "l'accès indicé du tableau est déclaré %<register%>"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "la valeur indicée n'est ni un tableau ni un pointeur"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objet manquant dans l'usage de %qE"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "le C++ ISO interdit l'appel de %<::main%> depuis l'intérieur du programme"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "il faut utiliser %<.*%> ou %<->*%> pour appeler une fonction via un pointeur vers un membre dans %<%E (...)%>, par ex: %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "l'expression ne peut pas être utilisée comme une fonction"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "trop d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "pas assez d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "trop d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "trop peu d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "trop d'arguments pour la fonction %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "trop peu d'arguments pour la fonction %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "trop d'arguments pour la méthode %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "pas assez d'arguments pour la méthode %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "le paramètre %P de %qD a un type incomplet %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "le paramètre %P a un type incomplet %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "le compilateur peut supposer que l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "suppose un transtypage vers le type %qT depuis la fonction surchargée"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL utilisé en arithmétique"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "le C++ ISO interdit la comparaison entre un pointeur et un entier"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "les types des opérandes sont %qT et %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "comparaison à trois voies de vecteurs"
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "comparaison non ordonnée sur un argument n'étant pas en virgule flottante"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversion implicite de %qH vers %qI pour correspondre à d'autres opérandes de l'expression binaire"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "les opérandes des types %qT et %qT sont invalides pour le %qO binaire"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur de type %<void *%> dans une soustraction"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une fonction dans une soustraction"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une méthode dans une soustraction"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "utilisation invalide d'un pointeur vers un type incomplet dans un pointeur arithmétique"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "utilisation invalide de %qE pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  un qualified-id est requis"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "les parenthèses autour de %qE ne peuvent pas être utilisées pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre non statique non qualifié ou entre parenthèses pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre liée pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "prise de l'adresse d'une r-valeur"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "le C++ ISO interdit de prendre l'adresse de la fonction %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ne peut créer un pointeur vers le membre de référence %qD"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "tentative de prendre l'adresse d'un champ de bits"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "prise de l'adresse d'une fonction immédiate %qD"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> sur une expression de type %<bool%>"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "vouliez-vous utiliser le non logique (%<!%>) ?"
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "le C++ ISO interdit d'incrémenter un enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "le C++ ISO interdit de décrémenter un enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ne peut incrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ne peut décrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit d'incrémenter un pointeur du type %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit de décrémenter un pointeur du type %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "l'expression %qs du type qualifié avec %<volatile%> est dépréciée"
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator--%> est interdite"
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est interdite en C++17"
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est dépréciée"
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ne peut prendre l'adresse de %<this%> qui est une expression r-valeur"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adresse de la variable registre explicite %qD requise"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse requise pour %qD qui est déclaré %<register%>"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "une initialisation par liste pour un type non classe ne doit pas être entre parenthèses"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation mémoire"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "la liste d'expressions est traitée comme une expression composée dans le transtypage fonctionnel"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "la liste d'expressions dans « %s » est traitée comme une expression composée"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "pas de contexte pour résoudre le type de %qE"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "le transtypage du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser %<static_cast%> pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser %<reinterpret_cast%> pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "transtypage inutile vers le type %q#T"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "les qualificatifs de type sont ignorés sur le type résultant du transtypage"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "%<static_cast%> invalide depuis le type %qT vers le type %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "le type classe %qT est incomplet"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 msgid "converting from %qH to %qI"
 msgstr "conversion de %qH vers %qI"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "transtypage invalide d'une expression r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr "le transtypage de %qH vers %qI perd en précision"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "transtypage entre types de fonctions incompatibles de %qH vers %qI"
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "transtypage entre des pointeurs incompatibles vers des types membres de %qH vers %qI"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "le transtypage de %qH vers %qI augmente l'alignement requis pour le type ciblé"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "le transtypage entre un pointeur vers une fonction et un pointeur vers un objet est supporté conditionnellement"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "transtypage invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "utilisation invalide de %<const_cast%> avec le type %qT qui n'est pas un pointeur, une référence, ni un type pointeur vers une donnée membre"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "utilisation invalide de %<const_cast%> avec le type %qT qui est un pointeur ou une référence à un type fonction"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "%<const_cast%> invalide d'une r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "%<const_cast%> invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "le C++ ISO interdit le transtypage vers un type tableau %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "transtypage invalide vers le type fonction %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr "une affectation composée avec un opérande de gauche qualifié avec %<volatile%> est déprécié"
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  lors de l'évaluation de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "affectation à un tableau depuis une liste d'initialisation"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "types incompatibles dans l'affectation de %qT vers %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "tableau utilisé comme initialisation"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "affectation de tableau invalide"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dans la conversion d'un pointeur vers une fonction membre"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "conversion d'un pointeur vers un membre via la base virtuelle %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dans la conversion d'un pointeur vers un membre"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversion invalide vers le type %qT à partir du type %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ne peut convertir %qH en %qI dans l'argument par défaut"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ne peut convertir %qH en %qI dans le passage d'argument"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ne peut convertir %qH en %qI dans l'initialisation"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr "ne peut convertir %qH en %qI dans le retour"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ne peut convertir %qH en %qI dans l'affectation"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "le paramètre %qP de %qD pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "le paramètre pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "la cible de la conversion pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "la cible de l'initialisation pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "dans le passage de l'argument %P de %qD"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "retourne une référence vers un temporaire"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "retourner une %<initializer_list%> temporaire n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "référence vers la variable locale %qD retournée"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "retourner la variable %<initializer_list%> locale %qD n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adresse de l'étiquette %qD retournée"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adresse de la variable locale %qD retournée"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "déplacer un objet local dans une instruction de retour empêche l'élision de la copie"
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "supprime l'appel à %<std::move%>"
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "déplacement redondant dans l'instruction de retour"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "retourne une valeur depuis un destructeur"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "ne peut retourner depuis le gestionnaire d'un try..catch sur tout le constructeur"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "retourne une valeur depuis un constructeur"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "instruction « return » sans valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "liste d'initialisation retournée"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "les types incohérents %qT et %qT sont déduits du type retourné par la lambda"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "déduction incohérente pour le type de retour auto: %qT et puis %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "instruction « return » avec une valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> ne doit pas retourner NULL à moins qu'il soit déclaré %<throw()%> (ou %<-fcheck-new%> est actif)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "utilisation d'une r-valeur comme l-valeur"
@@ -56240,107 +56299,107 @@ msgstr "enlever %<{ }%> autour d'un initialiseur"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "impossible d'initialiser l'agrégat du type %qT avec un littéral composé"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initialisation manquante pour le membre %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "le membre %qD est une référence non initialisée"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre %qD avec des champs de référence non initialisés"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "l'ordre du désignateur pour le champ %qD ne correspond pas à l'ordre de la déclaration dans %qT"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ %qD trouvé dans l'union initialisée"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur d'index au lieu d'un nom de champ dans l'initialisation de l'union"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détectée"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de %<->%> a un type non pointeur %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "le résultat de %<operator->()%> est un non pointeur"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de %<->%> n'est pas un pointeur"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE ne peut pas être utilisé comme pointeur de membre puisqu'il est de type %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer le pointeur membre %qE à %qE lequel est d'un type non classe %qT"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "le pointeur vers le type membre %qT est incompatible avec le type d'objet %qT"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une r-valeur"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur avant C++2a"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "transtypage fonctionnel vers le type tableau %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "impossible de déduire les arguments du patron pour %qT depuis %<()%>"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "l'initialisation par valeur du type référence est invalide"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "appel à la fonction %qD qui génère une exception du type incomplet %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "appel à une fonction qui génère une exception du type incomplet %q#T"
@@ -56564,10 +56623,10 @@ msgstr "La référence de tableau à %C a plus de 7 dimensions"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "La référence de tableau à %C ne peut pas avoir plus de %d dimensions"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -56734,7 +56793,7 @@ msgstr "Constructeurs de tableau du style [...] à %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Constructeur de tableau incluant la spécification de type à %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "La spécification de type à %L ne peut pas contenir de paramètre de type différé"
@@ -56851,7 +56910,7 @@ msgstr "La constante littérale BOZ à %L ne peut pas être un argument effectif
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Les arguments de %qs à %L et %L ne peuvent pas être tous les deux des constantes littérales BOZ"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Utilisation invalide de la constant littérale BOZ à %L"
@@ -56891,7 +56950,7 @@ msgstr "Fortran 2003: Caractère pour l'argument %qs de l'intrinsèque %qs à %L
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être INTEGER, REAL ou CHARACTER"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être d'un type intrinsèque"
@@ -56906,7 +56965,7 @@ msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être REAL ou COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être INTEGER ou PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une constante"
@@ -57026,167 +57085,167 @@ msgstr "Longueurs de caractères inégales (%ld/%ld) dans %s à %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "Les arguments %qs et %qs de l'intrinsèque %qs à %L doivent avoir le même type"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "Sous-types différents à %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "Le NULL à %L n'est pas permis comme argument effectif de la fonction intrinsèque %qs"
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être un POINTER"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point co-indexé"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être un pointeur ou une VARIABLE ou FONCTION cible"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être un POINTER ou un TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "La section de tableau avec un indice de vecteur à %L ne sera point la cible d'un pointeur"
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "Le pointeur NULL à %L n'est pas permis comme argument effectif de la fonction intrinsèque %qs"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "L'argument ATOM à %L pour la fonction intrinsèque %s sera un entier du sous-type ATOMIC_INT_KIND ou un logique du sous-type ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "L'argument ATOM à %L de la fonction intrinsèque %s sera un co-tableau ou un co-indexé"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L aura le même type que %qs à %L"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "Argument STAT= pour %s à %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "L'argument ATOM de la fonction intrinsèque %s à %L sera définissable"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "L'argument ATOM à %L pour la fonction intrinsèque %s sera un entier du sous-type ATOMIC_INT_KIND"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "L'argument VALUE de la fonction intrinsèque %s à %L sera définissable"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L n'est pas encore supporté"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L spécifiera un sous-type entier valide"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "L'argument OLD de la fonction intrinsèque %s à %L sera définissable"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "L'argument EVENT à %L pour l'intrinsèque EVENT_QUERY sera du type EVENT_TYPE"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "L'argument COUNT de la fonction intrinsèque EVENT_QUERY à %L sera définissable"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "L'argument COUNT de la fonction intrinsèque EVENT_QUERY à %L couvrira au moins la plage de l'entier par défaut"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Argument négatif N à %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne doit pas être présent si %<x%> est COMPLEX"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit avoir un type soit REAL ou soit INTEGER"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr "La conversion depuis %s vers le sous-type par défaut COMPLEX(%d) à %L pourrait perdre en précision, envisagez d'utiliser l'argument KIND"
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr "L'argument %<A%> avec INTENT(INOUT) à %L de la sous-routine intrinsèque %s n'aura pas d'indice vectoriel"
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "L'argument A à %L pour l'intrinsèque %s ne sera pas co-indexé"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "L'argument stat= à %L doit être une variable entière avec kind=4"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "L'argument errmsg= à %L doit être une variable caractère du sous-type par défaut"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "Co-tableaux désactivés à %L, utilisez %<-fcoarray=%> pour l'activer"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr "Le support pour l'argument A à %L qui est un argument A polymorphique ou a un composant allouable n'est pas encore implémenté"
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "L'argument A à %L de CO_REDUCE ne sera point polymorphique"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr "Le support pour l'argument A à %L avec des composants allouables n'est pas encore implémenté"
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "L'argument OPERATOR à %L doit être une fonction PURE"
@@ -57194,697 +57253,697 @@ msgstr "L'argument OPERATOR à %L doit être une fonction PURE"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "La fonction intrinsèque %s à %L n'est pas permise pour CO_REDUCE"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr "La fonction passée comme OPERATOR à %L aura deux arguments"
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr "L'argument A à %L a le type %s mais la fonction passée comme OPERATOR à %L retourne %s"
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr "La fonction passée comme OPERATOR à %L a des arguments de types %s et %s mais elle aura le type %s"
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr "La fonction passée comme OPERATOR à %L aura des arguments scalaires non pointeurs, non allouables et retournera un scalaire non pointeur non allouable"
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr "La fonction passée comme OPERATEUR à %L aura l'attribut VALUE pour aucun ou pour les deux arguments"
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr "La fonction passée comme OPERATOR à %L aura l'attribut TARGET pour aucun ou pour les deux arguments"
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr "La fonction passée comme OPERATOR à %L aura l'attribut ASYNCHRONOUS pour aucun ou pour les deux arguments"
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr "La fonction passée comme OPERATOR à %L aura l'attribut OPTIONAL pour aucun ou pour les deux arguments"
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr "La longueur de caractère de l'argument A à %L et des arguments de OPERATOR à %L seront les mêmes"
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr "La longueur de caractère de l'argument A à %L et de la fonction résultat de OPERATOR à %L seront les mêmes"
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L sera du type entier, réel ou caractère"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Intrinsèque %qs avec l'argument KIND à %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a une forme invalide dans la dimension %d (%ld/%ld)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit avoir le rang %d ou être un scalaire"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être numérique ou LOGICAL"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "Formes différentes pour les arguments %qs et %qs à %L pour l'intrinsèque %<dot_product%>"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être un réel par défaut"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "%qs doit être du même type et du même sous-type que %qs à %L dans %qs"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "L'argument %qs de l'intrinsèque %qs est manquant à %L pour %qs du type %qs"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "Argument INTEGER du sous-type pas par défaut passé à l'intrinsèque %s à %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "Argument COMPLEX %qs de l'intrinsèque %qs à %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "Les arguments de %qs ont des paramètres de type de genre différents à %L"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "L'argument de %s à %L doit être de longueur un"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être du même sous-type que %qs"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr "le sous-programme intrinsèque %qs à %L a été déprécié. Utilisez le sous-programme intrinsèque INT."
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "SIZE à %L doit être positif"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "La valeur absolue de SHIFT à %L doit être plus petite ou égale à SIZE à %L"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "Le STATUS à %L sera une variable INTENT(OUT)"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "%qs à %L sera une variable INTENT(OUT)"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une entité de donnée"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "L'intrinsèque %qs à %L doit avoir au moins deux arguments"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Argument %qs manquant pour l'intrinsèque %s à %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Argument %qs dupliqué à %L pour l'intrinsèque %s"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Argument %qs inconnu à %L pour l'intrinsèque %s"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "L'argument %<a%d%> de l'intrinsèque %qs à %L doit être %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "Intrinsèque %qs avec un argument CHARACTER à %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "L'argument %<a1%> de l'intrinsèque %qs à %L doit être INTEGER, REAL ou CHARACTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Les types des arguments de l'intrinsèque %qs à %L doivent correspondre (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "Formes différentes sur la dimension 1 des arguments %qs et %qs à %L pour l'intrinsèque matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "Formes différentes sur la dimension 2 de l'argument %qs et la dimension 1 de l'argument %qs à %L pour l'intrinsèque matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être de rang 1 ou 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être en conformité avec le type de l'argument %qs à %L"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être un INTEGER"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "L'argument FROM de MOVE_ALLOC à %L ne sera point co-indexé"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "L'argument TO de MOVE_ALLOC à %L ne sera point co-indexé"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "Les arguments TO dans MOVE_ALLOC à %L doivent être polymorphiques si FROM est polymorphique"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "Les arguments FROM et TO de l'intrinsèque MOVE_ALLOC à %L doivent avoir le même rang %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "Les arguments FROM et TO de l'intrinsèque MOVE_ALLOC à %L doivent avoir le même co-rang %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr "Les arguments FROM et TO à %L violent les restrictions d'aliasing (F2003 12.4.1.7)"
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "L'argument %<S%> de NEAREST à %L ne sera point zéro"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être POINTER, ALLOCATABLE ou un pointeur de procédure"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Intrinsèque NULL avec MOLD allouable à %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit fournir au moins autant d'éléments qu'il y a de valeurs .TRUE. dans %qs (%ld/%d)"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une variable muette"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une variable muette OPTIONAL"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne doit pas être un sous-objet de %qs"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "L'argument de l'intrinsèque RANK à %L doit être un objet de données"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "L'argument %<shape%> de l'intrinsèque %<reshape%> à %L doit être un tableau de taille constante"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L est vide"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "L'argument %<shape%> de l'intrinsèque %<reshape%> à %L a plus de %d éléments"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a un élément négatif (%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "L'élément %d de l'argument effectif de RESHAPE à %L ne peut pas être négatif"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a un mauvais nombre d'éléments (%d/%d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a une dimension hors limite (%d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a une permutation invalide des dimensions (dimension %qd dupliquée)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Sans rembourrage, il n'y a pas assez d'éléments dans la source de l'intrinsèque RESHAPE à %L pour correspondre à la forme"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne peut pas être du type %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être d'un type extensible"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND sans argument %<P%> ni %<R%> à %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Intrinsèque %qs avec un argument RADIX à %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "L'argument %<source%> de l'intrinsèque %<shape%> à %L ne doit pas être un tableau de taille tacite"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point une procédure"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point TYPE(*)"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point un tableau de taille tacite"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr a échoué"
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une entité de données interopérable: %s"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "L'argument C_PTR_1 à %L pour C_ASSOCIATED aura le type TYPE(C_PTR) ou TYPE(C_FUNPTR)"
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "L'argument C_PTR_2 à %L pour C_ASSOCIATED aura le même type que C_PTR_1: %s au lieu de %s"
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "L'argument CPTR à %L pour C_F_POINTER aura le type TYPE(C_PTR)"
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "L'argument FPTR à %L pour C_F_POINTER doit être un pointeur"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "L'argument FPTR à %L pour C_F_POINTER ne sera point polymorphique"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "L'argument FPTR à %L pour C_F_POINTER ne sera point co-indexé"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Argument SHAPE inattendu à %L pour C_F_POINTER avec FPTR scalaire"
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "Argument SHAPE inattendu pour C_F_POINTER avec FPTR tableau à %L"
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "L'argument SHAPE à %L pour C_F_POINTER doit avoir la même taille que le RANK de FPTR"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "FPTR polymorphique à %L pour C_F_POINTER"
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Tableau FPTR non interopérable à %L pour C_F_POINTER: %s"
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "L'argument CPTR à %L pour C_F_PROCPOINTER n'aura point le type TYPE(C_FUNPTR)"
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "L'argument FPTR à %L pour C_F_PROCPOINTER sera un pointeur de procédure"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "L'argument FPTR à %L pour C_F_PROCPOINTER ne sera point co-indexé"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Pointeur de procédure non interopérable à %L pour C_F_PROCPOINTER"
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "L'argument X à %L pour C_FUNLOC ne sera point co-indexé"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Le résultat %qs de la fonction à %L est invalide comme argument X pour C_FUNLOC"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "L'argument X à %L pour C_FUNLOC ne sera point une procédure ou un pointeur de procédure"
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Procédure non interopérable à %L pour C_FUNLOC"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "L'argument X à %L pour C_LOC ne sera point co-indexé"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "L'argument X à %L pour C_LOC ne sera point polymorphique"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "L'argument X à %L pour C_LOC aura soit l'attribut POINTER ou soit l'attribut TARGET"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "L'argument X à %L pour C_LOC ne sera point une chaîne de longueur nulle"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "L'argument à %L pour C_LOC ne sera point polymorphique"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Tableau non interopérable à %L comme argument pour C_LOC: %s"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Tableau d'un type interopérable à %L pour C_LOC qui n'est pas allouable et n'a pas de taille tacite ni de taille explicite"
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Section de tableau à %L pour C_LOC"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "argument REAL pas en double précision pour l'intrinsèque %s à %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être moins que le rang %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L n'est pas un index de dimension valide"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "L'argument %s pour IMAGE_INDEX doit être un tableau de rang un à %L"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Le nombre d'éléments du tableau de l'argument SUB pour IMAGE_INDEX à %L sera %d (co-rang) et non %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "Argument DISTANCE= pour NUM_IMAGES à %L"
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "Argument FAILED= pour NUM_IMAGES à %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "L'argument TEAM à %L pour l'intrinsèque TEAM_NUMBER sera du type TEAM_TYPE"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "L'argument DIM sans argument COARRAY n'est pas permis pour l'intrinsèque THIS_IMAGE à %L"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "L'argument DISTANCE ne peut pas être spécifié avec l'argument COARRAY ou DIM dans l'intrinsèque à %L"
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Argument DIM inattendu avec l'argument non co-tableau à %L"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "Argument DISTANCE= pour THIS_IMAGE à %L"
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr "L'argument %<MOLD%> de l'intrinsèque %<TRANSFER%> à %L est un tableau et n'aura pas une taille de stockage 0 quand l'argument %<SOURCE%> a une taille plus grande que 0"
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "L'argument %<SOURCE%> de l'intrinsèque %<TRANSFER%> à %L ne doit pas être un %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "L'argument %<MOLD%> de l'intrinsèque %<TRANSFER%> à %L ne doit pas être un %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "L'argument %<MOLD%> de l'intrinsèque %<TRANSFER%> à %L ne doit pas être %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "L'intrinsèque TRANSFER à %L a un résultat partiellement indéfini: taille de la source %ld < taille du résultat %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit avoir le même rang que %qs ou être un scalaire"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Les arguments %qs et %qs de l'intrinsèque %qs à %L doivent avoir des formes identiques."
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "La taille de l'argument %qs de l'intrinsèque %qs à %L est trop petite (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Trop d'arguments pour %s à %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "La chaîne fe_runtime_error doit être terminée par un zéro"
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Mauvais nombre d'arguments (%d au lieu de %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "L'argument COUNT de SYSTEM_CLOCK à %L a un sous-type pas par défaut"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Argument réel COUNT_RATE de SYSTEM_CLOCK à %L"
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "L'argument COUNT_RATE de SYSTEM_CLOCK à %L a un sous-type pas par défaut"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "L'argument COUNT_MAX de SYSTEM_CLOCK à %L a un sous-type pas par défaut"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être d'un sous-type pas plus large que le sous-type par défaut (%d)"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "L'argument effectif à %L de l'intrinsèque %qs sera une pointeur associé"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être INTEGER, LOGICAL ou une constante littérale BOZ"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "La fonction intrinsèque NULL à %L ne peut pas être un argument effectif de STORAGE_SIZE car il retourne un pointeur dissocié"
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "Les objets ou composants polymorphiques avec une taille tacite, tel que celui à %C, n'ont pas encore été implémentés"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Niveau d'extension maximum atteint avec le type %qs à %L"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "%qs de %qs est PRIVATE à %L"
@@ -58079,1755 +58138,1755 @@ msgstr "Mauvaise spécification INTENT à %C"
 msgid "deferred type parameter at %C"
 msgstr "paramètre de type différé à %C"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Expression INTEGER scalaire attendue à %L"
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Longueur de caractère dans l'ancien style à %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Erreur de syntaxe dans la spécification de la longueur de caractère à %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "La procédure %qs à %C est déjà définie à %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "La procédure contenue %qs à %C entre en conflit avec la procédure définie à %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Le nom %qs à %C est déjà défini comme une interface générique à %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "La procédure %qs à %C a une interface explicite d'une déclaration précédente"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "La procédure %qs définie dans le corps de l'interface à %L entre en conflit avec la procédure interne définie à %C"
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "La procédure %qs à %L doit avoir l'attribut BIND(C) pour être interopérable avec le C"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "La variable %qs à %L est un argument muet de la procédure BIND(C) %qs mais elle n'est pas interopérable avec le C car le type dérivé %qs n'est pas interopérable avec le C"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "La variable %qs à %L est un argument muet de la procédure BIND(C) %qs mais elle n'est pas interopérable avec le C car elle est polymorphique"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "La variable %qs à %L est un argument muet de la procédure BIND(C) %qs mais elle pourrait ne pas être interopérable avec le C"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "L'argument caractère %qs à %L doit avoir la longueur 1 car la procédure %qs est BIND(C)"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs à %L avec l'attribut ALLOCATABLE dans la procédure %qs avec BIND(C)"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs à %L avec l'attribut POINTER dans la procédure %qs avec BIND(C)"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "La variable %qs à %L ne peut pas avoir les deux attributs OPTIONAL et VALUE car la procédure %qs est BIND(C)"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variable %qs à %L avec l'attribut OPTIONAL dans la procédure %qs qui est BIND(C)"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Tableau de forme tacite %qs à %L comme argument muet à la procédure BIND(C) %qs à %L"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Le symbole %qs à %C est aussi déclaré comme un type à %L"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "La variable %qs dans le bloc commun %qs à %C doit être déclarée avec un sous-type interopérable avec le C puisque le bloc commun %qs est BIND(C)"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "La longueur de CHARACTER doit être une constante à %L"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "L'expression CHARACTER à %L est tronquée (%ld/%ld)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Les éléments CHARACTER dans le constructeur du tableau à %L doivent avoir la même longueur (%ld/%ld)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Initialisation interdite pour PARAMETER %qs à %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Le PARAMETER à %L n'a pas d'initialisation"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "La variable %qs à %C avec une initialisation apparaît déjà dans une instruction DATA"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Impossible d'initialiser un tableau de paramètres à %L avec des éléments de longueur variable"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "Impossible d'initialiser un tableau de forme implicite à %L avec un scalaire"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr "gfc_array_size a échoué"
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Limite inférieure non constante dans la déclaration avec une forme implicite à %L"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Le composant à %C doit avoir l'attribut POINTER"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Le composant %qs avec CLASS à %C doit être allouable ou un pointeur"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Le composant tableau de structures à %C doit avoir une forme explicite ou différée"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Le composant %qs à %C est déjà déclaré à %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Le composant tableau de pointeurs de structures à %C doit avoir une forme différée"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Le composant allouable de structures à %C doit avec une forme différée"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Le composant tableau de structures à %C doit avoir une forme explicite"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Le paramètre de type %qs à %C n'a pas d'entrée correspondante dans la liste des noms de paramètres de types à %L"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "L'initialisation NULL() à %C est ambiguë"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "L'initialisation NULL() à %C ne peut pas avoir MOLD"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "L'initialisation du pointeur à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Erreur dans l'initialisation du pointeur à %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Initialisation d'un pointeur non NULL à %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr "La variable RESULT %qs à %L interdit le nom de FUNCTION %qs à %C d'apparaître dans une instruction de spécification"
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "%qs n'est pas autorisé en dehors de STRUCTURE à %C"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs à %C est une extension DEC, activez-la avec %<-fdec-structure%>"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "L'entité %qs ne peut pas avoir d'attribut à %C"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Caractère %qc invalide dans le nom de la variable à %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Le symbole non PARAMETER %qs à %L ne peut pas avoir une forme implicite"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Tableau de forme implicite à %L"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Tableau de forme explicite avec des limites non constantes à %C"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs à %C est une redéfinition de la déclaration dans l'interface correspondante pour MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "L'entité %qs ne peut pas avoir un initialiseur à %C"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Spécificateur de tableau dupliqué pour le pointé de type Cray à %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "Impossible de définir la spécification du tableau pointé"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisation dans l'ancien style à %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Initialisation dans l'ancien style invalide pour le composant de type dérivé à %C"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Erreur de syntaxe dans l'initialisation de %s dans l'ancien style à %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "L'initialisation à %C n'est pas pour une variable pointeur"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "L'initialisation du pointeur à %C requiert %<=>%> et non %<=%>"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Une expression d'initialisation est attendue à %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "L'initialisation de la variable à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "L'initialisation du composant allouable à %C n'est pas permise"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "L'initialisation d'un composant de structure avec une constante HOLLERITH à %L n'est pas permise"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Le composant avec l'attribut KIND ou LEN à %C n'apparaît pas dans la liste des paramètres de type à %L"
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Le composant à %C qui apparaît dans la liste des paramètres de types à %L n'a ni l'attribut KIND ni l'attribut LEN"
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Le composant à %C, qui est un paramètre de type, doit être un scalaire"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "La constante littérale BOZ à %L ne peut pas apparaître comme une initialisation"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr "Initialisation incompatible entre une entité de type dérivé et une entité avec le type %qs à %C"
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "La déclaration du type %s*%d dans l'ancien style n'est pas supportée à %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Déclaration du type non standard %s*%d à %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Parenthèse droite manquante à %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Expression d'initialisation attendue à %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Expression d'initialisation d'un scalaire attendue à %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Le sous-type %d n'est pas supporté pour le type %s à %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Le paramètre d'un type du sous-type C est pour le type %s mais le type à %L est %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Parenthèse droite ou virgule manquante à %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Le sous-type %d n'est pas supporté pour CHARACTER à %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration CHARACTER à %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "RECORD à %C est une extension, activez-la avec %<-fdec-structure%>"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Nom de structure attendu après RECORD à %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "La liste de spec des paramètres de type à %C ne peut pas contenir les paramètres ASSUMED et DEFERRED en même temps"
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "La liste de spec des paramètres de types à %C ne contient pas assez d'expressions de paramètres"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Le paramètre dérivé %qs à %C n'a pas de valeur par défaut"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "L'expression paramètre à %C doit être de type INTEGER et non de type %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "Le paramètre KIND %qs à %C ne peut pas être ASSUMED ou DEFERRED"
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "La valeur pour le paramètre KIND à %qs à %C ne se réduit pas en une expression constante"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "La liste de spec des paramètres de type à %C contient trop d'expressions de paramètres"
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Le type dérivé paramétrisé à %C est ambigu"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "Type BYTE à %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Le type BYTE utilisé à %C n'est pas disponible sur la machine cible"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Le type tacite à %C n'est pas autorisé pour des composants"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Type tacite à %C"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE avec une spécification de type intrinsèque à %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "Spécification de type mal formée à %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX à %C"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Le nom de type %qs à %C est ambigu"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Instruction CLASS à %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Le nom du type %qs à %C est en conflit avec l'entité précédemment déclarée à %L qui a le même nom"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Instruction IMPLCIT NONE dupliquée à %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE avec une liste de spécifications à %C"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Plage de caractères manquante dans IMPLICIT à %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Les lettres doivent être dans l'ordre alphabétique dans l'instruction IMPLICIT à %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "L'instruction IMPLICIT à %C suit une instruction IMPLICIT NONE (type)"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Instruction IMPLICIT vide à %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "L'instruction IMPORT à %C est uniquement permise dans un corps d'INTERFACE"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: l'instruction IMPORT C1210 à %C n'est pas permise dans le corps d'interface d'une procédure d'un module"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Instruction IMPORT à %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste d'entités nommées attendue à %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Impossible d'utiliser IMPORT %qs depuis l'unité dans la portée de l'hôte à %C – n'existe pas."
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs est déjà IMPORTé depuis l'unité dans la portée de l'hôte à %C"
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction IMPORT à %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Spécification de co-dimension manquante à %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Spécification de dimension manquante à %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Attribut %s dupliqué à %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s à %L est une extension DEC, activez-la avec %<-fdec-static%>"
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE à %C dans une définition TYPE"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Attribut ALLOCATABLE à %C dans une définition STRUCTURE"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attribut KIND à %C dans une définition TYPE"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Attribut KIND à %C dans une définition STRUCTURE"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Le composant avec l'attribut KIND à %C doit être un INTEGER"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Le composant avec l'attribut KIND à %C doit être du sous-type entier par défaut (%d)"
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Attribut LEN à %C dans une définition TYPE"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Attribut LEN à %C dans une définition STRUCTURE"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Le composant avec l'attribut LEN à %C doit être un INTEGER"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Le composant avec l'attribut LEN à %C doit être du sous-type entier par défaut (%d)"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "L'attribut à %L n'est pas permis dans une définition TYPE"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "L'attribut à %L n'est pas permis dans une définition STRUCTURE"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s à %L dans une définition TYPE"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "L'attribut %s à %L n'est pas permis en dehors de la partie de la spécification d'un module"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "L'attribut à %L n'est pas permis en dehors d'une définition TYPE"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attribut ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attribut CONTIGUOUS à %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED à %C est uniquement autorisé dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attribut PROTECTED à %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attribut VALUE à %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attribut VOLATILE à %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Mauvais attribut"
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Identificateurs multiples fournis avec un seul spécificateur NAME= à %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La déclaration implicite de la fonction BIND(C) %qs à %L pourrait ne pas être interopérable avec le C"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable %qs dans le bloc commun %qs à %L ne peut pas être un sous-type interopérable avec le C bien que le bloc commun %qs est BIND(C)"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La déclaration de type %qs à %L n'est pas interopérable avec le C mais elle est BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable %qs à %L peut ne pas être d'un sous-type interopérable avec le C mais elle est BIND(C)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable %qs dans le bloc commun %qs à %L ne peut pas être déclarée avec BIND(C) puisqu'elle n'est pas globale"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable %qs à %L ne peut pas avoir les attributs POINTER et BIND(c) en même temps"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable %qs à %L ne peut pas avoir les attributs ALLOCATABLE et BIND(C) en même temps"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Le type de retour de la fonction BIND(C) %qs à %L ne peut pas être un tableau"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "Le type de retour de la fonction BIND(C) %qs de type caractère à %L doit avoir la longueur 1"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Le symbole %qs à %L est marqué PRIVATE mais il a reçu l'étiquette de liaison %qs"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "L'instruction de spécification d'attribut a besoin de soit un nom d'entité ou soit un nom de bloc commun à %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Il manque le nom d'entité ou le nom de bloc commun pour l'instruction de spécification d'attribut à %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbole manquant"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Instruction BIND(C) à %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Le type dérivé à %C n'a pas été précédemment défini et, par conséquent, il ne peut pas apparaître dans une définition de type dérivé"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration de la structure anonyme à %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration de donnée à %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Préfixe de MODULE à %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "préfixe MODULE à %C trouvé en dehors d'un module, sous-module ou interface"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Procédure IMPURE à %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE et IMPURE ne peuvent pas apparaître ensemble à %C"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe ELEMENTAL dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe PURE dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe RECURSIVE dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "Une liste de paramètre de types est requis à %C"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Argument de retour alternatif à %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Un nom de paramètre est requis à %C"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Le nom %qs à %C est le nom de la procédure"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Liste de paramètres attendue dans la déclaration du type à %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Rebut inattendu dans la liste d'arguments formels à %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Nom %qs en double dans la liste des paramètres à %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Symbole %qs dupliqué dans la liste d'arguments formels à %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Désaccord dans les noms des arguments formels de MODULE PROCEDURE (%s/%s) à %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Désaccord dans le nombre d'arguments formels de MODULE PROCEDURE à %C"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT à %C doit être différente du nom de la fonction"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Rebut inattendu après la déclaration de la fonction à %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "L'attribut BIND(C) à %L ne peut pas être spécifié pour une procédure interne"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "L'attribut BIND(C) à %C requiert une interface avec BIND(C)"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "La procédure BIND(C) avec NAME ne peut pas avoir l'attribut POINTER à %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "La procédure muette à %C ne peut pas avoir d'attribut BIND(C) avec NAME"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "La procédure %qs à %L a déjà le type de base de %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction PROCEDURE à %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> attendu après les attributs de liaison à %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS ou interface explicite requise à %C"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Erreur de syntaxe dans un composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE à %C doit être une interface générique"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "double : dans l'instruction MODULE PROCEDURE à %L"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Instruction PROCEDURE à %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Liste d'arguments formels attendue dans la définition de la fonction à %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "L'attribut BIND(C) à %L peut uniquement être utilisé pour des variables ou des blocs communs"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr "Désaccord dans les noms de BIND(C) (%qs/%qs) à %C"
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Instruction ENTRY à %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un PROGRAM"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un MODULE"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un SUBMODULE"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "L'instruction ENTRY à %C ne peut apparaître dans un BLOCK DATA"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une INTERFACE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc STRUCTURE"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc DERIVED TYPE"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc IF-THEN"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc DO"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc SELECT"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc FORALL"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc WHERE"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un sous programme contenu"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Instruction ENTRY inattendue à %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une procédure contenue"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Parenthèse requise manquante avant BIND(C) à %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "L'instruction ENTRY à %L avec BIND(C) est interdite dans une procédure élémentaire"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "L'argument fictif du retour alternatif ne peut pas apparaître dans une SUBROUTINE avec l'attribut BIND(C) à %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Identificateur C invalide dans le spécificateur NAME= à %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Erreur de syntaxe dans le spécificateur NAME= pour l'étiquette de liaison à %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Le spécificateur NAME= à %C devrait être une expression constante"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "Le spécificateur NAME= à %C devrait être un scalaire du sous-type de caractère par défaut"
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Parenthèse fermante manquante pour l'étiquette de liaison à %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Le nom de liaison n'est pas permis dans BIND(C) à %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Pour la procédure muette %s, aucun nom de liaison est autorisé dans BIND(C) à %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME pas autorisé sur BIND(C) pour ABSTRACT INTERFACE à %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Instruction END inattendue à %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Instruction END au lieu de l'instruction %s à %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Instruction %s attendue à %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "On attendait l'instruction %s à %L"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "On attendait le nom du bloc de %qs dans l'instruction %s à %L"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "On attendait un nom de terminaison à %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "On attendait l'étiquette %qs pour l'instruction %s à %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Spécification de tableau manquante à %L dans l'instruction DIMENSION"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensions spécifiées pour %s à %L après son initialisation"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Spécification de tableau manquante à %L dans l'instruction CODIMENSION"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La spécification de tableau doit être différée à %L"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Attribut DIMENSION dupliqué à %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Caractère inattendu dans la liste de variable à %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> attendu à %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Nom de variable attendu à %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Le pointeur Cray à %C doit être un entier"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Le pointeur Cray à %C a %d octets de précision; les adresses mémoire requièrent %d octets"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "« , » attendu à %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr "Ne peut définir la spécification de tableau dans le pointé de type Cray"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "« ) » attendue à %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> ou fin d'instruction attendue à %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT n'est pas permis à l'intérieur de BLOCK à %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL n'est pas permis à l'intérieur du BLOCK à %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "La déclaration de pointeur Cray à %C requiert l'option %<-fcray-pointer%>"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Instruction CONTIGUOUS à %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La spécification d'accès de l'opérateur %s à %C a déjà été spécifiée"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La spécification d'accès de l'opérateur .%s. à %C a déjà été spécifiée"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Instruction PROTECTED à %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction PROTECTED à %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "L'instruction PRIVATE à %C est uniquement permise dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "L'instruction PUBLIC à %C est uniquement permise dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nom de variable attendu à %C dans l'instruction PARAMETER"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Signe = attendu dans l'instruction PARAMETER à %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Expression attendue à %C dans l'instruction PARAMETER"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisation d'une variable déjà initialisée à %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER sans « () » à %C"
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caractères inattendus dans l'instruction PARAMETER à %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s à %C est une extension DEC, activez-la avec %<-fdec-static%>"
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Liste d'entités attendue dans l'instruction AUTOMATIC à %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction AUTOMATIC à %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Liste d'entités attendue dans l'instruction STATIC à %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction STATIC à %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "L'instruction SAVE générale à %C suit une instruction SAVE précédente"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "L'instruction SAVE à %C suit une instruction SAVE générale"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction SAVE à %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE n'est pas autorisé à l'intérieur de BLOCK à %C"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Instruction VALUE à %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction VALUE à %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Instruction VOLATILE à %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Spécification de VOLATILE pour la variable co-tableau %qs à %C qui est associée à use ou à l'hôte"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction VOLATILE à %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Instruction ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Déclaration de MODULE PROCEDURE à %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE à %C doit être dans une interface de module générique"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "La procédure intrinsèque à %L ne peut pas être un MODULE PROCEDURE"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Symbole ambigu dans la définition TYPE à %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Le symbole %qs à %C n'a pas été défini précédemment"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs dans l'expression EXTENDS à %C n'est pas un type dérivé"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs ne peut pas être étendu à %C car il est BIND(C)"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs ne peut pas être étendu à %C car il est un type SEQUENCE"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Le type dérivé à %C peut uniquement être PRIVATE dans la partie de spécification d'un module"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Le type dérivé à %C peut uniquement être PUBLIC dans la partie de spécification d'un module"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Type ABSTRACT à %C"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Échec lors de la création du type structure « %s » à %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "La définition du type de %qs à %C a déjà été définie à %L"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Rebut après l'instruction MAP à %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Rebut après l'instruction UNION à %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s à %C est une extension DEC, activez-la avec %<-fdec-structure%>"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Nom de structure attendu dans la déclaration de structure non imbriquée à %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Rebut après l'instruction STRUCTURE non imbriquée à %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Le nom de structure %qs à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: attendu dans la définition de TYPE à %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "Définition du type dérivé décoré à %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Le nom de type %qs à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Le nom du type dérivé %qs à %C a déjà le type de base %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Le nom du type dérivé %qs à %C a déjà un type de base"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "L'argument muet %qs à %L ne peut pas être un type dérivé à %C"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La définition du type dérivé %qs à %C a déjà été défini"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Rebut après la déclaration PARAMETERIZED TYPE à %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Le pointé de type Cray à %C ne peut pas être un tableau de forme tacite"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM et ENUMERATOR à %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "L'énumérateur excède le type entier du C à %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L pas initialisé avec une expression entière"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Instruction de définition ENUM attendue avant %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Erreur de syntaxe dans la définition ENUMERATOR à %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Spécificateurs d'accès dupliqués à %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Les attributs de liaison spécifient déjà « PASS », NOPASS illégal à %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Les attributs de liaison spécifient déjà « PASS »; PASS illégal à %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Attribut POINTER dupliqué à %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE dupliqué à %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED dupliqué à %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Spécificateur d'accès attendu à %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Attribut de liaison attendu à %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE et DEFERRED ne peuvent pas apparaître tous les deux à %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "L'attribut POINTER est requis pour un composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Nom d'interface attendu après %<(%> à %C"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> attendu à %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Une interface doit être spécifiée pour une liaison DEFERRED à %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) à %C devrait être déclarée DEFERRED"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Nom de liaison attendu à %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Liste PROCEDURE à %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> est invalide pour la liaison DEFERRED à %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> nécessaire dans une liaison PROCEDURE avec une cible explicite à %C"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Cible de liaison attendue après %<=>%> à %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Le type %qs contenant la liaison DEFERRED à %C n'est pas ABSTRACT"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Il y a déjà une procédure avec le nom de liaison %qs pour le type dérivé %qs à %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "Le GENERIC à %C doit être à l'intérieur du type dérivé CONTAINS"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> attendu à %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Nom générique ou descripteur d'opérateur attendu à %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Instruction GENERIC mal formée à %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> attendu à %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Il y a déjà une procédure non générique avec le nom de liaison %qs pour le type dérivé %qs à %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "La liaison à %C doit avoir le même accès que la liaison %qs déjà définie"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Nom de liaison spécifique attendu à %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs est déjà défini comme liaison spécifique pour le %qs générique à %C"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Rebut après la liaison GENERIC à %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La déclaration FINAL à %C doit être à l'intérieur d'une section CONTAINS du type dérivé"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La déclaration de type dérivé avec FINAL à %C doit être dans la partie de spécification d'un MODULE"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vide à %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Nom de procédure de module attendu à %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> attendu à %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nom de procédure %qs inconnu à %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs à %C est déjà défini comme procédure FINAL"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Attribut inconnu dans l'instruction !GCC$ ATTRIBUTES à %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction !GCC$ ATTRIBUTES à %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Directive %<GCC unroll%> requiert une constante entière non négative plus petite ou égale à %u à %C"
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Erreur de syntaxe dans la directive !GCC$ UNROLL à %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Erreur de syntaxe dans la directive !GCC$ IVDEP à %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Erreur de syntaxe dans la directive !GCC$ VECTOR à %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "Erreur de syntaxe dans la directive !GCC$ NOVECTOR à %C"
@@ -59952,12 +60011,12 @@ msgstr "l'index dans la dimension %d est hors de limites à %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "Le nombre d'éléments dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure autorisée %d.  Consultez l'option %<-fmax-array-constructor%>"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "LEN part_ref à %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "KIND part_ref à %C"
@@ -60032,7 +60091,7 @@ msgstr "L'intrinsèque transformationnel %qs à %L n'est pas permis dans une exp
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Évaluation d'une expression d'initialisation non standard à %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "La fonction %qs dans l'expression d'initialisation à %L doit être une fonction intrinsèque"
@@ -60298,7 +60357,7 @@ msgstr "Désaccord d'interface dans l'affectation du pointeur de procédure à %
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Interface explicite requise pour le composant %qs à %L: %s"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Interface explicite requise pour %qs à %L: %s"
@@ -60356,167 +60415,167 @@ msgstr "La cible du remappage du rang n'a pas le rang 1 à %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "La cible de données à %L n'aura point de co-index"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "L'expression cible dans l'affectation de pointeur à %L doit fournir un pointeur comme résultat"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "La cible de l'affectation du pointeur dans l'expression d'initialisation n'a pas l'attribut TARGET à %L"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "La cible de l'affectation du pointeur n'est ni TARGET ni POINTER à %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Mauvaise cible dans l'affectation du pointeur dans la procédure PURE à %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Affectation de pointeur avec un indice de vecteur dans le membre de droite à %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "La cible de l'affectation du pointeur a l'attribut PROTECTED à %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Affectation à un pointeur contigu depuis une cible non contigüe à %L"
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Le pointeur à %L dans l'affectation de pointeur pourrait vivre plus longtemps que la cible pointée"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "La cible de l'initialisation de pointeur à %L ne doit pas être ALLOCATABLE"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "La cible de l'initialisation du pointeur à %L ne doit pas avoir l'attribut TARGET"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "La cible de l'initialisation du pointeur à %L doit avoir l'attribut SAVE"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "La cible de l'initialisation du pointeur de procédure à %L ne peut pas être un pointeur de procédure"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "La procédure interne %qs est invalide dans l'initialisation du pointeur de procédure à %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "La procédure fictive %qs est invalide dans l'initialisation du pointeur de procédure à %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "generate_isocbinding_initializer(): mauvais type iso_c_binding, %<c_ptr%> ou %<c_funptr%> attendu"
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Fonctions pointeurs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expression non variable dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nommée %qs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs dans le contexte de définition de variable (%s) à %L n'est pas une variable"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non POINTER dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Type inaccessible dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT dans un contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans un contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L dans la procédure PURE"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs à %L associé à la cible vecteur indexé ne peut pas être utilisé dans le contexte de définition de variable (%s)"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs à %L associé a une expression ne peut pas être utilisé dans un contexte de définition de variable (%s)"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Le nom associé %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L car sa cible à %L ne le peut pas non plus"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Éléments avec la même valeur à %L et %L dans l'indice de vecteur dans le contexte de définition de variable (%s)"
@@ -60542,7 +60601,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Identifiant illégal dans copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -60733,12 +60792,12 @@ msgstr "Le premier argument de l'affectation définie à %L doit être INTENT(OU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -60808,582 +60867,582 @@ msgstr "Interfaces ambigües dans %s pour %qs à %L et %qs à %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Bien que non référencé, %qs a des interfaces ambigües à %L"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs à %L n'est pas une procédure de module"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Le tableau de rang tacite à %L requiert que l'argument muet %qs ait un rang tacite"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Rang non concordant dans l'argument %qs à %L (scalaire et rang %d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Rang non concordant dans l'argument %qs à %L (rang %d et scalaire)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Rang non concordant dans l'argument %qs à %L (rang %d et rang %d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effectif à %L (scalaire et rang %d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effectif à %L (rang %d et scalaire)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Rang non concordant entre l'argument effectif à %L et l'argument effectif à %L (rang %d et rang %d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Argument de procédure invalide à %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Interface non concordante dans la procédure muette %qs à %L: %s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "L'argument effectif au pointeur contigus du muet %qs à %L doit être simplement contigu"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Désaccord de type entre l'argument effectif à %L et l'argument effectif à %L (%s/%s)."
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Type non concordant dans l'argument %qs à %L; passé %s à %s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "L'argument effectif du type tacite à %L requiert que l'argument muet %qs soit d'un type tacite"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "L'argument effectif de %qs à %L doit être polymorphique"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "L'argument effectif de %qs à %L doit avoir le même type déclaré"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "L'argument effectif de %qs à %L doit être polymorphique illimité puisque l'argument de format est un pointeur ou une entité polymorphique illimité allouable [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "L'argument effectif de %qs à %L doit être un co-tableau"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-rang non concordant dans l'argument %qs à %L (%d et %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "L'argument effectif de %qs à %L doit être simplement contigu ou un élément vers un tel tableau"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Argument effectif vers le muet %qs non INTENT(INOUT) à %L qui est LOCK_TYPE ou a un composant LOCK_TYPE"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Argument effectif vers le muet %qs non INTENT(INOUT) à %L qui est EVENT_TYPE ou a un composant EVENT_TYPE"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "L'argument muet %qs doit être un pointeur, un tableau de forme tacite ou de rang tacite sans attribut CONTIGUOUS – car l'argument effectif à %L n'est pas simplement contigu et les deux sont ASYNCHRONOUS ou VOLATILE"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Passage d'un co-tableau à %L pour l'argument %qs allouable, non co-tableau, muet INTENT(OUT)"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Passage d'un co-tableau à %L pour l'argument %qs allouable, non co-tableau et muet qui est invalide si le statut d'allocation est modifié"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Scalaire polymorphique passé à l'argument tableau muet %qs à %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Un élément d'un tableau de forme tacite ou pointeur comme argument effectif à %L ne peut pas correspondre à l'argument effectif à %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Un élément d'un tableau de forme tacite ou pointeur est passé à l'argument tableau muet %qs à %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Extension: Argument effectif scalaire du sous-type pas par défaut, du sous-type non C_CHAR avec un argument muet tableau %qs à %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Argument effectif scalaire CHARACTER avec un argument muet tableau %qs à %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "L'argument mot-clé %qs à %L est invalide dans une fonction instruction"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "L'argument mot-clé %qs à %L n'est pas dans une procédure, vouliez-vous employer %qs ?"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "L'argument mot-clé %qs à %L n'est pas dans une procédure"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "L'argument mot-clé %qs à %L est déjà associé à un autre argument effectif"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Plus d'arguments effectifs que d'arguments formels dans l'appel de la procédure à %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Spécificateur de retour alternatif manquant dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Spécificateur de retour alternatif inattendu dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "NULL() intrinsèque inattendu à %L pour le muet %qs"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Pointeur null à %L pour un muet non pointeur %qs"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "L'argument effectif à %L pour le muet de type tacite est d'un type dérivé avec une connexion de type ou des procédures FINAL"
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Désaccord dans la longueur de CHARACTER (%ld/%ld) entre l'argument effectif et l'argument muet pointeur ou allouable %qs à %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Désaccord dans la longueur de CHARACTER (%ld/%ld) entre l'argument effectif et l'argument muet de forme tacite %qs à %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "L'argument effectif à %L pour l'argument muet allouable ou pointeur %qs doit avoir un paramètre de type différé si et uniquement si le muet en a un"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "La longueur de CHARACTER de l'argument effectif est plus court que celui de l'argument muet %qs (%lu/%lu) à %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "L'argument effectif contient trop peu d'éléments pour l'argument muet %qs (%lu/%lu) à %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Pointeur de procédure attendu pour l'argument %qs à %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Procédure attendue pour l'argument %qs à %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "L'argument effectif pour %qs ne peut pas être un tableau de taille tacite à %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "L'argument effectif pour %qs doit être un pointeur à %L"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Argument effectif non pointeur à %L vers le muet pointeur %qs"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Argument effectif co-indexé à %L vers le muet pointeur %qs"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "L'argument effectif co-indexé à %L vers le muet allouable %qs requiert INTENT(IN)"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "L'argument effectif co-indexé ASYNCHRONOUS ou VOLATILE à %L requiert que le muet %qs n'ait ni ASYNCHRONOUS ni VOLATILE"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "L'argument effectif co-indexé à %L avec un composant ultimement allouable pour le muet %qs requiert soit VALUE ou INTENT(IN)"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "L'argument effectif qui est un tableau de CLASS pour %qs doit être un tableau complet à %L"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "L'argument effectif pour %qs doit être ALLOCATABLE à %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "L'argument effectif qui est une section de tableau avec des indices de vecteur à %L est incompatible avec l'attribut INTENT(OUT), INTENT(INOUT), VOLATILE ou ASYNCHRONOUS de l'argument muet %qs"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif de forme tacite à %L est incompatible avec l'argument muet de forme non tacite %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif qui est une section de tableau à %L est incompatible avec l'argument muet de forme non tacite %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "L'argument effectif qui est un tableau de pointeurs à %L requiert un argument muet de forme tacite ou un tableau de pointeurs %qs à cause de l'attribut VOLATILE"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Spécification de retour alternatif manquant dans l'appel de la sous-routine à %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argument effectif manquant pour l'argument %qs à %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mauvais code de composant"
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Liste non concordante"
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): donnée corrompue"
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Le même argument effectif est associé avec l'argument INTENT(%s) %qs et l'argument INTENT(%s) %qs à %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Liste non concordante"
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "L'argument de procédure à %L est local dans une procédure PURE et a l'attribut POINTER"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "L'argument effectif co-indexé à %L dans une procédure PURE est passé à un argument INTENT(%s)"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "L'argument effectif co-indexé à %L dans une procédure PURE est passé à un argument muet de type POINTER"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "L'argument effectif polymorphique co-indexé à %L est passé à l'argument muet polymorphique %qs"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "La procédure %qs appelée à %L n'est pas explicitement déclarée, vouliez-vous employer %qs ?"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "La procédure %qs appelée à %L n'est pas explicitement déclarée"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procédure %qs appelée avec une interface implicite à %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "L'objet pointeur %qs à %L doit avoir une interface de fonction explicite ou être déclaré comme un tableau"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "L'objet allouable %qs à %L doit avoir une interface de fonction explicite ou être déclaré comme un tableau"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "La fonction allouable %qs à %L doit avoir une interface de fonction explicite"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Interface explicite requise pour l'argument polymorphique à %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "L'argument mot-clé requiert une interface explicite pour la procédure %qs à %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "L'argument de type tacite %s à %L requiert une interface explicite"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "L'argument effectif de LOCK_TYPE ou avec un composant LOCK_TYPE à %L requiert une interface explicite pour la procédure %qs"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "L'argument effectif de EVENT_TYPE ou avec un composant EVENT_TYPE à %L requiert une interface explicite pour la procédure %qs"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Argument MOLD requis pour NULL à %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Un argument de rang tacite requiert une interface explicite à %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Composant pointeur de procédure %qs appelé avec une interface implicite à %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "L'argument mot-clé requiert une interface explicite pour le composant pointeur de procédure %qs à %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= est requis dans l'argument NULL() à %L: Ambigüité entre les fonctions spécifiées %s et %s"
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Impossible de trouver le symbole %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "L'entité %qs à %L est déjà présente dans l'interface"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Mauvais type d'interface"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Ne peut écraser GENERIC %qs à %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs à %L redéfini une liaison de procédure déclarée NON_OVERRRIDABLE"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs à %L ne doit pas être DEFERRED car il redéfini une liaison non DEFERRED"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs à %L redéfini une procédure PURE et doit aussi être PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs à %L redéfini une procédure ELEMENTAL et doit aussi être ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs à %L redéfini une procédure non ELEMENTAL et ne doit pas être ELEMENTAL non plus"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs à %L redéfini une SUBROUTINE et doit aussi être une SUBROUTINE"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs à %L redéfini une FUNCTION et doit aussi être une FUNCTION"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Résultat non concordant pour la redéfinition de la procédure %qs à %L: %s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs à %L redéfini une procédure PUBLIC et ne doit pas être PRIVATE"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "L'argument muet %qs de %qs à %L devrait être nommé %qs pour correspondre à l'argument équivalent de la procédure redéfinie"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument non concordant pour la procédure redéfinissante %qs à %L: %s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs à %L doit avoir le même nombre d'arguments formels que la procédure redéfinie"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs à %L redéfini une liaison NOPASS et doit aussi être NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs à %L redéfini une liaison PASS et doit aussi être PASS"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "L'argument muet %qs de type objet passé à %L doit être à la même position que l'argument muet de type objet passé à la procédure redéfinie"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "L'argument muet DTIO à %L doit être du type %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "L'argument muet DTIO à %L doit avoir KIND = %d"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "L'argument muet DTIO à %L doit être un scalaire"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "L'argument muet DTIO à %L doit être ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "L'argument caractère DTIO à %L doit avoir une longueur tacite"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "L'argument muet DTIO à %L doit avoir INTENT %s"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Le retour alternatif à %L n'est pas permis dans une procédure DTIO"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "La procédure DTIO %qs à %L doit être une sous-routine"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Trop peu d'arguments muets dans la procédure DTIO %qs à %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Trop d'arguments muets dans la procédure DTIO %qs à %L"
@@ -61488,73 +61547,73 @@ msgstr "ALTERNATE RETURN pas permis à %L"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "Dans l'appel à %qs à %L, désaccord de type dans l'argument %qs; passe %qs à %qs"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr "resolve_intrinsic(): Trop d'arguments pour l'intrinsèque"
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "do_simplify(): Trop d'arguments pour l'intrinsèque"
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "init_arglist(): trop d'arguments"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "Code standard invalide pour l'intrinsèque %qs (%d)"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "L'intrinsèque %qs (est %s) est utilisé à %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "Fonction %qs comme expression d'initialisation à %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "La fonction transformationnelle %qs à %L est invalide dans une expression d'initialisation"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fonction élémentaire comme expression d'initialisation avec des arguments non entiers/non caractères à %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "L'appel de sous-routine à l'intrinsèque %qs dans un bloc DO CONCURRENT à %L n'est pas PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "L'appel de sous-routine à l'intrinsèque %qs à %L n'est pas PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Extension: Conversion de %s vers %s à %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Conversion non standard de %s vers %s à %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Changement possible de valeur dans la conversion de %s vers %s à %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Conversion de %s vers %s à %L"
@@ -61562,22 +61621,22 @@ msgstr "Conversion de %s vers %s à %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Impossible de convertir %s en %s à %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Impossible de convertir %qs en %qs à %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "%qs, déclaré à %L, pourrait masquer l'intrinsèque du même nom. Pour appeler l'intrinsèque, des déclarations INTRINSIC explicites peuvent être nécessaires."
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "%qs, déclaré à %L, est aussi le nom d'un intrinsèque. Il peut uniquement être appelé via une interface explicite ou s'il est déclaré EXTERNAL."
@@ -61923,12 +61982,12 @@ msgstr "Le type ACTION est en conflit avec le spécificateur READONLY à %L"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= à %L n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "BLANK= à %L n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr "DECIMAL= à %L n'est pas permis en Fortran 95"
@@ -61938,7 +61997,7 @@ msgstr "DECIMAL= à %L n'est pas permis en Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "ENCODING= à %L n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr "ROUND= à %L n'est pas permis en Fortran 95"
@@ -61983,7 +62042,7 @@ msgstr "L'instruction CLOSE à %L requiert le numéro d'un UNIT"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Le numéro de UNIT dans l'instruction CLOSE à %L doit être non négatif"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "L'instruction %s n'est pas permise dans une procédure PURE à %C"
@@ -62078,7 +62137,7 @@ msgstr "NAMELIST %qs dans l'instruction READ à %L contient le symbole %qs qui n
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
@@ -62144,7 +62203,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Expression attendue dans l'instruction %s à %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction %s à %C"
@@ -62159,83 +62218,83 @@ msgstr "Fichier interne à %L avec une liste de noms"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "Le IO UNIT dans l'instruction %s à %L doit être un fichier interne dans une procédure PURE"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "PAD= à %L pas permis en Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "DELIM= à %L pas permis en Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "La liste de noms dans PRINT à %C est une extension"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "La virgule après * à %C n'est pas permise sans liste d'E/S"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Virgule attendue dans la liste des E/S à %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "L'instruction PRINT à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "NULL() près de %L ne peut pas apparaître dans une instruction INQUIRE"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "L'instruction INQUIRE n'est pas permise dans une procédure PURE à %C"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "L'étiquette IOLENGTH est invalide dans l'instruction INQUIRE à %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "L'instruction INQUIRE à %L ne peut pas contenir les deux spécificateurs FILE et UNIT en même temps"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "L'instruction INQUIRE à %L requiert l'un des deux spécificateurs FILE ou UNIT"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "Le numéro de UNIT dans l'instruction INQUIRE à %L ne peut pas être %d"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "L'instruction INQUIRE à %L requiert un spécificateur PENDING= avec le spécificateur ID="
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT à %C interdit en Fortran 95"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "L'instruction WAIT n'est pas permise dans une procédure PURE à %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "débordement de l'identificateur : %d"
@@ -62480,505 +62539,505 @@ msgstr "Rebut après l'instruction ASSOCIATE à %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Le type dérivé %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Spécification de type invalide à %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Erreur de syntaxe dans l'itérateur FORALL à %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "Construction DO CONCURRENT à %C"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Le nom %qs dans l'instruction %s à %C est inconnu"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Le nom %qs dans l'instruction %s à %C n'est pas un nom de construction"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "L'instruction %s à %C quitte la construction CRITICAL"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "L'instruction %s à %C quitte la construction DO CONCURRENT"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "L'instruction %s à %C n'est pas à l'intérieur d'une construction"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "L'instruction %s à %C n'est pas à l'intérieur de la construction %qs"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "L'instruction CYCLE à %C n'est pas applicable à la construction %qs qui n'est pas une boucle"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Instruction EXIT sans nom de construction « do » à %C"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "L'instruction %s à %C n'est pas applicable à la construction %qs"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "L'instruction %s à %C quitte le bloc structuré OpenACC"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "L'instruction %s à %C quitte le bloc structuré OpenMP"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "L'instruction EXIT à %C termine la boucle !$ACC LOOP"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "Instruction CYCLE à %C pour une boucle !$ACC LOOP découpée en blocs qui n'est pas la plus à l'intérieur"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "Instruction CYCLE à %C pour une boucle !$ACC LOOP coalescée qui n'est pas la plus à l'intérieur"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "L'instruction EXIT à %C termine la boucle !$OMP DO"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "Instruction CYCLE à %C pour une boucle !$OMP DO coalescée qui n'est pas la plus à l'intérieur"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "Espace requis dans l'instruction %s près de %C"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "Le code de STOP à %C ne peut pas être négatif"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr "Le code de STOP à %C contient trop de chiffres"
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "Instruction %s à %C dans une procédure PURE"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "Instruction STOP de contrôle d'image à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "Instruction STOP de contrôle d'image à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr "Le code STOP à %L doit être une constante CHARACTER scalaire ou chiffre[chiffre[chiffre[chiffre[chiffre]]]]"
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "Le code STOP à %L doit être une expression constante scalaire CHARACTER ou INTEGER par défaut"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "Le code STOP à %L doit être soit le type INTEGER ou CHARACTER"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "Le code STOP à %L doit être scalaire"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "Le code STOP à %L doit être un caractère par défaut avec KIND=%d"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Le code STOP à %L doit être un entier par défaut avec KIND=%d"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "Instruction PAUSE à %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "Instruction ERROR STOP à %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "Instruction EVENT %s de contrôle d'image à %C dans une procédure PURE"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "Instruction EVENT %s de contrôle d'image à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "Instruction EVENT %s de contrôle d'image à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr "Balise STAT redondante trouvée à %L"
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "Balise ERRMSG redondante trouvée à %L"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "Balise UNTIL_COUNT redondante trouvée à %L"
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "Instruction EVENT POST à %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "Instruction EVENT WAIT à %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "Instruction FAIL IMAGE à %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "Instruction FORM TEAM à %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "Instruction CHANGE TEAM à %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "Instruction END TEAM à %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "Instruction SYNC TEAM à %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Instruction %s de contrôle d'image à %C dans une procédure PURE"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Instruction %s de contrôle d'image à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Instruction %s de contrôle d'image à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "Balise ACQUIRED_LOCK redondante trouvée à %L"
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "Instruction LOCK à %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "Instruction UNLOCK à %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Instruction SYNC de contrôle d'image à %C dans une procédure PURE"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "Instruction SYNC à %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "Instruction SYNC de contrôle d'image à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "Instruction SYNC de contrôle d'image à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "Instruction ASSIGN à %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Instruction GOTO assigné à %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "La liste d'étiquettes d'instructions dans le GOTO à %C ne peut pas être vide"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "GOTO calculé à %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Erreur dans la spécification de type à %L"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "typespec dans ALLOCATE à %L"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr "La liste de spec des paramètres de types dans le type-spec à %L ne peut pas contenir de paramètre DEFERRED"
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "Constante inattendue à %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Mauvais objet d'allocation à %C pour une procédure PURE"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "Objet allouable incompatible à %C pour la spec de type CHARACTER à %L"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE sur un co-tableau à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE sur un co-tableau à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "L'objet d'allocation à %L n'est ni un pointeur de données ni une variable allouable"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Le type de l'entité à %L est incompatible sur le type avec typespec"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Le paramètre de sous-type pour l'entité à %L diffère du paramètre de sous-type du typespec"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Spécification de forme pour un scalaire allouable à %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "La balise STAT à %L ne peut pas être une constante"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "Balise ERRMSG à %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "Balise SOURCE à %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr "Balise SOURCE redondante trouvée à %L"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "La balise SOURCE à %L est en conflit avec le typespec à %L"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "Balise SOURCE à %L avec plus d'un seul objet allouable"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "Balise MOLD à %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "Balise MOLD redondante trouvée à %L"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "La balise MOLD à %L est en conflit avec le typespec à %L"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "La balise MOLD à %L est en conflit avec la balise SOURCE à %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "L'objet allouable à %L avec un paramètre de type différé requiert soit une spécification de type ou une balise SOURCE ou une balise MOLD"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "L'objet allouable polymorphique illimité à %L requiert soit une spécification de type ou une balise SOURCE ou une balise MOLD"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "L'objet pointeur à %C ne sera point co-indexé"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr "NULLIFY n'autorise pas le remappage des limites pour l'objet pointeur à %C"
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Objet allouable illégal à %C pour une procédure PURE"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE d'un co-tableau à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE d'un co-tableau à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "L'objet allouable à %C n'est ni un pointeur vers une non procédure ni une variable allouable"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG à %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "Instruction RETURN de contrôle d'image à %C dans un bloc CRITICAL"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "Instruction RETURN de contrôle d'image à %C dans un bloc DO CONCURRENT"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "L'instruction RETURN avec retour alternatif à %C est uniquement autorisé dans une SUBROUTINE"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "Instruction RETURN dans le programme principal à %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Référence à un composant attendue à %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Rebut après CALL à %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Procédure liée à un type ou composant pointeur de procédure attendu à %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr "Une constante littérale BOZ à %L ne peut pas apparaître comme un argument effectif dans une référence de sous-routine"
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Erreur de syntaxe dans le nom du bloc commun à %C"
@@ -62986,218 +63045,218 @@ msgstr "Erreur de syntaxe dans le nom du bloc commun à %C"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "La variable %qs à %L dans le bloc commun %qs à %C doit être déclarée avec un sous-type interopérable avec le C puisque le bloc commun %qs est bind(c)"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "La variable %qs dans le bloc commun %qs à %C ne peut pas être bind(c) puisqu'elle n'est pas globale"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Le symbole %qs à %C est déjà dans le bloc COMMON"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Le symbole %qs initialisé à %C peut uniquement être COMMON dans BLOCK DATA"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "La spécification de tableau pour le symbole %qs dans COMMON à %C doit être explicite"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Le symbole %qs dans COMMON à %C ne peut pas être un tableau de POINTER"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Le symbole %qs dans le bloc COMMON %qs à %C est indirectement rendu équivalent à l'autre bloc COMMON %qs"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr "Construction BLOCK DATA à %L"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Le nom du groupe de la liste de noms %qs à %C a déjà le type de base %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Le nom du groupe de la liste de noms %qs à %C est déjà associé à use et ne peut pas être respécifié"
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %C n'est pas permis"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Le composant de type dérivé %C n'est pas un membre EQUIVALENCE permis"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "La référence au tableau dans EQUIVALENCE à %C ne peut pas être une section de tableau"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE à %C requiert deux objets ou plus"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Tentative de faire se chevaucher indirectement les blocs COMMON %s et %s par EQUIVALENCE à %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Une virgule est attendue dans EQUIVALENCE à %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "Instruction EQUIVALENCE à %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "La fonction-instruction à %L est récursive"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "La fonction-instruction %qs à %L entre en conflit avec le nom de la fonction"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "La fonction-instruction à %L ne peut pas apparaître à l'intérieur de INTERFACE"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Fonction-instruction à %C"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "L'expression dans le sélecteur CASE à %L ne peut pas être %s"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Expression d'initialisation attendue dans CASE à %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Nom de bloc %qs attendu pour la construction SELECT à %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "SELECT TYPE à %C ne peut pas apparaître dans cette portée"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "erreur d'analyse dans l'instruction SELECT TYPE à %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Le sélecteur dans SELECT TYPE à %C n'est pas une variable nommée; utilisez associate-name=>"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Instruction SELECT RANK à %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Le sélecteur de SELECT RANK à %C doit être une variable de rang tacite"
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "erreur d'analyse dans l'instruction SELECT RANK à %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Instruction CASE inattendue à %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Erreur de syntaxe dans la spécification CASE à %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Instruction TYPE IS inattendue à %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "La spécification de type ne spécifiera point un type dérivé d'une séquence ou un type avec l'attribut BIND dans SELECT TYPE à %C [F2003:C815]"
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Tous les paramètres de type LEN dans l'instruction TYPE IS à %C doivent être ASSUMED"
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Erreur de syntaxe dans la spécification TYPE IS à %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Erreur de syntaxe dans la spécification CLASS IS à %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Instruction RANK inattendue à %C"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "L'expression SELECT RANK CASE à %C doit être une constante entière scalaire"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "La valeur de l'expression SELECT RANK CASE à %C ne peut pas être inférieure à zéro ou plus grande que %d"
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Erreur de syntaxe dans la spécification RANK à %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Instruction ELSEWHERE à %C pas englobée dans un bloc WHERE"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "L'étiquette %qs à %C ne correspond pas à l'étiquette %qs de WHERE"
@@ -63238,12 +63297,12 @@ msgstr "match_level_4(): Mauvais opérateur"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Type non défini"
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Type non défini"
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Mauvais code"
@@ -63926,8 +63985,8 @@ msgstr "La sous-routine %s déclarée implicitement est utilisé dans !$OMP DECL
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "Le paramètre de la clause ORDERED est plus petit que COLLAPSE à %L"
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause IF à %L requiert une expression LOGICAL scalaire"
@@ -65341,172 +65400,172 @@ msgstr "%<%c%> inattendu pour la variable %qs du type non dérivé à %C"
 msgid "Expected structure component name at %C"
 msgstr "Nom de composant de structure attendu à %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr "part_ref RE ou IM à %C"
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr "Le part_ref RE ou IM à %C doit être appliqué à une expression COMPLEX"
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "Le part_ref LEN à %C doit être appliqué à une expression CHARACTER"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Liste d'arguments attendue à %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr "part_ref RE ou IM à %C"
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "Le part_ref KIND à %C doit être appliqué à une expression de type intrinsèque"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "Le composant pointeur de procédure %qs requiert une liste d'arguments à %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "Référence non polymorphique au type abstrait à %C"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Composant pointeur de procédure co-indexé à %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): L'expression n'est pas une variable"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_caf_attr(): L'expression n'est pas une variable"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_caf_attr(): Mauvaise référence à un tableau"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Constructeur de structure avec des arguments optionnels manquants à %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "Aucune initialisation pour le composant allouable %qs donné dans le constructeur de structure à %C"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "Pas d'initialisation donnée pour le composant %qs dans le constructeur de structure à %C"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "Impossible de construire le type ABSTRACT %qs à %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "Constructeur de structure avec des arguments nommés à %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr "Initialisation de composant sans nom après le composant nommé %s à %L"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "Trop de composants dans le constructeur de structure à %L"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans le constructeur (%ld/%ld) à %L"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Le composant %qs est initialisé deux fois dans le constructeur de structure à %L"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Expression co-indexée vers le composant pointeur %qs dans le constructeur de structure à %L"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "Le composant %qs à %L a déjà été défini par le constructeur d'un type parent dérivé"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr "%%LOC() a une r-valeur à %C"
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "%qs à %C est le nom d'une fonction récursive et, par conséquent, il fait référence à la variable résultat. Utilisez une variable RESULT explicite pour diriger la récursion (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Le symbole à %C ne convient pas pour une expression"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Utilisation inattendue du nom de sous-routine %qs à %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "La fonction-instruction %qs requiert une liste d'arguments à %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "La fonction %qs requiert une liste d'arguments à %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Argument manquant pour %qs à %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr "Le part-ref le plus à gauche dans le data-ref ne peut pas être une référence à une fonction à %C"
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Liste d'arguments manquante dans la fonction %qs à %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Le type dérivé %qs ne peut pas être utilisé comme une variable à %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "La constante nommée à %C est une EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%qs à %C n'est pas une variable"
@@ -65834,497 +65893,497 @@ msgstr "%qs à %L est ambigüe"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "La procédure GENERIC %qs n'est pas permise comme argument effectif à %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Le type spécifié pour la fonction intrinsèque %qs à %L est ignoré"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "La sous-routine intrinsèque %qs à %L n'aura point de spécificateur de type"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%qs déclaré INTRINSIC à %L n'existe pas"
 
 # %s est une chaîne non traduite telle que "available since Fortran 77".
 # voir bugs #38573 et #52279 à ce sujet.
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "L'intrinsèque %qs déclaré INTRINSIC à %L n'est pas disponible avec les paramètres standard actuels mais est %s. Utilisez l'option %<-std=*%> appropriée ou activez %<-fall-intrinsics%> de manière à pouvoir l'utiliser."
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs à %L semble s'appeler elle-même récursivement. Déclarez là RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "L'étiquette %d référencée à %L n'est jamais définie"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Le type dérivé %qs est utilisé comme argument effectif à %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "La fonction-instruction %qs à %L n'est pas permise comme argument effectif"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "L'intrinsèque %qs à %L n'est pas permis comme argument effectif"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Procédure interne %qs utilisée comme argument effectif à %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "La procédure ELEMENTAL non INTRINSIC %qs n'est pas permise comme argument effectif à %L"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Impossible de trouver une procédure INTRINSIC spécifique pour la référence %qs à %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Le symbole %qs à %L est ambigu"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "L'argument par valeur à %L n'est pas un type numérique"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "L'argument par valeur à %L ne peut pas être un tableau ou une section de tableau"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "L'argument par valeur à %L n'est pas permis dans ce contexte"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Passer la procédure interne à %L par position n'est pas permis"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Le composant pointeur de procédure ELEMENTAL %qs n'est pas permis comme argument effectif à %L"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Argument effectif co-indexé à %L avec un composant pointeur ultime"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%qs à %L est un tableau et est OPTIONAL; S'IL EST MANQUANT, il ne peut pas être l'argument effectif d'une procédure ELEMENTAL à moins qu'il y ait un argument non optionnel avec le même rang (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "L'argument effectif à %L pour le muet INTENT(%s) %qs de la sous-routine ELEMENTAL %qs est un scalaire mais un autre argument effectif est un tableau"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Désaccord dans le type de retour de la fonction %qs à %L (%s/%s)"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Non concordance de l'interface dans la procédure globale %qs à %L: %s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Il n'y a pas de fonction spécifique pour la fonction générique %qs à %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "La fonction générique %qs à %L n'est pas cohérente avec l'interface intrinsèque spécifique"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La fonction %qs à %L est INTRINSIC mais elle est incompatible avec un intrinsèque"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Impossible de résoudre la fonction spécifique %qs à %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT, vouliez-vous employer %qs ?"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
 
 # %s à la fin est le texte non traduit "mask" ou "block"
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Référence à la fonction impure %qs à %L à l'intérieur d'un FORALL %s"
 
 # %s à la fin est le texte non traduit "mask" ou "block"
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Référence à la fonction impure %qs à %L à l'intérieur d'un DO CONCURRENT %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Référence à la fonction impure %qs à %L dans une procédure PURE"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Rebut inattendu après %qs à %L"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs à %L n'est pas une fonction"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs ne doit pas être référencée à %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr "ABSTRACT INTERFACE %qs à %L ne doit pas avoir un résultat d'une longueur de caractères tacite (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "La fonction %qs est déclarée CHARACTER(*) et ne peut pas être utilisée à %L car elle n'est pas un argument muet"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): mauvais type de fonction"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr "Une constante littérale BOZ à %L ne peut pas apparaître comme un argument effectif dans une référence de fonction"
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "La fonction %qs non ELEMENTAL définie par l'utilisateur à %L n'est pas permise dans la construction WORKSHARE"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs à %L ne peut pas être appelé récursivement car la fonction %qs n'est pas RECURSIVE"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "La fonction %qs à %L ne peut pas être appelée récursivement car elle n'est pas RECURSIVE"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "L'appel de sous-routine à %qs dans le bloc FORALL à %L n'est pas PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "L'appel de sous-routine à %qs dans le bloc DO CONCURRENT à %L n'est pas PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "L'appel de sous-routine à %qs à %L n'est pas PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Il n'y a pas de sous-routine spécifique pour le générique %qs à %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "La sous-routine générique %qs à %L n'est pas cohérente avec l'interface de sous-routine intrinsèque"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "La sous-routine %qs à %L est INTRINSIC mais elle n'est pas compatible avec un intrinsèque"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Impossible de résoudre la sous-routine spécifique %qs à %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs à %L a un type, ce qui n'est pas cohérent avec l'appel CALL à %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs à %L ne peut pas être appelé récursivement car la sous-routine %qs n'est pas RECURSIVE"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs à %L ne peut pas être appelée récursivement car elle n'est pas RECURSIVE"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): mauvais type de fonction"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Les formes pour les opérandes à %L et %L ne sont pas conformes"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Mauvais intrinsèque"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "La fonction impure %qs à %L pourrait ne pas être évaluée"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "La fonction impure à %L pourrait ne pas être évaluée"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "La constante littérale BOZ à %L ne peut pas être un opérande de l'opérateur unaire %qs"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Les opérandes à %L et %L ne peuvent pas apparaître comme opérandes de l'opérateur binaire %qs"
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Mauvais intrinsèque"
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Mauvaise expression"
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la co-dimension %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la co-dimension %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Pas nul illégal à %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Mauvaise référence de tableau"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "La limite supérieure la plus à droite de la section du tableau de taille tacite n'est pas spécifiée à %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord de rang dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord du rang du co-index dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Le co-index de la co-dimension %d doit être un scalaire à %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "L'index de tableau à %L doit être scalaire"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "L'index de tableau à %L doit être du type INTEGER, on a trouvé %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "Index de tableau REAL à %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "L'argument dim à %L doit être scalaire"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "L'argument dim à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Spec manquante"
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): « as » inutilisé(1)"
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): « as » inutilisé(2)"
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "L'index de tableau à %L est un tableau de rang %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "L'index de départ de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "L'index de départ de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "L'index de départ de la sous-chaîne à %L est plus petit que un"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "L'index de fin de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "L'index de fin de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "L'index de fin de la sous-chaîne à %L excède la longueur de la chaîne"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "L'index de fin de la sous-chaîne à %L est trop grand"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Mauvaise référence de tableau"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut POINTER à %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut ALLOCATABLE à %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Deux références de parties (ou plus) avec un rang non nul ne peuvent pas être spécifiées à %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Deux specs de tableau"
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK peut uniquement être utilisée comme argument effectif"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -66333,12 +66392,12 @@ msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comm
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de type tacite %s à %L comme argument effectif à une fonction de requête sera le premier argument"
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -66347,286 +66406,286 @@ msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comm
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de rang tacite %s à %L comme argument effectif à une fonction intrinsèque sera le premier argument"
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de type tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de rang tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs, utilisée dans une expression de spécification, est référencée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs est utilisée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Sous-objet polymorphique d'un objet co-indexé à %L"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objet co-indexé avec un sous-composant allouable polymorphique à %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Erreur dans l'appel avec type lié à %L"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "L'objet passé à %L doit être scalaire"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de composant pointeur de procédure à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de procédure liée au type à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "L'objet de base pour l'appel de procédure liée au type NOPASS à %L doit être scalaire"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Aucune liaison spécifique correspondante pour l'appel à GENERIC %qs à %L"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs à %L devrait être une SUBROUTINE"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs à %L devrait être une FUNCTION"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Mauvais type d'expression"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s à %L doit être un scalaire"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s à %L doit être un entier"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s à %L doit être INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "L'expression de pas dans la boucle DO à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "La boucle DO à %L sera exécutée zéro fois"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde"
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde vers le bas"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Le nom d'index FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "L'expression de départ de FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "L'expression de fin de FORALL à %L doit être un INTEGER scalaire"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "L'expression de pas de FORALL à %L doit être un %s scalaire"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "L'expression de pas de FORALL à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "L'index %qs de FORALL ne peut pas apparaître dans une spécification de triplet à %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "L'objet allouable à %L doit être ALLOCATABLE ou un POINTER"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objet allouable co-indexé à %L"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "L'expression source à %L doit être scalaire ou avoir le même rang que l'objet allouable à %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "L'expression source à %L et l'objet allouable à %L doivent avoir la même forme"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Le type de l'entité à %L a un type incompatible avec l'expression source à %L"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "L'objet allouable à %L et l'expression source à %L auront le même paramètre de sous-type"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type LOCK_TYPE ni un composant LOCK_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type EVENT_TYPE ni un composant EVENT_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "L'allocation de %s du type de base ABSTRACT à %L requiert une spécification de type ou une expression source"
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "L'allocation de %s à %L avec la spécification de type requiert la même longueur de caractères dans le paramètre que dans la déclaration"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spécification de tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Une spécification de tableau ou une expression SOURCE= avec une valeur tableau est requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spécification de co-tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure à %L"
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure 1 à %L"
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs ne doit pas apparaître dans la spécification de tableau à %L dans la même instruction ALLOCATE où il est lui-même alloué"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "« * » attendu dans la spécification du co-index dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de co-tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat à %L doit être une variable INTEGER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG à %L est inutile sans la balise STAT"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "La variable ERRMSG à %L sera une variable CHARACTER du scalaire par défaut"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "L'objet alloué à %L apparaît aussi à %L"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
@@ -66635,284 +66694,284 @@ msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "L'étiquette CASE à %L chevauche l'étiquette CASE à %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "L'expression dans l'instruction CASE à %L doit être du type %s"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "L'expression dans l'instruction CASE à %L doit être du sous-type %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "L'expression dans l'instruction CASE à %L doit être scalaire"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "L'expression de sélection dans le GOTO calculé à %L doit être une expression entière scalaire"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "L'argument de l'instruction SELECT à %L ne peut pas être %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "L'argument de l'expression SELECT à %L doit être une expression scalaire"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "L'expression dans l'instruction CASE à %L n'est pas dans la plage de %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Le DEFAULT CASE à %L ne peut pas être suivi par un second DEFAULT CASE à %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Une plage logique n'est pas permise dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "La valeur logique constante est répétée dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La spécification d'étendue à %L ne peut jamais correspondre à quoi que ce soit"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Le bloc SELECT CASE logique à %L a plus de deux cas"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "L'entité associante %qs à %L est un pointeur de procédure"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Le type dérivé %qs ne peut pas être utilisé comme une variable à %L"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "L'entité associante %qs à %L est un nom de procédure"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "L'expression de sélecteur associant à %L donne une procédure"
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Le sélecteur à %L ne peut pas NULL()"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Le sélecteur à %L n'a pas de type"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Le nom associé %qs à %L est utilisé comme tableau"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Le sélecteur CLASS à %L a besoin d'un temporaire qui n'est pas encore implémenté"
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Le sélecteur sera polymorphique dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Le sélecteur à %L ne doit pas être co-indexé"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS à %L chevauche TYPE IS à %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Le type dérivé %qs à %L doit être extensible"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Le type dérivé %qs à %L doit être une extension de %qs"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Type intrinsèque %qs inattendu à %L"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La spécification de type à %L doit spécifier que chaque paramètre de type de longueur est tacite"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloc CLASS IS en double dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT à %L est répété à %L"
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) à %L est répété à %L"
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) à %L est répété à %L"
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) à %L ne peut pas être utilisé avec un pointeur ou un sélecteur allouable à %L"
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexte invalide pour l'intrinsèque NULL () à %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "La procédure DTIO %s à %L doit être récursive"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas être polymorphique à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants POINTER à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants de pointeur de procédure"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants ALLOCATABLE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "L'élément de transfert de données à %L ne peut pas être une référence complète à un tableau de taille tacite"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable verrou à %L doit être un scalaire de type LOCK_TYPE"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable d'événement à %L doit être un scalaire de type EVENT_TYPE"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau ou co-indexé"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau mais pas co-indexé"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "L'argument STAT= à %L doit être une variable INTEGER scalaire"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "L'argument ACQUIRED_LOCK= à %L doit être une variable LOGICAL scalaire"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "L'argument UNTIL_COUNT= à %L doit être une expression INTEGER scalaire"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "L'argument imageset à %L doit être une expression scalaire ou INTEGER de rang 1"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "L'argument imageset à %L doit être entre 1 et num_images()"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "L'instruction à %L n'est pas une instruction cible valable pour l'instruction de branchement à %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Le branchement à %L peut conduire à une boucle infinie"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction CRITICAL pour l'étiquette à %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'étiquette à %L"
@@ -66920,187 +66979,187 @@ msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'é
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "L'étiquette à %L n'est pas dans le même bloc que l'instruction GOTO à %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Le masque WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "La cible de l'affectation WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Affectation définie par l'utilisateur non ELEMENTAL dans WHERE à %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Instruction non supportée à l'intérieur de WHERE à %L"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Affectation à une variable d'index FORALL à %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Le FORALL avec l'index %qs n'est pas utilisé dans le membre de gauche de l'affectation à %L et, par conséquent, pourrait causer de multiples affectations à cet objet"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Construction FORALL à %L"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Le nom d'index de FORALL à %L doit être une variable scalaire de type entier"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Une construction de boucle FORALL extérieure a déjà un index avec ce nom à %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "La clause WHERE/ELSEWHERE à %L requiert un tableau LOGICAL"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Mauvais type de bloc"
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans l'affectation (%ld/%ld) à %L"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "L'expression co-indexée à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "Dans un sous-programme pure, un argument fictif INTENT(IN) ne sera point utilisé comme l'expression à %L d'une instruction d'affectation intrinsèque dans laquelle la variable est d'un type dérivé si le type dérivé a un composant pointeur à n'importe quel niveau de la sélection du composant."
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Affectation à une variable co-indexée à %L dans une procédure PURE"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "L'affectation à un co-tableau polymorphique à %L n'est pas permise"
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Affectation à une variable polymorphique allouable à %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "L'affectation à une variable polymorphique allouable à %L requiert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable non allouable ne doit pas être polymorphique dans l'affectation intrinsèque à %L – vérifiez qu'il existe une sous-routine spécifique correspondante pour l'opérateur « = »"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable co-indexée ne doit pas avoir un composant ultimement allouable dans l'affectation à %L"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "À FAIRE: la/les affectation(s) liée(s) au type à %L n'ont pas été réalisées car des références multiples à des parties de tableaux apparaîtraient dans des expressions intermédiaires."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Affectation à une procédure pointeur à %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Le résultat de la fonction dans le membre de gauche de l'affectation à %L doit avoir l'attribut pointeur."
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
-msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
+msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER scalaire"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Une étiquette cible n'a pas été affectée à la variable %qs à %L"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "L'instruction RETURN alternatif à %L requiert un spécificateur de retour SCALAR-INTEGER"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "L'instruction ASSIGN à %L requiert une variable scalaire INTEGER par défaut"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL invalide à %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "L'instruction IF arithmétique à %L requiert une expression scalaire REAL ou INTEGER"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Pas d'expression dans le DO WHILE"
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condition de sortie de la boucle DO WHILE à %L doit être une expression LOGICAL scalaire"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause de masque FORALL à %L requiert une expression scalaire LOGICAL"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mauvais code d'instruction"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La variable %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L du module %qs"
@@ -67108,956 +67167,956 @@ msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L uti
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La procédure %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longueur de chaîne à %L est trop grande"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le tableau allouable %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "L'objet scalaire %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le pointeur tableau %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Le tableau %qs à %L ne peut pas avoir une forme différée"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Le type %qs de la variable CLASS %qs à %L n'est pas extensible"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS %qs à %L doit être muette, allouable ou pointeur"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Le type %qs ne peut pas être associé à un hôte à %L car il est bloqué par un objet incompatible du même nom déclaré à %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "SAVE implicite pour la variable module %qs à %L, nécessaire à cause de l'initialisation par défaut"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre de type différé et requiert soit l'attribut POINTER ou ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Le tableau %qs à %L du module ou du programme principal doit avoir une forme constante"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "L'entité avec une longueur de caractère tacite à %L doit être un argument muet ou un PARAMETER"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs à %L doit avoir une longueur de caractère constante dans ce contexte"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON %qs à %L doit avoir une longueur de caractère constante"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "L'allouable %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "L'externe %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Le muet %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "L'intrinsèque %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Le résultat de fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Le tableau automatique %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s à %L"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La fonction-instruction %qs avec une valeur de caractère à %L doit avoir une longueur constante"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs est d'un type PRIVATE et ne peut pas être un argument muet de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "La procédure %qs dans l'interface PUBLIC %qs à %L prend des arguments muets de %qs qui est PRIVATE"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "L'objet externe %qs à %L ne peut pas avoir d'initialisation"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La fonction ELEMENTAL %qs à %L doit avoir un résultat scalaire"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La fonction-instruction %qs à %L ne peut pas avoir l'attribut pointeur ou allouable"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un tableau"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un pointeur"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être pure"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être récursive"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fonction CHARACTER(*) %qs à %L"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Le pointeur de procédure %qs à %L ne sera point élémental"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "La procédure muette %qs à %L ne sera point élémentale"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable résultat %qs de la fonction à %L de la fonction élémentale %qs n'aura point l'attribut ALLOCATABLE ou POINTER"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut SAVE dans %qs à %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut INTENT dans %qs à %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut RESULT dans %qs à %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "L'attribut EXTERNAL est en conflit avec l'attribut FUNCTION dans %qs à %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Le résultat du pointeur de procédure %qs à %L n'a pas d'attribut pointeur"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut ELEMENTAL entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut PURE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut RECURSIVE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s entre la déclaration MODULE PROCEDURE dans MODULE %qs et la déclaration à %L dans (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "La procédure FINAL %qs à %L n'est pas une SUBROUTINE"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "La procédure FINAL à %L doit avoir exactement un argument"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "L'argument de la procédure FINAL à %L doit être du type %qs"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être un POINTER"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être OPTIONAL"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "La procédure FINAL non scalaire à %L devrait avoir un argument de forme tacite"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "La procédure FINAL %qs déclarée à %L a le même rang (%d) que %qs"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Seules des procédures FINAL tableaux déclarées pour le type dérivé %qs à %L, une scalaire est également suggérée"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs et %qs ne peuvent pas être FUNCTION/SUBROUTINE mixte pour GENERIC %qs à %L"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs et %qs pour GENERIC %qs à %L sont ambigus"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Liaison spécifique %qs non définie comme cible du GENERIC %qs à %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs à %L doit cibler une liaison spécifique, %qs est GENERIC aussi"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs à %L ne peut écraser la liaison spécifique avec le même nom"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "L'opérateur lié au type à %L ne peut pas être NOPASS"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs doit être une procédure de module ou une procédure externe avec une interface explicite à %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "La procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "La procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argument muet passé comme objet non polymorphique de %qs à %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "L'argument muet de type objet passé de %qs à %L doit être scalaire"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être POINTER"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant de %qs"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant hérité de %qs"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Le type dérivé %qs déclaré à %L doit être ABSTRACT car %qs est DEFERRED et pas redéfini"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Le composant co-tableau %qs à %L doit être allouable avec une forme différée"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Le composant %qs à %L ayant TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Le composant %qs à %L avec le composant co-tableau sera un scalaire non pointeur, non allouable"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Le composant %qs à %L a l'attribut CONTIGUOUS mais n'est pas un pointeur de tableau"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Le composant %qs du type BIND(C) à %L doit avoir la longueur un"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Le composant pointeur de procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Le composant pointeur de procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être scalaire"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas avoir l'attribut POINTER"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Le composant %qs de %qs à %L a le même nom qu'une procédure liée au type héritée"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longueur de caractère du composant %qs doit être une expression de spécification constante à %L"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Le composant caractère %qs de %qs à %L avec une longueur différée doit être POINTER ou ALLOCATABLE"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "le composant %qs est un type PRIVATE et ne peut pas être un composant de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Le composant polymorphique %s à %L dans le type %s SEQUENCE ou BIND(C)"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Le composant %s du type SEQUENCE déclaré à %L n'a pas l'attribut SEQUENCE"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initialisations conflictuelles dans l'union à %L et %L"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Puisque l'extension du type %qs à %L a un composant co-tableau, le type parent %qs en aura un aussi"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Le type dérivé non extensible %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Le type paramétrisé %qs n'a pas de composant correspondant au paramètre %qs à %L"
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Le type dérivé %qs à %L n'a pas été déclaré"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "L'objet %qs à %L a un paramètre LEN différé %qs et n'est ni allouable ni un pointeur"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "L'objet AUTOMATIC %qs à %L ne doit pas avoir l'attribut SAVE ou être une variable déclarée dans le programme principal, un module ou un sous-module(F08/C513)"
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "L'objet %qs à %L avec des paramètres de type ASSUMED doit être fictif ou un sélecteur SELECT TYPE(F08/4.2)"
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Mauvaise spécification pour le tableau de taille tacite à %L"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable BIND(C) %qs à %L doit avoir la longueur un"
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type EVENT_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Entité définissable attendue près de %L"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "L'objet DATA près de %L a l'attribut pointeur et la valeur DATA correspondante n'est pas une cible de donnée initiale valable"
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc COMMON à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Référence à elle-même dans l'expression de longueur de caractère pour %qs à %L"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -68745,153 +68804,153 @@ msgstr "%qs à %L a des attributs spécifiés en dehors du corps de son INTERFAC
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Le symbole %qs à %L est en conflit avec le symbole du module %qs, associé à USE à %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Le symbole %qs à %L a déjà le type de base %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "La procédure %qs à %L ne peut pas avoir le type de base %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Le symbole %qs à %L ne peut pas avoir de type"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Le composant %qs à %C est déjà dans le type parent à %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Le symbole %qs à %C est ambigu"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Le type dérivé %qs à %C est utilisé avant sa définition"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Le composant %qs à %C est un composant PRIVATE de %qs"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs à %C n'est pas un membre de la structure %qs; vouliez-vous employer %qs ?"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs à %C n'est pas un membre de la structure %qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Étiquette d'instruction %d dupliquée à %L et %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "L'étiquette %d à %C est déjà référencée comme cible d'un branchement"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "L'étiquette %d à %C est déjà référencée comme une étiquette de format"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "Instruction de fin de DO qui n'est pas END DO ou CONTINUE avec l'étiquette %d à %C"
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Étiquette %d à %C précédemment utilisée comme étiquette de FORMAT"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Étiquette %d à %C précédemment utilisée comme cible de branchement"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Étiquette de fin de DO %d partagée à %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Instruction DO étiquetée à %L"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Le nom %qs à %C est une référence ambigüe à %qs depuis le module %qs"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Le nom %qs à %C est une référence ambigüe à %qs depuis l'unité de programme actuelle"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Le symbole %qs à %C a déjà été associée à un hôte"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Le symbole donné est NULL de manière inattendue"
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Le type dérivé %qs, déclaré à %L, doit avoir l'attribut BIND pour être interopérable avec le C"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Le type dérivé %qs avec l'attribut BIND(C) à %L est vide et peut être inaccessible pour le processeur C compagnon"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant %qs à %L ne peut pas avoir l'attribut POINTER car il est un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant pointeur de procédure %qs à %L ne peut pas être un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant %qs à %L ne peut pas avoir l'attribut ALLOCATABLE car il est un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Le composant %qs dans le type dérivé %qs à %L peut ne pas être interopérable avec le C bien que le type dérivé %qs soit BIND(C)"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Le composant %qs dans le type dérivé %qs à %L peut ne pas être interopérable avec le C"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Le type dérivé %qs à %L ne peut pas avoir l'attribut SEQUENCE car il est BIND(C)"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Le symbole %qs est utilisé à %L avant qu'un type lui soit assigné"
@@ -68928,83 +68987,83 @@ msgstr "Initialisations inégales et se chevauchant dans EQUIVALENCE à %C"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Le nombre d'éléments dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure permise %d. Voyez l'option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Création d'un temporaire pour le tableau à %L dans l'argument %qs"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "mauvais type d'expression durant le parcours (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "Le bloc COMMON nommé %qs à %L sera de la même taille que celui ailleurs (%lu vs %lu octets)"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "get_mpz(): N'est pas une constante entière"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr "element_number(): Mauvais type de dimension"
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Mauvaise référence à un tableau à %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Type de référence illégale à %L comme objet EQUIVALENCE"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Règles d'équivalence incohérentes impliquant %qs à %L et %qs à %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "L'ensemble des équivalences pour la variable %qs déclarée à %L violent les exigences de l'alignement"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "L'équivalence pour %qs ne correspond pas à l'ordre du COMMON %qs à %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "L'ensemble des équivalences pour %qs entraîne une extension invalide au COMMON %qs à %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Rembourrage de %d octets requis avant %qs dans le COMMON %qs à %L; réorganisez les éléments ou utilisez %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Rembourrage de %d octets requis avant %qs dans le COMMON à %L; réorganisez les éléments ou utilisez %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr "COMMON %qs à %L n'existe pas"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "Le COMMON %qs à %L requiert %d octets de rembourrage; réorganisez les éléments ou utilisez %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "Le COMMON à %L requiert %d octets de rembourrage; réorganisez les éléments ou utilisez %<-fno-align-commons%>"
@@ -69024,72 +69083,72 @@ msgstr "expression d'initialisation non constante à %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr "Le tableau %qs à %L est plus grand que la limite définie par %<-fmax-stack-var-size=%>, il est déplacé de la pile vers la zone de stockage statique. Ceci rend la procédure non sûr lorsqu'elle est appelée récursivement ou simultanément depuis plusieurs threads. Envisagez d'utiliser %<-frecursive%> ou augmentez la limite de %<-fmax-stack-var-size=%> ou changez le code pour utiliser un tableau ALLOCATABLE."
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variable intrinsèque qui n'est pas une procédure"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "La valeur de retour de la fonction %qs à %L n'est pas définie"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Paramètre de type différé pas encore supporté"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "Le backend decl pour la variable de module %qs existe déjà"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "La variable de module PRIVATE %qs inutilisée est déclarée à %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "L'argument muet %qs à %L a été déclaré INTENT(OUT) mais n'a pas reçu de valeur"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "L'argument muet %qs d'un type dérivé à %L a été déclaré INTENT(OUT) mais n'a pas reçu de valeur et n'a pas d'initialisation par défaut"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argument muet %qs inutilisé à %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "La variable de module %qs est inutilisée mais elle a été importée explicitement à %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Variable %qs inutilisée déclarée à %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Paramètre %qs inutilisé déclaré à %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Le paramètre %qs est inutilisé mais il a été importé explicitement à %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "La valeur de retour %qs de la fonction %qs est déclarée à %L mais ne reçoit pas de valeur"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Désolé, !$ACC DECLARE à %L n'est pas permis dans une construction BLOCK"
@@ -69104,27 +69163,27 @@ msgstr "Impossible de calculer la longueur du tableau de caractères à %L."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Du code pour réallouer la variable allouable à %L va être ajouté"
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un objet polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un composant polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Op intrinsèque inconnue"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Fonction de liste d'arguments inconnue à %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Si le remappage des limites est spécifié à %L, la cible du pointeur ne sera point NULL"
@@ -69160,22 +69219,22 @@ msgstr "build_dt: format avec une liste de noms"
 msgid "Bad IO basetype (%d)"
 msgstr "Mauvais type de base d'E/S (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr "correspondance implicite du tableau de taille tacite %qD"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, gcc-internal-format
 msgid "optional class parameter"
 msgstr "paramètre de classe optionnel"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr "composant de type dérivé non géré"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Mauvais code d'instruction"
@@ -69285,82 +69344,82 @@ msgstr "parenthèses non appairées"
 msgid "unable to open file"
 msgstr "impossible d'ouvrir le fichier"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "flux bytecode: rebut à la fin de la section des symboles"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "impossible de décoder le nombre hexadécimal"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "nom de fichier %s inattendu dans la résolution du fichier de l'éditeur de liens. %s attendu"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "impossible de décoder le décalage dans le fichier"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "décalage inattendu"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ligne invalide dans le fichier de résolution"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "résolution invalide dans le fichier de résolution"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "la résolution avec le sub id %wx n'est pas dans le fichier objet"
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "le flux bytecode dans le fichier %qs a été généré par le compilateur GCC plus vieux que 10.0"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "impossible de lire %<LTO_section_decls%> depuis %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Impossible d'ouvrir %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Impossible de mapper %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Impossible de lire %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "n'a pu ouvrir le fichier de résolution des symboles: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "donnée de résolution manquante pour %s"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "erreurs durant la fusion des unités de traductions"
@@ -70487,7 +70546,7 @@ msgstr "nom de macro manquant après %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "nom de fichier manquant après %qs"
@@ -70687,21 +70746,33 @@ msgstr "algorithme de réorganisation des blocs de base %qs inconnu"
 msgid "unknown TLS model %qs"
 msgstr "modèle TLS %qs inconnu"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "modèle de coût de la vectorisation %qs inconnu"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "valeur de visibilité %qs non reconnue"
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "priorité d'initialisation de la vérification de la vtable %qs inconnue"
 
+#~ msgid "Warn about code paths in which an uninitialized value is used."
+#~ msgstr "Avertir à propos de chemins dans le code où une valeur non initialisée est utilisée."
+
+#~ msgid "Use instructions for a future architecture."
+#~ msgstr "Utiliser les instructions pour une architecture future."
+
+#~ msgid "three-way comparison operator can only be defaulted in a class definition"
+#~ msgstr "l'opérateur de comparaison à trois voies peut uniquement être remis au défaut dans la définition d'une classe"
+
+#~ msgid "equality comparison operator can only be defaulted in a class definition"
+#~ msgstr "l'opérateur de comparaison par égalité peut uniquement être remis au défaut dans la définition d'une classe"
+
 #~ msgid "Same as %s.  Use the latter option instead."
 #~ msgstr "Comme %s. Utilisez plutôt cette dernière option."
 
diff --git a/gcc/po/hr.po b/gcc/po/hr.po
index fbeddae1ef9..1902805360c 100644
--- a/gcc/po/hr.po
+++ b/gcc/po/hr.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.7.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2012-07-05 15:49+0200\n"
 "Last-Translator: Tomislav Krznar <tomislav.krznar@gmail.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
@@ -1936,86 +1936,86 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid constant"
 msgstr "neispravni %%-kod"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand"
 msgstr "neispravni izraz kao operand"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid 'asm': "
 msgid "invalid address mode"
 msgstr "neispravni „asm”: "
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2031,18 +2031,18 @@ msgid "invalid %%r value"
 msgstr ""
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr ""
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr ""
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr ""
@@ -2072,7 +2072,7 @@ msgstr ""
 msgid "invalid %%U value"
 msgstr ""
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr ""
@@ -2082,7 +2082,7 @@ msgstr ""
 msgid "invalid %%C value"
 msgstr ""
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr ""
@@ -2092,10 +2092,10 @@ msgstr ""
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -2184,35 +2184,35 @@ msgstr "neispravni izraz kao operand"
 msgid "unrecognized supposed constant"
 msgstr ""
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2220,13 +2220,13 @@ msgstr ""
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2348,7 +2348,7 @@ msgstr ""
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2565,26 +2565,26 @@ msgstr ""
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand %%xn code"
 msgstr "neispravni %%-kod"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr ""
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, c-format
 msgid "invalid fp constant"
 msgstr ""
@@ -2732,7 +2732,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -2786,7 +2786,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr ""
 
@@ -2838,8 +2838,8 @@ msgstr ""
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -2972,169 +2972,207 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%-code"
+msgid "invalid %%A value"
+msgstr "neispravni %%-kod"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%e value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%t value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%V value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%z value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26742
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26744
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26746
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26754
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26757
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26760
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.c:26763
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr ""
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3145,88 +3183,88 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3489,8 +3527,8 @@ msgstr ""
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekujem %<;%>"
@@ -3510,7 +3548,7 @@ msgstr "očekujem %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekujem %<)%>"
@@ -3518,7 +3556,7 @@ msgstr "očekujem %<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekujem %<]%>"
@@ -3536,21 +3574,21 @@ msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekujem %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekujem %<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekujem %<{%>"
@@ -3561,12 +3599,12 @@ msgstr "očekujem %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekujem %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekujem %<while%>"
@@ -3575,7 +3613,7 @@ msgstr "očekujem %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekujem %<,%>"
@@ -3584,18 +3622,18 @@ msgstr "očekujem %<,%>"
 msgid "expected %<.%>"
 msgstr "očekujem %<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekujem %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekujem %<,%> ili %<)%>"
@@ -3603,19 +3641,19 @@ msgstr "očekujem %<,%> ili %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekujem %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekujem %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
@@ -3624,7 +3662,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -3636,34 +3674,34 @@ msgstr ""
 msgid "expected label"
 msgstr "očekujem %<while%>"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr ""
 
@@ -3752,7 +3790,7 @@ msgstr ""
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -3918,48 +3956,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -3999,17 +4037,17 @@ msgstr ""
 msgid "elemental binary operation"
 msgstr ""
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr ""
@@ -4082,7 +4120,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4097,7 +4135,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4203,11 +4241,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr ""
 
@@ -4215,199 +4253,199 @@ msgstr ""
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr ""
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr ""
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr ""
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr ""
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr ""
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr ""
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr ""
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr ""
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr ""
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr ""
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4420,27 +4458,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4515,7 +4553,7 @@ msgstr ""
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -4956,7 +4994,7 @@ msgstr ""
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5538,8 +5576,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -7982,105 +8020,100 @@ msgstr ""
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr ""
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12511,7 +12544,7 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
+msgid "Use instructions added in ISA 3.1."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:576
@@ -12524,6 +12557,11 @@ msgstr ""
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17472,7 +17510,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18115,369 +18153,369 @@ msgstr ""
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <datoteka>            Spremi izlaz u <datoteka>\n"
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr ""
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "  -shared                  Create a shared library\n"
 msgid "Create a shared library."
 msgstr "  -shared                  Napravi dijeljenu biblioteku\n"
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19633,8 +19671,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -19660,7 +19698,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected integer"
@@ -19725,7 +19763,7 @@ msgstr ""
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr ""
@@ -20079,7 +20117,7 @@ msgstr ""
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20164,12 +20202,12 @@ msgstr ""
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20187,8 +20225,8 @@ msgstr ""
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -20311,7 +20349,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -20602,7 +20640,7 @@ msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -20893,12 +20931,12 @@ msgstr ""
 msgid "%<asm%> clobber conflict with input operand"
 msgstr ""
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21408,302 +21446,302 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr ""
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr ""
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr ""
@@ -21789,12 +21827,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -21950,7 +21988,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr ""
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot open %s: %m"
@@ -22281,22 +22319,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr ""
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr ""
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr ""
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22356,7 +22394,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -22386,12 +22424,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -22406,7 +22444,7 @@ msgstr ""
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr ""
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
@@ -22426,37 +22464,37 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23080,13 +23118,13 @@ msgstr "tijelo funkcije nije dostupno"
 msgid "function returns address of local variable"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr ""
@@ -23676,10 +23714,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -23844,7 +23882,7 @@ msgstr ""
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
@@ -23894,13 +23932,13 @@ msgstr ""
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -23910,147 +23948,147 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -24125,7 +24163,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr ""
@@ -24397,7 +24435,7 @@ msgstr ""
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -24405,7 +24443,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24413,7 +24451,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -24421,7 +24459,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -24429,7 +24467,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24437,7 +24475,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24445,12 +24483,12 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24480,37 +24518,37 @@ msgstr ""
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr ""
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24560,57 +24598,57 @@ msgstr ""
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -24870,52 +24908,52 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr ""
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr ""
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25137,52 +25175,52 @@ msgstr ""
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr ""
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -26513,132 +26551,132 @@ msgstr ""
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr ""
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr ""
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr ""
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr ""
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr ""
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr ""
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr ""
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr ""
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr ""
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr ""
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr ""
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr ""
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr ""
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr ""
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr ""
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr ""
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr ""
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -26733,176 +26771,176 @@ msgstr ""
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr ""
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr ""
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr ""
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid position or size operand to %qs"
 msgstr "neispravni izraz kao operand"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr ""
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr ""
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr ""
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid %qs offset operator"
 msgstr "neispravni izraz kao operand"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr ""
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid address operand in %qs"
 msgstr "neispravni izraz kao operand"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid offset operand in %qs"
 msgstr "neispravni izraz kao operand"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr ""
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr ""
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -26913,508 +26951,508 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr ""
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr ""
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr ""
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr ""
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr ""
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr ""
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr ""
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr ""
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr ""
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr ""
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr ""
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr ""
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr ""
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr ""
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid (pointer) operands %qs"
 msgstr "neispravni izraz kao operand"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr ""
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr ""
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr ""
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr ""
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr ""
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr ""
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr ""
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr ""
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr ""
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr ""
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr ""
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr ""
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr ""
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr ""
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr ""
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr ""
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr ""
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -27429,47 +27467,47 @@ msgstr ""
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -27984,12 +28022,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr ""
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -28054,7 +28092,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28064,27 +28102,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr ""
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -28159,32 +28197,32 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -28209,232 +28247,232 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:14387
+#: tree.c:14398
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr ""
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr ""
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -28559,82 +28597,82 @@ msgstr ""
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr ""
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr ""
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr ""
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -29214,7 +29252,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -29234,7 +29272,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -29604,12 +29642,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr ""
@@ -29765,12 +29803,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -29871,7 +29909,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr ""
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
@@ -29881,124 +29919,124 @@ msgstr ""
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr ""
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr ""
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr ""
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr ""
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr ""
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr ""
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30053,502 +30091,502 @@ msgstr ""
 msgid "format string argument follows the arguments to be formatted"
 msgstr ""
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr ""
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr ""
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr ""
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr ""
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr ""
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr ""
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr ""
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr ""
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr ""
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr ""
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr ""
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr ""
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr ""
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr ""
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr ""
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr ""
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr ""
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr ""
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr ""
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr ""
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr ""
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr ""
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr ""
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr ""
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr ""
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr ""
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr ""
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr ""
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr ""
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr ""
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr ""
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr ""
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -30709,7 +30747,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -30724,17 +30762,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
@@ -30744,7 +30782,7 @@ msgstr ""
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -31342,7 +31380,7 @@ msgid "wrong type argument to %s"
 msgstr ""
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -32018,7 +32056,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -32095,7 +32133,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -32115,7 +32153,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
@@ -32135,7 +32173,7 @@ msgstr ""
 msgid "too many input files"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -32166,14 +32204,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -32692,393 +32730,400 @@ msgstr ""
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:unknown function '%u'\n"
 msgid "unknown tuning option (%s)"
 msgstr "%s:nepoznata funkcija „%u”\n"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr ""
@@ -33259,17 +33304,17 @@ msgstr ""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33419,12 +33464,12 @@ msgstr ""
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -33432,194 +33477,194 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33629,283 +33674,283 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr ""
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr ""
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr ""
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr ""
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -33913,22 +33958,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr ""
@@ -34007,17 +34052,17 @@ msgstr ""
 msgid "%<-fPIE%> is not supported"
 msgstr ""
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
@@ -34283,7 +34328,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr ""
@@ -34614,53 +34659,53 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr ""
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr ""
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr ""
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr ""
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "broj operanada je izvan granica"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -34798,132 +34843,132 @@ msgstr ""
 msgid "parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr ""
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr ""
@@ -35303,144 +35348,144 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -35886,7 +35931,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -36962,52 +37007,52 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr ""
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -37123,323 +37168,324 @@ msgstr ""
 msgid "junk at end of %<#pragma longcall%>"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -37459,219 +37505,224 @@ msgstr ""
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
@@ -37992,139 +38043,139 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
@@ -38543,8 +38594,8 @@ msgstr ""
 msgid "could not read the BRIG file"
 msgstr "ne mogu pisati u privremenu datoteku %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -38821,7 +38872,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -38891,7 +38942,7 @@ msgstr ""
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -38921,7 +38972,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
@@ -39129,7 +39180,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39468,7 +39519,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -39775,7 +39826,7 @@ msgstr ""
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -39825,7 +39876,7 @@ msgstr ""
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -39861,7 +39912,7 @@ msgstr ""
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -39891,7 +39942,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
@@ -39921,7 +39972,7 @@ msgstr ""
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -40036,12 +40087,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -40049,257 +40100,257 @@ msgstr ""
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr ""
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr ""
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr ""
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr ""
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -40319,7 +40370,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekujem kraj retka"
@@ -40365,7 +40416,7 @@ msgid "unknown type name %qE"
 msgstr ""
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -40385,7 +40436,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -40400,8 +40451,8 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -40439,7 +40490,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -40467,7 +40518,7 @@ msgstr ""
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr ""
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -40497,7 +40548,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -40542,14 +40593,14 @@ msgstr ""
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -40634,7 +40685,7 @@ msgstr ""
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr ""
@@ -40644,7 +40695,7 @@ msgstr ""
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr ""
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -40704,7 +40755,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -40719,7 +40770,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
@@ -40744,17 +40795,17 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr ""
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -40774,12 +40825,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -40794,8 +40845,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr ""
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -40823,12 +40874,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -41219,61 +41270,61 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -41283,18 +41334,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
@@ -41315,56 +41366,56 @@ msgstr "očekujem %<,%> ili %<)%>"
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<data%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41386,12 +41437,12 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
@@ -41401,23 +41452,23 @@ msgstr ""
 msgid "expected constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -41432,55 +41483,55 @@ msgstr ""
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr ""
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "unexpected argument"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<concurrent%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -41490,7 +41541,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -41525,24 +41576,24 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid depend kind"
 msgstr "neispravni izraz kao operand"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid map kind"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -41558,78 +41609,78 @@ msgstr ""
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41645,7 +41696,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "očekujem kraj retka"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -41655,67 +41706,67 @@ msgstr ""
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr ""
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41725,62 +41776,62 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -41790,74 +41841,74 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<for%> after %qs"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<point%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41872,57 +41923,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<match%>"
@@ -41933,12 +41984,12 @@ msgstr "očekujem %<;%>"
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -41948,34 +41999,34 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<target%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected %<declare%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -42031,44 +42082,44 @@ msgstr "očekujem %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -42083,27 +42134,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -42113,7 +42164,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -42128,7 +42179,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -42249,7 +42300,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -42274,7 +42325,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42387,17 +42438,17 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr ""
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -42422,7 +42473,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -42670,7 +42721,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -42837,7 +42888,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -42997,7 +43048,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -43028,7 +43079,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -43173,7 +43224,7 @@ msgstr ""
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -43213,7 +43264,7 @@ msgstr ""
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -43223,17 +43274,17 @@ msgstr ""
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -43248,7 +43299,7 @@ msgstr ""
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
@@ -43258,22 +43309,22 @@ msgstr ""
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -43324,7 +43375,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -43354,51 +43405,51 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -43408,8 +43459,8 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
@@ -43578,12 +43629,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -43608,8 +43659,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -43624,19 +43675,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -43706,116 +43757,116 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr ""
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -44011,30 +44062,30 @@ msgid "expected case label"
 msgstr "očekujem kraj retka"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -44042,749 +44093,749 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr ""
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr ""
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr ""
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr ""
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr ""
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr ""
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, gcc-internal-format
 msgid "  declared here"
 msgstr ""
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -44813,519 +44864,519 @@ msgstr ""
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr ""
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr ""
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr ""
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr ""
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr ""
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr ""
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr ""
@@ -45405,7 +45456,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr ""
@@ -45461,7 +45512,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
@@ -45516,369 +45567,368 @@ msgstr ""
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, gcc-internal-format
 msgid "allocated here"
 msgstr ""
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr ""
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -45920,7 +45970,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -45958,292 +46008,292 @@ msgstr ""
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr ""
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -46308,7 +46358,7 @@ msgstr ""
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr ""
@@ -46489,12 +46539,12 @@ msgstr ""
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr ""
@@ -46507,44 +46557,44 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -46552,650 +46602,650 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr ""
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr ""
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -47203,7 +47253,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -47211,7 +47261,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -47219,177 +47269,177 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr ""
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
@@ -47659,7 +47709,7 @@ msgstr ""
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
@@ -47824,7 +47874,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
@@ -48025,811 +48075,811 @@ msgstr ""
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "%qD cannot be %qs"
 msgstr "[ne mogu naći %s]"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -48841,95 +48891,95 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -48938,72 +48988,72 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -49043,7 +49093,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -49053,7 +49103,7 @@ msgstr ""
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -49379,148 +49429,148 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr ""
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -49701,338 +49751,338 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr ""
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr ""
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -50192,12 +50242,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr ""
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr ""
@@ -50222,157 +50272,162 @@ msgstr ""
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
+#: cp/method.c:1115
 #, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1111
+#: cp/method.c:1123
 #, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must be %<const%>"
 msgstr ""
 
-#: cp/method.c:1126
+#: cp/method.c:1128
 #, gcc-internal-format
-msgid "defaulted %qD must return %<bool%>"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1155
 #, gcc-internal-format
-msgid "defaulted %qD must be %<const%>"
+msgid "defaulted %qD is not a friend of %qT"
 msgstr ""
 
-#: cp/method.c:1158
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr ""
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr ""
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr ""
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr ""
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr ""
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -50414,133 +50469,133 @@ msgstr ""
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr ""
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s%s\n"
 msgid "%s %s %p %d"
 msgstr "%s %s%s\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -50548,78 +50603,78 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr ""
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -50644,7 +50699,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50669,7 +50724,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -50749,7 +50804,7 @@ msgstr ""
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -50870,7 +50925,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -50990,7 +51045,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -51092,12 +51147,12 @@ msgstr ""
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -51132,7 +51187,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -51147,7 +51202,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
@@ -51162,7 +51217,7 @@ msgstr ""
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
@@ -51187,914 +51242,919 @@ msgstr ""
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr ""
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr ""
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr ""
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr ""
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr ""
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "neispravni izraz kao operand"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr ""
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr ""
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr ""
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr ""
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr ""
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -52103,432 +52163,432 @@ msgstr ""
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected attribute before %<...%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -52537,545 +52597,545 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<auto%>"
 msgstr "očekujem %<;%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "očekujem %<@end%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr ""
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr ""
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53346,7 +53406,7 @@ msgstr ""
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
@@ -53371,67 +53431,67 @@ msgstr ""
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr ""
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -53439,17 +53499,17 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -53457,47 +53517,47 @@ msgstr ""
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -53507,57 +53567,57 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -53565,7 +53625,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -53573,132 +53633,132 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53706,297 +53766,297 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -54014,291 +54074,291 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr ""
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -54310,135 +54370,135 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr ""
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -54643,7 +54703,7 @@ msgstr ""
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -54693,7 +54753,7 @@ msgstr ""
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -54792,7 +54852,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -54832,7 +54892,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
@@ -54957,117 +55017,117 @@ msgstr ""
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -55307,797 +55367,797 @@ msgstr ""
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr ""
@@ -56357,107 +56417,107 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr ""
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -56681,10 +56741,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -56851,7 +56911,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -56968,7 +57028,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -57008,7 +57068,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr ""
@@ -57023,7 +57083,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr ""
@@ -57143,167 +57203,167 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr ""
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr ""
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr ""
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr ""
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr ""
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr ""
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr ""
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr ""
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr ""
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr ""
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr ""
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -57311,697 +57371,697 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr ""
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr ""
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr ""
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr ""
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr ""
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr ""
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr ""
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr ""
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr ""
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr ""
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr ""
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr ""
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr ""
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr ""
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr ""
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr ""
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr ""
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr ""
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr ""
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr ""
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr ""
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr ""
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr ""
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr ""
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr ""
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -58197,1760 +58257,1760 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr ""
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr ""
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr ""
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr ""
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "očekujem %<(%>"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "nisam uspio zatvoriti datoteku stanja %s [%s]"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr ""
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr ""
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>"
 msgid "Expected %<::%> at %C"
 msgstr "očekujem %<:%>"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "očekujem %<=%>"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "očekujem %<,%>"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr ""
@@ -60075,12 +60135,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr ""
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr ""
@@ -60155,7 +60215,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -60421,7 +60481,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -60479,167 +60539,167 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -60666,7 +60726,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -60858,12 +60918,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -60933,582 +60993,582 @@ msgstr ""
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -61613,73 +61673,73 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr ""
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr ""
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr ""
@@ -61687,22 +61747,22 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -62048,12 +62108,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62063,7 +62123,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62108,7 +62168,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -62203,7 +62263,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -62269,7 +62329,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -62284,83 +62344,83 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr ""
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr ""
@@ -62606,505 +62666,505 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr ""
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr ""
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr ""
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr ""
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr ""
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr ""
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr ""
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr ""
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -63112,217 +63172,217 @@ msgstr ""
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr ""
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr ""
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr ""
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr ""
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr ""
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -63363,12 +63423,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -64056,8 +64116,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -65466,172 +65526,172 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr ""
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
 #, gcc-internal-format, gfc-internal-format
-msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
+msgid "RE or IM part_ref at %C"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
-msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
+msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected argument list at %C"
+msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2366
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
+msgid "Expected argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr ""
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr ""
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr ""
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr ""
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr ""
@@ -65958,493 +66018,493 @@ msgstr ""
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr ""
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -66453,12 +66513,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -66467,283 +66527,283 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -66752,284 +66812,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67037,187 +67097,187 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67225,954 +67285,954 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -68860,153 +68920,153 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -69044,83 +69104,83 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr ""
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr ""
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -69140,72 +69200,72 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -69220,27 +69280,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -69276,22 +69336,22 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, gcc-internal-format
 msgid "optional class parameter"
 msgstr ""
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -69402,82 +69462,82 @@ msgstr ""
 msgid "unable to open file"
 msgstr "nisam uspio otvoriti %s"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr ""
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr ""
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr ""
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr ""
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr ""
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr ""
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr ""
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -70607,7 +70667,7 @@ msgstr ""
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr ""
@@ -70807,17 +70867,17 @@ msgstr ""
 msgid "unknown TLS model %qs"
 msgstr ""
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/id.po b/gcc/po/id.po
index 52a900033f7..caafd655a56 100644
--- a/gcc/po/id.po
+++ b/gcc/po/id.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -2071,18 +2071,18 @@ msgstr "pemodifikasi panjang dalam format strfmon"
 msgid "<command-line>"
 msgstr "<baris-perintah>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
@@ -2090,78 +2090,78 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "punctuation %qc tidak valid dalam batasan"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "hilang operan"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "insn tidak valid:"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "operan %%d tidak valid"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "alamat tidak valid"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operan tidak valid dalam operasi binary"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2177,18 +2177,18 @@ msgid "invalid %%r value"
 msgstr "nilai %%r tidak valid"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "nilai %%R tidak valid"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
@@ -2218,7 +2218,7 @@ msgstr "nilai %%M tidak valid"
 msgid "invalid %%U value"
 msgstr "nilai %%U tidak valid"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
@@ -2228,7 +2228,7 @@ msgstr "nilai %%s tidak valid"
 msgid "invalid %%C value"
 msgstr "nilai %%C tidak valid"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
@@ -2238,10 +2238,10 @@ msgstr "nilai %%E tidak valid"
 msgid "unknown relocation unspec"
 msgstr "relokasi unspek tidak diketahui"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "kode %%xn tidak valid"
@@ -2330,36 +2330,36 @@ msgstr "UNSPEC tidak valid sebagai operan"
 msgid "unrecognized supposed constant"
 msgstr "konstanta yang diharapkan tidak dikenal"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "operan shift tidak valid"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruksi Thumb terprediksi"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruksi terprediksi dalam urutan berkondisi"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2367,13 +2367,13 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "instruksi tidak pernah dijalankan"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2510,7 +2510,7 @@ msgstr "operan tidak terduga"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2729,27 +2729,27 @@ msgstr "operan output_move_double buruk"
 msgid "bad output_condmove_single operand"
 msgstr "operan output_condmove_single buruk"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand %%xn code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand %%xn code invalid for QImode"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid fp constant"
@@ -2912,7 +2912,7 @@ msgstr "operasi di %<__fpreg%> tidak valid"
 msgid "invalid %%P operand"
 msgstr "operan %%P tidak valid"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -2970,7 +2970,7 @@ msgid "post-increment address is not a register"
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -3028,8 +3028,8 @@ msgstr "'%%%c' bukan sebuah awalan operan yang valid"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "penggunaan dari '%%%c' tidak valid"
@@ -3170,181 +3170,235 @@ msgstr "Kehabisan ruang stack.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Mencoba menjalankan '%s' dalam shell untuk meningkatkan batasannya.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Gunakan piranti keras titik pecahan"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Non-aktifkan pengalamatan terindeks"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%H value"
+msgid "invalid %%A value"
+msgstr "nilai %%H tidak valid"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "nilai %%D tidak valid"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "konversi dari %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "konversi ke %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "konversi dari %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "konversi ke %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "konversi dari %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "konversi ke %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "konversi dari %<__fpreg%> tidak valid"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "konversi ke %<__fpreg%> tidak valid"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3355,102 +3409,102 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "tidak dapat menguraikan alamat"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'O'"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "operan kode keluaran tidak valid"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 #| msgid "invalid expression for min lvalue"
 msgid "invalid expression - try using an output modifier"
 msgstr "ekspresi tidak valid untuk minimal lvalue"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "target penunjuk dalam kembali berbeda dalam signedness"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3736,8 +3790,8 @@ msgstr "<anonim>"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
@@ -3757,7 +3811,7 @@ msgstr "diduga %<,%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -3766,7 +3820,7 @@ msgstr "diduga %<{%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -3787,13 +3841,13 @@ msgstr "diduga %<,%>, %<,%> atau %<}%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -3801,8 +3855,8 @@ msgstr "diduga %<{%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -3813,13 +3867,13 @@ msgstr "diduga %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -3829,7 +3883,7 @@ msgstr "diduga %<{%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -3841,20 +3895,20 @@ msgstr "diduga %<{%>"
 msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -3863,20 +3917,20 @@ msgstr "diduga %<,%> atau %<,%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
@@ -3887,7 +3941,7 @@ msgstr "diduga %<#pragma omp section%> atau %<}%>"
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -3900,19 +3954,19 @@ msgstr "diduga %<{%>"
 msgid "expected label"
 msgstr "Diduga nama"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "type %qs has a user-defined constructor"
 msgid "  after user-defined conversion:"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -3920,19 +3974,19 @@ msgid_plural "candidates are:"
 msgstr[0] "kandidat 1:"
 msgstr[1] "kandidat 1:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "lompat ke label %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "lompat ke case label"
 
@@ -4042,7 +4096,7 @@ msgstr "parameter template %q+#D"
 msgid "<statement>"
 msgstr "dalam pernyataan"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown src"
 msgid "<unknown>"
@@ -4240,54 +4294,54 @@ msgstr "konversi ke %qT mengubah nilai konstanta %qT"
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tipe argumen salah ke unary minus"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "tipe argumen salah ke bit-complement"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "tipe argumen salah ke abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "tipe argumen salah ke konjugasi"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 #, fuzzy
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "no pre-increment operator for type"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 #, fuzzy
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "no pre-decrement operator for type"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4329,19 +4383,19 @@ msgstr "Karakter tidak legal dalam konstanta BOZ di %C"
 msgid "elemental binary operation"
 msgstr "operasi binari elemen"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, fuzzy, c-format
 #| msgid "Different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "Bentuk berbeda untuk argumen '%s' dan '%s' di %L untuk intrinsik 'dot_product'"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, fuzzy, c-format
 #| msgid "Different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "Bentuk berbeda untuk argumen '%s' dan '%s' di %L untuk intrinsik 'dot_product'"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, fuzzy, c-format
 #| msgid "Different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
@@ -4415,7 +4469,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Driving:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4430,7 +4484,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4536,11 +4590,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
@@ -4548,249 +4602,249 @@ msgstr "assignmen penunjuk"
 msgid "simple IF"
 msgstr "IF sederhana"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "assignmen penunjuk"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "argumen tidak cocok"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "argumen tidak cocok"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "penempatan array"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "tidak ada argumen"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 #, fuzzy
 #| msgid "elemental procedure"
 msgid "bind(c) procedure"
 msgstr "prosedur elemental"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator numerik unary '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operan binari numerik '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operan dari string operator konkatenasi di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator logikal '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operan dari operator .not. di %%L adalah %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "kuantitas KOMPLEKS tidak dapat dibandingkan di %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logikal di %%L harus dibandingkan dengan %s daripada %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator perbandingan '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tingkat tidak konsisten untuk operator di %%L dan %%L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4804,29 +4858,29 @@ msgstr "Pajang KARAKTER berbeda (%d/%d) dalam konstruktor array di %L"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, fuzzy, c-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, fuzzy, c-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4909,7 +4963,7 @@ msgstr "Sintaks error dalam pernyataan IMPOR di %C"
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5407,7 +5461,7 @@ msgstr "Peringatkan mengenai pembuatan dari array sementara"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6067,8 +6121,8 @@ msgstr "Tambahkan garis bawah ke nama eksternal yang tampak"
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
@@ -8822,109 +8876,103 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr ""
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Peringatkan mengenai variabel yang terinisialisasi ke dirinya sendiri"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "Dump beberapa kompiler internal ke sebuah berkas"
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "Dump various analyzer internals to stderr."
 msgstr "Dump beberapa kompiler internal ke sebuah berkas"
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13921,10 +13969,9 @@ msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:572
-#, fuzzy, no-c-format
-#| msgid "Use Branch Likely instructions, overriding the architecture default"
-msgid "Use instructions for a future architecture."
-msgstr "Gunakan Branch Likely instruksi, overriding instruksi baku arsitektur"
+#, no-c-format
+msgid "Use instructions added in ISA 3.1."
+msgstr ""
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13937,6 +13984,12 @@ msgstr "Jangan hasilkan fused kali/tambah instruksi"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate load/store with update instructions"
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Hasilkan load/store dengan update instruksi"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -19509,7 +19562,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -20248,414 +20301,414 @@ msgstr "Lakukan penguraian loop ketika jumlah iterasi diketahui"
 msgid "Perform loop unrolling for all loops."
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:2863
+#: common.opt:2867
 #, fuzzy, no-c-format
 #| msgid "Allow optimization for floating-point arithmetic which may change the"
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Ijinkan optimisasi untuk aritmetik titik pecahan dimana mungkin mengubah"
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Sama seperti -fassociative-math untuk ekspresi yang memasukan pembagian."
 
-#: common.opt:2876
+#: common.opt:2880
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Ijinkan optimisasi matematik yang mungkin melanggar standar  IEEE atau ISO"
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Lakukan loop unswitching"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Lakukan loop peeling"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Buat tabel unwind untuk penanganan eksepsi"
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Lakukan pelacakan variabel dan juga variabel tag yang tidak terinisialisasi"
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktifkan propagasi penyalinan dari informasi skalar-evolusi."
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Tambahkan ekstra komentar ke keluaran perakit"
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Gunakan nilai ekspresi profiles dalam optimisasi"
 
-#: common.opt:3048
+#: common.opt:3052
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Konstruksi webs dan pisahkan penggunaan tidak berelasi dari variabel tunggal"
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 #| msgid "Enable conditional dead code elimination for builtin calls"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktifkan kondisional penghapusan kode mati untuk panggilan bawaan"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Lakukan optimisasi seluruh aplikasi"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Tempatkan nol data terinisialisasi dalam daerah bss"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Hasilkan informasi debug dalam formas DWARF v2"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Hasilkan informasi debug dalam format baku extended"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, fuzzy, no-c-format
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Hasilkan informasi debug dalam format STABS"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Hasilkan informasi debug dalam formas STABS extended"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Hasilkan informasi debug dalam format XCOFF"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Hasilkan informasi debug dalam format XCOFF extended"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Hasilkan instruksi isel"
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Tempatkan keluaran kedalam <berkas>"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "Aktifkan profiling fungsi"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Seperti -pedantic tetapi menisukannya sebagai errors"
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Jangan tampilkan fungsi yang dikompile atau waktu yang sudah lewat"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Aktifkan keluaran verbose"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Tampilkan versi dari kompiler"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Tekan peringatan"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "Buat sebuah perpustakaan terbagi"
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21931,8 +21984,8 @@ msgstr "Terikat dengan jumlah dari pemeriksaan waktu jalan dimasukan dengan loop
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Terikat ke jumlah dari pemeriksaan rutinitas yang dimasukan dengan loop tervektor dengan versi untuk pemeriksaan alignment"
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "nilai dihitung tidak digunakan"
@@ -21968,7 +22021,7 @@ msgid "expected boolean type"
 msgstr "diduga bukan tuple"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -22055,7 +22108,7 @@ msgstr "tidak ada argumen"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -22511,7 +22564,7 @@ msgstr "%qE atribut konflik dengan atribut %s"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -22602,12 +22655,12 @@ msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -22625,8 +22678,8 @@ msgstr "%qE atribut diabaikan"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -22754,7 +22807,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr "ofset diluar dari jangkauan dari konstanta string"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -23055,7 +23108,7 @@ msgstr "hilang argumen ke \"%s\""
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K penggunakan tidak valid dari %<__builtin_va_arg_pack ()%>"
@@ -23370,13 +23423,13 @@ msgstr "asm clobber konflik dengan keluaran operan"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "asm clobber konflik dengan masukan operan"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "not protecting local variables: variable length buffer"
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "tidak memproteksi variabel lokal: panjang buffer variabel"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not protecting function: no buffer at least %d bytes long"
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
@@ -23920,313 +23973,313 @@ msgstr "blok dasar tidak ditempatkan secara berurutan"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "jumlah dari catatan bb dalam rantai instruksi (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "jumlah ujung pemanggil negatif"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "missing direct call for speculation %i"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use control speculation"
 msgid "missing ref for speculation %i"
 msgstr "Gunakan spekulasi kontrol"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "elemen penginisialisasi bukan sebuah konstanta"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Asumsikan simbol mungkin tidak valid"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "PIC code generation is not compatible with fast indirect calls"
 msgid "edge count is not compatible with function count"
 msgstr "Pembuatan kode PIC tidak kompatibel dangan panggilan cepat tidak langsung"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "penunjuk inlined_to salah"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "multiple pemanggil inline"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "penunjuk inlined_to diset untuk pemanggil bukan inline"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "penunjuk inlined_to diset tetapi tidak ada predecessor ditemukan"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "penunjuk inlined_to mereferensikan ke dirinya sendiri"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "shared call_stmt:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "titik ujung ke deklarasi salah:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "hilang ujung callgraph untuk pemanggilan stmt:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "diduga pernyataan"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gagal"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -24326,12 +24379,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F digunakan tetapi tidak pernah didefinisikan"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
@@ -24500,7 +24553,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
@@ -24853,22 +24906,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "pembagian rtl tidak valid ditemukan dalam instruksi"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "shared rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "kegagalan konsistensi internal"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn digunakan dimana emit_jump_insn dibutuhkan:\n"
@@ -24934,7 +24987,7 @@ msgstr "array tidak cocok dengan daerah pohon"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "array tidak cocok dengan daerah pohon"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -24964,12 +25017,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut error: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut peringatan: %s"
@@ -24986,7 +25039,7 @@ msgstr "tipe argumen tidak valid dari %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "ukuran frame %wd bytes adalah lebih besar dari %wd bytes"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
@@ -25008,37 +25061,37 @@ msgstr "konstanta titik-tetap besar secara implisit dipotong ke tipe titik-tetap
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "perbandingan selalu %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> dari pemeriksaan tidak cocok tidak-sama selalu 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> dari mutually eksklusif test-sama selalu 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mereduksi konstanta dalam perbandingan"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mengkombinasi konstan diantar sebuah perbandingan"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "pemeriksaan fold: pohon asal diubah oleh fold"
@@ -25727,13 +25780,13 @@ msgstr "fungsi mengembalikan alamat dari variabel lokal"
 msgid "function returns address of local variable"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -26325,10 +26378,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -26515,7 +26568,7 @@ msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 msgid "enclosing %<target%>"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
@@ -26572,13 +26625,13 @@ msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -26588,152 +26641,152 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gagal"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT dipromosikan ke %qT ketika dilewatkan melalui %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(jadi anda harus melewatkan %qT bukan %qT ke %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jika kode ini dicapai, aplikasi akan digagalkan"
@@ -26814,7 +26867,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -27096,54 +27149,54 @@ msgstr "Lingkupan array tidak cocok"
 msgid "the extra base is defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -27177,38 +27230,38 @@ msgstr "%J fungsi mungkin merupakan kandidat untuk atribut %<noreturn%>"
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification failed: %s"
 msgid "IPA-SRA access verification failed"
 msgstr "verifikasi gagal: %s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -27262,59 +27315,59 @@ msgstr "batasan operan tidak konsisten dalam sebuah %<asm%>"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Jumlah maksimum dari percobaan dari sebuah insn dapat dijadwalkan"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "tidak dapat menemukan class %qs"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "tidak dapat menemukan deklarasi protokol untuk %qs"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -27587,54 +27640,54 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr ""
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "... with %qs clause here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -27871,53 +27924,53 @@ msgstr "masukan tidak valid ke blok struktur OpenMP"
 msgid "invalid branch to/from %s structured block"
 msgstr "cabang tidak valid ke/dari sebuah blok struktur OpenMP"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "routine %qD declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -29364,144 +29417,144 @@ msgstr "-fstack-protector tidak didukung untuk target ini"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "pilihan %qs tidak lagi didukung"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "penjadwalan instruksi tidak didukung dalam target mesin ini"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "target mesin ini tidak memiliki percabangan tertunda"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore tidak didukung dalam target mesin ini"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "tidak dapat membuka berkas dump %qs: %s"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the \"%s\" debug format"
 msgid "target system does not support the %qs debug format"
 msgstr "target sistem tidak mendukung format debug \"%s\""
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "pelacakan variabel diminta, tetapi tidak berguna kecuali menghasilkan informasi debug"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "pelacakan variabel diminta, tetapi tidak didukung oleh format debug ini"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections tidak didukung untuk target ini"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini (coba pilihan -march)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-array tidak didukung dengan -Os"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math non-aktif; pilihan lain mengambil prioritas"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector tidak didukung untuk target ini"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -fpic are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fPIC dan -fpic tidak didukung untuk target ini"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "error menulis ke %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "error menutup %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -29604,189 +29657,189 @@ msgstr "%H%<[*]%> tidak diijinkan selain dalam sebuah deklarasi"
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "konstanta tidak dihitung ketika ADDR_EXPR berubah"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "efek samping tidak diperhitungkan ketika ADDR_EXPR berubah"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "alamat diambil, tetapi bit ADDRESSABLE tidak diset"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "ekspresi tidak valid untuk minimal lvalue"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "operan tidak valid dalam referensi tidak langsung"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr ""
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "posisi atau ukuran operan tidak valid ke BIT_FIELD_REF"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "integral result type precision does not match field size of BIT_FIELD_REF"
 msgid "integral result type precision does not match field size of %qs"
 msgstr "tipe ketepatan hasil integral tidak cocok dengan ukuran field dari BIT_FIELD_REF"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
 #| msgid "mode precision of non-integral result does not match field size of BIT_FIELD_REF"
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "mode ketepatan dari hasil bukan integral tidak cocok dengan ukuran field dari BIT_FIELD_REF"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "tipe tidak cocok dalam referensi array"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "operan tidak valid ke %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in not expression"
 msgid "type mismatch in %qs"
 msgstr "tipe tidak cocok dalam ekspresi tidak"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid shift operand"
 msgid "invalid %qs offset operator"
 msgstr "operan shift tidak valid"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s operand"
 msgid "invalid address operand in %qs"
 msgstr "operan %%s tidak valid"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid shift operand"
 msgid "invalid offset operand in %qs"
 msgstr "operan shift tidak valid"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "IF sederhana"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion in gimple call"
 msgid "invalid function in gimple call"
 msgstr "konversi tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "bukan fungsi dalam panggilan gimple"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "pure const state tidak valid untuk fungsi"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "LHS tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "konversi tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion in gimple call"
 msgid "invalid static chain in gimple call"
 msgstr "konversi tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -29797,555 +29850,555 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 #| msgid "invalid LHS in gimple call"
 msgid "invalid argument to gimple call"
 msgstr "LHS tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in comparison expression"
 msgid "mismatching comparison operand types"
 msgstr "tipe tidak cocok dalam ekspresi perbandingan"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "non-vector operands in vector comparison"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in comparison expression"
 msgid "invalid vector comparison resulting type"
 msgstr "operan tidak valid dalam ekspresi perbandingan"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "bogus comparison result type"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "bukan register seperti RHS dari operasi unary"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "operan tidak valid dalam operasi unari"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "tipe tidak valid dalam konversi nop"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "tipe tidak valid dalam konversi nop"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid types in address space conversion"
 msgstr "tipe tidak valid dalam konversi nop"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "tipe tidak valid dalam konversi titik tetap"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "tipe tidak valid dalam konversi ke titik pecahan"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "tipe tidak valid dalam konversi ke integer"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in shift expression"
 msgid "type mismatch in %qs expression"
 msgstr "tipe tidak cocok dalam ekspresi shift"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid types for %qs"
 msgstr "tipe abstrak tidak valid untuk %q+D"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "konversi bukan trivial dalam operasi unari"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "bukan register seperti LHS dari operasi binari"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid non-vector operands to %qs"
 msgstr "operan tidak valid ke %%R"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "mode pointer tidak valid %qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "tipe tidak cocok dalam ekspresi binary"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, fuzzy, gcc-internal-format
 #| msgid "non-register as LHS of unary operation"
 msgid "non-register as LHS of ternary operation"
 msgstr "bukan register seperti RHS dari operasi unary"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid operands in ternary operation"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid mask type in %qs"
 msgstr "tipe abstrak tidak valid untuk %q+D"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "not allowed type combination in %qs"
 msgstr "'&' tidak diperboleh dengan sendirinya dalam baris %d"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "invalid position or size in %qs"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "konversi bukan trivial di penempatan"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "%qs LHS in clobber statement"
 msgstr "dalam pernyataan"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "operan tidak valid ke %%R"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "rhs tidak valid untuk penyimpanan memori gimple"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect number of vector %qs elements"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "PHI argument is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "argumen PHI bukan sebuah nilai GIMPLE"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR dengan sebuah kondisi always-false"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "operan tidak valid dalam pernyataan return"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "konversi tidak valid dalam pernyataan return"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "tujuan goto bukan sebuah label ataupun sebuah penunjuk"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to switch statement"
 msgid "non-integral type switch statement"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to switch statement"
 msgid "invalid case range in switch statement"
 msgstr "operan tidak valid ke pernyataan switch"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map.\n"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "masukan tidak benar dalam label_to_block_map.\n"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "string format memiliki jumlah operan yang tidak valid"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion in gimple call"
 msgid "invalid comparison code in gimple cond"
 msgstr "konversi tidak valid dalam panggilan gimple"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "invalid labels in gimple cond"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "Hasil PHI tidak valid"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "hilang definisi PHI"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "argumen PHI tidak valid"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "Incompatible types in PHI argument"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "tipe tidak kompatibel dalam argumen PHI"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple gagal"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "Dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "STMT dalam tabel EH mati"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "local declaration from a different function"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) diset ke blok dasar salah"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "PHI node with location"
 msgstr "dari lokasi ini"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) diset ke blok dasar yang salah"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "pernyataan ditandai untuk throw, tetapi tidak"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "pernyataan ditandai untuk throw di tengah dari blok"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple gagal"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK memiliki IL diasosiasikan dengannya"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK memiliki IL diasosiasikan dengannya"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru ke keluar dari bb %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "bukan lokal label "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "label "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "kontrol aliran di tengah dari blok dasar %d"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fallthry edge setelah sebuah pernyataan kontrol dalam bb %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "benar/salah edge setelah sebuah bukan-COND_COND dalam bb %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "tanda edge keluar salah diakhir dari bb %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "eksplisit goto di akhir dari bb %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "return edge tidak menunjuk ke akhir dalam bb %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "ditemukan case baku bukan diawal dari case vektor"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case label tidak diurutkan: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "kelebihan outgoing edge %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "hilang edge %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> fungsi tidak kembali"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "kontrol mencapai akhir dari fungsi bukan void"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -30362,53 +30415,53 @@ msgstr "redefinisi dari %q+D"
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i tidak dapat throw tetapi memiliki EH edges"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "BB %i tidak dapat throw tetapi memiliki EH edges"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i pernyataan terakhir memiliki daerah set tidak benar"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unnecessary EH edge %i->%i"
 msgid "Incorrect EH edge %i->%i"
 msgstr "EH edge %i->%i tidak diperlukan"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "insn salah dalam ujung fallthru"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i has incorrect edge"
 msgstr "BB %i pernyataan terakhir memiliki daerah set tidak benar"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -30939,12 +30992,12 @@ msgstr "stmt (%p) ditandai dimodifikasi setelah tahap optimisasi: "
 msgid "verify_ssa failed"
 msgstr "verify_ssa gagal"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, fuzzy, gcc-internal-format
 #| msgid "target specific option mismatch"
 msgid "target specific builtin not available"
@@ -31014,7 +31067,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -31025,31 +31078,31 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "redeklarasikan disini sebagai %q#D"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "%Harray subscrip dibawah dari array bounds"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -31129,37 +31182,37 @@ msgstr "pemeriksaan pohon: diakses operan %d dari %s dengan %d operan dalam %s,
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari omp_clause %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:13103
+#: tree.c:13105
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:13106
+#: tree.c:13108
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:13112
+#: tree.c:13114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tipe sudah ditinggalkan"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tipe sudah ditinggalkan"
@@ -31184,236 +31237,236 @@ msgstr "tipe sudah ditinggalkan"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "main variant is not defined"
 msgstr "variabel lingkungan \"%s\" tidak terdefinisi"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -31549,92 +31602,92 @@ msgstr "alignmen yang diminta untuk %q+D lebih besar dari alignmen yang diimplem
 msgid "storage size of %q+D isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "penginisialisasi untuk nilai integer/titik-tetap terlalu kompleks"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "penginisialisasi untuk nilai pecahan bukan sebuah konstanta pecahan"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initial value for member %qE"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D dideklarasikan inline setelah dipanggil"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "deklarasi lemah dari %q+D harus mengawali definisi"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "deklarasi lemah dari %q+D harus berupa publik"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "deklarasi lemah dari %q+D tidak didukung"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "hanya aliases lemah yang didukung dalam konfigurasi ini"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref is not supported in this configuration"
 msgid "weakref is not supported in this configuration"
 msgstr "%J weakref tidak didukung dalam konfigurasi ini"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "-pg tidak didukung dalam platform ini"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "weakref %q+D secara ultimate mentarget dirinya sendiri"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "weakref %q+D harus memiliki static linkage"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "alias definitions not supported in this configuration"
 msgstr "%J definisi alias tidak didukung dalam konfigurasi ini"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s tidak didukung untuk konfigurasi ini"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "visibility atribut tidak didukung dalam konfigurasi ini; diabaikan"
@@ -32283,7 +32336,7 @@ msgstr "%qE atribut diabaikan untuk %qE"
 msgid "type was previously declared %qE"
 msgstr "setelah deklarasi sebelumnya %q+D"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -32307,7 +32360,7 @@ msgstr "%qD tidak dideklarasikan dalam %qD"
 msgid "%qE argument is not a function"
 msgstr "membersihkan argumen bukan sebuah fungsi"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "deprecated message is not a string"
@@ -32709,12 +32762,12 @@ msgstr "%<@end%> hilang dalam konteks implementasi"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "disarankan parentheses disekitar assignmen digunakan sebagai nilai kebenaran"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "penggunaan tidak valid dari %<restrict%>"
@@ -32883,12 +32936,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -32997,7 +33050,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "ukuran dari array terlalu besar"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -33009,84 +33062,84 @@ msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "melewatkan argumen %d dari %qE membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "both arguments must be compatible"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "tidak cukup argumen ke fungsi %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Tipe/tingkat tidak cocok dalam argumen '%s' di %L"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "index value is out of bound"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -33094,58 +33147,58 @@ msgstr "konversi dari %qT ke %qT adalah ambigu"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D cannot be declared weak"
 msgid "built-in function %qE must be directly called"
 msgstr "fungsi inline %q+D tidak dapat dideklarasikan lemah"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "ukuran dari array negatif"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -33203,540 +33256,540 @@ msgstr "%qE bukan sebuah format tipe fungsi yang dikenal"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "argumen format string mengikuti argumen yang akan diformat"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "fungsi mungkin menjadi kandidat untuk %qs atribut format"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "hilang $ jumlah operan dalam format"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s tidak mendukung %%n$ jumlah format operan"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "jumlah operan diluar dari jangkauan dalam format"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "argumen format %d digunakan lebih dari sekali dalam format %s"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$ jumlah operan digunakan setelah format tanpa jumlah operan"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "argumen format %d digunakan sebelum digunakan argumen %d dlaam $-gaya format"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "format bukan sebuah string literal, format string tidak diperiksa"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "format bukan sebuah string literal dan tidak ada format argumen"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "format bukan sebuah string literal, tipe argumen tidak diperiksa"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "terlalu banyak argumen untuk format"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "argumen yang tidak digunakan dalam $-gaya format"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "panjang-nol %s format string"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "format adalah sebuah karakter lebar string"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string argument not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "argumen format string bukan sebuah tipe string"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "format string tidak terselesaikan"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s digunakan dengan %<%%%c%>  %s format"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s tidak mendukung %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s tidak mendukung %s dengan %<%%%c%> %s format"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "diulang %s dalam format"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "hilang karakter pengisi di akhir dari format strfmon"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "lebar nol dalam %s format"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "presisi kiri kosong dalam %s format"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "presisi kosong dalam %s format"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s tidak mendukung %qs %s pemodifikasi panjang"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s tidak mendukung %<%%%c%> %s format"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s diabaikan dengan %s dan %<%%%c%> %s format"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s diabaikan dengan %s dalam %s format"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "penggunaan dari %s dan %s bersama dengan %<%%%c%> %s format"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "penggunaan dari %s dan %s bersama dalam %s format"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> hanya menghasilkan 2 angka terakhir dari tahun dalam beberapa lokal"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> hanya menghasilkan 2 angka terakhir dari tahun"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "tidak ada penutup %<]%> untuk %<%%[%> format"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "penggunaan dari %qs pemodifikasi panjang dengan tipe karakter %qc"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s tidak mendukung format %<%%%s%c%> %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "jumlah operan yang dispesifikasikan dengan assignmen yang ditekan"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "jumlah operan yang dispesifikasikan untuk format yang tidak mengambil argumen"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "diulang %s dalam format"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "diulang %s dalam format"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "embedded %<\\0%> dalam format"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "unquoted attribute in format"
 msgstr "%qE atribut diabaikan"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "tidak dapat menon-aktifkan fungsi bawaan %qs"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "spurious akhiran %<%%%> dalam format"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "inconsistent capitalization in format"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "spurious akhiran %<%%%> dalam format"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "diulang %s dalam format"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "diulang %s dalam format"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "diulang %s dalam format"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "spurious akhiran %<%%%> dalam format"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "spurious akhiran %<%%%> dalam format"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Tab character in format at %C"
 msgid "unquoted non-graph characters in format"
 msgstr "Ekstensi: Karakter tab dalam format di %C"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Do not generate #line directives"
 msgid "unterminated quoting directive"
 msgstr "Jangan hasilkan #line direktif"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "tipe karakter konversi %qc dalam format tidak dikenal"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "spurious akhiran %<%%%> dalam format"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "konversi kurang tipe diakhir dari format"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "Proses #ident direktif"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "embedded %<\\0%> dalam format"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "alternatif dialek perakit tidak terselesaikan"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "menulis melalui pointer kosong (argumen %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "membaca melalui pointer kosong (argumen %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "menulis kedalam objek konstan (argumen %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "kelebihan tipe kualifier dalam format argumen (argumen %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%s%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "format %q.*s diduga bertipe %<%s%s%>, tetapi argumen %d memiliki tipe %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs diduga sebuah konstanta argumen"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "format %q.*s diduga bertipe %<%T%s%>, tetapi argumen %d memiliki tipe %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs diduga sebuah konstanta argumen"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> tidak didefinisikan sebagai %<long%> atau %<long long>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "args yang akan diformat bukan %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime format tidak dapat memformat argumen"
@@ -33904,7 +33957,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -33920,17 +33973,17 @@ msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
@@ -33940,7 +33993,7 @@ msgstr "hilang ekspresi peningkatan"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -34599,7 +34652,7 @@ msgid "wrong type argument to %s"
 msgstr "tipe argumen salah ke abs"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow dalam konstanta ekspresi"
@@ -35333,7 +35386,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
@@ -35421,7 +35474,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 msgstr[1] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -35441,7 +35494,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "used here"
 msgid "defined here"
@@ -35463,7 +35516,7 @@ msgstr "\"%s\" bukan sebuah pilihan valid untuk preprosesor"
 msgid "too many input files"
 msgstr "terlalu banyak berkas masukan"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -35497,14 +35550,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -36077,428 +36130,435 @@ msgstr "definisi alias tidak didukung dalam Mach-O; abaikan"
 msgid "profiler support for VxWorks"
 msgstr "dukungan profiler untuk VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "index mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "indeks mask harus berupa sebuah immediate"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "the second argument must be a 4-bit immediate"
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "argumen kedua harus berupa sebuah 4 bit immediate"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "diduga %qT tetapi argumen memiliki tipe %qT"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "diduga %qT tetapi argumen memiliki tipe %qT"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> bukan sebuah string atau angka"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "sampah diakhir dari #pragma GCC java_exceptions"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "Link with the fast floating-point library"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "Hubungkan dengan perpustakaan titik pecahan cepat"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code for the counting ISA extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Keluarkan kode untuk menghitung ekstensi ISA"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "nilai %%h tidak valid"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "fungsi spesifikasi '%s' tidak diketahui"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Spesifikasikan pengurutan alokasi register"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s;"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to -fdebug-prefix-map"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "argumen %qs tidak valid ke -fdebug-prefix-map"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to '%s' option"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "hilang argumen ke pilihan '%s'"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-march%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "pilihan -mcpu=%s konflik dengan pilihan -march="
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s tidak mendukung %s"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "salah bentuk %<#pragma init%>"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -36699,17 +36759,17 @@ msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -36875,12 +36935,12 @@ msgstr ""
 msgid "invalid type for %<asm%> flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -36888,199 +36948,199 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]."
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s diduga sebuah integer literal dalam jangkauan [%d, %d]."
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "pemilih harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "argumen atribut `%s' seharusnya berada diantara 0 sampai 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -37090,307 +37150,307 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC dan -G tidak kompatibel"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "aktifkan dukungan backtrace hanya berarti ketika mengkompile untuk Thumb"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "aktifkan dukungan callee kerja sama yang berarti ketika mengkompile untuk Thumb"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g dengan -mno-apcs-frame mungkin tidak memberikan debugging yang masuk akal"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "tidak dapat menggunakan -mtp=cp15 dengan 16-bit Thumb"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC tidak kompatibel dengan Thumb"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-fjni tidak kompatibel dengan -freduced-reflection"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "target CPU tidak mendukung instruksi THUMB"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "target CPU does not support unaligned accesses"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check tidak kompatibel dengan -mno-apcs-frame"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic dan -macps-reent tidak kompatibel"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS reentrant kode tidak didukung. Diabaikan"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "ukuran batas struktur hanya dapat diset ke %s"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "ukuran batas struktur hanya dapat diset ke %s"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC tidak kompatibel dengan -msingle-pic-base"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= tidak berguna tanpa -fpic"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "tidak dapat menggunakan '%s' untuk register PIC"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition tidak bekerja dalam arsitektur ini"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable dan -msdata=%s tidak kompatibel"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt membutuhkan sebuah AAPCS kompatibel ABI untuk operasi yang sesuai"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi membutuhkan sebuah iwmmxt kapabel cpu"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "target CPU tidak mendukung instruksi THUMB"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard dan VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "tidak dapat menghitung lokasi ril dari parameter terstack"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Tidak terduga akhir dari modul"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "tidak ada register bawah yang tersedia unruk popping register atas"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -37399,24 +37459,24 @@ msgstr "tipe vektori tidak valid untuk atribut %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "nama register: %s tidak dikenal"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -37508,19 +37568,19 @@ msgstr "-pipe tidak didukung"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G dan -static adalah mutually exclusive"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -37815,7 +37875,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "argumen ke fungsi bawaan tidak valid"
@@ -38172,56 +38232,56 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "Lewatkan argumen titik pecahan dalam register titik pecahan"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type of argument %s"
 msgstr "tipe argumen salah ke abs"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "TLS is not implemented for GCN."
 msgstr "DW_LOC_OP %s tidak diimplementasikan"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "Builtin not implemented"
 msgstr "Finalisasi di %L belum diimplementasikan"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "nomor operan diluar dari jangkauan"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -38374,148 +38434,148 @@ msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 msgid "parameter to builtin not valid: %s"
 msgstr "Argumen ke -ffpe-trap tidak valid: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 #| msgid "the third argument must be a 8-bit immediate"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argumen ketiga harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE membutuhkan pilihan isa tidak diketahui"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE membutuhkan pilihan isa %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -38943,160 +39003,160 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -39585,7 +39645,7 @@ msgstr "%qs tidak dapat memiliki baik atribut %<mips16%> dan %<nomips16%>"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -40746,56 +40806,56 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -40917,368 +40977,369 @@ msgstr "angka harus berupa 0 atau 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "sampah diakhir dari #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s hanya menerima 1 argumen"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s tidak didukung untuk konfigurasi ini"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "kombinasi parameter untuk AltiVec intrinsik tidak valid"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dikembalikan dengan referensi: ekstensi bukan standar ABI dengan tidak ada garansi kompabilitas"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dilewatkan dengan referensi: bukan ekstensi standar ABI dengan tidak ada garansi kompabilitas"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs tidak didukung oleh subtarget ini"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "%srtd%s diabaikan dalam mode 64 bit"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "%srtd%s diabaikan dalam mode 64 bit"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s hanya menerima 1 argumen"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "Argumen dari ATANH di %L harus berada didalam jangkauan -1 ke 1"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "argumen kedua dari %q+D seharusnya %<char **%>"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid option to the preprocessor"
 msgid "%qs is only valid for the cell processor"
 msgstr "\"%s\" bukan sebuah pilihan valid untuk preprosesor"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires branch-likely instructions"
 msgid "%qs requires the %qs option"
 msgstr "%qs membutuhkan instruksi branch-likely"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires branch-likely instructions"
 msgid "%qs requires the %qs and %qs options"
 msgstr "%qs membutuhkan instruksi branch-likely"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported with the current options"
 msgstr "%s tidak didukung untuk konfigurasi ini"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -41299,241 +41360,246 @@ msgstr "Gunakan register r2 dan r5"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 membutuhkan arsitektur PowerPC64, mengaktifkan"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power tidak didukung untuk 64 bit Darwin; ini tidak kompatibel dengan perpustakaan C dan C++ yang terpasang"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring tidak didukung di sistem little endian"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-fjni tidak kompatibel dengan -freduced-reflection"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Menggunakan IEEE ekstended presisi long double"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Menggunakan IBM ekstended presisi long double"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s tidak mendukung %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
 #| msgid "unknown vectorization library ABI type (%s) for %sveclibabi=%s %s"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "perpusatakaan vektorisasi tidak dikenal tipe ABI (%s) untuk pilihan %sveclibabi=%s %s"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Butuh sebuah call-clobbered target register"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "tipe abstrak tidak valid %qT untuk %qE"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
@@ -41883,150 +41949,150 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "ukuran frame dari %qs adalah "
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs menggunakan alokasi dinamis stack"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, fuzzy, gcc-internal-format
 #| msgid "Hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia dalam mode ESA/390"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can't be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp tidak dapat digunakan dalam konjungsi dengan -msoft-float"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float tidak didukung dalam kombinasi"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "ukuran stack harus lebih besar dari nilai penjaga stack"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard mengimplikasikan penggunaan dari -mstack-size"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "atribut %qs tidak didukung hanya untuk SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -42490,8 +42556,8 @@ msgstr "%qs atribut hanya berlaku ke variabel"
 msgid "could not read the BRIG file"
 msgstr "tidak dapat menulis ke berkas response %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "nilai void tidak diabaikan karena ini seharusnya"
@@ -42785,7 +42851,7 @@ msgstr "deklarasi dari %q+D membayangi bukan-variabel sebelumnya"
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
@@ -42863,7 +42929,7 @@ msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H (Setiap identifier yang tidak dideklarasikan hanya dilaporkan sekali)"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "label %qE direferensikan diluar dari fungsi apapun"
@@ -42895,7 +42961,7 @@ msgstr "melompat kedalam pernyataan ekspresi"
 msgid "duplicate label declaration %qE"
 msgstr "duplikasi deklarasi label %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "duplikasi label %qD"
@@ -43117,7 +43183,7 @@ msgstr "tidak dapat meletakan objek dengan bagian volatile kedalam register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "tidak terinisialisasi const %qD"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -43499,7 +43565,7 @@ msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
@@ -43838,7 +43904,7 @@ msgstr "nested redefinisi dari %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
@@ -43890,7 +43956,7 @@ msgstr "struct tidak memiliki anggota bernama"
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -43930,7 +43996,7 @@ msgstr "nested redefinisi dari %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeklarasi dari %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -43962,7 +44028,7 @@ msgstr "overflow dalam nilai enumerasi"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -43996,7 +44062,7 @@ msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -44126,12 +44192,12 @@ msgstr "argumen %qD tidak cocok dengan prototipe bawaan"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -44140,278 +44206,278 @@ msgstr "parameter %qD dinisialisasi"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> deklarasi inisial loop hanya diijinkan dalam mode C99"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "gunakan pilihan -std=c99 atau -std=gnu99 untuk mengkompile kode anda"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel statis %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari bukan-variabel %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "duplikasi %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support fixed-point types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C tidak mendukung titik pecahan desimal"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "tipe titik tetap tidak didukung untuk target ini"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE gagal untuk menjadi sebuah typedef atau tipe bawaan"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> digunakan dengan %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s tidak mendukung %s"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> sebelum %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> sebelum %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "multiple class penyimpanan dalam deklarasi penspesifikasi"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> digunakan tanpa %<_Fract%> atau %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "jumlah geser kanan >= lebar dari tipe"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -44433,7 +44499,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -44483,7 +44549,7 @@ msgid "unknown type name %qE"
 msgstr "nama register: %s tidak dikenal"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -44505,7 +44571,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -44523,8 +44589,8 @@ msgstr "atribut diabaikan di template instantiation"
 msgid "unexpected attribute"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -44566,7 +44632,7 @@ msgstr "%<auto%> dalam file-scope deklarasi kosong"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "diduga %<,%> atau %<,%>"
@@ -44596,7 +44662,7 @@ msgstr "ISO C90 tidak mendukung %<long long%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "diduga string literal"
@@ -44630,7 +44696,7 @@ msgstr "ekspresi integral %qE bukan konstan"
 msgid "static assertion failed: %E"
 msgstr "static assertion gagal: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -44680,14 +44746,14 @@ msgstr "template argumen %d tidak valid"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "koma di akhir dari daftar pengenumerasi"
@@ -44775,7 +44841,7 @@ msgstr "diduga deklarasi penspesifikasi atau %<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "parameter pack harus berada di akhir dari daftar parameter"
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute does not take any arguments"
@@ -44787,7 +44853,7 @@ msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -44847,7 +44913,7 @@ msgstr "ISO C90 melarang pencampuran deklarasi dan kode"
 msgid "expected %<}%> before %<else%>"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> tanpa sebuah sebelumnya %<if%>"
@@ -44862,7 +44928,7 @@ msgstr "label diakhir dari pernyataan compound"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "diduga pernyataan"
@@ -44887,17 +44953,17 @@ msgstr "sebuah label hanya dapat menjadi bagian dari sebuah pernyataan dan sebua
 msgid "expected identifier or %<*%>"
 msgstr "diduga pengidentifikasi atau %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<if%>"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<else%>"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -44920,12 +44986,12 @@ msgstr "multiple atribut interupsi tidak diijinkan"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "register tidak valid dalam instruksi"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44942,8 +45008,8 @@ msgstr "hilang sentinel dalam pemanggilan fungsi"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -44974,12 +45040,12 @@ msgstr "ISO C melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -45410,68 +45476,68 @@ msgstr "diduga penspesifikasi deklarasi"
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%J alamat daerah atribut tidak dapat dispesifikasikan untuk fungsi"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
@@ -45482,19 +45548,19 @@ msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
@@ -45516,59 +45582,59 @@ msgstr "diduga %<,%> atau %<,%>"
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -45591,13 +45657,13 @@ msgstr "%<num_threads%> nilai harus positif"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
@@ -45609,24 +45675,24 @@ msgstr "%<num_threads%> nilai harus positif"
 msgid "expected constant integer expression"
 msgstr "diduga ekspresi integer"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -45643,60 +45709,60 @@ msgstr "num_threads ekspresi harus integral"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Elemen tidak diduga"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "baik %<long%> dan %<void%> dalam penspesifikasi deklarasi"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
@@ -45707,7 +45773,7 @@ msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -45748,25 +45814,25 @@ msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -45784,81 +45850,81 @@ msgstr "jenis penjadwalan tidak valid"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -45875,7 +45941,7 @@ msgstr "%H%qE belum pernah dideklarasikan"
 msgid "expected function name"
 msgstr "diduga nama class"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -45886,72 +45952,72 @@ msgstr "%q+D bukan sebuah fungsi,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -45961,63 +46027,63 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "diduga %<:%>, %<,%>, %<,%>, %<}%> atau %<__attribute__%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
@@ -46027,76 +46093,76 @@ msgstr "diduga iterasi deklarasi atau inisialisasi"
 msgid "not enough perfectly nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -46112,64 +46178,64 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "expected trait selector name"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, fuzzy, gcc-internal-format
 #| msgid "constructor not allowed for non-vector types"
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "konstruktor tidak diperbolehkan untuk tipe bukan-vektor"
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "score argument must be non-negative"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "diduga string literal"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
@@ -46181,13 +46247,13 @@ msgstr "diduga %<{%>"
 msgid "variant %qD is not a function"
 msgstr "%q+D bukan sebuah fungsi,"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -46197,34 +46263,34 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -46283,44 +46349,44 @@ msgstr "diduga pengidentifikasi atau %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -46336,27 +46402,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -46366,7 +46432,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -46383,7 +46449,7 @@ msgstr "%Hparallel yang melingkupi"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "penggunaan tidak valid dari ekspresi void"
@@ -46513,7 +46579,7 @@ msgstr "dereferensi penunjuk %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscrip bukan sebuah integer"
@@ -46538,7 +46604,7 @@ msgstr "ISO C90 melarang subscripting array bukan lvalue"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -46659,18 +46725,18 @@ msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C+
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "perbandingan dengan string literal menghasilkan perilaku yang tidak dispesifikasikan"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "perbandingan diantara penunjuk dan integer"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -46697,7 +46763,7 @@ msgstr "penunjuk ke sebuah fungsi digunakan dalam pengurangan"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -46964,7 +47030,7 @@ msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast ke penunjuk dari integer dari ukuran yang berbeda"
@@ -47158,7 +47224,7 @@ msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
@@ -47333,7 +47399,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array dari tipe yang tidak sesuai terinisialisasi dari konstanta string"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
@@ -47365,7 +47431,7 @@ msgstr "elemen penginisialisasi tidak dapat dihitung di waktu load"
 msgid "invalid initializer"
 msgstr "penginisialisasi tidak valid"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
@@ -47514,7 +47580,7 @@ msgstr "kelebihan elemen dalam penginisialisasi skalar"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C melarang %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
@@ -47556,7 +47622,7 @@ msgstr "pilihan %<long%> ekspresi tidak diubah ke %<int%> dalam ISO C"
 msgid "case label is not an integer constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
@@ -47566,17 +47632,17 @@ msgstr "label case tidak dalam label pernyataan switch"
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "pernyataan break digunakan dengan OpenMP untuk loop"
@@ -47593,7 +47659,7 @@ msgstr "pernyataan break tidak dalam loop atau switch"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "pernyataan dengan tidak ada efek"
@@ -47603,23 +47669,23 @@ msgstr "pernyataan dengan tidak ada efek"
 msgid "expression statement has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -47673,7 +47739,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
@@ -47705,56 +47771,56 @@ msgstr "menggunaka nilai tipe union dimana skalar dibutuhkan"
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -47766,8 +47832,8 @@ msgstr "%qE bukan sebuah variabel dalam clause %qs"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
@@ -47950,12 +48016,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
@@ -47980,8 +48046,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
@@ -47997,19 +48063,19 @@ msgstr "%qD muncul lebih dari sekali dalam data clauses"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
@@ -48085,127 +48151,127 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%qs variable is not a pointer"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "argumen pertama ke %<va_arg%> bukan dari tipe %<va_list%>"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -48417,875 +48483,875 @@ msgid "expected case label"
 msgstr "diduga nama class"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T, %T) <built-in>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T) <built-in>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s %D(%T) <built-in>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s %T <conversion>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D <near match>"
 msgid "%s%#qD (near match)"
 msgstr "%s %+#D <near match>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  inherited here"
 msgstr "%J  ketika diinisialisasi disini"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 #| msgid "conversion to %qT from boolean expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "tidak dapat mengubah %qE ke %qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%D(%A)%> adalah ambigu"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "pointer-ke-anggota fungsi %E tidak dapat dipanggil tanpa sebuah objek; pertimbangkan menggunakan .* atau ->*"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "tidak ada yang cocok untuk panggilan ke %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "panggilan dari %<(%T) (%A)%> adalah ambigu"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "konversi ambigu untuk array subscript"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Operator pengguna:\n"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s untuk ternary %<operator?:%> dalam %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s untuk %<operator[]%> dalam %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s untuk %qs dalam %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "  or %<operator=(const %T&)%>"
 msgid "%<operator %s%>"
 msgstr "  atau %<operator=(const %T&)%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan kedua ke operator kondisional bertipe %<void%>, tetapi operan ketika bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan ketiga ke opertor kondisional bertipe %<void%>, tetapi operan kedua bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "operan ke ?: memiliki tipe berbeda %qT dan %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "perbandingan antara %q#T dan %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "tidak ada dealokasi fungsi yang berhubungan untuk %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "tidak cocok %<operator %s%> untuk %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D tidak dapat diakses"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "melewatkan koson ke argumen bukan penunjuk %P dari %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "mengubah ke tipe bukan penunjuk %qT dari KOSONG"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 #| msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  inisialisasi argumen %P dari %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "terlalu banyak kurung diantara penginisialisasi untuk %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "mengubah ke %qT untuk daftar penginisialisasi akan menggunakan konstruktor eksplist %qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "tidak dapat mengikat bitfield %qE ke %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "tidak dapat mengikat packed field %qE ke %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "tidak dapat mengikat rvalue %qE ke %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "tidak dapat melewatkan objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "tidak dapat menerima objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumen baku untuk parameter %d dari %qD belum diparse"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT bukan sebuah dasar yang bisa diakses dari %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use value-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use copy-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%s(%A)%> adalah ambigu"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "tidak dapat memanggil anggota fungsi %qD tanpa objek"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "melewatkan %qT memilih %qT diatas %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "memilih %qD diatas %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  karena urutan konversi untuk argumen lebih baik"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "argumen baku tidak cocok dalam kelebihan beban resolusi"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -49321,573 +49387,573 @@ msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis ma
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "spesifikasi akses konflik untuk metoda %q+D, diabaikan"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "spesifikasi akses konflik untuk field %qE, diabaikan"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  karena dari metoda lokal %q+#D dengan nama sama"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local method %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  karena dari anggota lokal %q+#D dengan nama sama"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "semua anggota fungsi dalam kelas %qT adalah private"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T hanya mendefinisikan sebuah desktruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T hanya mendefinisikan konstruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "tidak ada unik final overrider untuk %qD dalam %qT"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D telah disembunyikan"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  oleh %q+D"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bit-field %q+#D dengan tipe bukan integral"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit-field %q+D lebar bukan sebuah konstanta integer"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "lebar negatif dalam bit-field %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "lebar nol untuk bit-field %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "lebar dari %q+D melebihi tipenya"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D terlalu kecil untuk menjaga seluruh nilai dari %q#T"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "anggota %q#D dengan konstruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "anggota %q+#D dengan penempatan salinan operator tidak diijinkan dalam union"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D mungkin bukan statis karena ini adalah anggota dari sebuah union"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "field %q+D secara tidak valid mendeklarasikan tipe fungsi"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "mengabaikan atribut packed karena dari unpacked non-POD field %q+#D"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "multiple field dalam union %qT tida terinisialisasi"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "field %q+#D dengan nama sama seperti class"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T memiliki anggota data penunjuk"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  tetapi tidak override %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  atau %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  tetapi tidak override %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "penginisialisasi dispesifikasikan untuk metode %q+D bukan virtual"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "Java class %qT tidak dapat memiliki sebuah destruksi"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referensi bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "anggota const bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direct base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtual base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "ofset dari %q+D adalah bukan ABI komplian dan mungkin berubah dalam versi GCC yang akan datang"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T memiliki fungsi maya dan dapat diakses bukan virtual desktruktor"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "tipe %qs memiliki anggota fungsi virtual"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#D is marked %<dllimport%>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "mencoba menyelesaikan struct, tetapi ditendang keluar karena error parse sebelumnya"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "bahasa string %<\"%E\"%> tidak dikenal"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "tidak dapat meresolf fungsi overloaded %qD berdasar dari konversi ke tipe %qT"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "tidak cocok mengubah fungsi %qD ke tipe %q#T"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "mengubah fungsi overloaded %qD ke tipe %q#T adalah ambigu"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "mengasumsikan penunjuk ke anggota %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tidak cukup informasi mengenai tipe"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "tidak dapat mengubah %qE dari tipe %qT ke tipe %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -49975,7 +50041,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
@@ -50037,7 +50103,7 @@ msgstr "Mencoba untuk mengalokasikan array yang telah dialokasikan"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "deklarasi dari %qD membayangi sebuah lokal sebelumnya"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
@@ -50101,419 +50167,418 @@ msgstr "ekspresi integral %qE bukan konstan"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "dipanggil dari sini"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not initialized"
 msgid "%qD used in its own initializer"
 msgstr "%qE tidak terinisialisasi"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D adalah private"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD belum pernah dideklarasikan dalam lingkup ini"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "inline assembly is not a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT alters %qT constant value"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "konversi ke %qT mengubah nilai konstanta %qT"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "non-function in gimple call"
 msgid "function concept must be called"
 msgstr "bukan fungsi dalam panggilan gimple"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
 msgstr "Tidak terduga akhir dari berkas dalam '%s'"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qD does not have integral type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -50567,7 +50632,7 @@ msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe s
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "casting %qT ke %qT tidak medereferensi penunjuk"
@@ -50611,327 +50676,327 @@ msgstr "%q#T digunakan dimana seubah nilai titik pecahan telah diduga"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "konversi dari %qT ke tipe bukan-skalar %qT diminta"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "pseudo-destruktor tidak dipanggil"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "apliasi tidak valid dari %qs ke tipe tidak lengkap %qT"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "pernyataan dengan tidak ada efek"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "mengubah NULL ke tipe bukan penunjuk"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "ambigu tipe konversi baku dari %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  kandidat konversi termasuk %qD dan %qD"
@@ -51004,7 +51069,7 @@ msgstr "dari deklarasi sebelumnya %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -51217,12 +51282,12 @@ msgstr "deklarasi sebelumnya dari %q+D ada disini"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "definisi terhapus dari %qD"
@@ -51235,50 +51300,50 @@ msgstr "definisi terhapus dari %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: atribut visibility diabaikan karenanya"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "redefinisi dari %q#T"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -51286,714 +51351,714 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local deklarasi dari %q+D mengikuti deklarasi bukan-thread-lokal"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local deklarasi dari %q+D mengikuti deklarasi thread-local"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  dari sini"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  keluar OpenMP structured block"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  menyilangi inisialisasi dari %q+#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  memasuki blok percobaan"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  mamasuki blok penangkapan"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  memasuki blok terstruktur OpenMP"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named %q#T in %q#T"
 msgid "no type named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah class template"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah tipe"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "parameter template tidak cocok dengan template"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "alignmen yang diminta bukan kelipatan dari 2"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan konstruktor tidak diijinkan dalam kumpulan anonymous"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam kumpulan anoymous"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan operator penempatan salin tidak diperbolehkan dalam kumpulan anonymous"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "atribut untuk %q+#T harus mengikuti kata kunci %qs"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "multiple tipe dalam satu deklarasi"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ menghambat struct anonymous"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> hanya dapat dispesifikasikan untuk konstruktor"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> telah diabaikan dalam deklarasi ini"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qs cannot be used for type declarations"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe kelas %qT diluar dari definisi"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe dependen %qT tanpa sebuah deklarasi yang berasosiasi"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan decltype)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarasi dari %q#D memiliki %<extern%> dan terinisialisasi"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tidak mengijinkan %<%T::%D%> untuk didefinisikan sebagai %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "duplikasi inisialisasi dari %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabel %q#D memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "kumpulan %q#D memiliki tipe tidak lengkap dan tidak dapat didefinisikan"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nama digunakan dalam sebuah gaya GNU diperuntukan penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "bukan trivial designated penginisialisasi tidak didukung"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  anda dapat memperbaiki ini dengan menghapus penginisialisasi"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipe tidak valid %qT sebagai penginisialisasi untuk sebuah vektor dari tipe %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elemen dari array %q#T memiliki tipe tidak lengkap"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ukuran-variabel compound literals"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "objek skalar %qD membutuhkan satu elemen dalam penginisialisasi"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "dalam C++98 %qD harus diinisialisasi dengan konstruktor, bukan dengan %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "array %qD diinisialisasi dengan tanda kurung string literal %qE"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "penginisialisasi tidak valid untuk anggota statis  dengan konstruktor"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(diluar dari kelas inisialisasi dibutuhkan)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "parameter %qD dinisialisasi"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "membayangi tipe deklarasi sebelumnya dari %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "%u name provided for structured binding"
@@ -52001,215 +52066,215 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%Hpenginisialisasi disediakan untuk fungsi"
 msgstr[1] "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "tidak dapat menguraikan alamat"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -52501,7 +52566,7 @@ msgstr "overflow dalam dimensi array"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
@@ -52685,7 +52750,7 @@ msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
@@ -52904,891 +52969,891 @@ msgstr "%qE atribut diabaikan"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> fungsi mengembalikan nilai bukan-void"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member %<%T::%s%> within %qT"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "typedef may not be a member function definition"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%H%<[*]%> tidak diijinkan selain dalam sebuah deklarasi"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "tidak dapat mendeklarasikan parameter %q+D untuk menjadi tipe abstrak %qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "a destructor cannot be %qs"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "a constructor cannot be %<concept%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "tidak dapat membuka %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ melarang overloading operator ?:"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -53800,97 +53865,97 @@ msgstr "%qT direferensikan sebagai enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -53900,78 +53965,78 @@ msgstr "tipe yang digaris bawahi %<%T%> dari %<%T%> harus berupa sebuah tipe int
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -54012,7 +54077,7 @@ msgstr "tidak dapat menghapus sebuah fungsi. Hanya penunjuk-ke-objek yang valid
 msgid "deleting %qT is undefined"
 msgstr "menghapus %qT tidak terdefinisi"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "template deklarasi dari %q#D"
@@ -54023,7 +54088,7 @@ msgstr "template deklarasi dari %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "daftar parameter template yang disediakan tidak cocok dengan paramter template dari %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destruktor %qD dideklarasikan sebagai anggota template"
@@ -54381,172 +54446,172 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
 msgstr "fungsi %q+D terhapus"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "menggunakan %<typename%> diluar dari template"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "tidak ada argumen"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, fuzzy, gcc-internal-format
 #| msgid "%Hreference to %<%T::%D%> is ambiguous"
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "%Hreferensi ke %<%T::%D%> adalah ambigu"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a member of %qD"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%H%qD bukan sebuah anggota dari %qD"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a member of %qD"
 msgid "%qD is not a member of %qD"
 msgstr "%H%qD bukan sebuah anggota dari %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%H%<::%D%> belum pernah dideklarasikan"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared"
@@ -54744,366 +54809,366 @@ msgstr "nilai-inisialisasi dari referensi"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD seharusnya diinisialisasi dalam daftar anggota inisialisasi"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD digunakan tidak terinisialisasi dalam fungsi ini"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "anggota const tidak terinisialisasi %qD"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "dasar %qT akan diinisialisasi setelah"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  dasar %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  ketika diinisialisasi disini"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J multiple penginisialisasi diberikan untuk %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%J multiple penginisialisasi diberikan untuk dasar %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J inisialisasi untuk multiple anggota dari %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D adalah sebuah anggota data statis; ini hanya dapat diinisialisasikan di definisinya"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang tidak memiliki kelas dasar"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang menggunakan turunan multiple"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD keduanya sebuah dasar langsung dan sebuah virtual base tidak langsung"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "tipe tidak lengkap %qT tidak memiliki anggota %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "penunjuk tidak valid ke bit-field %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "integer overflow dalam ekspresi"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' not allowed in expression at %L"
 msgid "variably modified type not allowed in new-expression"
 msgstr "Dummy argumen '%s' tidak diijinkan dalam ekspresi di %L"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "tipe %<void%> tidak valid untuk new"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "tidak ada %qD yang sesuai yang ditemukan dalam kelas %qT"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "permintaan untuk anggota %qD adalah ambigu"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new tidak dapat diaplikasikan untuk mereferensikan sebuah tipe"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "penginisialisasi berakhir secara prematur"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukuran array tidak diketahui dalam delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
@@ -55272,13 +55337,13 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can't use default assignment operator"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "anggota const bukan static %q#D, tidak dapatmenggunakan operator assignmen baku"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can't use default assignment operator"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -55308,170 +55373,174 @@ msgstr "tipe konfliks untuk %q+D"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class Java"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class Java"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD harus mengambil %<void%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr ""
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD telah menjadi sebuah friend dari %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot default compare union %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "tidak dapat membuat penunjuk ke anggota referensi %qD"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T member"
 msgid "cannot default compare anonymous union member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "synthesized method %qD first required here "
 msgid "synthesized method %qD first required here"
 msgstr "metode yang disintesa %qD pertama dibutuhkan disini "
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "union member %q+D with non-trivial %qD"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "initializer for %q#D is invalid"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "deklarasi extern dari %q#D tidak cocok"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected signature: %qD"
 msgstr "diduga pernyataan"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be defaulted"
 msgid "a template cannot be defaulted"
 msgstr "%qD tidak dapat dibakukan"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD tidak dapat dibakukan"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "defaulted function %q+D with default argument"
@@ -55517,230 +55586,230 @@ msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklarasi dari %q#D membayangi sebuah parameter"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "global deklarasi %q+#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
 msgstr "konflik dengan deklarasi sebelumnya %q+#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> names desktruktor"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qE"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD seharusnya telah dideklarasikan didalam %qD"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD atribut tidak berarti karena anggota dari anonymous namespace memperoleh simbol lokal"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "atribut %qD direktif diabaikan"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' di %L adalah ambigu"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namespace alias %qD tidak diijinkan disini, diasumsikan %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX memasuki pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -55769,7 +55838,7 @@ msgstr "pengidentifikasi %<%s%> akan menjadi sebuah kata kunci dalam C++0x"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -55798,7 +55867,7 @@ msgstr "%H%<::%E%> belum pernah dideklarasikan"
 msgid "request for member %qE in non-class type %qT"
 msgstr "%Hpermintaan untuk anggota %qE dalam tipe bukan kelas %qT"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -55893,7 +55962,7 @@ msgstr "%Htemplate-id tidak valid"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "sebuah cast ke sebuah tipe selain dari sebuah integral atau tipe enumerasi tidak dapat muncul dalam sebuah ekspresi konstan"
@@ -56037,7 +56106,7 @@ msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
@@ -56171,7 +56240,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -56289,13 +56358,13 @@ msgstr "%Hdeklarasi dari %<~%T%> sebagai anggota dari %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%Htypedef-nama %qD digunakan sebagai desktruktor deklarator"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "diduga specifier-qualifier-list"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bukan sebuah template"
@@ -56335,7 +56404,7 @@ msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 msgid "expected nested-name-specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in casts"
@@ -56353,7 +56422,7 @@ msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -56369,7 +56438,7 @@ msgstr "ISO C++ melarang compound literals"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "penggunaan tidak valid dari %qD"
@@ -56397,1043 +56466,1048 @@ msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray bound forbidden after parenthesized type-id"
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "%Harray bound dilarang setelah parenthesized tipe id"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "penggunaan dari gaya-lama cast"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> operator will be treated as two right angle brackets in C++0x"
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%H%<>>%> operator akan diperlakukan sebagai dua sudut brackets dalam C++0x"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "disarankan tanda kurung disekeliling ekspresi %<>>%>"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C tidak mengijinkan kelebihan %<;%> diluar dari sebuah fungsi"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Tidak terduga akhir dari modul"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "already captured %qD in lambda expression"
 msgstr "operan tidak valid dalam ekspresi unary"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a reference type"
 msgid "%<this%> cannot be captured by reference"
 msgstr "new tidak dapat diaplikasikan untuk mereferensikan sebuah tipe"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "duplikasi %<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcase label %qE not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "%Hlabel case %qE tidak dalam sebuah pernyataan switch"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "condition declares a function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "kelebihan %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__label__%> not at the beginning of a block"
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%H%<__label__%> tidak berada diawal dari sebuah blok"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmixing declarations and function-definitions is forbidden"
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "%Hpencampuran deklarasi dan definisi fungsi dilarang"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "deklarasi kosong"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<friend%> used outside of class"
 msgid "%<friend%> used outside of class"
 msgstr "%H%<friend%> digunakan diluar dari kelas"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%H%<auto%> akan mengubah arti dalam C++0x; mohon hapus itu"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D tidak valid dalam %q#T"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "type-specifier invalid in lambda"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, fuzzy, gcc-internal-format
 #| msgid "%Hclass definition may not be declared a friend"
 msgid "class definition may not be declared a friend"
 msgstr "%Hdefinisi kelas mungkin tidka dideklarasikan sebagai friend"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in explicit-specifier"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "%Honly constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anachronistic gaya-lama kelas dasar penginisialisasi"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (sebuah anggota terkualifikasi secara implisit adalah sebuah tipe)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "operan tidak terduga"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter packs cannot have default arguments"
 msgid "template parameter packs cannot have default arguments"
 msgstr "%Htemplate parameter pack tidak dapat memiliki argumen baku"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> adalah sebuah penyebutan alternatif untuk %<[%>. Masukan spasi diantara %<<%> dan %<::%>"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(jika anda menggunakan %<-fpermissive%> G++ akan menerima kode anda)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid template-argument-list"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "%<<::%> cannot begin a template-argument list"
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "parse error in template argument list"
 msgstr "%Hparse error dalam daftar argumen template"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
 msgstr "diduga pernyataan"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnon-template %qD used as template"
 msgid "non-template %qD used as template"
 msgstr "%Hbukan-template %qD digunakan sebagai template"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "gunakan %<%T::template %D%> untuk mengindikasikan bahwa ini adalah template"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate specialization with C linkage"
 msgid "template specialization with C linkage"
 msgstr "%Hspesialisasi template dengan C linkage"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%H%qE tidak bernama sebuah tipe"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "Recognize GNU-defined keywords"
 msgid "concept defined here"
 msgstr "Kenali kata kunci didefinisikan GNU"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklarasi %qD tidak mendeklarasikan apapun"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "atribut diabaikan di elaborated type penspesifikasi yang tidak memforward sebuah deklarasi"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktifkan instantiation template otomatis"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in namespace %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam namespace %qD yang tidak dilingkupi %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam %qD yang tidak dilingkup %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, fuzzy, gcc-internal-format
 #| msgid "%Hextra qualification not allowed"
 msgid "extra qualification not allowed"
 msgstr "%Hekstra pengkualifikasi diabaikan"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD tidak didefinisikan diluar dari jangkauan fungsi"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT bukan sebuah namespace"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD tidak didefinisikan diluar dari jangkauan fungsi"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a function-definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "initializer provided for function"
 msgstr "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -57443,493 +57517,493 @@ msgstr "%H%<%T::%E%> bukan sebuah tipe"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of constructor as a template"
 msgid "invalid use of constructor as a template"
 msgstr "%Hpenggunaan tidak valid dari konstruktor sebagai sebuah template"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "penggunaan %<%T::%D%> daripada %<%T::%D%> untuk menamai konstruktor dalam sebuah nama berkualifikasi"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is a namespace"
 msgid "%qD is a namespace"
 msgstr "%H%qD adalah sebuah namespace"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate cv-qualifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple ref-qualifiers"
 msgstr "multiple pemanggil inline"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "hilang target makefile setelah %qs"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdefault arguments are only permitted for function parameters"
 msgid "default arguments are only permitted for function parameters"
 msgstr "%Hargumen baku hanya diijinkan untuk parameter fungsi"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack %qD cannot have a default argument"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack cannot have a default argument"
 msgid "template parameter pack cannot have a default argument"
 msgstr "%Htemplate parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid class name in declaration of %qD"
 msgid "invalid class name in declaration of %qD"
 msgstr "%Hnama kelas tidak valid dalam deklarasi dari %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, fuzzy, gcc-internal-format
 #| msgid "%Han explicit specialization must be preceded by %<template <>%>"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%Hsebuah eksplisit spesialisasi harus diawali oleh %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprevious definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%Hdefinisi sebelumnya dari %q+#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "diduga nama class"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "%Hsebuah class-key harus digunakan ketikan mendeklarasikan sebuah friend"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "friend declaration does not name a class or function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "pure-specifier on function-definition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 #| msgid "invalid AE type specified (%s)\n"
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "tipe AE yang dispesifikasikan (%s) tidak valid\n"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (kelas dasar  adalah sebuah tipe implisit)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "expression must be enclosed in parentheses"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "posisi yang diminta bukan sebuah konstanta integer"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "alignmen yang diminta bukan sebuah konstanta"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -57939,621 +58013,621 @@ msgstr "%Hterlalu sedikit template-parameter-list"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qT defined as %qs here"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "diduga ekspresi integer"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option tidak diijinkan didalam fungsi"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "konversi baku tidak diijinkan dalam konteks ini"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -58849,7 +58923,7 @@ msgstr "pola ekspansi %<%E%> berisi tidak ada argumen packs"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameter packs tidak diekspan dengan %<...%>:"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -58878,73 +58952,73 @@ msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 msgid "template parameter %qD declared here"
 msgstr "tipe parameter template %qT dideklarasikan %<friend%>"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack argumen %qE harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack argumen %qT harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -58952,19 +59026,19 @@ msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "tipe %qT dari template argumen %qE tergantung di parameter template"
 msgstr[1] "tipe %qT dari template argumen %qE tergantung di parameter template"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "tidak ada argumen baku untuk %qD"
@@ -58972,53 +59046,53 @@ msgstr "tidak ada argumen baku untuk %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE harus berada di akhir dari daftar parameter template"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumen baku untuk parameter dari tipe %qT memiliki tipe %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parameter %qD dideklarasikan void"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -59029,58 +59103,58 @@ msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definisi template dari bukan template %q#D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "diduga %d tingkat dari parm template untuk %q#D, diperoleh %d"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  tetapi %d dibutuhkan"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "gunakan template<> untuk spesialisasi eksplisit"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "penspesifikasi template tidak dispesifikasikan dalam deklarasi dari %qD"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclared with %d template parameter"
@@ -59088,7 +59162,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeklarasikan dengan %d parameter template"
 msgstr[1] "redeklarasikan dengan %d parameter template"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter(s)"
 msgid "previous declaration %qD used %d template parameter"
@@ -59096,478 +59170,478 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 msgstr[1] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parameter template %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT bukan sebuah anggota dari %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs tidak valid untuk %qs"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena string literal tidak dapat digunakan dalam konteks ini"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "in template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "akumulator bukan sebuah konstanta integer"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  diduga sebuah template dari tipe %qD, diperoleh %qD"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
@@ -59585,308 +59659,308 @@ msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in comparison expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "operan tidak valid dalam ekspresi perbandingan"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -59899,149 +59973,149 @@ msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bukan sebuah namespace"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -60268,7 +60342,7 @@ msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "tidak valid pengkualifikasi lingkup dalam nama pseudo-destruktor"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
@@ -60319,7 +60393,7 @@ msgstr "spesifikasi kelas dasar tidak valid"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
@@ -60427,7 +60501,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -60470,7 +60544,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
@@ -60614,131 +60688,131 @@ msgstr "%qD muncul lebih dari sekali dalam data clauses"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "reimplementasi dari class %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -61018,878 +61092,878 @@ msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah c
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "tipe kanonikal berbeda untuk tipe identik %T dan %T"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "tipe titik kanonikal sama untuk tipe berbeda %T dan %T"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplikasi tidak valid dari %qs ke anggota fungsi"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<sizeof%> ke sebuah bit-field"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<sizeof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<__alignof%> ke sebuah bit-field"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<__alignof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "akses tidak valid ke anggota data tidak statis %qD dari objek KOSONG"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "tipe objek %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "tipe yang sedang dihancurkan adalah %qT, tetapi destruktor merefer ke %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT bukan sebuah basis dari %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bukan sebuah penunjuk-ke-objek tipe"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objek hilang dalam penggunaan dari %qE"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ melarang pemanggilan %<::main%> dari dalam aplikasi"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "harus menggunakan %<.*%> atau %<->*%> untuk memanggil penunjuk-ke-anggota fungsi dalam %<%E (...)%>, contoh %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to member function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to member function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "terlalu banyak argumen ke fungsi"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "terlalu sedikit argumen ke fungsi"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P dari %qD memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "mengasumsikan cast ke tipe %qT dari fungsi overloaded"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL digunakan dalam aritmetik"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ melarang perbandingan diantara penunjuk dan integer"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "perbandingan tidak berurut di argumen bukan titik pecahan"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operang tidak valid untuk tipe %qT dan %qT ke binari %qO"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk dari tipe %<void *%> dalam pengurangan"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah metoda  dalam pengurangan"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "penggunaan tidak valid dari sebuah penunjuk ke sebuah tipe tidak lengkap dalam aritmetik penunjuk"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "penggunaan tidak valid dari %qE untuk membentuk sebuah penunjuk ke anggota fungsi"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  sebuah kualified-id dibutuhkan"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "tanda kurung disekitar %qE tidak dapat digunakan untuk membentuk sebuah penunjuk-ke-anggota-fungsi"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari tidak terkualifikasi atau bertanda kurun anggota bukan statis fungsi untuk membentuk sebuah penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah anggota fungsi terikat ke sebuah bentuk penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ melarang mengambil alamat dari fungsi %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "tidak dapat membuat penunjuk ke anggota referensi %qD"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "tidak dapat mengambil alamat dari bit-field %qD"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "taking address of an immediate function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ melarang mengurangi sebuah enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ melarang meningkatkan sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ melarang mengurangi sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "alamat dari variabel eksplisit register %qD diminta"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "alamat yang diminta untuk %qD, yang dideklarasikan %<register%>"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away constness"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "tidak valid static_cast dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "mengubah dari %qT ke %qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "cast dari %qT ke %qT kehilangan presisi"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast dari %qT ke %qT menaikan alignmen yang dibutuhkan dari tipe target"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ melarang casting diantara penunjuk ke fungsi dan penunjuk ke objek"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang bukan sebuah penunjuk, referensi, ataupun sebuah tipe penunjuk-ke-anggota-data"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang merupakan sebuah penunjuk atau referensi ke sebuah tipe fungsi"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "const_cast tidak valid dari sebuah rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "const_cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ melarang casting ke sebuah tipe array %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  dalam evaluasi dari %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipe tidak kompatibel dalam assignmen dari %qT ke %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array digunakan sebagai penginisialisasi"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "assignmen array tidak valid"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dalam penunjuk ke anggota fungsi konversi"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "penunjuk ke anggota konversi melalui basis maya %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dalam penunjuk ke anggota konversi"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "dalam melewatkan argumen %P dari %q+D"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "referensi ke variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in return statement"
 msgid "redundant move in return statement"
 msgstr "operan tidak valid dalam pernyataan return"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "tidam dapat kembali dari sebuah penanganan dari sebuah fungsi-coba-blok dari sebuah konstruktor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "hilang penginisialisasi"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> harus tidak mengembalikan KOSONG kecuali ini dideklarasikan %<throw()%> (atau ada dalam pengaruh -fcheck-new )"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -62184,114 +62258,114 @@ msgstr "kurung disekitar penginisialisasi skalar"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "prototipe untuk %q#D tidak cocok dengan kelas apapun %qT"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -62533,10 +62607,10 @@ msgstr "Referensi array di %C tidak dapat memiliki lebih dari %d dimensi"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "Referensi array di %C tidak dapat memiliki lebih dari %d dimensi"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -62718,7 +62792,7 @@ msgstr "Fortran 2003: [...] gaya array konstruktor di %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003: Array konstruktor termasuk tipe spesifikasi di %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
@@ -62842,7 +62916,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -62890,7 +62964,7 @@ msgstr "Fortran 2003: %s atribut dengan %s atribut di %L"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "'a1' argumen dari '%s' intrinsik di %L harus berupa INTEGER, REAL, atau KARAKTER"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
@@ -62908,7 +62982,7 @@ msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa REAL atau KOMPLEKS"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa INTEGER atau PROSEDUR"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -63048,186 +63122,186 @@ msgstr "Panjang karakter tidak sama (%ld/%ld) dalam %s di %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Different type kinds at %L"
 msgid "Different type kinds at %L"
 msgstr "Ekstensi: Jenis tipe berbeda di %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "Penunjuk KOSONG di %L tidak diijinkan sebagai argumen aktual dari '%s' fungsi intrinsik"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa jenis %d"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah penunjuk atau target VARIABELatau FUNGSI"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER or a TARGET"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah PENUNJUK atau sebuah TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "Bagian array dengan sebuah vektor subscript di %L tidak boleh menjadi target dari sebuah penunjuk"
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "Penunjuk KOSONG di %L tidak diijinkan sebagai argumen aktual dari '%s' fungsi intrinsik"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tipe yang sama dan jenis sebagai '%s'"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "STAT= argument to %s at %L"
 msgstr "Terlalu banyak argumen ke %s di %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa baku nyata"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa baku nyata"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa %s"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa baku nyata"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa baku nyata"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected argument list at %C"
 msgid "Negative argument N at %L"
 msgstr "Diduga daftar argumen di %C"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be present if 'x' is COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "'%s' argumen dari '%s' intrinsik di %L tidak boleh ada jika 'x' adalah KOMPLEKS"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of type REAL or COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus memiliki tipe REAL atau KOMPLEKS"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa jenis %d"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT tag in %s statement at %L must be a variable"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "STAT tag dalam pernyataan %s di %L harus berupa sebuah variabel"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "OPERATOR argument at %L must be a PURE function"
@@ -63236,775 +63310,775 @@ msgstr "Argumen dari %s di %L harus berupa panjang satu"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic function '%s' at %L is not permitted in an initialization expression"
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Fungsi intrinsik '%s' di %L tidak diperbolehkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tingkat 1 atau 2"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Fortran 2003: '%s' intrinsik dengan JENIS argumen di %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "SHIFT argument at %L of CSHIFT must have rank %d or be a scalar"
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "argumen SHIFT di %L dari CHIFT harus memiliki tingkat %d atau berupa sebuah skalar"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be numeric or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa numerik atau LOGIKAL"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "Different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "Bentuk berbeda untuk argumen '%s' dan '%s' di %L untuk intrinsik 'dot_product'"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa baku nyata"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa jenis sama dengan '%s'"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "SIZE at %L must be positive"
 msgstr "%s tag di %L harus berupa tipe %s"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of LOG at %L cannot be less than or equal to zero"
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "Argumen dari LOG di %L tidak dapat lebih kecil atau sama dengan nol"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a variable"
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "'%s' di %C bukan sebuah variabel"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah konstanta"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Intrinsik '%s' di %L harus memiliki paling tidak dua argumen"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "'a%d' argumen dari '%s' intrinsik di %L harus berupa %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with CHARACTER argument at %L"
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "Fortran 2003: '%s' intrinsik dengan argumen KARAKTER di %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 #| msgid "'a1' argument of '%s' intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "'a1' argumen dari '%s' intrinsik di %L harus berupa INTEGER, REAL, atau KARAKTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 #| msgid "Argument types of '%s' intrinsic at %L must match (%s/%s)"
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Tipe argumen dari '%s' intrinsik di %L harus sesuai dengan (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 #| msgid "Different shape on dimension 1 for arguments '%s' and '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "Bentuk berbeda dalam dimensi 1 untuk argumen '%s' dan '%s' di %L untuk intrinsik matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 #| msgid "Different shape on dimension 2 for argument '%s' and dimension 1 for argument '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "Bentuk berbeda dalam dimensi 2 untuk argumen '%s' dan dimensi 1 untuk argumen '%s' di %L untuk intrinsik matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tingkat 1 atau 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tipe yang sama dan jenis sebagai '%s'"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tingkat yang sama %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tingkat yang sama %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah jenis tidak lebih lebar dari jenis baku (%d)"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah variabel dummy"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an OPTIONAL dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah variabel dummy OPSIONAL"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be a subobject of '%s'"
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "'%s' argumen dari '%s' intrinsik di %L tidak boleh berupa subobjek dari '%s'"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah variabel"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "'shape' argumen dari 'reshape' intrinsik di %L harus berupa sebuah array dari konstantaukuran"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa %s"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "'shape' argumen dari 'reshape' intrinsik di %L memiliki lebih dari %d elemen"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "'a%d' argumen dari '%s' intrinsik di %L harus berupa %s(%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus dari tingkat %d"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Tanpa padding, disana tidak cukup elemen dalam sumber intrinsik RESHAPE di %L untuk cocok dengan shape"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tipe numerik"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Fortran 2003: '%s' intrinsik dengan JENIS argumen di %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "'source' argumen dari 'shape' intrinsik di %L tidak boleh sebuah ukuran arrayyang diasumsikan"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah skalar"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L tidak dapat berupa INTENT(IN)"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "'source' argumen dari 'shape' intrinsik di %L tidak boleh sebuah ukuran arrayyang diasumsikan"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tipe bukan-turunan"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FIELD argument at %L of UNPACK must have the same rank as MASK or be a scalar"
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "argumen FIELD di %L dari UNPACK harus memiliki tingkat sama seperti MASK atau berupa sebuah skalar"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L has no IMPLICIT type"
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Hasil fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus lebih kecil dari tingkat %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Tidak teduga sampah dalam daftar argumen formal di %C"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "'MOLD' argumen dari 'TRANSFER' intrinsik di %L tidak boleh berupa %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "'MOLD' argumen dari 'TRANSFER' intrinsik di %L tidak boleh berupa %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "'MOLD' argumen dari 'TRANSFER' intrinsik di %L tidak boleh berupa %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Intrinsik TRANSFER di %L memiliki hasil tidak terdefinisi sebagian: ukuran sumber %ld < ukuran hasil %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa jenis sama dengan '%s'"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 #| msgid "Size of '%s' argument of '%s' intrinsic at %L too small (%i/%i)"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Ukuran dari '%s' argumen dari '%s' intrinsik di %L terlalu kecil (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Terlalu banyak argumen ke %s di %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah jenis tidak lebih lebar dari jenis baku (%d)"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah skalar"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa INTEGER atau LOGIKAL"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' of '%s' is PRIVATE at %C"
 msgid "%qs of %qs is PRIVATE at %L"
@@ -64223,822 +64297,822 @@ msgstr "Spesifikasi INTENT buruk di %C"
 msgid "deferred type parameter at %C"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Old-style character length at %C"
 msgstr "Karakter tidak valid dalam nama di %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Sintaks error dalam spesifikasi panjang karakter di %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Prosedur '%s' di %C telah terdefinisi di %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Prosedur '%s' di %C telah terdefinisi di %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Nama '%s' di %C telah terdefinisi sebagai sebuah antar-muka umum di %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Prosedur '%s' di %C memiliki sebuah antar-muka eksplisit dan tidak boleh memiliki atribut terdeklarasi di %L"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L must have the BIND(C) attribute to be C interoperable"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Prosedur '%s' di %L harus memiliki atribut BIND(C) supaya C interoperable"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' at %L is a parameter to the BIND(C)  procedure '%s' but is not C interoperable because derived type '%s' is not C interoperable"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Tipe '%s' di %L adalah sebuah parameter ke BIND(C) prosedur '%s' tetapi bukan C interoperable karena tipe turunan '%s' bukan C interoperable"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Variabel '%s' di %L adalah sebuah parameter ke prosedur BIND(C) '%s' tetapi mungkintidak C interoperable"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Variabel '%s' di %L adalah sebuah parameter ke prosedur BIND(C) '%s' tetapi mungkintidak C interoperable"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, fuzzy, gcc-internal-format
 #| msgid "Character argument '%s' at %L must be length 1 because procedure '%s' is BIND(C)"
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Argumen karakter '%s' di %L harus memiliki panjang 1 karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the ALLOCATABLE attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut ALLOCATABLE karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the POINTER attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut PENUNJUK karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the OPTIONAL attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut OPSIONAL karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the OPTIONAL attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut OPSIONAL karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape array '%s' at %L cannot be an argument to the procedure '%s' at %L because the procedure is BIND(C)"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Bentuk-diasumsikan array '%s' di %L tidak dapat berupa sebuah argumen ke prosedur '%s' di %L karena prosedur adalah BIND(C)"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Simbol '%s' di %L tidak dapat memiliki sebuah tipe"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Variabel '%s' dalam blok umum '%s' di %C harus terdeklarasi dengan sebuah jenis C interoperable karena blok umum '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "ekspresi KARAKTER di %L terpotong (%d/%d)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Elemen KARAKTER dari konstruktor array di %L harus memiliki panjang yang sama (%d/%d)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Penginisialisasi tidak diperbolehkan untuk PARAMETER '%s' di %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER di %L hilang sebuah penginisialisasi"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variabel '%s' di %C dengan sebuah penginisialisasi telah muncul dalam sebuah pernyataan DATA"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "tidak dapat menginisialisasi array multidimensi dengan penginisialisasi"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Komponen array dari struktur di %C harus memiliki bentuk eksplisit atau deffered"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponen '%s' di %C telah dideklarasikan di %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Komponen penunjuk array dari struktur di %C harus memilki sebuah bentuk deffered"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Komponen dapat dialokasikan dari struktur di %C harus memiliki sebuah bentuk deffered"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Struktur komponen array di %C harus memiliki sebuah bentuk eksplisit"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "sebuah daftar parameter dengan sebuah ellipsis tidak dapat cocok dengan sebuah parameter kosong deklarasi daftar nama"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "inisialisasi NULL() di %C adalah ambigu"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "inisialisasi NULL() di %C adalah ambigu"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari pointer di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Karakter tidak valid dalam nama di %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Duplikasi spesifikasi array untuk Cray pointee di %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "tidak dapat mengubah ke sebuah tipe penunjuk"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Inisialisasi di %C bukan sebuah variabel penunjuk"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Inisialisasi dari penunjuk di %C membutuhkan '=>', bukan '='"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Diduga sebuah ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari variabel di %C tidak diperbolehkan alam prosedur PURE"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Inisialisasi dari komponen dapat dialokasikan di %C tidak diperbolehkan"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of allocatable component at %C is not allowed"
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "Inisialisasi dari komponen dapat dialokasikan di %C tidak diperbolehkan"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Komponen penunjuk '%s' dari '%s' di %L adalah sebuah tipe yang belum pernah dideklarasikan"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Tipe deklarasi gaya-lama %s*%d tidak didukung di %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Tipe deklarasi tidak-baku %s*%d di %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Hilang paranthesis kanan di %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Diduga ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Didugak ekspresi inisialisasi skalar di %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Jenis %d tidak didukung untuk tipe %s di %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Jenis tipe parameter C adalah untuk tipe %s tetapi tipe di %L adalah %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Hilang paranthesis kanan atau koma di %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Jenis %d tidak didukung untuk KARAKTER di %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Sintaks error dalam deklarasi KARAKTER di %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "parameter pertama dari %<operator new%> tidak dapat memiliki sebuah argumen baku"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Ekspresi di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Array '%s' di %L bukan sebuah variabel, yang tidak mereduksi ke sebuah ekspresi konstanta"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Ekstensi: BYTE tipe di %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "tipe BYTE digunakan di %C tidak tersedia dalam mesin target"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "malformed spec function name"
 msgid "Malformed type-spec at %C"
 msgstr "spesifikasi nama fungsi salah format"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tipe nama '%s' di %C adalah ambigu"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Duplikasi pernyataan IMPLISIT NONE di %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Hilang jangkauan karakter dalam IMPLISIT di %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Huruf harus dalam urutan alphabet dalam pernyataan IMPLISIT di %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Tidak dapat IMPOR '%s' dari satuan host scoping di %C - tidak ada."
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' telah ter-IMPOR dari satuan host scoping di %C."
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Sintaks error dalam pernyataan IMPOR di %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Components in TYPE at %C must precede CONTAINS"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponen dalam TYPE di %C harus mengawali CONTAINS"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s atribut di %L tidak diperbolehka diluar dari bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "TERPROTEKSI di %C hanya diperbolehkan dalam bagian spesifikasi dari modul"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: atribut TERPROTEKSI di %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: atribut NILAI di %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: atribut VOLATILE di %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Multiple pengidentifikasi disediakan dengan penspesifikasi NAMA= tunggal di %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "secara implisit terdeklarasi fungsi BIND(C) '%s' di %L mungkin tidak C interoperable"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L mungkin tidak berupa jenis C dapat berinteroperasi melalui blok umum '%s' adalah BIND(C)"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Tipe deklarasi '%s' di %L bukan C interoperable tetapi ini adalah BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabel '%s' di %L mungkin bukan sebuah jenis C interoperable tetapi ini adalah bind(c)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L tidak dapat dideklarasikan dengan BIND(C)karena ini bukan sebuah global"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Tipe kembali dari fungsi BIND(C) '%s' di %L tidak dapat berupa sebuah array"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
@@ -65046,1105 +65120,1105 @@ msgstr "Tipe kembali dari fungsi BIND(C) '%s' di %L tidak dapat berupa string ka
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Simbol '%s' di %L ditandai PRIVATE tetapi telah diberikan level binding '%s'"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Dibutuhkan baik entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Hilang entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "hilang angka"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Tipe turunan di %C belum pernah didefinisikan sebelumnya jadi tidak dapat muncul dalam sebuah tipe definisi turunan"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "PROSEDUR MODUL di %C harus dalam sebuah antar-muka modul umum"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "nama prosedur = %s"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer expression required at %C"
 msgid "A type parameter list is required at %C"
 msgstr "Ekspresi integer dibutuhkan di %C"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Diduga alternatif label kembali di %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "A parameter name is required at %C"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Nama '%s' di %C adalah nama dari prosedur"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Diduga dimensi lain dalam deklarasi array di %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Tidak teduga sampah dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "variabel RESULT di %C harus berbeda dari nama fungsi"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: BIND(C) atribut di %L mungkin tidak dispesifikasikan untuk sebuah prosedur internal"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "atribut BIND(C) di %C membutuhkan sebuah antar-muka dengan BIND(C)"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "prosedur BIND(C) dengan NAMA mungkin tidak memiliki atribut PENUNJUK di %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Prosedur dummy di %C mungkin tidak memiliki atribut BIND(C) dengan NAMA"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Diduga '::' setelah atribut binding di %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Procedure pointer component at %C"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Sintaks error dalam struktur konstruktor di %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROSEDUR di %C harus berupa sebuah antar-muka umum"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROCEDURE statement at %C"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Diduga daftar argumen formal dalam definisi fungsi di %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "atribut BIND(C) di %L hanya dapat digunakan untuk variabel atau blok umum"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah APLIKASI"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah DATA BLOK"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok TIPE TURUNAN"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok IF-THEN"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok FORALL"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok WHERE"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah subprogram terkontain"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah prosedur terkontain"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Hilang parantheses yang dibutuhkan sebelum BIND(C) di %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah prosedur terkontain"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return cannot appear in operator interface at %L"
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "Kembali alternatif tidak dapat muncul dalam antar-muka operator di %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nama C tidak valid dalam penspesifikasi NAMA= di %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= penspesifikasi di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Hilang penutup paren untuk binding label di %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Untuk prosedur dummy %s, tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAMA tidak diijinkan dalam BIND(C) untuk ANTAR-MUKA ABSTRAK di %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
 msgstr "pernyataan %s di %C tidak dapat mengikuti pernyataan %s di %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "pernyataan %s tidak terduga di %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Diduga pernyataan %s di %C"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Diduga nama blok dari '%s' dalam pernyataan %s di %C"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Diduga label '%s' untuk pernyataan %s di %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensi dipesifikasikan untuk %s di %L setelah inisialisasinya"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Spesifikasi array harus deferred di %L"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Karakter tidak terduda dalam daftar variabel di %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Diduga nama variabel di %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Penunjuk Cray di %C memiliki %d bytes ketelitian; alamat memori membutuhkan %d bytes"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "tidak dapat mengubah ke sebuah tipe penunjuk"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Diduga \")\" di %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Diduga \",\" atau akhir dari pernyataan di %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "Deklarasi penunjuk cray di %C membutuhkan pilihan -fcray-pointer"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator %s di %C telah dispesifikasikan"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator .%s.  di %C telah dispesifikasikan"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PRIVATE di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PUBLIK di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nama variabel diduga di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Diduga tanda = dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Diduga ekspresi di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Inisialisasi variabel  yang telah diinisialisasi di %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket pernyataan SAVE di %C mengikuti pernyataan SAVE sebelumnya"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: pernyataan NILAI di %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROSEDUR MODUL di %C harus dalam sebuah antar-muka modul umum"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic procedure '%s' not allowed in PROCEDURE statement at %C"
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Prosedur intrinsik '%s' tidak diperbolehkan dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Ambigu simbol dalam definisi TIPE di %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' dalam ekspresi EXTENDS di %C bukan sebuah tipe turunan"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah BIND(C)"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah tipe SEQUENCE"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PRIVATE dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PUBLIK dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "tipe ABSTRAK '%s' digunakan di %L"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Duplikasi konstruksi label '%s' di %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Diduga :: dalam definisi TIPE di %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "Mangled derived type definition at %C"
 msgstr "Fortran 2003: blok CONTAINS dalam definisi turunan di %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa OPSIONAL"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray Pointee di %C tidak dapat diasumsikan bentuk array"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM dan ENUMERATOR di %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumerator melebihi tipe integer C di %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L tidak diinisialisasi dengan ekspresi integer"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "pernyataan definisi ENUM diduga sebelum %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Sintaks error dalam definisi ENUMERATOR di %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Duplikasi penspesifikasi akses di %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal NOPASS di %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal PASS di %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate NON_OVERRIDABLE at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Diduga penspesifikasi akses di %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Diduga atribut binding di %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in NAME= specifier for binding label at %C"
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE(interface) at %C is not yet implemented"
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDUR(antar-muka) di %C belum diimplementasikan"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Diduga nama binding di %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "'::' diperlukan dalam binding PROCEDUR dengan target eksplisit di %C"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Diduga binding target setelah '=>' di %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC di %C harus berada didalam sebuah tipe turunan CONTAINS"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Diduga '::' di %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected generic name at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Diduga nama generik di %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Form tidak valid dari pernyataan APLIKASI di %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur bukan generik dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Binding di %C harus memiliki akses sama seperti telah didefinisikan binding '%s'"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Diduga nama binding spesifik di %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "'%s' telah didefinisikan sebagai binding spesifik untuk generik '%s' di %C"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Sampah setelah binding GENERIC di %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "deklarasi FINAL di %C harus berada didalam sebuah tipe turunan daerah CONTAINS"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklarasi tipe turunan dengan FINAL di %C harus berada dalam spesifikasi dari sebuah MODULE"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Kosong FINAL di %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Diduga nama prosedur modul di %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nama prosedur tidak dikenal \"%s\" di %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%s' di %C telah didefinisikan sebagai prosedur FINAL!"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Sintaks error dalam iterasi FORALL di %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Sintaks error dalam deklarasi KARAKTER di %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Sintaks error dalam deklarasi KARAKTER di %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in ENUMERATOR definition at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -66275,12 +66349,12 @@ msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr ""
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid KIND parameter of %s at %L"
 msgid "KIND part_ref at %C"
@@ -66360,7 +66434,7 @@ msgstr "intrinsik transformational '%s' di %L tidak diijinkan dalam sebuah ekspr
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Ekstensi: Evaluasi dari ekspresi inisialisasi ekpresi tidak baku di %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic or a specification function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -66662,7 +66736,7 @@ msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -66724,179 +66798,179 @@ msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Target penempatan penunjuk memiliki atribut PROTECTED di %L"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Target penempatan penunjun baik bukan TARGET ataupun PENUNJUN di %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Target buruk dalam penempatan penunjuk dalam prosedur PURE di %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Penempatan penunjuk dengan subscrip vektori di rhs di %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Target penempatan penunjuk memiliki atribut PROTECTED di %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Noninteger exponent in an initialization expression at %L"
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003: eksponen bukan integer dalam sebuah ekspresi inisialisasi di %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 #| msgid "Argument to '%s' at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "Argumen ke '%s' di %L bukan sebuah variabel"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Variabel '%s' tidak dapat muncul dalam ekspresi di %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabel %s tidak dapat ditempatkan dalam prosedur PURE di %C"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -66925,7 +66999,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -67134,12 +67208,12 @@ msgstr "Argumen pertama dari penempatan yang didefinisikan di %L harus berupa IN
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -67216,664 +67290,664 @@ msgstr "Interface ambigu '%s' dan '%s' dalam %s di %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Walaupun tidak direferensikan, '%s' di %L memiliki antar-muka ambigu"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a module procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "'%s' di %L bukan sebuah prosedur module"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan diasumsikan-bentuk argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) argumen aktual di %L mungkin menginterferensi dengan argumen aktual di %L."
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 #| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in argument '%s' at %L (%d and %d)"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Tingkat tidak cocok dalam argumen '%s' di %L (%d dan %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped array passed to dummy argument '%s' at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Elemen dari array bentuk-diasumsikan dilewatkan ke argumen dummy '%s' di %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Skalar KARAKTER aktual argumen dengan array dummy argumen '%s' di %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Kata kunci argumen '%s' di %L tidak dalam prosedur"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Argumen kata-kunci '%s' di %L telah berasosiasi dengan argumen aktual lain"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Lebih aktual daripada formal argumen dalam pemanggilan prosedur di %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Tidak terduga alternaatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan penunjuk atau dapat dialokasikan argumen dummy '%s' di %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, fuzzy, gcc-internal-format
 #| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Panjang karakter tidak cocok (%ld/%ld) diantara argumen aktual dan diasumsikan-bentuk argumen dummy '%s' di %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Panjang karakter dari argumen aktual lebih pendek dari argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure pointer for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Diduga sebuah prosedur penunjuk untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktual argumen untuk '%s' tidak dapat diasumsikan array berukuran di %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktual argumen untuk '%s' harus DAPAT DIALOKASIKAN di %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT) or VOLATILE attribute of the dummy argument '%s'"
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Daerah array aktual argumen dengan vektor subscript di %L adalah tidak kompatibel dengan INTENT(OUT), INTENT(INOUT) atau VOLATILE atribut dari argumen dummy'%s'"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Bentuk-diasumsikan aktual argumen di %L adalah tidak kompatibel dengan bentuk tidak diasumsikan dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Daerah array aktual argumen di %L adalah tidak kompatibel dengan tidak-diasumsikanbentuk dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Penunjuk array aktual argumen di %L membutuhkan sebuah bentuk diasumsikan ataupenunjuk array dummy argumen '%s' karena atribut VOLATILE"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Hilang alternatif spesifikasi kembali dalam pemanggilan subroutine di %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Hilang aktual argumen untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Aktual argumen sama berasosiasi dengan INTENT(%s) argumen '%s' dan INTENT(%s) argumen '%s' di %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan memiliki atribut PENUNJUK"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Prosedur argumen di %L adalah lokal ke sebuah prosedur PURE dan adalah dilewatkan ke sebuah argumen INTENT(%s)"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Otomatis panjang fungsi karakter '%s' di %L harus memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Prosedur '%s' dipanggil dengan sebuah antar-muka implisit di %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Kata kunci argumen membutuhkan antar-muka eksplisit untuk prosedur '%s' di %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D teraliasi ke simbol tidak terdefinisi %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiti '%s' di %C telah ada dalam sebuah antar-muka"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC '%s' at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Tidak dapat overwrite GENERIC '%s' di %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "'%s' di %L overrides sebuah prosedur binding dideklarasikan NON_OVERRIDABLE"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "'%s' di %L overrides sebuah prosedur PURE dan juga harus berupa PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "'%s' di %L overrides sebuah prosedur ELEMENTAL dan juga harus berupa ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "'%s' di %L overrides sebuah prosedur bukan ELEMENTAL dan tidak harus berupa ELEMENTAL juga"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "'%s' di %L overrides sebuah SUBROUTINE dan juga harus berupa sebuah SUBROUTINE"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "'%s' di %L overrides sebuah FUNGSI dan juga harus berupa sebuah FUNGSI"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "'%s' di %L overrides sebuah prosedur PUBLIK dah tidak harus berupa PRIVATE"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Argumen dummy '%s' dari '%s' di %L seharusnya bernama '%s' untuk mencocokan dengan argumen yang berhubungan dengan prosedur overridden"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "'%s' di %L harus memiliki jumlah sama dari argumen formal seperti prosedur overridden"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "'%s' di %L overrides sebuah binding NOPASS dan juga harus berupa NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "'%s' di %L overrides sebuah pengikatan dengan PASS dan juga harus berupa PASS"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Argumen dummy objek yang dilewatkan dari '%s' di %L harus berada di posisi yang sama sebagai argumen dumy objek yang dilewatkan dari prosedur overridden"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s tag di %L harus berupa tipe %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Nilai-karakter fungsi internal '%s' di %L tidak boleh dengan panjang diasumsikan"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "pernyataan DATA di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Terlalu banyak argumen dalam panggilan ke '%s' di %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -67992,82 +68066,82 @@ msgstr "ALTERNATIF KEMBALI tidak diijinkan di %L"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "Tipe tidak cocok dalam argumen '%s' di %L; dilewatkan %s ke %s"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "init_arglist(): too many arguments"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' (is %s) is used at %L"
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "Intrinsik '%s' (adalah %s) digunakan di %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Function '%s' as initialization expression at %L"
 msgid "Function %qs as initialization expression at %L"
 msgstr "Fortran 2003: Fungsi '%s' sebagai ekspresi inisialisasi di %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 #| msgid "transformational intrinsic '%s' at %L is not permitted in an initialization expression"
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "intrinsik transformational '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003: Fungsi elemental sebagai ekspresi inisialisasi dengan bukan integer/bukan-karakter argumen di %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Panggilan subroutine ke intrinsik '%s' di %L tidak PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Panggilan subroutine ke intrinsik '%s' di %L tidak PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Ekstensi: Konversi dari %s ke %s di %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Konversi dari %s ke %s di %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Ekstensi: Konversi dari %s ke %s di %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Konversi dari %s ke %s di %L"
@@ -68075,25 +68149,25 @@ msgstr "Konversi dari %s ke %s di %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Tidak dapat mengubah %s ke %s di %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Tidak dapat mengubah %s ke %s di %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "'%s' dideklarasikan di %L mungkin bayangan intrinsik dari nama sama. Dengan tujuan untuk memanggil intrinsik, eksplisit deklarasi INTRINSIK mungkin dibutuhkan."
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
@@ -68493,13 +68567,13 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: ASYNCHRONOUS= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: BLANK= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -68511,7 +68585,7 @@ msgstr "Fortran 2003: DECIMAL= di %C tidak diijinkan dalam Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: ENCODING= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -68562,7 +68636,7 @@ msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
@@ -68665,7 +68739,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -68737,7 +68811,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Diduga ekspresi dalam pernyataan %s di %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Sintaks error dalam pernyataan %s di %C"
@@ -68754,89 +68828,89 @@ msgstr "Fortran 2003: Berkas internal di %L dengan daftar-nama"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "pernyataan DATA di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: PAD= di %C belum terimplementasi dalam Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003: DELIM= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "daftar-nama PRINT di %C adalah sebuah ekstensi"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "tag AKHIR di %C tidak diperbolehkan dalam pernyataan keluaran"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Diduga koma dalam daftar I/O di %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "pernyataan INQUIRE tidak diperbolehkan dalam prosedur di %C"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENTH tag tidak valid dalam pernyataan INQUIRE di %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "pernyataan INQUIRE di %L tidak dapat berisi baik BERKAS dan penspesifikasi SATUAN"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "pernyataan INQUIRE di %L membutuhkan baik BERKAS atau penspesifikasi SATUAN"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "pernyataan INQUIRE di %L membutuhkan sebuah PENDING= penspesifikasi dengan ID= penspesifikasi"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: WAIT di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "pernyataan WAIT tidak diperbolehkan dalam prosedur PURE di %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -69113,551 +69187,551 @@ msgstr "Duplikasi pernyataan PRIVATE di %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "tipe argumen tidak valid"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Sintaks error dalam iterasi FORALL di %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Nama '%s' dalam pernyataan %s di %C bukan sebuah nama loop"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Nama '%s' dalam pernyataan %s di %C bukan sebuah nama loop"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "%s statement at %C is not within a construct"
 msgstr "pernyataan %s di %C tidak dalam jangkauan sebuah loop"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "pernyataan %s di %C tidak dlam jangkauan loop '%s'"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "pernyataan %s di %C tidak dlam jangkauan loop '%s'"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "pernyataan %s di %C tidak dlam jangkauan loop '%s'"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "pernyataan %s di %C meninggalkan OpenMP blok terstruktur"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "pernyataan EXIT di %C mengakhiri loop !$OMP DO"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "lvalue dibutuhkan dalam pernyataan asm"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "STOP code at %C cannot be negative"
 msgstr "Spesifikasi bentuk di %L tidak dapat negatif"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "pernyataan DATA di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT POST statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT WAIT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "FAIL IMAGE statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: IMPORT statement at %C"
 msgid "FORM TEAM statement at %C"
 msgstr "Fortran 2003: pernyataan IMPOR di %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CHANGE TEAM statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "END TEAM statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC TEAM statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "LOCK statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Featur terhapus: pernyataan ASSIGN di %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Featur terhapus: Terassign pernyataan GOTO di %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Daftar pernyataan label dalam GOTO di %C tidak dapat kosong"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad allocate-object in ALLOCATE statement at %C for a PURE procedure"
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Alokasi-objek buruk dalam pernyataan ALOKASI di %C untuk sebuah prosedur PURE"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "STAT tag at %L cannot be a constant"
 msgstr "Variabel loop di %C tidak dapat berupa sebuah sub-komponen"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "BLOK DATA kosong di %C konflik dengan BLOK DATA sebelumnya di %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "ekspresi deallokasi tidak legal dalam DEALLOCATE di %C untuk sebuah prosedur PURE"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Pernyataan alternatif RETURN di %C hanya diperbolehkan dalam sebuah SUBROUTINE"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Ekstensi: pernyataan RETURN dalam aplikasi utama di %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Diduga referensi komponen di %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Sampah setelah CALL di %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected type-bound procedure reference at %C"
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Diduga referensi type-bound prosedur di %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Sintaks error dalam nama blok umum di %C"
@@ -69665,245 +69739,245 @@ msgstr "Sintaks error dalam nama blok umum di %C"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "Variabel '%s' di %L dalam blok umum '%s' di %C harus terdeklarasi dengan sebuah C interoperable kind karena blok umum '%s' adalah bind(c)"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "Variabel '%s' dalam blok umum '%s' di %C tidak dapat bind(c) karena ini bukan global"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Simbol '%s' di %C telah dalam sebuah blok COMMON"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, fuzzy, gcc-internal-format
 #| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Simbol terinisialisasi '%s' di %C hanya dapat berupa COMMON dalam BLOK DATA"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Spesifikasi array untuk simbol '%s' dalam COMMON di %C harus eksplisit"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Simbol '%s' dalam COMMON di %C tidak dapat berupa sebuah array PENUNJUK"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Simbol '%s', dalam blok COMMON '%s' di %C sedang secara tidak langsung sama dengan ke COMMON blok '%s' lain"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Daftar-nama nama grup '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Daftar-nama nama grup '%s' di %C telah USE diasosiasikan dan tidak dapat berupa respecified."
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Tipe komponen turunan %C bukan sebuah anggota EQUIVALENCE yang diijinkan"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Referensi array dalam EQUIVALENCE di %C tidak dapat berupa daerah array"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE di %C membutuhkan dua atau lebih objek"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Mencoba secara tidak langsung overlap blok COMMON %s dan %s dengan EQUIVALENCE di %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Diduga koma dalam daftar I/O di %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "EQUIVALENCE statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Pernyataan fungsi di %L adalah rekursif"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Pernyataan fungsi di %L adalah rekursif"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function at %C"
 msgstr "Pernyataan fungsi di %L adalah rekursif"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be scalar"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Diduga ekspresi inisialisasi dalam CASE di %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "Expected the name of the SELECT CASE construct at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Diduga nama dari SELECT CASE konstruk di %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "pernyataan ELSEWHERE di %C tidak terenklose dalam blok WHERE"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -69947,12 +70021,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -70711,8 +70785,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
@@ -72243,194 +72317,194 @@ msgstr "Karakter tidak terduda dalam daftar variabel di %C"
 msgid "Expected structure component name at %C"
 msgstr "Diduga nama struktur komponen di %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Diduga daftar argumen di %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "parameter KIND dari %s di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "Fungsi '%s' membutuhkan sebuah daftar argumen di %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Structure constructor with missing optional arguments at %C"
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Fortran 2003: Konstruktor struktur dengan argumen pilihanonal hilang di %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 #| msgid "No initializer for component '%s' given in the structure constructor at %C!"
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "Tidak ada penginisialisasi untuk komponen '%s' yang diberikan dalam struktur konstruktor di %C"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "No initializer for component '%s' given in the structure constructor at %C!"
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "Tidak ada penginisialisasi untuk komponen '%s' yang diberikan dalam struktur konstruktor di %C"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 #| msgid "Can't construct ABSTRACT type '%s' at %C"
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "Tidak dapat mengkontruksi tipe ABSTRACT '%s' di %C"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Structure constructor with named arguments at %C"
 msgid "Structure constructor with named arguments at %C"
 msgstr "Fortran 2003: Struktur konstruktor dengan argumen bernama di %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component initializer without name after component named %s at %C!"
 msgid "Component initializer without name after component named %s at %L"
 msgstr "Penginisialisasi komponen tanpa nama setelah komponen bernama %s di %C!"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many components in structure constructor at %C!"
 msgid "Too many components in structure constructor at %L"
 msgstr "Terlalu banyak komponen dalam struktur konstruktor di %C!"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' is initialized twice in the structure constructor at %C!"
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Komponen '%s' telah terinisialisasi dua kali dalam struktur konstruktor di %C!"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "Too many components in structure constructor at %C!"
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Terlalu banyak komponen dalam struktur konstruktor di %C!"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "component '%s' at %L has already been set by a parent derived type constructor"
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "komponen '%s' di %L telah diset oleh sebuah konstruktor tipe turunan induknya"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "'%s' di %C adalah nama dari sebuah fungsi rekursi dan jadi merefer ke hasil variabel. Gunakan sebuah variabel RESULT eksplisit untuk rekursif langsung (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Simbol di %C tidak sesuai untuk sebuah ekspresi"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected use of subroutine name '%s' at %C"
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Tidak diduga penggunaan dari nama subroutine '%s' di %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Pernyataan fungsi '%s' membutuhkan daftar argumen di %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Function %qs requires an argument list at %C"
 msgstr "Fungsi '%s' membutuhkan sebuah daftar argumen di %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument to '%s' at %C"
 msgid "Missing argument to %qs at %C"
 msgstr "Hilang argumen ke '%s' di %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Missing argument list in function %qs at %C"
 msgstr "Hilang daftar argumen dalam fungsi '%s' di %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Nama '%s' tidak dapat digunakan sebagai sebuah operator terdefinisi di %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Konstanta bernama di %C dalam sebuah EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a variable"
 msgid "%qs at %C is not a variable"
@@ -72816,547 +72890,547 @@ msgstr "'%s' di %L adalah ambigu"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "prosedur UMUM '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 #| msgid "Type specified for intrinsic function '%s' at %L is ignored"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Tipe dispesifikasikan untuk fungsi intrinsik '%s' di %L diabaikan"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' declared INTRINSIC at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "'%s' dideklarasikan INTRINSIC di %L tidak ada"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, fuzzy, gcc-internal-format
 #| msgid "The intrinsic '%s' declared INTRINSIC at %L is not available in the current standard settings but %s.  Use an appropriate -std=* option or enable -fall-intrinsics in order to use it."
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Intrinsik '%s' dideklarasikan INTRINSIC di %L tidak tersedia dalam konfigurasi baku sekarang tetapi %s. Gunakan sebuah pilihan -std=* yang sesuai atau aktifkan -fall-intrinsics untuk menggunakan itu."
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, fuzzy, gcc-internal-format
 #| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Prosedur internal '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsik '%s' di %L tidak diperbolehkan sebagai sebuah argumen aktual"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Prosedur internal '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL bukan INTRINSIK prosedur '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Tidak dapat menemukan sebuah prosedur INTRINSIK spesifik untuk referensi '%s' di %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Simbol '%s' di %L adalah ambigu"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Argumen dengan nilai di %L adalah bukan tipe numerik"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Melewati prosedur internal di %L dengan lokasi tidak diperbolehkan"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL bukan INTRINSIK prosedur '%s' tidak diperbolehkan sebagai sebuah argumen aktual di %L"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "'%s' di %L adalah sebuah array dan OPSIONAL; JIKA INI HILANG, ini tidak dapat berupa argumen aktual dari sebual prosedur ELEMENTAL kecuali disana ada sebuah tidak pilihanonal argumen dengan tingkat sama (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Argumen aktual di %L untuk INTENT(%s) dummy '%s' dari subroutine ELEMENTAL '%s' adalah sebuah skalar, tetapi argumen aktual lain adalah sebuah array"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Disana tidak ada fungsi spesifik untuk umum '%s' di %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Fungsi umum '%s' di %L tidak konsisten dengan sebuah antar-muka spesifik intrinsik."
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Fungsi '%s' di %L adalah INTRINSIK tetapi tidak kompatibel dengan sebuah intrinsik"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Tidak dapat meresolf fungsi spesifik '%s'di %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "referensi ke fungsi bukan-PURE '%s' di %L didalam sebuah FORALL %s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "referensi ke fungsi bukan-PURE '%s' di %L didalam sebuah FORALL %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Tidak dapat menulis ke internal berkas satuan '%s' di %C didalam prosedur PURE"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "'%s' di %L bukan sebuah fungsi"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, fuzzy, gcc-internal-format
 #| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ANTAR-MUKA ABSTRAK '%s' tidak boleh direferensikan di %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Fungsi '%s' adalah dideklarasikan KARAKTER(*) dan tidak dapat digunakan di %L karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Fungsi bukan-ELEMENTAL definisi pengguna '%s' di %L tidak diperbolehkan dalam WORKSHAREkonstruksi"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "MASUKAN '%s' di %L tidak dapat dipanggil secara rekursif, karena fungsi '%s' tidak REKURSIF"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Fungsi '%s' di %L tidak dapat dipanggil secara rekursif, karena ini bukan REKURSIF"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' dalam blok FORALL di %L tidak PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' dalam blok FORALL di %L tidak PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Panggilan subroutine ke '%s' di %L bukan PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Disana tidak ada subroutine spesifik untuk umum '%s' di %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Subroutine umum '%s' di %L tidak konsisten dengan sebuah anta-muka subroutine intrinsik"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Subroutine '%s' di %L adalah INTRINSIK tetapi tidak kompatibel dengan sebuah intrinsik"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Tidak dapat meresolf subroutine spesifik '%s' di %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' di %L memiliki sebuah tipe, yang tidak konsisten dengan CALL di %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "MASUKAN '%s' di %L tidak dapat dipanggil secara rekursif, karena subroutine '%s' tidak REKURSIF"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE '%s' di %L tidak dapat dipanggil secara rekursif, karena ini bukan REKURSIF"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Bentuk untuk operan di %L dan %L tidak konformant"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Spesifikasi bentuk di %L tidak dapat negatif"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tidak legal stride dari nol di %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Jangkauan paling kanan ats dari daerah ukuran array yang diasumsikan tidak dispesifikasikan di %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Indeks array di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ekstensi: indeks array RIL di %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Indeks array di %L adalah sebuah array dari tingkat %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Indeks awal substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Indeks awal substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Indeks awal substring di %L lebih kecil dari satu"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Indeks akhir substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Indeks akhir substring di %L melebihi panjang string"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut PENUNJUK di %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut DAPAT DIALOKASIKAN di %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Dua atau lebih referensi bagian dengan tingkat bukan-nol tidak boleh dispesifikasikan di %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -73366,12 +73440,12 @@ msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -73381,303 +73455,303 @@ msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s', digunakan dalam sebuah ekspresi spesifikasi, direferensikan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s' digunakan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -73686,310 +73760,310 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Nama '%s' tidak dapat digunakan sebagai sebuah operator terdefinisi di %C"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -73997,192 +74071,193 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -74190,7 +74265,7 @@ msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -74198,1076 +74273,1076 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "dalam %s, di %s:%d"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumen dari ICHAR di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%H%qE belum pernah dideklarasikan"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Panjang karakter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -76003,174 +76078,174 @@ msgstr "'%s' di %L memiliki atribut dispesifikasikan diluar dari badan ANTAR-MUK
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Fungsi '%s' di %C telah memiliki sebuah tipe dari %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Simbol '%s' di %L tidak dapat memiliki sebuah tipe"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponen '%s' di %C telah berada dalam tipe induknya di %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Simbol '%s' di %C adalah ambigu"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Tipe turunan '%s' di %C sedang digunakan sebelum itu didefinisikan"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponen '%s' di %C adalah sebuah komponen PRIVATE dari '%s'"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Duplikasi pernyataan label %d di %L dan %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Label %d di %C telah direferensikan sebagai target percabangan"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Label %d di %C telah direferensikan sebagai sebuah format label"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Label %d di %C sebelumnya digunakan sebagai sebuah FORMAT label"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Label %d di %C sebelumnya digunakan sebagai target percabangan"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Nama '%s' di C adalah sebuah referensi ambigu ke '%s' dari module '%s'"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Nama '%s' di %C adalah sebuah referensi ambigu ke '%s' dari satuan aplikasi sekarang"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Tipe turunan '%s' dideklarasikan di %L harus memiliki atribut BIND ke Cinteroperable"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut DAPAT DIALOKASIKAN karena ini sebuah anggota dari tipe turunan BIND(C) '%s' di %L"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel, walaupun melalui tipe turunan '%s' adalah BIND(C)"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Tipe turunan '%s' di %L tidak dapat memiliki urutan atribut karena ini adalah BIND(C)"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -76211,94 +76286,94 @@ msgstr "Overlapping tidak sama penginisialisasi dalam EKUIVALEN di %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Membuat array sementara di %L untuk argumen '%s'"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipe ekspresi buruk selama walk (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "Blok UMUM bernama '%s' di %L seharusnya berukuran sama"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "posisi yang diminta bukan sebuah konstanta integer"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Tipe referensi tidak legal di %L sebagai objek EKUIVALEN"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Aturan ekuivalen tidak konsisten melibatkan '%s' di %L dan '%s' di %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, fuzzy, gcc-internal-format
 #| msgid "The equivalence set for variable '%s' declared at %L violates alignment requirements"
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "Set ekuivalen untuk variabel '%s' dideklarasikan di %L violates alignmen yang dibutuhkan"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "Equivalence for '%s' does not match ordering of COMMON '%s' at %L"
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "Ekuivalen untuk '%s' tidak cocok pengurutan dari UMUM '%s' di %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, fuzzy, gcc-internal-format
 #| msgid "The equivalence set for '%s' cause an invalid extension to COMMON '%s' at %L"
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "Set ekuivalen untuk '%s' karena ekstensi tidak valid untuk UMUM '%s' di %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L; reorder elements or use -fno-align-commons"
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Padding dari %d bytes dibutuhkan sebelum '%s' dalam UMUM '%s' di %L; urutkan kembali elemen atau gunakan -fno-align-commons"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON at %L; reorder elements or use -fno-align-commons"
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Padding dari %d bytes dibutuhkan sebelum '%s' dalam UMUM '%s' di %L; urutkan kembali elemen atau gunakan -fno-align-commons"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L does not exist"
 msgid "COMMON %qs at %L does not exist"
 msgstr "UMUM '%s' di %L tidak ada"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L requires %d bytes of padding at start; reorder elements or use -fno-align-commons"
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "UMUM '%s' di %L membutuhkan %d bytes dari padding di awal; urutkan kembali elemen atau gunakan -fno-align-commons"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON at %L requires %d bytes of padding at start; reorder elements or use -fno-align-commons"
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
@@ -76320,84 +76395,84 @@ msgstr "Diduga sebuah ekspresi inisialisasi di %C"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "variabel instrinsic yang bukan sebuah prosedur"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Return value of function %qs at %L not set"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "backend deklarasi untuk variabel modul %s telah ada"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Dummy argumen '%s' di %L telah dideklarasikan INTENT(OUT) tetapi belum diset"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Dummy argumen '%s' di %L telah dideklarasikan INTENT(OUT) tetapi belum diset"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "Unused dummy argument '%s' at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Argumen dummy tidak digunakan '%s' di %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable '%s' declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Variabel '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "Return value '%s' of function '%s' declared at %L not set"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Nilai kembali dari fungsi '%s' dideklarasikan di %L tidak diset"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -76412,27 +76487,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Instrinsik op tidak diketahui"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Daftar fungsi argumen tidak diketahui di %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -76471,24 +76546,24 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr "IO basetype buruk (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "implicit mapping of assumed size array %qD"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "optional class parameter"
 msgstr "parameter %qs tidak valid"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_omp_workshare(): Bad statement code"
@@ -76614,92 +76689,92 @@ msgstr "argumen tidak cocok"
 msgid "unable to open file"
 msgstr "tidak dapat mengemulasikan %qs"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "could not open response file %s"
 msgid "could not parse file offset"
 msgstr "tidak dapat membuka berkas response %s"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected offset"
 msgstr "operan tidak terduga"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid line in the resolution file"
 msgstr "register tidak valid dalam instruksi"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid resolution in the resolution file"
 msgstr "register tidak valid dalam instruksi"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr ""
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 #| msgid "could not open response file %s"
 msgid "could not open symbol resolution file: %m"
 msgstr "tidak dapat membuka berkas response %s"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -77955,7 +78030,7 @@ msgstr "nama makro hilang setelah %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "hilang nama berkas setelah %qs"
@@ -78182,19 +78257,19 @@ msgstr "algoritma ira \"%s\" tidak diketahui"
 msgid "unknown TLS model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "nilai visibility \"%s\" tidak dikenal"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
diff --git a/gcc/po/ja.po b/gcc/po/ja.po
index c0fd4be2395..11de13e75b1 100644
--- a/gcc/po/ja.po
+++ b/gcc/po/ja.po
@@ -20,7 +20,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 8.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2018-07-17 22:26+0900\n"
 "Last-Translator: Takeshi Hamasaki <hmatrjp@users.sourceforge.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -2049,18 +2049,18 @@ msgstr "strfmon 書式の長さ修飾子"
 msgid "<command-line>"
 msgstr "<コマンドライン>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
@@ -2068,77 +2068,77 @@ msgstr "コード '%c' に対する無効な被演算子です"
 msgid "invalid operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid vector permutation constant"
 msgid "invalid vector constant"
 msgstr "無効なベクトル順列定数です"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "被演算子がありません"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "無効な命令:"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "無効な %%d 被演算子です"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "無効なバージョン番号形式"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二進演算内で無効な被演算子です"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
@@ -2154,18 +2154,18 @@ msgid "invalid %%r value"
 msgstr "無効な %%r 値"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "無効な %%R 値"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
@@ -2195,7 +2195,7 @@ msgstr "無効な %%M 値"
 msgid "invalid %%U value"
 msgstr "無効な %%U 値"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
@@ -2205,7 +2205,7 @@ msgstr "無効な %%s 値"
 msgid "invalid %%C value"
 msgstr "無効な %%C 値"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
@@ -2215,10 +2215,10 @@ msgstr "無効な %%E 値"
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無効な %%xn コード"
@@ -2307,36 +2307,36 @@ msgstr "被演算子として無効な UNSPEC です"
 msgid "unrecognized supposed constant"
 msgstr "認識できない定数のようなもの"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "無効なシフト被演算子"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "述語付き Thumb 命令"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "条件シーケンスにある述語付き命令"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2344,13 +2344,13 @@ msgstr "コード '%c' に対する無効な被演算子です"
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "命令は決して実行されません"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2492,7 +2492,7 @@ msgstr "予期しない演算子"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2709,27 +2709,27 @@ msgstr "誤った output_move_double 被演算子"
 msgid "bad output_condmove_single operand"
 msgstr "誤った output_condmove_single 被演算子"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand %%xn code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand %%xn code invalid for QImode"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid fp constant"
@@ -2890,7 +2890,7 @@ msgstr "%<__fpreg%> に関する無効な操作です"
 msgid "invalid %%P operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -2944,7 +2944,7 @@ msgid "post-increment address is not a register"
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -2996,8 +2996,8 @@ msgstr "'%%%c' は有効な被演算子接頭辞ではありません"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "'%%%c' の無効な使用法です"
@@ -3141,185 +3141,239 @@ msgstr "スタック空間が足りなくなりました。\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "'%s' をシェル内で実行して制限値を上げてください\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx はハードウェア浮動小数を要求します"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "Disable preprocessing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "前処理を無効にする"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx と -mno-altivec は併用できません"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec は vsx を無効にします"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "無効な %%J 値"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "無効な %%D 値です"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無効な %%H 値"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "無効な %%J 値"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "無効な %%J 値"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "無効な %%J 値"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 #| msgid "Enable unaligned load/store instruction"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "%<__fpreg%> からの無効な変換です"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "%<__fpreg%> への無効な変換です"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "%<__fpreg%> からの無効な変換です"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "%<__fpreg%> への無効な変換です"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "%<__fpreg%> からの無効な変換です"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "%<__fpreg%> への無効な変換です"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "%<__fpreg%> からの無効な変換です"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "%<__fpreg%> への無効な変換です"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3330,93 +3384,93 @@ msgstr "シンボルによるメモリ参照は z10 またはそれ以降での
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'E' 出力修飾子用の無効な比較演算子です"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "'J' 出力修飾子用の無効な参照です"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "'R' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "'S' 出力修飾子用にはメモリ参照が予期されます"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "'S' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "'N' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "'M' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無効な定数です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 #| msgid "invalid constant for output modifier '%c'"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無効な式です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な式です"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "戻りでのポインタの先の符号が異なります"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3705,8 +3759,8 @@ msgstr "({無名})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
@@ -3726,7 +3780,7 @@ msgstr "%<;%> が予期されます"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -3734,7 +3788,7 @@ msgstr "%<)%> が予期されます"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -3752,21 +3806,21 @@ msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -3777,12 +3831,12 @@ msgstr "%<{%> が予期されます"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
@@ -3791,7 +3845,7 @@ msgstr "%<while%> が予期されます"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -3800,18 +3854,18 @@ msgstr "%<,%> が予期されます"
 msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
@@ -3819,19 +3873,19 @@ msgstr "%<,%> または %<)%> が予期されます"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
@@ -3840,7 +3894,7 @@ msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -3852,36 +3906,36 @@ msgstr "%<<%> が予期されます"
 msgid "expected label"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "候補 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable user-defined instructions"
 msgid "  after user-defined conversion:"
 msgstr "利用者定義命令を有効にする"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "候補 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "候補 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "case ラベルにジャンプしています"
 
@@ -3975,7 +4029,7 @@ msgstr "<テンプレートパラメータエラー>"
 msgid "<statement>"
 msgstr "<文>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<不明>"
@@ -4154,48 +4208,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "単項マイナスへの引数の型が間違っています"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "単項プラスへの引数の型が間違っています"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "ビット反転への引数の型が間違っています"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs への引数の型が間違っています"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "複素共役(~)への引数の型が間違っています"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4236,17 +4290,17 @@ msgstr "無効な文字定数が #if にあります"
 msgid "elemental binary operation"
 msgstr ""
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr ""
@@ -4321,7 +4375,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4336,7 +4390,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4449,11 +4503,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
@@ -4462,223 +4516,223 @@ msgstr "代入"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "not enough arguments"
 msgid "asynchronous argument"
 msgstr "十分な引数がありません"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "invalid PHI argument"
 msgid "optional argument"
 msgstr "無効な PHI 引数です"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 msgid "pointer argument"
 msgstr "代入"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 #| msgid "invalid PHI argument"
 msgid "value argument"
 msgstr "無効な PHI 引数です"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "array assignment"
 msgid "coarray argument"
 msgstr "配列代入"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "引数がありません"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 #| msgid "mismatched arguments"
 msgid "assumed-type argument"
 msgstr "合っていない引数です"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 #| msgid "<unknown operator>"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "<不明な演算子>"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4691,27 +4745,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4786,7 +4840,7 @@ msgstr ""
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5269,7 +5323,7 @@ msgstr "一時配列の生成に関して警告する"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
@@ -5879,8 +5933,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
@@ -8629,109 +8683,103 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "主ファイル内で定義されているが使用されていないマクロに関して警告する"
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "変数がそれ自身によって初期化されている場合に警告する"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "Dump various analyzer internals to stderr."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13703,9 +13751,9 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "instruction scheduling not supported on this target machine"
-msgid "Use instructions for a future architecture."
-msgstr "命令スケジューリングはこのターゲットマシンではサポートされません"
+#| msgid "Use vector/scalar (VSX) instructions"
+msgid "Use instructions added in ISA 3.1."
+msgstr "vector/scalar (VSX) 命令を使用する"
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13719,6 +13767,12 @@ msgstr "複数命令のロード/ストアを生成する"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "整列されていないメモリ参照を使用しない"
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate bit instructions"
+msgid "Generate (do not generate) MMA instructions."
+msgstr "ビット命令を生成する"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -19265,7 +19319,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -19962,408 +20016,408 @@ msgstr "反復回数が既知のとき、ループ展開を行なう"
 msgid "Perform loop unrolling for all loops."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "ループの展開を行う"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "巻き戻しを行なう例外補足用テーブルを生成する"
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "変数追跡を実施する"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "変数追跡を実施する"
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "余分なコメントをアセンブラ出力に追加する"
 
-#: common.opt:3001
+#: common.opt:3005
 #, fuzzy, no-c-format
 #| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tシンボル可視性のデフォルトを設定する"
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 #| msgid "Enable conditional execution other than moves/scc"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "moves/scc 以外で条件付き実行を有効にする"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:3076
+#: common.opt:3080
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
-#: common.opt:3080
+#: common.opt:3084
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 (or later) format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 (またはそれ以降) 形式でデバッグ情報を生成する"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "デフォルト拡張形式でデバッグ情報を生成する"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "各関数で単一の終了点を生成する"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, fuzzy, no-c-format
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "拡張 STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 #| msgid "Toggle debug information generation"
 msgid "Toggle debug information generation."
 msgstr "デバッグ情報生成の有効・無効を切り替える"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "VMS 形式でデバッグ情報を生成する"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "拡張 XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "isel 命令を生成する"
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "-o <file>\tPlace output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t出力を <file> に配置する"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "関数プロファイルを有効にする"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic と同様だが、エラーとして出力する"
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "コンパイルされた関数または費やした時間に関して出力しない"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "冗長な出力を有効にする"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "`コンパイラのバージョンを表示する"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "警告を抑止する"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "共有ライブラリを作成する"
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21579,8 +21633,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "計算された値が使用されません"
@@ -21608,7 +21662,7 @@ msgid "expected boolean type"
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected integer"
@@ -21682,7 +21736,7 @@ msgstr "十分な引数がありません"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "引数が多すぎます"
@@ -22074,7 +22128,7 @@ msgstr "%qE 属性は %s 属性と競合します"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -22160,12 +22214,12 @@ msgstr "型が既に定義されているため型属性が無視されました
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -22183,8 +22237,8 @@ msgstr "%qE 属性は無視されました"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "前方での `%s' の宣言"
@@ -22306,7 +22360,7 @@ msgstr "%qD はここで宣言されています"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "オフセットが定数文字列の境界の外にあります"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -22602,7 +22656,7 @@ msgstr "%qs への有効な引数は次の通りです: %s"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K %<__builtin_va_arg_pack ()%> の無効な使用法です"
@@ -22909,12 +22963,12 @@ msgstr "%<asm%> 被演算子制約が被演算子サイズと互換性があり
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "%<asm%> 被演算子制約が被演算子サイズと互換性がありません"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "スタック防護機能が局所変数を防護していません: 可変長バッファ変数です"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "スタック防護機能が関数を防護していません: 全ての局所配列が %d バイト以下です"
@@ -23428,309 +23482,309 @@ msgstr "基本ブロックが連続的に番号付けられていません"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "命令連鎖中の bb の数 (%d) が n_basic_blocks (%d) と違います"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "insufficient arguments to overloaded function %s"
 msgid "missing direct call for speculation %i"
 msgstr "オーバーロードされた関数 %s への不十分な引数です"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use control speculation"
 msgid "missing ref for speculation %i"
 msgstr "制御投機を使用する"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "tp_first_run must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "シンボルが有効であると見なす"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "戻り型が void の関数で、`return' に値があります"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "edge count is not compatible with function count"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "セクションポインタを欠いています"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "重複する `virtual' 指定子"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "`%s' は宣言よりも先に使用されました"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "文が予期されます"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node に失敗しました"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr ""
@@ -23823,12 +23877,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F が使用されましたが定義されていません"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
@@ -23990,7 +24044,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "`この設定内では LTO サポートが有効になっていません"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t open %s: %m"
 msgid "cannot open %s: %m"
@@ -24337,22 +24391,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "命令内に無効な rtl 共有が見つかりました"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "共有 rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "内部一貫性がありません"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn が emit_jump_insn が必要な場所で使用されました:\n"
@@ -24417,7 +24471,7 @@ msgstr "region_array が region_tree と適合しません"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array が region_tree と適合しません"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "atexit failed"
 msgid "%qs failed"
@@ -24448,12 +24502,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -24470,7 +24524,7 @@ msgstr "%qs への有効な引数は次の通りです: %s"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "フレームサイズ (%wd バイト) が %wd バイトより大きいです"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "最終命令ダンプファイル %qs が開けません: %m"
@@ -24490,37 +24544,37 @@ msgstr "大きな固定小数定数が暗黙的に固定整数型に切り詰め
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較が常に %d となります"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -25179,13 +25233,13 @@ msgstr "関数が局所変数のアドレスを返します"
 msgid "function returns address of local variable"
 msgstr "関数が局所変数のアドレスを返します"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "ここで宣言されています"
@@ -25765,10 +25819,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -25944,7 +25998,7 @@ msgstr "`%s' の宣言が矛盾しています"
 msgid "enclosing %<target%>"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
@@ -25995,13 +26049,13 @@ msgstr "インスタンス変数 `%s' は private と宣言されています"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -26011,150 +26065,150 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "結果の数が値の数と一致しません"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification に失敗しました"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "このコードまで到達した場合、プログラムは中止されます"
@@ -26230,7 +26284,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -26511,48 +26565,48 @@ msgstr "<戻り値> "
 msgid "the extra base is defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -26585,37 +26639,37 @@ msgstr "関数は正常に戻ると分かった場合、属性 %<%s%> の候補
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr "検証エラー (PC=%d)"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -26667,57 +26721,57 @@ msgstr "%<asm%> 内の被演算子制約に一貫性がありません"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -26992,54 +27046,54 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "previously used here"
 msgid "... to the previous %qs clause here"
 msgstr "前にここで使われました"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "switch starts here"
 msgid "... with %qs clause here"
 msgstr "switch がここから開始します"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -27266,53 +27320,53 @@ msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 msgid "invalid branch to/from %s structured block"
 msgstr "OpenMP 構造化ブロックへ/からの無効な分岐です"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "routine %qD declared here"
 msgstr "%qD はここで宣言されています"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -28756,143 +28810,143 @@ msgstr "-fstack-protector はこのターゲットではサポートされてい
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "命令スケジューリングはこのターゲットマシンではサポートされません"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "このターゲットマシンは遅延分岐を持っていません"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore はこのターゲットマシンではサポートされません"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr ""
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the \"%s\" debug format"
 msgid "target system does not support the %qs debug format"
 msgstr "ターゲットシステムは \"%s\" デバッグ形式をサポートしません"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "変数追跡が要求されましたが、デバッグ情報を生成しない限り意味がありません"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "変数追跡が要求されましたが、このデバッグ形式ではサポートされていません"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections はこのターゲットではサポートされていません"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays はこのターゲットではサポートされていません"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays はこのターゲットではサポートされていません (-march スイッチを試してください)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays を -Os と併せて使用することはサポートされていません"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math は無効です。他のオプションが優先して使用されます"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -fpic are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fPIC and -fpic はこのターゲットではサポートされていません"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "%s への書き込み中にエラーが発生しました: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "-mas100-syntax is incompatible with -gdwarf"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "-mas100-syntax と -gdwarf は併用できません"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -28989,188 +29043,188 @@ msgstr "大域 register 変数が関数定義の後ろにあります"
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR が変更されたときに定数が再計算されません"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR が変更されたときに副作用が計算されません"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr ""
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "間接参照内で無効な被演算子です"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "non-scalar type"
 msgid "non-scalar %qs"
 msgstr "非スカラー型"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "integral result type precision does not match field size of BIT_FIELD_REF"
 msgid "integral result type precision does not match field size of %qs"
 msgstr "整数結果の型精度が BIT_FIELD_REF のフィールドサイズに適合しません"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
 #| msgid "mode precision of non-integral result does not match field size of BIT_FIELD_REF"
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "非整数結果のモード精度が BIT_FIELD_REF のフィールドサイズに適合しません"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs of non-mode-precision operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "配列参照内で型不一致です"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "%%R への無効な被演算子です"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "型が前方の外部宣言と一致しません"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid shift operand"
 msgid "invalid %qs offset operator"
 msgstr "無効なシフト被演算子"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "NaN から整数への変換です"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address operand in MEM_REF"
 msgid "invalid address operand in %qs"
 msgstr "MEM_REF 内で無効なアドレス被演算子です"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offset operand in MEM_REF"
 msgid "invalid offset operand in %qs"
 msgstr "MEM_REF 内で無効なオフセット被演算子です"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "無効な %qD の使用です"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "INDIRECT_REF in gimple IL"
 msgid "%qs in gimple IL"
 msgstr "INDIRECT_REF が gimple IL 内にあります"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "gimple 呼び出し内で無効な関数です"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "gimple 呼び出し内で非関数です"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr ""
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "gimple 呼び出し内で無効な LHS です"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "gimple 呼び出し内で無効な変換ですcall"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -29181,548 +29235,548 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "gimple 呼び出しへの無効な引数です"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in comparison expression"
 msgid "mismatching comparison operand types"
 msgstr "比較式内で型不一致です"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "non-vector operands in vector comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector permutation constant"
 msgid "invalid vector comparison resulting type"
 msgstr "無効なベクトル順列定数です"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "bogus comparison result type"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "単項演算子内で無効な被演算子です"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "nop 変換内で無効な型です"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "nop 変換内で無効な型です"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "アドレス空間変換内で無効な型です"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "固定小数変換内で無効な型です"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "浮動小数点への変換内で無効な型です"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "整数への変換内で無効な型です"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in address expression"
 msgid "type mismatch in %qs expression"
 msgstr "アドレス式内で型不一致です"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "`%s' に対するレジスタ名として無効です"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "二進演算内で無効な被演算子です"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-vector operands to vector valued plus"
 msgid "invalid non-vector operands to %qs"
 msgstr "ベクトル値加算への無効な非ベクトル被演算子です"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "無効なポインタモード %qs です"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "vector type expected in %qs"
 msgstr "整数式が予期されます"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "二進式内で型不一致です"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "vector types expected in %qs"
 msgstr "整数式が予期されます"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "vectors with different element number found in %qs"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "無効な回転 (rotate) 命令です"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size in %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number %qs"
 msgid "non-trivial conversion in %qs"
 msgstr "無効なバージョン番号 %qs です"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "%qs LHS in clobber statement"
 msgstr "式内"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R への無効な被演算子です"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments to function %qE"
 msgid "incorrect number of vector %qs elements"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "PHI argument is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI 引数が GIMPLE 値ではありません"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "non-vector %qs with elements"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "return 文内で無効な被演算子です"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "return 文内で無効な変換です"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto の先がラベルでもポインタでもありません"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "switch 文への無効な被演算子です"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to switch statement"
 msgid "non-integral type switch statement"
 msgstr "switch 文への無効な被演算子です"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to switch statement"
 msgid "invalid case range in switch statement"
 msgstr "switch 文への無効な被演算子です"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "label_to_block_map 内に間違ったエントリがあります"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "gimple 条件内で無効なラベルです"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "無効な PHI 結果です"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "PHI 定義がありません"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "無効な PHI 引数です"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in PHI argument %u"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "PHI 引数 %u 内で互換性のない型です"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple に失敗しました"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "EH 表内に不要な (dead) STMT があります"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) が間違った基本ブロックに設定されています"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) が間違った基本ブロックに設定されています"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "文が throw とマークされていますが、 throw しません"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple に失敗しました"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "非局所ラベル "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "ラベル "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "明示的な goto が基本ブロック %d の末尾にあります"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr ""
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> 関数が戻り (return) ます"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "制御が非 void 関数の終りに到達しました"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -29739,47 +29793,47 @@ msgstr "%q+D が再定義されました"
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -30296,12 +30350,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr "verify_ssa に失敗しました"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -30372,7 +30426,7 @@ msgstr "配列の添字が配列境界の外にあります"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -30383,31 +30437,31 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "共用体がここで定義されています"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "配列の添字が配列の境界を下回っています"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -30486,34 +30540,34 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型は廃止されました: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "型は廃止されました"
@@ -30538,236 +30592,236 @@ msgstr "型は廃止されました"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "type is not compatible with its variant"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "main variant is not defined"
 msgstr "環境変数 %qs が定義されていません"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -30901,86 +30955,86 @@ msgstr "要求された %q+D 用の整列は実装されている整列 %wu よ
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D の記憶域サイズが不明です"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "整数/固定小数用の初期化子が複雑すぎます"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "浮動小数点数の初期設定子の値が、浮動小数点定数ではありません"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "メンバ %qE 用の無効な初期値です"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%q+D の弱い (weak) 宣言は定義の前に無ければ行けません"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D の弱い (weak) 宣言は公開 (public) でなければいけません"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "%q+D の弱い (weak) 宣言はサポートされていません"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "弱い別名のみこの設定ではサポートされています"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "弱い参照はこの設定ではサポートされていません"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "弱い参照 %q+D は静的リンクされなければいけません"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "この設定では別名定義はサポートされていません"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s はこの設定ではサポートされていません"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可視性属性はこの設定ではサポートされていません。無視されました"
@@ -31607,7 +31661,7 @@ msgstr "%qE 属性は %qE 用としては無視されます"
 msgid "type was previously declared %qE"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
@@ -31629,7 +31683,7 @@ msgstr "%qD は %qD 内では宣言されていません"
 msgid "%qE argument is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "廃止された (deprecated) メッセージが文字列ではありません"
@@ -32026,12 +32080,12 @@ msgstr "列挙型定数がここで定義されています"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "真偽値として使われる代入のまわりでは、丸括弧の使用をお勧めします"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> の誤った使用法です"
@@ -32195,12 +32249,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -32306,7 +32360,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "配列のサイズが大きすぎます"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -32318,82 +32372,82 @@ msgstr "%d 番目の %qE の引数用の互換性がない型です"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "types are not quite compatible"
 msgid "both arguments must be compatible"
 msgstr "型は全く互換がありません"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be an address"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be an address"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a multiple of %d"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%d 番目の %qE の引数は %d の倍数でなければいけません"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "invalid memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -32401,55 +32455,55 @@ msgstr "%qT から %qT への変換が曖昧です"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "built-in function %qE must be directly called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "配列 %qE のサイズが負です"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "配列 %qE のサイズが負です"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -32508,33 +32562,33 @@ msgstr "%qE は認識できない書式関数型です"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "書式文字列引数が文字列型ではありません"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "関数が %qs 書式属性の候補である可能性があります"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "書式内に $ の被演算子番号がありません"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s は %%n$ 被演算子番号書式をサポートしません"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "被演算子番号が書式の範囲外です"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "%d 番目の書式引数が %s 書式内で二回以上使用されています"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
@@ -32542,504 +32596,504 @@ msgstr "$ 被演算子番号が被演算子番号が無い書式の後に使用
 
 # %d の位置の都合上 before を前と訳せないため意訳しています
 # 苦しい訳です
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "$-スタイル書式内の %d 番目の引数が、後にある %d 番目の引数が使用されたにも関わらず使用されていません"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "書式が文字列リテラルではありません。書式文字列は検査されません"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "書式が文字列リテラルでは無く、かつ書式引数ではありません"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "書式が文字列リテラルではありません。引数の型は検査されません"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "書式への引数が多すぎます"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "$-スタイルの書式で未使用の引数があります"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "長さが 0 の %s 書式文字列です"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "書式がワイド文字列です"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string argument is not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "書式文字列引数が文字列型ではありません"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "終端されていない書式文字列です"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s が %<%%%c%> %s 書式と併せて使用されています"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s は %s をサポートしません"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s は %s と %<%%%c%> %s 書式を併せて使用することをサポートしません"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "書式内に %s の繰り返しがあります"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "strfmon 書式の最後に詰め文字がありません"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "%s 書式の幅が 0 です"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "%s 書式の左精度が空です"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "%s 書式の精度が空です"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s は %qs %s 長さ修飾子をサポートしません"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s は %<%%%c%> %s 書式をサポートしません"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s は %s と %<%%%c%> %s 書式を併せて使用しているため無視されます"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s は %s を %s 書式で使用しているため無視されます"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "%s と %s を %<%%%c%> %s 書式で一緒に使用しています"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "%s と %s を %s 書式で一緒に使用しています"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> はいくつかのロケールでは年の下二桁のみを表します"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> は年の下二桁のみを表します"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "%<%%[%> 書式用の閉じる %<]%> がありません"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "%qs 長さ修飾子を %qc 型変換文字で使用しています"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s は %<%%%s%c%> %s 書式をサポートしません"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "被演算子番号が代入の抑制と共に使われています"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "被演算子番号が引数を取らない書式で指定されています"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "書式内に %<\\0%> が組み込まれています"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "spec %qs invalid"
 msgid "use %qs instead"
 msgstr "spec %qs が無効です"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "multiple function type attributes specified"
 msgid "unquoted attribute in format"
 msgstr "複数の関数型属性が指定されています"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "組み込み関数への無効な引数です"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr "%<-mcpu=%> は廃止されました。代わりに %<-mtune=%> または %<-march=%> を使用してください"
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "書式内に %s の繰り返しがあります"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph characters in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Do not generate #line directives"
 msgid "unterminated quoting directive"
 msgstr "#line 指示を生成しない"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "書式の最後に型変換がありません"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "#ident 指示を処理する"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "書式内に %<\\0%> が組み込まれています"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated format string"
 msgid "unterminated color directive"
 msgstr "終端されていない書式文字列です"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "NULL ポインタを通して書き込んでいます (第 %d 引数)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "NULL ポインタを通して読み込んでいます (第 %d 引数)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "定数オブジェクトに書き込んでいます (第 %d 引数)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "書式引数内に余分な型修飾子があります (第 %d 引数)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> は引数の型が %<%s%s%> であると予期されますが、第 %d 引数の型は %qT です"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> は対応した %<%s%s%> 引数が予期されます"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> は引数の型が %<%T%s%> であると予期されますが、第 %d 引数の型は %qT です"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> は対応した %<%T%s%> 引数が予期されます"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> が型として定義されていません"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> が %<long%> または %<long long%> として定義されていません"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> が型として定義されていません"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> が型として定義されていません"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> が型として定義されていません"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> が型として定義されていません"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "書式解釈される引数が %<...%> ではありません"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime 書式は引数を書式解釈できません"
@@ -33205,7 +33259,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -33221,17 +33275,17 @@ msgstr "%qs が自動変数 %qE 用に指定されています"
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
@@ -33241,7 +33295,7 @@ msgstr "増分式がありません"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -33891,7 +33945,7 @@ msgid "wrong type argument to %s"
 msgstr "%s への間違った型の引数です"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "定数式内でオーバーフローしました"
@@ -34595,7 +34649,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
@@ -34679,7 +34733,7 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -34699,7 +34753,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
@@ -34720,7 +34774,7 @@ msgstr "%qs は前処理の有効なオプションではありません"
 msgid "too many input files"
 msgstr "入力ファイルが多すぎます"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -34754,15 +34808,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -35327,429 +35381,436 @@ msgstr "別名定義は Mach-O ではサポートされていません。無視
 msgid "profiler support for VxWorks"
 msgstr "VxWorks 用のプロファイルサポート"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引数は定数でなければいけません"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "マスクは即値でなければなりません"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "引数は定数でなければいけません"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "multilib はサポートしません"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "引数は定数でなければいけません"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected expression"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "式が予期されます"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected expression"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "式が予期されます"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> が文字列または番号ではありません"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明な #pragma GCC coprocessor %E です"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "関数型に対して new を適用できません"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<operator%> が予期されます"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with Thumb"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with Thumb"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the bit-field instructions"
 msgid "this operation requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the bit-field instructions"
 msgid "%qE requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid format for sve_width"
 msgstr "無効な #pragma %s です"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "無効な %%h 値"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function %qs"
 msgid "unknown tuning option (%s)"
 msgstr "不明な spec 関数 %qs です"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib はサポートしません"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, fuzzy, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "間違った形式の %<#pragma init%> です"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -35946,17 +36007,17 @@ msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありま
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありません"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -36122,13 +36183,13 @@ msgstr "不明な IRA アルゴリズム %qs です"
 msgid "invalid type for %<asm%> flag output"
 msgstr "無効な被演算子出力コード"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "coprocessor not enabled"
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "コプロセッサが有効ではありません"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -36136,199 +36197,199 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "引数は定数でなければいけません"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "マスクは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "セレクタは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "マスクは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -36338,310 +36399,310 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC と -G は併用できません"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "バックトレースサポートの有効化は Thumb 用にコンパイルしたときのみ意味があります"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "呼び出し先 ARM/Thumb 相互利用有効化は Thumb 用にコンパイルしたときのみ意味があります"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g に -mno-apcs-frame をつけると、きめ細かなデバッグはできないでしょう"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "-mtp=cp15 を 16 ビット Thumb で使用できません"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-G はデフォルトの PIC コードと共存できません"
 
 # 公式な名前は Thumb であり THUMB ではない
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "target CPU does not support unaligned accesses"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check と -mno-apcs-frame は併用できません"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic と -mapcs-reent は併用できません"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS 再入可能コードはサポートされていません。無視されました"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC は -msingle-pic-base と併用できません"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= は -fpic をつけないと役に立ちません"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "PIC レジスタ用に '%s' を使用できません"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上ではサポートされていません"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable と -msdata=%s は併用できません"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt は適切な操作用に AAPCS 互換 ABI を必要とします"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt ABI は iwmmxt 機能がある CPU を必要とします"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "ターゲット CPU は ARM/Thumb 相互利用をサポートしていません"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS は -mcaller-super-interworking をサポートしません"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS は -mcallee-super-interworking をサポートしません"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 かつ ldrh 無し"
 
 # 公式な名前は Thumb であり THUMB ではない
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard および VFP"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard および VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 ハードウェア浮動小数 VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect on unit local functions"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "スタックに積まれた仮引数の実際の位置を計算できません"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高位レジスタを pop する為に使用できる低位レジスタがありません"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -36650,24 +36711,24 @@ msgstr "%qs 属性用の無効なベクトル型です"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes SPE ABI"
 msgid "unknown target attribute or pragma %qs"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -36760,18 +36821,18 @@ msgstr "-fpic はサポートされていません"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-pedantic と -traditional とは相互排他的です"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "%qs function cannot have arguments"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "functions cannot return __fp16 type"
 msgid "%qs function cannot return a value"
@@ -37064,7 +37125,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "組み込み関数への無効な引数です"
@@ -37418,56 +37479,56 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "浮動小数点レジスタで浮動小数点引数を渡す"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "wrong type of argument %s"
 msgstr "%s への間違った型の引数です"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr "ret 命令は実装されていません"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "Builtin not implemented"
 msgstr "DW_LOC_OP %s は実装されていません"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "被演算子の数字が範囲外です"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -37617,144 +37678,144 @@ msgstr "%qs への引数は 2 ビット符号無しリテラルでなければ
 msgid "parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE は isa オプション %s が必要です"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後の引数は即値でなければいけません"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -38180,154 +38241,154 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -38808,7 +38869,7 @@ msgstr "%qE は %<mips16%> と %<nomips16%> 属性の両方を持つことは出
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE が競合する %qs 属性付きで再宣言されました"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -39972,56 +40033,56 @@ msgstr "%qE 属性は整数定数引数のみ許可されています"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -40148,367 +40209,368 @@ msgstr "数値は 0 または 1 でなければいけません"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "#pragma longcall の末尾にゴミがあります"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s はこの設定ではサポートされていません"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function to %s already processed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs はこのターゲットではサポートされていません"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a value between 0 and 3."
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a value between 0 and 7."
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "%srtd%s は 64 ビットモードでは無視されます"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+#| msgid "%srtd%s is ignored in 64bit mode"
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "%srtd%s は 64 ビットモードでは無視されます"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "第三引数は 4 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "第三引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "%q+D の第二引数は %<char **%> であるべきです"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "%qs is only valid for the cell processor"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "%qs requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "%qs requires the %qs and %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "Enable 32-bit multiply instructions"
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "32 ビット乗算命令を有効にする"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE not supported for MIPS16"
 msgid "%qs is not supported with the current options"
 msgstr "組み込み関数 %qE は MIPS16 用にはサポートされていません"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
@@ -40531,242 +40593,247 @@ msgstr "レジスタ r2 と r5 を使用する"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 は PowerPC64 アーキテクチャが有効のまま残されていることが必要です"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power は 64 ビット Darwin ではサポートされていません。インストールされている C および C++ ライブラリと互換性がありません"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring はリトルエンディアンシステム上ではサポートされていません"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "target 属性または pragma が long double のサイズを変更します"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s は %s をサポートしません"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s は %s をサポートしません"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
 #| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target 属性または pragma が AltiVec ABI を変更します"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target 属性または pragma が darwin64 ABI を変更します"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t use %qs as a call-used register"
 msgid "%qs needs a valid base register"
 msgstr "%qs を呼び出しで使用されるレジスタとして使用できません"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
@@ -41121,148 +41188,148 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局所変数の合計サイズがアーキテクチャの制限を超過しています"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs のフレームサイズ: "
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs は動的スタック割り当てを使用します"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ハードウェア十進浮動小数点命令は ESA/390 モードでは使用出来ません"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp は -msoft-float と併用できません"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float の組み合わせはサポートされていません"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "スタックサイズは 64k より大きくてはいけません"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard は -mstack-size を暗黙的に使用します"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 属性は SH2A 用にのみサポートされています"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -41709,8 +41776,8 @@ msgstr "%qs 属性は配列型のみに適用できます"
 msgid "could not read the BRIG file"
 msgstr "応答ファイル %s を書き込めませんでした"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void の値が本来の意味通りに無視されませんでした"
@@ -41993,7 +42060,7 @@ msgstr "%q+D の宣言は前の非変数を隠します"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
@@ -42066,7 +42133,7 @@ msgstr "%qE が宣言されていません (この関数内での最初の使用
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "未宣言の識別子は出現した各関数内で一回のみ報告されます"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ラベル %qE があらゆる関数の外側から参照されました"
@@ -42096,7 +42163,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr "重複したラベルの宣言 %qE です"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複したラベル %qD です"
@@ -42312,7 +42379,7 @@ msgstr "volatile フィールドがあるオブジェクトをレジスタに配
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -42660,7 +42727,7 @@ msgstr "型名は配列を返す関数として定義されています"
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
@@ -42983,7 +43050,7 @@ msgstr "%<struct %E%> の入れ子になった再定義です"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "%qs 式内での型定義は C++ では無効です"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
@@ -43033,7 +43100,7 @@ msgstr "構造体に名前付きメンバがありません"
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
@@ -43071,7 +43138,7 @@ msgstr "%<enum %E%> の入れ子になった再定義です"
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> の再定義です"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -43102,7 +43169,7 @@ msgstr "列挙値がオーバーフローしました"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -43134,7 +43201,7 @@ msgstr "前に %qD 用のプロトタイプがありません"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
@@ -43249,12 +43316,12 @@ msgstr "引数 %qD が組み込みプロトタイプと一致しません"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
@@ -43262,275 +43329,275 @@ msgstr "仮引数 %qD が設定されましたが使用されません"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "オプション -std=c99 または -std=gnu99 をコードコンパイル時に使用してください"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "静的変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "非変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "互換性のないアドレス空間修飾子 %qs と %qs です"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "宣言指定が予期されます"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE が重複しています"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "固定小数点型はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C は固定小数点型をサポートしません"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE は宣言の開始ではありません"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s は %s をサポートしません"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> が %<extern%> の前にあります"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> が %<static%> の前にあります"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣言指定内に複数の記憶域クラスがあります"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> が %<_Fract%> または %<_Accum%> 無しで使用されています"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右シフト回数が負です"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -43551,7 +43618,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -43599,7 +43666,7 @@ msgid "unknown type name %qE"
 msgstr "不明な型名 %qE です"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -43621,7 +43688,7 @@ msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -43636,8 +43703,8 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -43678,7 +43745,7 @@ msgstr "ファイルスコープの空の宣言内に %<auto%> があります"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> または %<;%> が予期されます"
@@ -43706,7 +43773,7 @@ msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "文字列リテラルが予期されます"
@@ -43737,7 +43804,7 @@ msgstr "静的アサーション内の式が定数ではありません"
 msgid "static assertion failed: %E"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -43786,14 +43853,14 @@ msgstr "マクロ引数 \"%s\" は文字列化されます"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列挙型リストの最後にコンマがあります"
@@ -43880,7 +43947,7 @@ msgstr "宣言指定または %<...%> が予期されます"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not take any arguments"
@@ -43892,7 +43959,7 @@ msgstr "%qE 属性は型に適用できません"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -43952,7 +44019,7 @@ msgstr "ISO C90 は宣言とコードの混合を禁止しています"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> が %<else%> の前に予期されます"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> の前に %<if%> がありません"
@@ -43967,7 +44034,7 @@ msgstr "複合文の最後にラベルがあります"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "文が予期されます"
@@ -43992,17 +44059,17 @@ msgstr "ラベルは文または宣言の一部にのみなることができま
 msgid "expected identifier or %<*%>"
 msgstr "識別子または %<*%> が予期されます"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%<if%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%<else%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "%<else%> が曖昧になることを避けるために明示的に中括弧で括ることを推奨します"
@@ -44022,12 +44089,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44043,8 +44110,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重複した %<volatile%> です"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "first seen here"
@@ -44075,12 +44142,12 @@ msgstr "ISO C は中間項が省略された ?: 式を禁じます"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -44507,64 +44574,64 @@ msgstr "objective-c メソッド定義が予期されます"
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -44575,19 +44642,19 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
@@ -44609,59 +44676,59 @@ msgstr "%<,%> または %<)%> が予期されます"
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -44684,13 +44751,13 @@ msgstr "%<num_threads%> 値は正でなければいけません"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
@@ -44702,25 +44769,25 @@ msgstr "%<num_threads%> 値は正でなければいけません"
 msgid "expected constant integer expression"
 msgstr "整数式が予期されます"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with unspecified category"
@@ -44738,58 +44805,58 @@ msgstr "添え字は整数でなければいけません"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<concurrent%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
@@ -44800,7 +44867,7 @@ msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりませ
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -44837,25 +44904,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with Thumb"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -44873,82 +44940,82 @@ msgstr "`無効なスケジュールの種類です"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -44964,7 +45031,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "メンバ関数の名前を欠いています"
@@ -44974,72 +45041,72 @@ msgstr "メンバ関数の名前を欠いています"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -45049,62 +45116,62 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -45114,76 +45181,76 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -45200,65 +45267,65 @@ msgstr "%<#pragma align%> は %D の前に現れなければいけません。
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected trait selector name"
 msgstr "クラス名が予期されます"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "score argument must be constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "score argument must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "文字列リテラルが予期されます"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "property must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -45269,13 +45336,13 @@ msgstr "%<catch%> が予期されます"
 msgid "variant %qD is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s と -msdata=%s は併用できません"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -45286,35 +45353,35 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -45372,45 +45439,45 @@ msgstr "関数が予期されます"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -45427,27 +45494,27 @@ msgstr "可変長配列が使用されています"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -45457,7 +45524,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -45473,7 +45540,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD は不完全型を持っています"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void 式の無効な使用法です"
@@ -45603,7 +45670,7 @@ msgstr "%<void *%> ポインタの参照を解除しています"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "添字が付けられた値が、配列、ポインタまたはベクトルではありません"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "配列の添字が整数型ではありません"
@@ -45628,7 +45695,7 @@ msgstr "ISO C90 は左が値でない配列に添字を付けることを禁止
 msgid "enum constant defined here"
 msgstr "列挙型定数がここで定義されています"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -45746,18 +45813,18 @@ msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "文字列リテラルの比較結果は不定です"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "ポインタと整数との比較を行なっています"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -45782,7 +45849,7 @@ msgstr "関数ポインタの差を求めようとしています"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -46039,7 +46106,7 @@ msgstr "ポインタから異なるサイズの整数へのキャストです"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "型 %qT の関数呼び出しから一致しない型 %qT へのキャストです"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "異なるサイズの整数からポインタへのキャストです"
@@ -46213,7 +46280,7 @@ msgstr "左辺への代入は format 属性の候補のようです"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
@@ -46389,7 +46456,7 @@ msgstr "互換性のないポインタ型からの初期化です"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "適切でない型の配列が文字列定数で初期化されています"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "非左辺値配列の無効な使用です"
@@ -46420,7 +46487,7 @@ msgstr "初期化子の要素がロード時に計算出来ません"
 msgid "invalid initializer"
 msgstr "無効な初期化子です"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
@@ -46566,7 +46633,7 @@ msgstr "スカラー初期化子内の要素が多すぎます"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C は %<goto *expr;%> を禁止しています"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
@@ -46607,7 +46674,7 @@ msgstr "ISO C では %<long%> による switch 文は %<int%> による switch 
 msgid "case label is not an integer constant expression"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "switch 文の外にある case ラベルです"
@@ -46617,17 +46684,17 @@ msgstr "switch 文の外にある case ラベルです"
 msgid "%<default%> label not within a switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP のループ用に break 文が使用されています"
@@ -46644,7 +46711,7 @@ msgstr "ループまたは switch 文の外にある break 文です"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "効果がない文です"
@@ -46654,24 +46721,24 @@ msgstr "効果がない文です"
 msgid "expression statement has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, fuzzy, gcc-internal-format
 #| msgid "different number of results"
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -46723,7 +46790,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "NULL ポインタがあるポインタの順序比較です"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "整数 0 とポインタとの順序比較です"
@@ -46754,53 +46821,53 @@ msgstr "スカラーが必要な場所で共用体型の値が使用されてい
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "メンバ関数の名前を欠いています"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "参照を参照として宣言できません"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -46812,8 +46879,8 @@ msgstr "%qE は句 %qs 内では変数ではありません"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
@@ -46994,12 +47061,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
@@ -47024,8 +47091,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -47041,19 +47108,19 @@ msgstr "%qE がデータ句内で二回以上出現しています"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
@@ -47130,125 +47197,125 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "ソースはポインタではありません"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%> の第一引数が %<va_list%> 型ではありません"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -47456,852 +47523,852 @@ msgid "expected case label"
 msgstr "%<__label__%> が予期されます"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 #| msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  %qT から %qT へ %<this%> パラメータを暗黙的に変換する方法が不明です"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T, %T) <組み込み>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T) <組み込み>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%D(%T) <組み込み>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s%T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s%T <変換>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <deleted>"
 msgid "%s%#qD (deleted)"
 msgstr "%s%#D <削除済み>"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <deleted>"
 msgid "%s%#qD (reversed)"
 msgstr "%s%#D <削除済み>"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s: %s"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 msgid "  inherited here"
 msgstr "無効な初期化子"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "オーバーロードされている %<%D(%A)%> の呼び出しが曖昧です"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> への呼び出しが適合しません"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> の呼び出しが曖昧です"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E ? %E : %E%> 内にある三項演算子 %<operator?:%> が適合しません "
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> で %<%E%s%> 内にあるものが適合しません"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E[%E]%> 内の %<operator[]%> が適合しません"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> で %<%E %s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ は中間項が省略された ?: 式を禁止しています"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "条件式での型の組合わせが適合しません"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "pointer/integer type mismatch in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T と %q#T の間での比較です"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator %s%> は %qT 用としては適切ではありません"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D はアクセス出来ません"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL から非ポインタ型 %qT へ変換しています"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT 用の初期化子の周りに中括弧が多すぎます"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, fuzzy, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "関数呼び出しの引数が format 属性の候補であるようです"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "オーバーロードされた %<%s(%A)%> の呼び出しは曖昧です"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "デストラクタから値を返そうとしています"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "conversion from %q#T to %q#T"
 msgid "  for conversion from %qH to %qI"
 msgstr "%q#T から %q#T への変換です"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " 候補 1: %q+#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " 候補 2: %q+#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "無効なバージョン番号形式"
@@ -48332,550 +48399,550 @@ msgstr ""
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "`%s' のセクションは前方でに宣言されたものと衝突します"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "メソッド %q+D 用のアクセス指定が競合しています。無視されました"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "フィールド %qE 用のアクセス指定が競合しています。無視されました"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qT declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "クラス %qT 内の全てのメンバ関数が非公開です"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T はフレンドが無い非公開デストラクタのみ定義しています"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T はフレンドが無い非公開コンストラクタのみ定義しています"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D は隠されています"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "        %qD"
 msgid "  by %qD"
 msgstr "        %qD"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "ビットフィールド %q+#D が非整数型です"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ビットフィールド %q+D の幅が整数定数ではありません"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が負です"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が 0 です"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D の幅が型の大きさを超えています"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D は %q#T の全ての値を持つには小さすぎます"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "コンストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "デストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "コピー代入演算子を持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D は共用体のメンバのため静的ではありません"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "フィールド %q+D はが関数型として無効な宣言をされました"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "共用体 %qT 内の複数のフィールドが初期化されました"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "フィールド %q+#D がクラス名と同じです"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T がポインタデータメンバを持っています"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "関数を inline にできません"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "直接の基底 %qT は曖昧なため %qT 内でアクセスできません"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "仮想基底 %qT は曖昧なため %qT 内ではアクセスできません"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "可変配列メンバの無効な使用法です"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T は仮想関数を持っており非仮想デストラクタからアクセス可能です"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "type transparent %q#T does not have any fields"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "言語文字列 %<\"%E\"%> は認識できません"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "関数 %qD から型 %q#T への変換が適合しません"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "オーバーロードされた関数 %qD から型 %q#T への変換は曖昧です"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "メンバ %qD へのポインタと見なしています"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "型情報が不十分です"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -48956,7 +49023,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
@@ -49014,7 +49081,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr "`%s' の宣言は前方のローカルシンボルを覆い隠します"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
@@ -49073,398 +49140,397 @@ msgstr "初期化子の要素が定数ではありません"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not initialized with a constant expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not initialized with a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "ここで宣言されています"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qE は初期化されていません"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D は const ではありません"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D は volatile です"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "NaN から整数への変換です"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<template%>"
 msgid "unexpected template-id %qE"
 msgstr "%<template%> が予期されます"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "function concept must be called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "仮想関数は friend にできません"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have integral type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "evaluating %qs"
@@ -49514,7 +49580,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -49557,298 +49623,298 @@ msgstr "%q#T が浮動小数点値が予期される場所で使用されまし
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "%qT から非スカラ型 %qT への変換が要求されました"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "疑似デストラクタが呼び出されません"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "文は効果がありません"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT からのデフォルトの型変換が曖昧です"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -49919,7 +49985,7 @@ msgstr "前方での `%s' の宣言"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "前方での `%s' の宣言"
@@ -50114,12 +50180,12 @@ msgstr "前の %q+D の宣言はここです"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD"
@@ -50133,45 +50199,45 @@ msgstr "%q+D が再定義されました"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -50179,865 +50245,865 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %q+D"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%q+D の冗長な再宣言です"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  ここから"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  catch ブロックに入ります"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "文が予期されます"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "%qD used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 #| msgid "unknown type name %qE"
 msgid "no type named %q#T in %q#T"
 msgstr "不明な型名 %qE です"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求された整列が 2 の累乗ではありません"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一つの宣言に複数の型があります"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typdef 宣言で型名を欠いています"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "`%s' の宣言で型がデフォルトの `int' とされました"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef `%s' が初期化されました"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "重複した初期化子"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "変数 `%s' には初期化子がありますが、不完全型です"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "自明でないラベルのついた初期化子です"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 #| msgid "initialized variable %q+D is marked dllimport"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "初期化された変数 %q+D は dllimport とマークされています"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無効なビット列初期化子です"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C89 は複合リテラルを禁じます"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pramga が括弧で囲まれた文字列リテラルを受け取りました"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(クラス外での初期化を必要とします)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -51317,7 +51383,7 @@ msgstr "配列の次元がオーバーフローしました"
 msgid "%qD declared as array of %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
@@ -51484,7 +51550,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
@@ -51698,833 +51764,833 @@ msgstr "%qE 属性は無視されました"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function %qD without object"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "typedef may not be a member function definition"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "%s を開けません"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "static data member %qE declared %qs"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -52536,95 +52602,95 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "述語は識別子でなければなりません"
@@ -52633,77 +52699,77 @@ msgstr "述語は識別子でなければなりません"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant is too large for %<unsigned long%> type"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -52745,7 +52811,7 @@ msgstr "関数を削除 (delete) できません。%<delete%> の有効な引数
 msgid "deleting %qT is undefined"
 msgstr "%qT の削除は定義されていません"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
@@ -52755,7 +52821,7 @@ msgstr "%q#D のテンプレート宣言です"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "デストラクタ %qD がメンバテンプレートとして宣言されています"
@@ -53093,166 +53159,166 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "引数がありません"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -53437,345 +53503,345 @@ msgstr "可変配列メンバを初期化しています"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD はこの関数内で初期化されずに使用されています"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%qD will be initialized after"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "無効な初期化子"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "基底クラスを持つクラスのオブジェクト用の初期化子リストです"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "無効な参照型です"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %qT is invalid in C++"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "式内で整数がオーバーフローしました"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "variably modified type not allowed in new-expression"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "new に対して無効な型である `void'"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "フィールド '%s' がクラス内に見つかりません"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "関数型に対して new を適用できません"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初期設定子の末尾が本来より早く出現しました"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete での配列サイズが不明です"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
@@ -53938,13 +54004,13 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -53973,160 +54039,165 @@ msgstr "%q+D と型が競合しています"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "`java_interface' 属性は Java クラス定義に対してのみ用いる事ができます"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "`java_interface' 属性は Java クラス定義に対してのみ用いる事ができます"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "重複した %<const%> です"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "`::main' を static としては宣言できません"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%s に `%s' という名前のメンバはありません"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD is invalid in C++"
 msgid "initializer for %q#D is invalid"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "   ポインタからメンバへの変換で"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "キャストによる関数の型が適合しません"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "キャストによる関数の型が適合しません"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -54167,220 +54238,220 @@ msgstr "パラメタはメソッドの型を不正に宣言しました"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "無効な宣言です"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %qD"
 msgid "does not match previous declaration %q#D"
 msgstr "前に %qD 用の定義がありません"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "列挙型 %q+D の再宣言です"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qE"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D が宣言されています"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "`%s' 属性の疑似命令が無視されました"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "弱い %q+D は %qE として定義できません"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "構造体がここで定義されています"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "メソッド属性を指定するのは最後のみでなければいけません"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -54407,7 +54478,7 @@ msgstr "識別子 %qE は C++ 予約語と競合しています"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -54433,7 +54504,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -54514,7 +54585,7 @@ msgstr "無効な型: `void &'"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -54641,7 +54712,7 @@ msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
@@ -54765,7 +54836,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -54870,12 +54941,12 @@ msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -54910,7 +54981,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -54926,7 +54997,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -54942,7 +55013,7 @@ msgstr "ISO C++ は複合リテラルを禁じます"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "無効な %qD の使用です"
@@ -54968,967 +55039,972 @@ msgstr "ISO C++ は名前つき戻り値を許可しません"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected expression-list or type-id"
 msgstr "式が予期されます"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "古いスタイルのキャストを使用しています"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| と共に使われる && の周りでは括弧をつけることをお勧めします"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "already captured %qD in lambda expression"
 msgstr "単項演算式内で無効な被演算子です"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "%s を参照として宣言できません"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%q#D declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "%qs 句が多すぎます"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複した %<volatile%> です"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 #| msgid "attributes in parameter array declarator ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ラベル付き文が予期されます"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case ラベル %qE が switch 文の中にありません"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "フィールド %qE が関数として宣言されています"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "空の宣言です"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "メンバ関数 %qD 用の無効な初期化子です"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> がクラスの外側で使用されています"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, fuzzy, gcc-internal-format
 #| msgid "%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> は C++0x で意味が変更になります。削除してください"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "type-specifier invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無効なリンク指定です"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "前時代的な古いスタイルの基底クラス初期化子です"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "識別子が予期されます"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "二進演算内で無効な被演算子です"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "演算子が予期されます"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "cv-qualified type parameter"
 msgstr "無効なパラメータ %qs です"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "無効な型: `void &'"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "マクロ引数リストにあり得ないトークン"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "テンプレート名が予期されます"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "型指定が予期されます"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "型名が予期されます"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "共用体がここで定義されています"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> または %<{%> が予期されます"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD は名前空間名ではありません"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重複した %<volatile%> です"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD は関数スコープの外側で定義されていません"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -55937,447 +56013,447 @@ msgstr ""
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無効な宣言子です"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "宣言子が予期されます"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD は名前空間です"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ポインタ演算子が予期されます"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-specifier"
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> または %<...%> が予期されます"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "メソッドは関数ポインタに変換できません"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "構造体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> または %<:%> が予期されます"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "クラス %s 用のファイルを見つけられません。"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD の宣言内に無効なクラス名です"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T の前の定義"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "width of bit-field %qD has non-integral type %qT"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "ビットフィールドの幅が %qD 非整数型 %qT です"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<:%> または %<...%> が予期されます"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "expression must be enclosed in parentheses"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -56386,564 +56462,564 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> が予期されます"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c method declaration is expected"
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "整数式が予期されます"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不十分な型情報"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "メンバ関数の名前を欠いています"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option は関数内では許可されていません"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "#if 式の中では文字列定数が使えません"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -57221,7 +57297,7 @@ msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -57249,86 +57325,86 @@ msgstr "%q+D の再宣言は仮引数を隠します"
 msgid "template parameter %qD declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "関数 %qE への引数が多すぎます"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "重複したラベル %qD です"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 用のデフォルト引数がありません"
@@ -57336,47 +57412,47 @@ msgstr "%qD 用のデフォルト引数がありません"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "仮引数リスト中の `void' はリスト全体を占めなければなりません"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -57386,199 +57462,199 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "非テンプレート %q#D のテンプレート定義です"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %q+#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -57586,307 +57662,307 @@ msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "内部一貫性がありません"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE は宣言の開始ではありません"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
@@ -57904,296 +57980,296 @@ msgstr "メンバ関数へのポインタが呼ばれましたが、クラスス
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -58205,141 +58281,141 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "不完全な typedef `%s' の使用は不適切です"
@@ -58557,7 +58633,7 @@ msgstr "トップレベルでの `this' の使用は無効です"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -58608,7 +58684,7 @@ msgstr "無効な宣言です"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -58711,7 +58787,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -58753,7 +58829,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
@@ -58888,127 +58964,127 @@ msgstr "%qE がデータ句内で二回以上出現しています"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<hint%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -59268,829 +59344,829 @@ msgstr "型が全く異なるポインタの比較でキャストを欠いてい
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ビットフィールドに `__alignof' が適用されました"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "添字をつけられた値が配列でもポインタでもありません"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "メンバへのポインタ構築の使用でオブジェクトを欠いています"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ はプログラムの中から `::main' を呼び出すことを禁じます"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "関数に対する引数が多すぎます"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "関数への引数が少なすぎます"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "関数ポインタが計算で使われました"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ はポインタと整数との比較を禁じます"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮動小数点引数での順序付けられない比較です"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ポインタ演算で不完全型へのポインタを使うことは無効です"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ は `::main' 関数のアドレスを取ることを禁じます"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "register 変数 `%s' のアドレスが要求されました"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "NaN から整数への変換です"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "%s: 全体的な精度の低下"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "キャストによってポインタが示す型の要求アラインメントが増加します"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ は関数ポインタとオブジェクトポインタの間でのキャストを禁じます"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C は共用体型へのキャストを禁じます"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "配列の不正な初期化"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "代入として無効な左辺値です"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   ポインタからメンバ関数への変換で"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "無効なバージョン番号形式"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in return"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "return 文に十分な値がありません"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "デストラクタから値を返そうとしています"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "コンストラクタの関数 try ブロックのハンドラからは return できません"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -60360,110 +60436,110 @@ msgstr "スカラー初期化子が中括弧で囲まれています"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -60689,10 +60765,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -60861,7 +60937,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -60981,7 +61057,7 @@ msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無効なビット列初期化子です"
@@ -61021,7 +61097,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
@@ -61036,7 +61112,7 @@ msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
@@ -61157,169 +61233,169 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr ""
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "フォーマットへの引数が多すぎます"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "右シフト回数が負の数です"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "右シフト回数が負の数です"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Negative argument N at %L"
 msgstr "%s への間違った型の引数です"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -61327,699 +61403,699 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "言語 %s は認識できません"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "arguments 1 and 2 have different types"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "引数1と引数2が異なる型を持っています"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr ""
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr ""
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "\"%s\" は正常なファイル名ではありません"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "フォーマットへの引数が多すぎます"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -62219,1781 +62295,1781 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "無効な文字定数が #if にあります"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in %qT"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "%qD は既に %qT 内で定義されています"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "初期化子を欠いています"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "多次元配列は初期化子で初期化することができません"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "無効な文字定数が #if にあります"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "関数を inline にできません"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "ポインタ型へ変換できません"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "重複した初期化子"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "-traditional は C++ では受け付けられません"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "無効な型引数です"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can%'t set %qE attribute after definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can%'t set %qE attribute after definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can%'t set %qE attribute after definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "FPU レジスタ内の機能の値を返す"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "数値がありません"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter name omitted"
 msgid "A type parameter list is required at %C"
 msgstr "仮引数名が省略されています"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter name omitted"
 msgid "A parameter name is required at %C"
 msgstr "仮引数名が省略されています"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "配列の次元を宣言で指定することはできません"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "parameter name missing from parameter list"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "ENTRY statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected statement"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "文が予期されます"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr ""
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無効なビット列初期化子です"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "'%s' トークンの所で文法エラー"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> が予期されます"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "述語は識別子でなければなりません"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "ポインタ型へ変換できません"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "配列を仮引数リストによって初期化しようとしています"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "VALUE statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close read state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "読み込んだ状態ファイル %s を閉じるのに失敗しました [%s]"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "関数を inline にできません"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "空の宣言です"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD は既に定義されています"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "反復子 `%s' は非整数型です"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "`*' の前に型の名前があるべきです"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "識別子が必要です"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "')' が必要です"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<::%>"
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> が予期されます"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "%<=%> が予期されます"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> が予期されます"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
@@ -64119,12 +64195,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "仮引数 `%s' は無効です"
@@ -64199,7 +64275,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
@@ -64465,7 +64541,7 @@ msgstr "代入として無効な左辺値です"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -64523,167 +64599,167 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -64710,7 +64786,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -64905,12 +64981,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -64980,584 +65056,584 @@ msgstr ""
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "参照 `%s' は曖昧です: interface `%s' と interface `%s' に現れました"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D が未定義シンボル %qE の別名となっています"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
@@ -65665,74 +65741,74 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "init_arglist(): too many arguments"
 msgstr "引数が多すぎます"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr ""
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "NaN から整数への変換です"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "NaN から整数への変換です"
@@ -65740,22 +65816,22 @@ msgstr "NaN から整数への変換です"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -66115,12 +66191,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -66130,7 +66206,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -66175,7 +66251,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -66270,7 +66346,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -66336,7 +66412,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "式文が無効です"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
@@ -66351,83 +66427,83 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "式文が無効です"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "式の整数がオーバーフローしました"
@@ -66674,508 +66750,508 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "無効な型引数です"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "  try ブロックに入ります"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr ""
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "アセンブラ文内に左辺値が必要です"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr ""
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr ""
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr ""
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "LOCK statement at %C"
 msgstr "式内"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected statement"
 msgid "Unexpected constant at %C"
 msgstr "文が予期されます"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -67183,221 +67259,221 @@ msgstr ""
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In constructor %qs"
 msgid "BLOCK DATA construct at %L"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "EQUIVALENCE statement at %C"
 msgstr "式内"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "関数の引数が構造体だったら警告する"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "関数の引数が構造体だったら警告する"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "関数の引数が構造体だったら警告する"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr ""
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "SELECT RANK statement at %C"
 msgstr "式内"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected statement"
 msgid "Unexpected RANK statement at %C"
 msgstr "文が予期されます"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -67438,12 +67514,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -68128,8 +68204,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -69545,173 +69621,173 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
 #, gcc-internal-format, gfc-internal-format
-msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
+msgid "RE or IM part_ref at %C"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
-msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
+msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected argument list at %C"
+msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2366
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
+msgid "Expected argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "参照を参照として宣言できません"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires prototypes with named arguments"
 msgid "Structure constructor with named arguments at %C"
 msgstr "%qs 属性は名前付き引数を持つプロトタイプが必要です"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "関数 `%s' に対する引数が多すぎます"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "式の浮動小数点数がオーバーフローしました"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "`%s' オプションに対する引数がありません"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "\"%s\" は正常なファイル名ではありません"
@@ -70039,499 +70115,499 @@ msgstr "%s: オプション `%s' はあいまいです\n"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function %qs"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "expected numeric type"
 msgid "Unexpected junk after %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "shared と mdll とは共存できません"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "Impure function at %L might not be evaluated"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "要求されたアラインメントが大きすぎます"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -70540,12 +70616,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -70554,284 +70630,284 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index must be integer"
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -70840,286 +70916,286 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 #| msgid "expected numeric type"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -71127,188 +71203,188 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In constructor %qs"
 msgid "FORALL construct at %L"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -71316,961 +71392,961 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD は既に定義されています"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "式文が無効です"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -72961,154 +73037,154 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "Labeled DO statement at %L"
 msgstr "式内"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -73146,84 +73222,84 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr ""
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -73243,72 +73319,72 @@ msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "フォーマットへの引数が多すぎます"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -73324,27 +73400,27 @@ msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -73381,23 +73457,23 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "optional class parameter"
 msgstr "無効な PHI 引数です"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -73510,85 +73586,85 @@ msgstr "合っていない引数です"
 msgid "unable to open file"
 msgstr "%s を開くのに失敗しました"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "ダンプファイル %s を開けませんでした"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr ""
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr ""
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "%s を開けません"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "%s を開けません"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "%s を開けません"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -74729,7 +74805,7 @@ msgstr "%qs の後にマクロ名がありません"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs の後にファイル名がありません"
@@ -74950,18 +75026,18 @@ msgstr "不明な IRA アルゴリズム %qs です"
 msgid "unknown TLS model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "認識できない可視性の値 %qs です"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
diff --git a/gcc/po/nl.po b/gcc/po/nl.po
index 4794fc848ee..ca4309cda9c 100644
--- a/gcc/po/nl.po
+++ b/gcc/po/nl.po
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -1899,91 +1899,91 @@ msgstr "lengte-modifier in strfmon-formaat"
 msgid "<command-line>"
 msgstr "<opdrachtregel>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "operand ontbreekt"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "ongeldige operand"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ongeldige operandprefix '%%%c'"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ongeldige adresseringsmodus"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ongeldige operanden in binaire bewerking"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -1999,18 +1999,18 @@ msgid "invalid %%r value"
 msgstr "ongeldige waarde voor %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "ongeldige waarde voor %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
@@ -2040,7 +2040,7 @@ msgstr "ongeldige waarde voor %%M"
 msgid "invalid %%U value"
 msgstr "ongeldige waarde voor %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
@@ -2050,7 +2050,7 @@ msgstr "ongeldige waarde voor %%s"
 msgid "invalid %%C value"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
@@ -2061,10 +2061,10 @@ msgstr "ongeldige waarde voor %%E"
 msgid "unknown relocation unspec"
 msgstr "onbekende 'unspec' relocatie"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ongeldige code voor %%xn"
@@ -2148,36 +2148,36 @@ msgstr "ongeldige UNSPEC als operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "vermoedelijke constante niet herkend"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "ongeldige shift-operand"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "Thumb-instructie met predicaat"
 
 # mja. snappen wie snappen kan ^^
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2185,13 +2185,13 @@ msgstr "ongeldige operand voor code '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "instructie wordt nooit uitgevoerd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2322,7 +2322,7 @@ msgstr "onverwachte operand"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2540,26 +2540,26 @@ msgstr "ongeldige output_move_double operand"
 msgid "bad output_condmove_single operand"
 msgstr "ongeldige output_condmove_single operand"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operand %%xn code"
 msgstr "ongeldige operand voor %%Z-code"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid fp constant"
@@ -2707,7 +2707,7 @@ msgstr "ongeldige bewerking met %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -2765,7 +2765,7 @@ msgid "post-increment address is not a register"
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -2818,8 +2818,8 @@ msgstr "'%%%c' is geen geldige operand-prefix"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ongeldig gebruik van '%%%c'"
@@ -2955,177 +2955,231 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "lege declaratie"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Schakel geïndexeerde adressering uit"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx en -mno-altivec zijn incompatibel"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "case-label niet in een switch-statement"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%H value"
+msgid "invalid %%A value"
+msgstr "ongeldige waarde voor %%H"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "ongeldige waarde voor %%D"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "ongeldige conversie van %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "ongeldige conversie naar %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "ongeldige conversie van %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "ongeldige conversie naar %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "ongeldige conversie van %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "ongeldige conversie naar %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "ongeldige conversie van %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "ongeldige conversie naar %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3137,92 +3191,92 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "kan adres niet ontleden"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ongeldige operand voor 'O' modifier"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ongeldige code voor operanduitvoer"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ongeldige expressie als operand"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
 # 'signedness' = 'signed-heid'?
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3493,8 +3547,8 @@ msgstr "{{anoniem}}"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
@@ -3514,7 +3568,7 @@ msgstr "ongeldige operand van %s"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -3522,7 +3576,7 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -3541,21 +3595,21 @@ msgstr "ongeldige operand van %s"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -3566,12 +3620,12 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
@@ -3580,7 +3634,7 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -3590,18 +3644,18 @@ msgstr "ongeldige operand van %s"
 msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
@@ -3609,19 +3663,19 @@ msgstr "ongeldige operand van %s"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
@@ -3630,7 +3684,7 @@ msgstr "top-level declaratie van %qs specifieert %<auto%>"
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -3641,38 +3695,38 @@ msgstr "ongeldige operand van %s"
 msgid "expected label"
 msgstr "ongeldige operand van %s"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidaat 1:"
 msgstr[1] "kandidaat 1:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "kandidaat 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "herhaald label %qs"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr ""
 
@@ -3769,7 +3823,7 @@ msgstr "meerdere parameters hebben de naam %qs"
 msgid "<statement>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, fuzzy, gcc-internal-format
 msgid "<unknown>"
 msgstr "onbekende machine-modus %qs"
@@ -3948,54 +4002,54 @@ msgstr "conversie gooit constantheid weg"
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argument van verkeerd type voor unaire min"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argument van verkeerd type voor bit-complement"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argument van verkeerd type voor abs"
 
 # OK, ik geef het op: wat is hier een goede vertaling voor 'conjugation'?
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argument van verkeerd type voor vervoeging"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4037,17 +4091,17 @@ msgstr "opvulkarakter in strfmon-formaat"
 msgid "elemental binary operation"
 msgstr "elementaire binaire operatie"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, fuzzy, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, fuzzy, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
@@ -4121,7 +4175,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4136,7 +4190,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4252,12 +4306,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
@@ -4266,213 +4320,213 @@ msgstr "ongeldige lvalue in toewijzing"
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 msgid "allocatable argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 msgid "optional argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 msgid "pointer argument"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 msgid "target argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 msgid "value argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 msgid "volatile argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 msgid "coarray argument"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "geen argumenten"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "slechte combinatie van argumenten"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4485,27 +4539,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4582,7 +4636,7 @@ msgstr "%s voor %qs"
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5041,7 +5095,7 @@ msgstr "pointer naar functie gebruikt in rekensom"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5625,8 +5679,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -8101,105 +8155,100 @@ msgstr ""
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr ""
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12654,7 +12703,7 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
+msgid "Use instructions added in ISA 3.1."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:576
@@ -12667,6 +12716,11 @@ msgstr "ongeldig gebruik van %<restrict%>"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "ongeldig gebruik van %<restrict%>"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Use portable calling conventions"
@@ -17634,7 +17688,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18277,372 +18331,372 @@ msgstr ""
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 msgid "Perform loop unswitching."
 msgstr "recursieve inlining"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 msgid "Perform loop splitting."
 msgstr "recursieve inlining"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 msgid "Perform variable tracking."
 msgstr "recursieve inlining"
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2959
+#: common.opt:2963
 #, fuzzy, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, fuzzy, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "lege declaratie"
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "ongeldig register in de move-instructie"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Arithmetic overflow at %L"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Arithmetische overflow op %L"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 msgid "Generate debug information in default format."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr ""
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 msgid "Enable function profiling."
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Zoals -pedantic, maar beschouw problemen als fouten"
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
 # kan beter
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Schakel uitgebreide boodschappen in"
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Onderdruk waarschuwingen"
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19792,8 +19846,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, fuzzy, gcc-internal-format
 msgid "value computed is not used"
 msgstr "modus van %qs is geen modus"
@@ -19824,7 +19878,7 @@ msgid "expected boolean type"
 msgstr "ongeldige operand van %s"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ongeldige operand van %s"
@@ -19898,7 +19952,7 @@ msgstr "geen argumenten"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "te veel argumenten voor formaat"
@@ -20289,7 +20343,7 @@ msgstr "attribuut %qE botst met attribuut %s"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -20373,12 +20427,12 @@ msgstr ""
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20396,8 +20450,8 @@ msgstr "attribuut %qE wordt genegeerd"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "eerdere declaratie van %qs"
@@ -20518,7 +20572,7 @@ msgstr "ongeldige beginwaarde"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "offset buiten de grenzen van een constante string"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -20807,7 +20861,7 @@ msgstr "ontbrekend argument bij %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
@@ -21104,12 +21158,12 @@ msgstr ""
 msgid "%<asm%> clobber conflict with input operand"
 msgstr ""
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21619,304 +21673,304 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "beginwaarde ontbreekt"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "beginwaarde-element is niet constant"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "case-selector niet compatibel met label"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "dit is een eerdere declaratie"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "ongeldige beginwaarde"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "origin points to a different parent"
 msgstr "conversie van register naar een andere grootte"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "het argument van '-%s' ontbreekt"
@@ -22005,12 +22059,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -22163,7 +22217,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "open %s"
@@ -22498,22 +22552,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, fuzzy, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "ongeldige operand voor %s-code"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr ""
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr ""
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22573,7 +22627,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "kan bestand '%s' niet openen"
@@ -22603,12 +22657,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -22623,7 +22677,7 @@ msgstr "ongeldige waarde voor %%C"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "grootte van %qs is %u bytes"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "kan bestand '%s' niet openen"
@@ -22643,37 +22697,37 @@ msgstr "grote integer impliciet afgekapt naar 'unsigned' type"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23300,13 +23354,13 @@ msgstr "functie geeft adres van lokale variabele terug"
 msgid "function returns address of local variable"
 msgstr "functie geeft adres van lokale variabele terug"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -23887,10 +23941,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -24059,7 +24113,7 @@ msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 msgid "enclosing %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
@@ -24109,13 +24163,13 @@ msgstr "statische variable %qs is als dllimport aangeduid"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -24125,147 +24179,147 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT wordt tot %qT gepromoveerd indien het via %<...%> wordt doorgegeven"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(dus U zou %qT, en niet %qT, moeten doorgeven aan %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "indien deze code bereikt wordt, zal het programma afgebroken worden"
@@ -24342,7 +24396,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -24614,54 +24668,54 @@ msgstr ""
 msgid "the extra base is defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24693,37 +24747,37 @@ msgstr "deze functie is mogelijk kandidaat voor attribuut %<%s%> als het normaal
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr ""
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24773,57 +24827,57 @@ msgstr ""
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "kan %s niet vinden"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -25081,52 +25135,52 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr "%Jeerder hier gebruikt"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25347,52 +25401,52 @@ msgstr "continue-statement niet in een lus"
 msgid "invalid branch to/from %s structured block"
 msgstr "continue-statement niet in een lus"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -26739,133 +26793,133 @@ msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "deze doelmachine heeft geen delayed branches"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore wordt niet ondersteund op deze doelmachine"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "%s ondersteunt het %<%%%s%c%> %s formaat niet"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr ""
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-f%sleading-underscore wordt niet ondersteund op deze doelmachine"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, fuzzy, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, fuzzy, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "#error %s"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "case-selector niet compatibel met label"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -26960,176 +27014,176 @@ msgstr "globale registervariabele volgt op een functiedefinitie"
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "ongeldige expressie als operand"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "ongeldige operand in de instructie"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr "In functie %qs"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "ongeldige constraints voor operand"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "ongeldige operand voor %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in shift expression"
 msgid "type mismatch in %qs"
 msgstr "types in shift-expressie komen niet overeen"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid shift operand"
 msgid "invalid %qs offset operator"
 msgstr "ongeldige shift-operand"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "conversie van register naar een andere grootte"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "ongeldige operand voor %%R"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "ongeldige shift-operand"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "functie kan niet inline gemaakt worden"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "ongeldige PC in tabel met regelnummers"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "ongeldige conversie in 'gimple'-aanroep"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "ongeldige PC in tabel met regelnummers"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -27140,518 +27194,518 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "ongeldige operand in de instructie"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, fuzzy, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "ongeldige types in NOP-conversie"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "ongeldige types in NOP-conversie"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "ongeldige types in adresruimte-conversie"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr ""
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "ongeldige types in conversie naar floating-point"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "ongeldige types in conversie naar integer"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in shift expression"
 msgid "type mismatch in %qs expression"
 msgstr "types in shift-expressie komen niet overeen"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "niet-triviale conversie in unaire bewerking"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "niet-register als linkerhand van binaire bewerking"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "ongeldige operanden in binaire bewerking"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "ongeldige waarheidsexpressie"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "ongeldige waarheidsexpressie"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "niet-ondersteunde versie"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid position or size in %qs"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs is geen iterator"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "ongeldige beginwaarde"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "ongeldige operand voor %%R"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ongeldig vector-type voor attribuut %qs"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, fuzzy, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "default-label niet in een switch-statement"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "ongeldige operand voor %%s-code"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "ongeldige operand in de instructie"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "Ongeldig token in expressie"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "ongeldig adres"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "ongeldige waarde voor %%C"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr ""
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "impliciete declaratie van functie %qE"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "-pipe wordt niet ondersteund"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> functie keert terug"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "%Hde returnwaarde van een functie, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
@@ -27666,48 +27720,48 @@ msgstr "%Jherdefinitie van %qD"
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -28218,12 +28272,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr ""
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -28288,7 +28342,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28298,27 +28352,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "array subscript is geen integer"
@@ -28393,32 +28447,32 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13103
+#: tree.c:13105
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13106
+#: tree.c:13108
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13112
+#: tree.c:13114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -28443,232 +28497,232 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -28793,83 +28847,83 @@ msgstr "het gevraagde alignment voor %s is groter dan het geïmplementeerde alig
 msgid "storage size of %q+D isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, fuzzy, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "initializer voor integerwaarde is te ingewikkeld"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "initializer voor floating-point waarde is geen floating-point constante"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%J%qD als inline gedeclareerd na oproep"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "de zwakke declaratie van %qs moet publiek zijn"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "de zwakke declaratie van %qs moet publiek zijn"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "enkel zwakke aliasen worden in deze configuratie ondersteund"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "-pg wordt op dit platform niet ondersteund"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
@@ -29485,7 +29539,7 @@ msgstr "attribuut %qE volgt na %qE"
 msgid "type was previously declared %qE"
 msgstr "eerdere declaratie van %qs"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
@@ -29505,7 +29559,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "%qE argument is not a function"
 msgstr "het argument van %<cleanup%> is geen functie"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -29889,12 +29943,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gebruik liefst haakjes rond toewijzingen die als waarheid gebruikt worden"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -30052,12 +30106,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -30159,7 +30213,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -30170,124 +30224,124 @@ msgstr "incompatibel type voor argument %d van %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "%<defined%> zonder een naam"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "doorgeven van argument %d van %qs"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "indexwaarde valt buiten bereik"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "grootte van array %qs is negatief"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30342,516 +30396,516 @@ msgstr "%qs is een onbekend type formaatfunctie"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "de formaatstring volgt de te formatteren argumenten"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "deze functie is mogelijk kandidaat voor opmaak-attribuut %qs"
 
 # niet zeker of '$-operandnummer' wel de juiste betekenis vervat
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "$-operandnummer ontbreekt in formaat"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s ondersteunt geen %%n$ operandnummer formaten"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "operandnummer buiten bereik in formaat"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "formaat-argument %d meer dan eens gebruikt in %s formaat"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr "operandnummer opgegeven voor formaat dat geen argument heeft"
 
 # moet beter kunnen
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "formaat-argument %d ongebruikt voor gebruikt argument %d in $-stijl formaat"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "formaat is geen stringconstante, de formaatstring werd dus niet nagekeken"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "formaat is geen stringconstante en er zijn geen formaat-argumenten"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "formaat is geen stringconstante, de argumenttypes werden dus niet nagekeken"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "te veel argumenten voor formaat"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "%s formaatstring van lengte 0"
 
 # "brede string"? "string met brede karakters/tekens"?
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "formaat is een wide-character string"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "de formaatstring is geen string-type"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "formaatstring niet beëindigd"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, fuzzy, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s gebruikt bij %<%%%c%> %s formaat"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s ondersteunt %s niet"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, fuzzy, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s ondersteunt %s niet bij het %<%%%c%> %s formaat"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "herhaalde %s in formaat"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "opvulkarakter ontbreekt aan het einde van dit strfmon-formaat"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "breedte van nul in %s formaat"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "lege linkse precisie gebruikt in %s formaat"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "lege precisie in %s formaat"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, fuzzy, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s ondersteunt de %qs %s lengte-modifier niet"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, fuzzy, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, fuzzy, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s ondersteunt het %<%%%c%> %s formaat niet"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, fuzzy, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s wordt genegeerd bij %s en %<%%%c%> %s formaat"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s wordt genegeerd bij %s in %s formaat"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, fuzzy, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "zowel %s als %s gebruikt bij '%%%c' %s formaat"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "zowel %s als %s gebruikt in %s formaat"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, fuzzy, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> geeft enkel de laatste twee cijfers van het jaartal in sommige omgevingen"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, fuzzy, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> geeft enkel de laatste twee cijfers van het jaartal"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, fuzzy, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "geen eind-%<]%> voor %<%%[%> formaat"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "%qs lengte-modifier samen met typekarakter %<%c%> gebruikt"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, fuzzy, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s ondersteunt het %<%%%s%c%> %s formaat niet"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "operandnummer opgegeven met onderdukte uitlijning"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "operandnummer opgegeven voor formaat dat geen argument heeft"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "herhaalde %s in formaat"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "herhaalde %s in formaat"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "ingesloten %<\\0%> in formaat"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 msgid "use %qs instead"
 msgstr "spec '%s' is ongeldig"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "unquoted attribute in format"
 msgstr "attribuut %qE wordt genegeerd"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr "overbodige %<%%%> achteraan formaat"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "overbodige %<%%%> achteraan formaat"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "herhaalde %s in formaat"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "herhaalde %s in formaat"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "herhaalde %s in formaat"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "overbodige %<%%%> achteraan formaat"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "overbodige %<%%%> achteraan formaat"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "onbekend typeconversie-karakter %qc in formaat"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, fuzzy, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "overbodige %<%%%> achteraan formaat"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "conversie mist type aan het einde van het formaat"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "ongeldig preprocessing-commando"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, fuzzy, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "ingesloten %<\\0%> in formaat"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "onbeëindigd alternatief assembly-dialect"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "beschrijving via null pointer (arg %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "uitlezing via null-pointer (arg %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s zou van type %<%s%s%> moeten zijn, maar argument %d heeft %qT als type"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s zou van type %<%s%s%> moeten zijn, maar argument %d heeft %qT als type"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, fuzzy, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr "de te formatteren argumenten zijn niet ..."
 
 # Klinkt wat vreemd...
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime formaten kunnen geen argumenten formatteren"
@@ -31012,7 +31066,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -31028,17 +31082,17 @@ msgstr "ongeldig type voor iteratie-variabele %qE"
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
@@ -31048,7 +31102,7 @@ msgstr "toewijzingsonderdrukking"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -31658,7 +31712,7 @@ msgid "wrong type argument to %s"
 msgstr "argument van verkeerd type voor abs"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow in constante expressie"
@@ -32342,7 +32396,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
@@ -32424,7 +32478,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "cast laat qualifiers van doeltype van pointer vallen"
 msgstr[1] "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -32444,7 +32498,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "%qs tevoren hier gedefinieerd"
@@ -32464,7 +32518,7 @@ msgstr "-fPIC is niet geldig met -mcoff"
 msgid "too many input files"
 msgstr "te veel invoerbestanden"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "slechte waarde (%s) voor optie -mcpu"
@@ -32496,15 +32550,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -33037,401 +33091,408 @@ msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "argument moet een constante zijn"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "ondersteunt geen multilib"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> is geen string of getal"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "misvormde #pragma pack"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "ongeldige operand van %s"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "case-selector niet compatibel met label"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "case-selector niet compatibel met label"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "ongeldige constraints voor operand"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "ongeldige waarde voor %%h"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Ongeldige optie voor floating-point emulatie: -mfpe-%s"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "onbekende spec-functie '%s'"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "ongeldig type-argument %qs"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument in %<__builtin_args_info%>"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argument ontbreekt in %<__builtin_args_info%>"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "beginwaarde ontbreekt"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "ondersteunt geen multilib"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "misvormde #pragma pack"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "misvormde #pragma weak"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "niet-ondersteunde versie"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr "De -shared optie wordt op het ogenblik niet ondersteund voor VAX ELF."
@@ -33615,17 +33676,17 @@ msgstr "het argument van %<asm%> is geen constante string"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "het argument van %<asm%> is geen constante string"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33782,12 +33843,12 @@ msgstr "onbekende machine-modus %qs"
 msgid "invalid type for %<asm%> flag output"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "ingeschakelde opties: "
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -33795,194 +33856,194 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33992,291 +34053,291 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt en NEON zijn incompatibel"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g met -fomit-frame-pointer geeft mogelijk geen fatsoenlijke debug-mogelijkheden"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check is niet compatibel met -mno-apcs-frame"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic en -mapcs-reent zijn incompatibel"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS reentrant code wordt niet ondersteund.  Genegeerd"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "kan %qs niet nabootsen"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable en -msdata=%s zijn incompatibel"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "attribuut %qE wordt genegeerd voor non-class-types"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to initialized variables with external linkage"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "attribuut %qE is enkel van toepassing op geïnitialiseerde variabelen die extern gelinkt zijn"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "ongeldige operand van %s"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ongeldig type-argument %qs"
@@ -34284,24 +34345,24 @@ msgstr "ongeldig type-argument %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ongeldig vector-type voor attribuut %qs"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "rommel aan einde van #pragma %s"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
@@ -34380,17 +34441,17 @@ msgstr "-pipe wordt niet ondersteund"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G en -static sluiten elkaar uit"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "functie %qs kan geen waarde teruggeven"
@@ -34660,7 +34721,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
@@ -34997,52 +35058,52 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "te veel argumenten voor formaat"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "argument van verkeerd type voor abs"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr ""
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr ""
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "operandnummer buiten bereik"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -35179,133 +35240,133 @@ msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 msgid "parameter to builtin not valid: %s"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
@@ -35694,148 +35755,148 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "de '-%c' moet een argument hebben"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
@@ -36280,7 +36341,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -37377,52 +37438,52 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "het argument van %<asm%> is geen constante string"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
@@ -37541,330 +37602,331 @@ msgstr ""
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "rommel aan einde van #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit sub-doelsysteem"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "argument moet een constante zijn"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "argument moet een constante zijn"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "lege declaratie"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
@@ -37884,221 +37946,226 @@ msgstr "%<__thread%> samen met %<register%> gebruikt"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "Ongeldige modus voor gen_tst_reg"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "SH2a does not support little-endian"
 msgid "%qs is not supported on little endian systems"
 msgstr "SH2a ondersteunt little-endian niet"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s ondersteunt %s niet"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -38426,141 +38493,141 @@ msgstr "gevraagde positie is geen integerconstante"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argument van %qs is te groot (max. %d)"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -38986,8 +39053,8 @@ msgstr "attribuut %qs is enkel van toepassing op array-types"
 msgid "could not read the BRIG file"
 msgstr "kan niet schrijven naar antwoordbestand %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-waarde niet genegeerd zoals het hoort"
@@ -39271,7 +39338,7 @@ msgstr "%Jdeclaratie van %qD verbergt een eerdere niet-variabele"
 msgid "declaration of %qD shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
@@ -39342,7 +39409,7 @@ msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Elke niet-gedeclareerde naam wordt slechts één"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -39372,7 +39439,7 @@ msgstr "overflow in constante expressie"
 msgid "duplicate label declaration %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "herhaald label %qs"
@@ -39584,7 +39651,7 @@ msgstr "een object met een volatile veld kan niet in een register geplaatst word
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ongeïnitialiseerde const %qD is ongeldig in C++"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39925,7 +39992,7 @@ msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
@@ -40233,7 +40300,7 @@ msgstr "geneste herdefinitie van %<struct %s%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
@@ -40283,7 +40350,7 @@ msgstr "struct heeft geen benoemde leden"
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
@@ -40319,7 +40386,7 @@ msgstr "geneste herdefinitie van %<enum %qs%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "herdeclaratie van %<enum %qs%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -40350,7 +40417,7 @@ msgstr "overflow in enumeratiewaarden"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
@@ -40380,7 +40447,7 @@ msgstr "%Jgeen eerder prototype voor %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
@@ -40495,12 +40562,12 @@ msgstr "argument %qs komt niet overeen met prototype"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -40508,262 +40575,262 @@ msgstr "parameter %qD krijgt beginwaarde"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "herhaalde %qs"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
 # is letterlijke vertaling maar klinkt zo vreemd...
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, fuzzy, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qs slaagt er niet in een typedef of ingebouwd type te zijn"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s ondersteunt %s niet"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vóór %<static%> gebruikt"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -40784,7 +40851,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -40830,7 +40897,7 @@ msgid "unknown type name %qE"
 msgstr "onbekende machine-modus %qs"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -40850,7 +40917,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -40865,8 +40932,8 @@ msgstr "herhaalde definitie %qs"
 msgid "unexpected attribute"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -40906,7 +40973,7 @@ msgstr "%<auto%> in lege declaratie op bestandsniveau"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -40934,7 +41001,7 @@ msgstr "ISO C90 ondersteunt %<long long%> niet"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -40964,7 +41031,7 @@ msgstr "beginwaarde-element is niet constant"
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "pex_init mislukt"
@@ -41009,14 +41076,14 @@ msgstr "argument %d is alleen-lezen"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma aan het einde van enumerator-lijst"
@@ -41101,7 +41168,7 @@ msgstr "top-level declaratie van %qs specifieert %<auto%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not take any arguments"
@@ -41113,7 +41180,7 @@ msgstr "attribuut %qE heeft geen betekenis voor types"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -41173,7 +41240,7 @@ msgstr "ISO C90 verbiedt labeldeclaraties"
 msgid "expected %<}%> before %<else%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -41188,7 +41255,7 @@ msgstr "ISO C verbiedt een label aan het einde van een samengesteld statement"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "ongeldige beginwaarde"
@@ -41213,17 +41280,17 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr ""
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -41243,12 +41310,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ongeldig register in de instructie"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -41264,8 +41331,8 @@ msgstr "sentinel ontbreekt in functie-oproep"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "herhaalde case-waarde"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -41292,12 +41359,12 @@ msgstr "ISO C verbiedt het weglaten van de middelste term van een ?: expresie"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -41698,61 +41765,61 @@ msgstr "meerdere opslagklassen in declaratie van %qs"
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attribuut %<getter%> mag slechts één keer opgegeven worden"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -41762,18 +41829,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
@@ -41793,53 +41860,53 @@ msgstr "ongeldige operand van %s"
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41861,12 +41928,12 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -41876,22 +41943,22 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "expected constant integer expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -41906,53 +41973,53 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qs value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "zowel %<long%> als %<void%> opgegeven bij declaratie"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -41962,7 +42029,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -41997,22 +42064,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "case-selector niet compatibel met label"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -42027,77 +42094,77 @@ msgstr "ongeldige const_double operand"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "lege declaratie"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ongeldige linker operand van %s"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -42112,7 +42179,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "expected function name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qs is meestal een functie"
@@ -42122,67 +42189,67 @@ msgstr "%qs is meestal een functie"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -42192,57 +42259,57 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
@@ -42252,73 +42319,73 @@ msgstr "herdeclaratie van %qs"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -42333,57 +42400,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "ongeldige operand van %s"
@@ -42393,12 +42460,12 @@ msgstr "ongeldige operand van %s"
 msgid "variant %qD is not a function"
 msgstr "%qs is meestal een functie"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -42408,32 +42475,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -42488,42 +42555,42 @@ msgstr "ongeldige operand van %s"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -42538,27 +42605,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -42568,7 +42635,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -42583,7 +42650,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "%qs heeft een onvolledig type"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ongeldig gebruik van een void-expressie"
@@ -42705,7 +42772,7 @@ msgstr "%<void *%> pointer wordt gederefereerd"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscript is geen integer"
@@ -42730,7 +42797,7 @@ msgstr "ISO C90 verbiedt het gebruik van subscripts bij een array die geen lvalu
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42844,18 +42911,18 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "vergelijking tussen pointer en integer"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "kan niet derefereren, is geen pointer."
@@ -42882,7 +42949,7 @@ msgid "arithmetic on pointer to an incomplete type"
 msgstr "rekensom met pointer naar onvolledig type"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "rekensom met pointer naar onvolledig type"
@@ -43136,7 +43203,7 @@ msgstr "cast van pointer naar integer met andere grootte"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast naar pointer van integer met andere grootte"
@@ -43312,7 +43379,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -43479,7 +43546,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array van ongeschikt type heeft stringconstante als beginwaarde"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
@@ -43510,7 +43577,7 @@ msgstr "beginwaarde-element kan niet berekend worden tijdens het laden"
 msgid "invalid initializer"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -43657,7 +43724,7 @@ msgstr "overtollige elementen in beginwaarde van scalair"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C verbiedt %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
@@ -43698,7 +43765,7 @@ msgstr "%<long%> switch-expressie wordt in ISO C niet naar %<int%> geconverteerd
 msgid "case label is not an integer constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-label niet in een switch-statement"
@@ -43708,17 +43775,17 @@ msgstr "case-label niet in een switch-statement"
 msgid "%<default%> label not within a switch statement"
 msgstr "default-label niet in een switch-statement"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-statement niet in een lus of switch"
@@ -43733,7 +43800,7 @@ msgstr "break-statement niet in een lus of switch"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "statement zonder effect"
@@ -43744,22 +43811,22 @@ msgstr "statement zonder effect"
 msgid "expression statement has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -43811,7 +43878,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "geordende vergelijking van pointer met null-pointer"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordende vergelijking van pointer met integer nul"
@@ -43841,51 +43908,51 @@ msgstr "waarde van union-type gebruikt waar een scalair nodig is"
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qs is meestal een functie"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -43895,8 +43962,8 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -44064,12 +44131,12 @@ msgstr "grootte van %qs is %u bytes"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -44094,8 +44161,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -44110,19 +44177,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -44192,118 +44259,118 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qs is geen static veld"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
 # Of misschien beter "... niet van het %<va_list%> type"?
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "het eerste argument van %<va_arg%> is geen %<va_list%>"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -44490,797 +44557,797 @@ msgid "expected case label"
 msgstr "ongeldige operand van %s"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "ongeldige registernaam voor %qs"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 msgid "  no known conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "<ingebouwd>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "<ingebouwd>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "<ingebouwd>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr ""
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 msgid "  inherited here"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ verbiedt het weglaten van de middelste term van een ?: expresie"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "vergelijking tussen %q#T en %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "impliciete declaratie van functie %qE"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%s is niet addresseerbaar"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is too large"
 msgid "; use assignment instead"
 msgstr "gevraagd alignment is te groot"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ongeldige registernaam voor %qs"
@@ -45310,520 +45377,520 @@ msgstr ""
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "%s voor %qs"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, fuzzy, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, fuzzy, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%s heeft geen benoemde leden"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "geen beginwaarde voor variant-veld %qs"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "omvang van array %qs is te groot"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "taal-string %<\"%E\"%> wordt niet herkend"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "herhaald lid %qs"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "ongeldige naam %qs"
@@ -45903,7 +45970,7 @@ msgstr "%<register%> in lege declaratie op bestandsniveau"
 msgid "%q+E is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "kan functie %<main%> niet inline maken"
@@ -45959,7 +46026,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "kan functie %<main%> niet inline maken"
@@ -46015,370 +46082,369 @@ msgstr "beginwaarde-element is niet constant"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "ongeldige beginwaarde"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "functie kan niet inline gemaakt worden"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -46424,7 +46490,7 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "kan niet derefereren, is geen pointer."
@@ -46464,292 +46530,292 @@ msgstr ""
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "ongeldige toepassing van %qs op onvolledig type %qT "
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "statement zonder effect"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -46814,7 +46880,7 @@ msgstr "eerdere declaratie van %qs"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "eerdere declaratie van %qs"
@@ -46996,12 +47062,12 @@ msgstr "%Jeerdere declaratie van %qD was hier"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "%Jherdefinitie van %qD"
@@ -47014,44 +47080,44 @@ msgstr "%Jherdefinitie van %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "herdefinitie van %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD botst met gebruikte functie"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -47059,845 +47125,845 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%Jdeclaratie van %qD als thread-local volgt declaratie als niet-thread-local"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%Jdeclaratie van %qD als niet-thread-local volgt declaratie als thread-local"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, fuzzy, gcc-internal-format
 msgid "  from here"
 msgstr "van hieruit opgeroepen"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "ongeldige operand van %s"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nutteloos sleutelwoord of typenaam in lege declaratie"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE is hier niet gedeclareerd (niet in een functie)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabele %qs heeft beginwaarde, maar een onvolledig type"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%Jherdeclaratie van enum %qD"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "dereferentie van pointer naar onvolledig type"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "opslagklasse opgegeven voor structure-veld %qs"
 msgstr[1] "opslagklasse opgegeven voor structure-veld %qs"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "herhaald lid %qs"
 
 # Betere vertaling voor 'decompose'?
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan adres niet ontleden"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "teruggeeftype is onvolledig"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
@@ -48168,7 +48234,7 @@ msgstr ""
 msgid "%qD declared as array of %qT"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
@@ -48333,7 +48399,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
@@ -48535,815 +48601,815 @@ msgstr "attribuut wordt genegeerd"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> functie geeft niet-void waarde terug"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "cast geeft functie-type op"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "In functie %qs"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "open %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -49355,95 +49421,95 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
@@ -49452,73 +49518,73 @@ msgstr "grootte van array %qs is van een niet-integer type"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -49558,7 +49624,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "herdeclaratie van %qs"
@@ -49568,7 +49634,7 @@ msgstr "herdeclaratie van %qs"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "%<%s %s%> binnen parameterlijst gedeclareerd"
@@ -49894,148 +49960,148 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "geen argumenten"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -50216,338 +50282,338 @@ msgstr "dubbele beginwaarde"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "ongeldige beginwaarde"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 msgid "  %q#D"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, fuzzy, gcc-internal-format
 msgid "  base %qT"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "integer overflow in expressie"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -50707,12 +50773,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "%qs is geen static veld"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "%qs is geen static veld"
@@ -50738,160 +50804,163 @@ msgstr "%Jonverenigbare types voor %qD"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "attribuut %qE is enkel van toepassing op Java-class-definities"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "attribuut %qE is enkel van toepassing op Java-class-definities"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "herhaalde %<const%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "kan klasse '%s' niet vinden"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "variable met beginwaarde %qs is als dllimport aangeduid"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "%qs is geen static veld"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "externe declaratie van %qs komt niet overeen met de globale declaratie"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "ongeldige operand van %s"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "ongeldig type-argument %qs"
@@ -50931,212 +51000,212 @@ msgstr "parameter %qs als void gedeclareerd"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%J%s %<%c%s%>"
 
 # XXX FIXME:  useless gettextization
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s%s\n"
 msgid "%s %s %p %d"
 msgstr "%s %s%s\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "%Jherdeclaratie van enum %qD"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%qs is geen iterator"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attribuut-commando %qD wordt genegeerd"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%s voor %qs"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -51161,7 +51230,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
@@ -51186,7 +51255,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "request for member %qE in non-class type %qT"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -51266,7 +51335,7 @@ msgstr "ongeldig karakter in naam van macro-parameter"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -51387,7 +51456,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -51507,7 +51576,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "lege declaratie"
@@ -51609,12 +51678,12 @@ msgstr "de declaratie van %qs verbergt een parameter"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qs is geen iterator"
@@ -51649,7 +51718,7 @@ msgstr "meerdere opslagklassen in declaratie van %qs"
 msgid "expected nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -51664,7 +51733,7 @@ msgstr "types in voorwaardelijke expressie komen niet overeen"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -51679,7 +51748,7 @@ msgstr "ISO C++ verbiedt het gebruik van samengestelde expressies als lvalues"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -51704,918 +51773,923 @@ msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gebruik liefst haakjes rond && binnen ||"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "herhaalde %<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 msgid "condition declares an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ongeldige operand van %s"
 
 # vertaling voor 'statement'?
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "lege declaratie"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ongeldige const_double operand"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "onverwachte operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "%qs is geen iterator"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "ongeldige beginwaarde"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "herhaalde case-waarde"
 
 # betere vertaling voor 'function scope'?
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD is niet gedefinieerd buiten een functie"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qs is geen iterator"
 
 # betere vertaling voor 'function scope'?
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD is niet gedefinieerd buiten een functie"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%qs is geen iterator"
@@ -52624,431 +52698,431 @@ msgstr "%qs is geen iterator"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "[kan %s niet vinden]"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "eerdere definitie van %qs"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "gevraagd alignment is geen constante"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -53057,546 +53131,546 @@ msgstr "twee of meer data types in de declaratie van %qs"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qs is meestal een functie"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rommel aan einde van %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53869,7 +53943,7 @@ msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
@@ -53894,84 +53968,84 @@ msgstr "de declaratie van %qs verbergt een parameter"
 msgid "template parameter %qD declared here"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "herhaald label %qs"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "argument %d is alleen-lezen"
 msgstr[1] "argument %d is alleen-lezen"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "ongeldig type-argument %qs"
@@ -53979,47 +54053,47 @@ msgstr "ongeldig type-argument %qs"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -54029,495 +54103,495 @@ msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "macro %qs gebruikt zonder argumenten"
 msgstr[1] "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "eerdere declaratie van %qs"
 msgstr[1] "eerdere declaratie van %qs"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ongeldige naam %qs"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "%Jherdefinitie van typedef %qD"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "iterator %qs is van een afgeleid type"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
@@ -54535,294 +54609,294 @@ msgstr "pointer naar lid-functie gebruikt in rekensom"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#qS"
 msgstr "%s %qs"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "impliciete declaratie van functie %qs"
@@ -54834,134 +54908,134 @@ msgstr "impliciete declaratie van functie %qs"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ongeldig type-argument %qs"
@@ -55168,7 +55242,7 @@ msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -55218,7 +55292,7 @@ msgstr "ongeldige linker operand van %s"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
@@ -55319,7 +55393,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -55359,7 +55433,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -55485,117 +55559,117 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "te veel invoerbestanden"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -55850,812 +55924,812 @@ msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qs is meestal een functie"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qs is geen iterator"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ verbiedt accolade-groepen in expressies"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "te veel argumenten voor functie"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "te weinig argumenten voor functie"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ verbiedt een vergelijking tussen pointer en integer"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operand-types zijn %qT en %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with null pointer"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "geordende vergelijking van pointer met null-pointer"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ verbiedt voorwaardelijke expressies tussen 0 en een functiepointer"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "ongeldige lvalue in asm-statement"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -56919,107 +56993,107 @@ msgstr "accolades rond scalaire beginwaarde"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -57245,10 +57319,10 @@ msgstr "grootte van %qs is %u bytes"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -57416,7 +57490,7 @@ msgstr "Lege array-constructor op %C is niet toegestaan"
 msgid "Array constructor including type specification at %C"
 msgstr "eerdere definitie van %qs"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -57534,7 +57608,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%s voor %qs"
@@ -57580,7 +57654,7 @@ msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
@@ -57597,7 +57671,7 @@ msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -57743,174 +57817,174 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr ""
 
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "overflow in constante expressie"
+
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:1452
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "overflow in constante expressie"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "STAT= argument to %s at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "expressie-statement heeft onvolledig type"
@@ -57918,734 +57992,734 @@ msgstr "expressie-statement heeft onvolledig type"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "overflow in constante expressie"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be an array"
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr ""
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be an array"
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be an array"
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be an array"
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "ongeldig type-argument %qs"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -58846,1761 +58920,1761 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "argument moet een constante zijn"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "beginwaarde ontbreekt in PARAMETER op %L"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "een parameterlijst met een beletselteken kan niet overeenkomen met een declaratie met lege parameterlijst"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
 # vertaling voor 'statement'?
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr ""
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%qs is geen iterator"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "%Jparameternaam weggelaten"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Array subscript-stap verwacht op %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Functienaam '%s' niet toegestaan op %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "herhaalde case-waarde"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "lege declaratie"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "gevraagd alignment is geen macht van 2"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "%s voor %qs"
@@ -60725,12 +60799,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "ongeldige beginwaarde"
@@ -60805,7 +60879,7 @@ msgstr "overflow in constante expressie"
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "ongeldige waarheidsexpressie"
@@ -61072,7 +61146,7 @@ msgstr "Te veel argumenten voor %s op %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
@@ -61130,169 +61204,169 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
 # dit klinkt niet al te best
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
 # dit klinkt niet al te best
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -61318,7 +61392,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -61509,12 +61583,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -61584,582 +61658,582 @@ msgstr ""
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "te veel argumenten voor %s %q+#D"
@@ -62264,73 +62338,73 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, fuzzy, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "ongeldige registernaam voor %qs"
@@ -62338,22 +62412,22 @@ msgstr "ongeldige registernaam voor %qs"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -62699,12 +62773,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62714,7 +62788,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -62760,7 +62834,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -62857,7 +62931,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -62923,7 +62997,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s voor %qs"
@@ -62939,84 +63013,84 @@ msgstr "case-selector niet compatibel met label"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "integer overflow in expressie"
@@ -63261,505 +63335,505 @@ msgstr "ongeldige beginwaarde"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "continue-statement niet in een lus"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "ongeldige lvalue in asm-statement"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "continue-statement niet in een lus"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "vector overflow in expressie"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -63767,218 +63841,218 @@ msgstr ""
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "overflow in constante expressie"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
 # vertaling voor 'statement'?
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "overflow in constante expressie"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -64019,12 +64093,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -64708,8 +64782,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -66119,172 +66193,172 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr ""
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "herhaald lid %qs"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, fuzzy, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "floating-point overflow in expressie"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr ""
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
@@ -66611,494 +66685,494 @@ msgstr "grootte van %qs is %u bytes"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs is meestal een functie"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "-shared en -mdll zijn niet compatibel"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -67107,12 +67181,12 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -67121,283 +67195,283 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67406,287 +67480,287 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67694,189 +67768,189 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "In functie %qs"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
-msgstr ""
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
+msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67884,959 +67958,959 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -69527,153 +69601,153 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "herhaalde case-waarde"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -69710,84 +69784,84 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -69807,72 +69881,72 @@ msgstr "ongeldige waarheidsexpressie"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -69887,27 +69961,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "onbekende machine-modus %qs"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -69944,22 +70018,22 @@ msgstr "case-selector niet compatibel met label"
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 msgid "optional class parameter"
 msgstr "geen argumenten"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -70072,82 +70146,82 @@ msgstr "slechte combinatie van argumenten"
 msgid "unable to open file"
 msgstr "kan %s niet openen"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "kan antwoordbestand %s niet openen"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, fuzzy, gcc-internal-format
 msgid "unexpected offset"
 msgstr "onverwachte operand"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ongeldig register in de instructie"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ongeldig register in de instructie"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "kan %s niet vinden"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "open %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr ""
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "open %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "kan antwoordbestand %s niet openen"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -71281,7 +71355,7 @@ msgstr "Macro-naam ontbreekt na -U optie"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, fuzzy, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "beginwaarde ontbreekt"
@@ -71485,17 +71559,17 @@ msgstr "onbekende machine-modus %qs"
 msgid "unknown TLS model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "niet-herkende zichtbaarheidswaarde %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(dicht bij initialisatie van %qs)"
@@ -72660,6 +72734,9 @@ msgstr "(dicht bij initialisatie van %qs)"
 #~ msgid "pointer comparison expression is not a constant expression"
 #~ msgstr "beginwaarde-element is niet constant"
 
+#~ msgid "%qE attribute can only be applied to Java class definitions"
+#~ msgstr "attribuut %qE is enkel van toepassing op Java-class-definities"
+
 #, fuzzy
 #~ msgid "taking sizeof array of runtime bound"
 #~ msgstr "ongeldig gebruik van een array zonder opgegeven grenzen"
diff --git a/gcc/po/ru.po b/gcc/po/ru.po
index 8e555d1dc31..a789c561703 100644
--- a/gcc/po/ru.po
+++ b/gcc/po/ru.po
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 9.1-b20190414\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2019-05-04 12:10+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
@@ -2066,90 +2066,90 @@ msgstr "модификатор размера в формате strfmon"
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "недопустимый операнд для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "отсутствует операнд"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "недопустимая константа"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "некорректный операнд"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "некорректный префикс операнда '%%%c'"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "неверные операнды в бинарной операции"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' использовано без локальной динамической TLS ссылки"
@@ -2165,18 +2165,18 @@ msgid "invalid %%r value"
 msgstr "некорректное значение %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "некорректное значение %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
@@ -2206,7 +2206,7 @@ msgstr "некорректное значение %%M"
 msgid "invalid %%U value"
 msgstr "некорректное значение %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
@@ -2216,7 +2216,7 @@ msgstr "некорректное значение %%s"
 msgid "invalid %%C value"
 msgstr "некорректное значение %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
@@ -2226,10 +2226,10 @@ msgstr "некорректное значение %%E"
 msgid "unknown relocation unspec"
 msgstr "некорректное unspec-перемещение"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "некорректный код %%xn"
@@ -2311,35 +2311,35 @@ msgstr "некорректный операнд UNSPEC: %d"
 msgid "unrecognized supposed constant"
 msgstr "неопознанная константа"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "некорректный оператор сдвига"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикативная инструкция для архитектуры Thumb"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикативная инструкция в условной последовательности"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Неподдерживаемый операнд для кода '%c'"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2347,13 +2347,13 @@ msgstr "Неподдерживаемый операнд для кода '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "инструкция никогда не выполняется"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "устаревший код формата Maverick '%c'"
@@ -2480,7 +2480,7 @@ msgstr "некорректный операнд"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2697,27 +2697,27 @@ msgstr "некорректный операнд для output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "некорректный операнд для output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operand %%xn code"
 msgstr "некорректный операнд для кода %%Z"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "c4x_operand_subword: invalid mode"
 msgid "operand %%xn code invalid for QImode"
 msgstr "c4x_operand_subword: некорректная мода"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid fp constant"
@@ -2866,7 +2866,7 @@ msgstr "некорректный операнд для %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -2920,7 +2920,7 @@ msgid "post-increment address is not a register"
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -2972,8 +2972,8 @@ msgstr "'%%%c' не является корректным префиксом о
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "недопустимое использование '%%%c'"
@@ -3115,182 +3115,236 @@ msgstr "Выход за границу стека.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Попробуйте выполнить '%s' в командной строке, чтобы увеличить его размер.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx требует аппаратной реализации плавающей арифметики"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "для -mvsx требуется индексная адресация"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "ключи -mvsx и -mno-altivec несовместимы"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec отменяет vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "ключ -mquad-memory требует 64-битного режима"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 #, fuzzy
 #| msgid "-mquad-memory-atomic requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "ключ -mquad-memory-atomic требует 64-битного режима"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 #| msgid "-mquad-memory is not available in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "ключ -mquad-memory не поддерживается для обратного (little endian) порядка байт"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "некорректная 128-битная пересылка"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "некорректное %%J значение"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "неверное значение для кода %%D"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "некорректное %%e значение"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 и __ibm128 нельзя использовать в одном выражении"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 и long double нельзя использовать в одном выражении"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 и long double нельзя использовать в одном выражении"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "Не удалось сгенерировать дополнительное значение для синтеза"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Не удалось сгенерировать смещение загрузки/сохранения для синтеза"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Некорректный GPR синтез"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "некорректное преобразование из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "некорректное преобразование к %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "некорректное преобразование из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "некорректное преобразование к %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "некорректное преобразование из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "некорректное преобразование к %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "некорректное преобразование из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "некорректное преобразование к %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3301,88 +3355,88 @@ msgstr "символьные ссылки на память поддержива
 msgid "cannot decompose address"
 msgstr "ошибка при декомпозиции адреса"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "некорректный оператор сравнения для 'E' модификатора вывода"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "некорректная ссылка для 'J' модификатора вывода"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "некорректный адрес для 'O' модификатора вывода"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "некорректный адрес для 'R' модификатора вывода"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "ожидалась ссылка на память для 'S' модификатора вывода"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "некорректный адрес для 'S' модификатора вывода"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "ожидалось выражении из регистров и памяти для 'N' модификатора вывода"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "ожидался регистр или выражение памяти для модификатора вывода 'M'"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "некорректная константа для модификатора вывода '%c'"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "некорректная константа - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "некорректная константный вектор для модификатора вывода '%c'"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "некорректное выражение - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некорректное выражение для модификатора вывода '%c'"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr "векторный аргумент передан в функцию без прототипа"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "типы различаются знаковостью"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr "бинарный оператор не поддерживает два операнда-вектора с булевыми компонентами"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr "бинарный оператор не поддерживает операнд - вектор с булевыми компонентами"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "бинарный оператор не поддерживает сочетание операндов вектор с булевыми компонентами и вектор с плавающими компонентами"
 
@@ -3645,8 +3699,8 @@ msgstr "({anonymous})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
@@ -3666,7 +3720,7 @@ msgstr "ожидалось %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалась %<)%>"
@@ -3674,7 +3728,7 @@ msgstr "ожидалась %<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалась %<]%>"
@@ -3692,21 +3746,21 @@ msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалась %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалась %<{%>"
@@ -3717,12 +3771,12 @@ msgstr "ожидалась %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
@@ -3731,7 +3785,7 @@ msgstr "ожидалось %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалась %<,%>"
@@ -3740,18 +3794,18 @@ msgstr "ожидалась %<,%>"
 msgid "expected %<.%>"
 msgstr "ожидалась %<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалась %<,%> или %<)%>"
@@ -3759,19 +3813,19 @@ msgstr "ожидалась %<,%> или %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалась %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
@@ -3780,7 +3834,7 @@ msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<<%>"
@@ -3791,38 +3845,38 @@ msgstr "ожидалось %<<%>"
 msgid "expected label"
 msgstr "ожидалась метка"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Включить определяемые пользователем инструкции."
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
 msgstr[1] "претенденты:"
 msgstr[2] "претенденты:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "переход по метке %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "переход по case-метке"
 
@@ -3911,7 +3965,7 @@ msgstr "<ошибка параметра шаблона>"
 msgid "<statement>"
 msgstr "<оператор>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<неизвестный>"
@@ -4077,48 +4131,48 @@ msgstr "преобразование типа отбрасывает конст
 msgid "source type is not polymorphic"
 msgstr "тип источника не является полиморфным"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неверный тип аргумента для унарного минуса"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неверный тип аргумента для побитового дополнения"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неверный тип аргумента для abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неверный тип аргумента для сопряжения"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "в аргументе унарного !"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "нет преинкрементного оператора для типа"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "нет постинкрементного оператора для типа"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "нет предекрементного оператора для типа"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "нет постдекрементного оператора для типа"
 
@@ -4160,17 +4214,17 @@ msgstr "Некорректный символ в BOZ константе в %C"
 msgid "elemental binary operation"
 msgstr "элементная бинарная операция"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "аргументы 'a%d' и 'a%d' для внутренней функции '%s'"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "аргументы '%s' и '%s' для внутренней функции %s"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "аргументы '%s' и '%s' для внутренней функции '%s'"
@@ -4243,7 +4297,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Движущий:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "фактический аргумент для INTENT = OUT/INOUT"
 
@@ -4258,7 +4312,7 @@ msgstr "внутреннее устройство в WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s тег с INQUIRE"
@@ -4364,11 +4418,11 @@ msgstr "блочный IF"
 msgid "implied END DO"
 msgstr "предписанный END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "присваивание указателя"
 
@@ -4376,199 +4430,199 @@ msgstr "присваивание указателя"
 msgid "simple IF"
 msgstr "простой IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "элементная процедура"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr "размещаемый аргумент"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr "асинхронный аргумент"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "необязательный аргумент"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "аргумент-указатель"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "целевой аргумент"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "value аргумент"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr "volatile аргумент"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr "assumed-shape аргумент"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr "assumed-rank аргумент"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr "coarray аргумент"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr "аргумент параметризованного производного типа"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr "полиморфный аргумент"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "атрибут NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr "аргумент предполагаемого типа"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "результат-массив"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr "указательный или размещаемый результат"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr "результат с неконстантной character длиной"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr "процедура bind(c)"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Некорректный контекст для NULL() указателя в %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарного числового оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды бинарного числового оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнды оператора конкатенации строк в %%L есть %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды логического оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX величины не могут сравниваться в %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логические в %%L должны сравниваться посредством %s вместо %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды оператора сравнения %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Неизвестный оператор %%<%s%%> в %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд пользовательского оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды пользовательского оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Противоречивые ранги для оператора в %%L и %%L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Переменная цикла"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr "Переменная итератора"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "Начальное выражение в DO цикле"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "Конечное выражение в DO цикле"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "Шаговое выражение в DO цикле"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE объект"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "ALLOCATE объект"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "STAT переменная"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "ERRMSG переменная"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr "элемент в READ"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK переменная"
 
@@ -4581,27 +4635,27 @@ msgstr "Разные CHARACTER длины (%ld/%ld) в конструкторе
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Целочисленное переполнение при вычислении объема памяти для размещения"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки не соответствует декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки меньше декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Цель переотображения ранга слишком мала (%ld < %ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr "Присваивание скаляра неразмещенному массиву"
 
@@ -4678,7 +4732,7 @@ msgstr "Номер устройства в операторе ввода/выв
 msgid "Assigned label is not a target label"
 msgstr "Assigned метка не есть целевая метка"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Некорректный image номер %d в SYNC IMAGES"
@@ -5116,7 +5170,7 @@ msgstr "Предупреждать о создании временных мас
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ничего не делает. Сохранён для обратной совместимости."
@@ -5703,8 +5757,8 @@ msgstr "Добавлять подчёркивания к доступным из
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ничего не делает.  Сохранён для обратной совместимости."
@@ -8202,109 +8256,103 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "Предупреждать об определенных в основном файле, но неиспользованных макросах."
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves."
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Предупреждать о переменных, в инициализации которых используется их значение."
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "-fdump-<type>\tВыдать внутреннюю информацию о компиляции в файл."
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgid "Dump various analyzer internals to stderr."
 msgstr "-fdump-<type>\tВыдать внутреннюю информацию о компиляции в файл."
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12783,12 +12831,11 @@ msgstr "Включить использование инструкций IEEE 12
 msgid "Enable default conversions between __float128 & long double."
 msgstr "Включить подразумеваемое преобразование между __float128 & long double."
 
-#
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "BMX instructions are only supported with R2 architecture"
-msgid "Use instructions for a future architecture."
-msgstr "BMX инструкции поддерживаются только с R2 архитектурой"
+#| msgid "Use vector instructions added in ISA 3.0."
+msgid "Use instructions added in ISA 3.1."
+msgstr "Использовать векторные инструкции добавленные в ISA 3.0."
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -12802,6 +12849,12 @@ msgstr "Генерировать инструкции четверных сло
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Генерировать код относительно pc."
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate norm instruction."
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Генерировать нормальные инструкции"
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17830,7 +17883,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18474,372 +18527,372 @@ msgstr "Выполнить развертку циклов с известным
 msgid "Perform loop unrolling for all loops."
 msgstr "Выполнить развертку всех циклов."
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Разрешить оптимизации плавающей арифметики, которые могут изменить результат операции из-за округления."
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "То же, что -fassociative-math для выражений, включающих деление."
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Разрешить оптимизации плавающих вычислений, которые могут противоречить стандартам IEEE или ISO."
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Выполнить декомпозицию циклов, содержащих условные ветвления."
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Выполнить расщепление циклов"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Генерировать unwind-таблицы только для обработки исключений."
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Использовать bfd компоновщик вместо подразумеваемого."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Использовать gold компоновщик вместо подразумеваемого."
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 #| msgid "Use the gold linker instead of the default linker."
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Использовать gold компоновщик вместо подразумеваемого."
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Выполнить отслеживание переменных."
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Выполнить отслеживание переменных путем аннотирования присваиваний."
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Переключить -fvar-tracking-assignments."
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Выполнить отслеживание переменных и пометить неинициализированные переменные."
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Выполнить векторизацию циклов на древовидном представлении."
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Выполнить векторизацию циклов на древовидном представлении."
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Выполнить векторизацию базовых блоков (SLP) на древовидном представлении."
 
-#: common.opt:2959
+#: common.opt:2963
 #, fuzzy, no-c-format
 #| msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tЗадает ценовую модель для векторизации."
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tЗадает ценовую модель для кода помеченного simd директивой."
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Enables the dynamic vectorizer cost model.  Сохранён для обратной совместимости."
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Выполнять распространение копий по информации об эволюции скалярных значений."
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Добавить комментарии к ассемблерному коду."
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tУстановить атрибут видимости символов по умолчанию."
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Проверяйте vtable указатели до их использования."
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Выдать vtable верификационные счетчики."
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Выдать информацию о множествах vtable верификационных указателей."
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Использовать данные профилирования значений при оптимизациях."
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Снять зависимости между различными использованиями одной и той же переменной."
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Выполнить удаление условного мертвого кода для вызовов встроенных функций."
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Выполнить оптимизации на уровне всей программы."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Предполагать циклический перенос при арифметических переполнениях."
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Помещать данные, инициализированные нулями, в секцию bss."
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Генерировать отладочную информацию в формате по умолчанию."
 
-#: common.opt:3076
+#: common.opt:3080
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
 
-#: common.opt:3080
+#: common.opt:3084
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Записывать DW_AT_decl_column и DW_AT_call_column в DWARF."
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Генерировать отладочную информацию в подразумеваемой версии DWARF формата."
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Генерировать отладочную информацию в формате DWARF версии 2 (или более поздней)."
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Генерировать отладочную информацию в расширенном формате по умолчанию."
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function."
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Генерировать одну выходную точку для каждой функции."
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Не генерировать DWARF pubnames и pubtypes секции."
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Генерировать DWARF pubnames и pubtypes секции."
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Генерировать DWARF pubnames и pubtypes секции с GNU расширениями."
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Записывать ключи командной строки gcc в DWARF DW_AT_producer."
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Генерировать отладочную информацию в отдельных .dwo файлах."
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Генерировать отладочную информацию в формате STABS."
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Генерировать отладочную информацию в расширенном формате STABS."
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Не генерировать дополнения DWARF, не входящие в выбранную версию."
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Переключить генерацию отладочной информации."
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Генерировать отладочную информацию в формате VMS."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Генерировать отладочную информацию в формате XCOFF."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Генерировать отладочную информацию в расширенном формате XCOFF."
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Генерировать сжатые debug секции."
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tГенерировать сжатые отладочные секции в формате <format>."
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<каталог>\tУстановить <каталог> подгружаемых модулей по умолчанию."
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <каталог>\tУстановить <каталог> заголовочных файлов для мультиархитектуры."
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <файл>\tЗаписать результат в <файл>."
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Включить профилирование функций."
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Как -pedantic, но выдавать ошибки, а не предупреждения."
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Не отображать время компиляции функций."
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Включить подробную выдачу."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Показать версию компилятора."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Подавить выдачу предупреждений."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Создать разделяемую библиотеку."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Использовать сохранение регистров вызывающей стороной при всех возможных вызовах."
@@ -20024,8 +20077,8 @@ msgstr "Максимальное число проверок времени вы
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки выравнивания."
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "вычисленное значение не используется"
@@ -20051,7 +20104,7 @@ msgid "expected boolean type"
 msgstr "ожидался булевый тип"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "ожидалось целое"
@@ -20117,7 +20170,7 @@ msgstr "недостаточно аргументов"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "слишком много аргументов"
@@ -20472,7 +20525,7 @@ msgstr ""
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20557,12 +20610,12 @@ msgstr "атрибуты типов игнорируются, если тип у
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20580,8 +20633,8 @@ msgstr "атрибут %qE проигнорирован"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "предыдущая декларация %qD"
@@ -20706,7 +20759,7 @@ msgstr "параметр шаблона %qD декларирован здесь"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "смещение %qwi вне границ константной строки"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -21023,7 +21076,7 @@ msgstr "отсутствует аргумент для %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack ()%>"
@@ -21327,12 +21380,12 @@ msgstr "конфликт в списках переписываемых реги
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "конфликт в списках переписываемых регистров и входных операндов в asm"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "локальные переменные не защищены протектором стека: буфер переменного размера"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "функция не защищена протектором стека: все локальные массивы имеют размер менее %d байт"
@@ -21844,309 +21897,309 @@ msgstr "блоки не были размещены последовательн
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "число меток блоков в списке RTL-инструкций (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "missing direct call for speculation %i"
 msgstr "Отсутствует спецификатор измерения в %C"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "отсутствует барьер после блока %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "для дуги %s->%s установлено вспомогательное поле"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "подставляемый клон в том же списке comdat группы"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "inline clone is forced to output"
 msgid "inline clone count is not compatible"
 msgstr "inline клон принудительно выводится"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "tp_first_run must be non-negative"
 msgstr "значение %<priority%> должен быть неотрицательным"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "локальные символы должны быть определены"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "видимый извне inline клон"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "взятие inline клона с адресом"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "inline клон принудительно выводится"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 #| msgid "returns_nonnull attribute on a function not returning a pointer"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "returns_nonnull атрибут для функции не возвращающей указатель"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux поле установлено для косвенной дуги из %s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Косвенная дуга из %s не помечена как косвенная или имеет ассоциированную indirect_info, соответствующий оператор есть: "
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "comdat-local функция вызвана из %s вне ее comdat"
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "некорректный указатель inlined_to"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "множественные inline-вызовы"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "указатель inlined_to установлен для не inline вызова"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "указатель inlined_to установлен, но не найдено ни одного предшественника"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "указатель inlined_to ссылается на себя"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node имеет некорректный clone_of"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node имеет некорректный список клонов"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "cgraph_node в списке клонов, но он не клон"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "cgraph_node имеет некорректный prev_clone указатель"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "испорчен двусвязный список клонов"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias имеет дуги вызовов"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias имеет не-alias ссылку"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias имеет более одной alias ссылки"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Проанализированный alias не имеет ссылки"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Нет дуги из thunk-узла"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Более одной дуги исходит из thunk-узла"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk не должен иметь тела"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "разделяемый call_stmt:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "дуга указывает на неверную декларацию:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "косвенная дуга с неизвестной вызываемой функцией, соответствующая call_stmt, в известной декларации"
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "отсутствует дуга callgraph для инструкции вызова:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "ссылка на мертвый оператор"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "отсутствует call_stmt, соответствующий дуге %s->%s"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "косвенная дуга из %s не имеет соответствующего call_stmt"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "origin points to a different parent"
 msgstr "преобразование регистра к другому размеру"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "процедура verify_cgraph_node выявила ошибки"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: section %s is missing"
 msgid "%s: section %s.%d is missing"
@@ -22243,12 +22296,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "атрибут %<weakref%> игнорируется, поскольку переменная инициализирована"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F используется, но нигде не определена"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
@@ -22405,7 +22458,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "Поддержка LTO в данной конфигурации отсутствует"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "невозможно открыть %s: %m"
@@ -22756,22 +22809,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) найден в расположении переменной"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "Некорректное разделение rtl-кода в инструкции"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "разделяемый rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "обнаружена несогласованность внутреннего представления gcc"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "Внутренняя ошибка: использование emit_insn вместо emit_jump_insn:\n"
@@ -22836,7 +22889,7 @@ msgstr "region_array не соответствует region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array не соответствует region_tree"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -22867,12 +22920,12 @@ msgstr "обратить порядок хранения для %smode"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "запись %wu-бит данных вне границ объекта-приемника, данные усечены до %wu-бит"
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом error: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом warning: %s"
@@ -22888,7 +22941,7 @@ msgstr ""
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "размер кадра %wd байт больше чем %wd байт"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "ошибка открытия дамп-файла прохода final %qs: %m"
@@ -22908,37 +22961,37 @@ msgstr "большая константа с фиксированной точк
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "предполагается, что при упрощении проверки диапазона не произошло переполнение"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "результат сравнения - всегда %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> от двух сравнений на неравенство с разными величинами - всегда 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> от двух взаимно исключающих сравнений на равенство - всегда 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "предполагается, что при редукции константы в сравнении не произошло переполнение"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "предполагается, что при комбинировании констант вокруг сравнения не произошло переполнение"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "проверка fold: исходное дерево изменено функцией fold"
@@ -23591,13 +23644,13 @@ msgstr "функция может возвращать адрес локальн
 msgid "function returns address of local variable"
 msgstr "функция возвращает адрес локальной переменной"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "объявлено здесь"
@@ -24238,10 +24291,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -24413,7 +24466,7 @@ msgstr "%qE не задано в объемлющей %qs"
 msgid "enclosing %<target%>"
 msgstr "объемлющая целевая область"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "переменная %qE декларирована в объемлющей %<host_data%> области"
@@ -24466,14 +24519,14 @@ msgstr "%qD не есть переменная в клаузуле %<lastprivate
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
@@ -24484,158 +24537,158 @@ msgstr "модель кода %<large%> пока не поддерживаетс
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%> клаузула для переменной отличной от итератора цикла заданного в конструкции, скомбинированной с %<distribute%>"
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "отображение поля %qE структуры переменной длины"
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE встречается более одного раза в map клаузуле"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate переменная %qE не является threadprivate или private во внешнем контексте"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s переменная %qE является частной для внешнего контекста"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "ожидался %qs %<if%> модификатор клаузулы а не %qs"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD в неявной %<map%> клаузуле"
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD в неявной %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "та же переменная использована в %<firstprivate%> и %<lastprivate%> клаузулах %<distribute%> конструкции"
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "несовместимая клаузула данных с редукцией %qE; преобразовано в present_or_copy"
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "некорректная private редукция на %qE"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "%<linear%> клаузула не может задаваться вместе с %<ordered%> клаузулой с параметром"
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "%<teams%> конструкция не вложена замкнуто в %<target%> конструкции"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, fuzzy, gcc-internal-format
 #| msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<distribute%> область должна быть строго вложена в %<teams%> конструкции"
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, fuzzy, gcc-internal-format
 #| msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "только %<distribute%> или %<parallel%> области могут быть строго вложены в %<teams%> области"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "%<#pragma omp declare reduction%> объединитель ссылается на переменную %qD, которая не %<omp_out%> и не %<omp_in%>"
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%> конструкция с %<depend%> клаузулой должна быть замкнуто вложена внутри цикла с %<ordered%> клаузулой с параметром"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "переменная %qE не есть итерация самого внешнего цикла %d, ожидалось %qE"
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, fuzzy, gcc-internal-format
 #| msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "число переменных в %<depend(sink)%> клаузуле не соответствует числу итерационных переменных"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, fuzzy, gcc-internal-format
 #| msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "более одной %<depend(source)%> клаузулы %<ordered%> конструкции"
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, fuzzy, gcc-internal-format
 #| msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<depend(source)%> клаузула задана вместе с %<depend(sink:)%> клаузулами в той же конструкции"
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "преобразование в gimple завершилось неуспешно"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT преобразован к %qT при передаче через %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(поэтому %<va_arg%> нужно передать %qT, а не %qT)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "при достижении этого кода выполнение программы завершится аварийно"
@@ -24713,7 +24766,7 @@ msgstr "токен %u имеет x-location == %u"
 msgid "token %u has %<y-location == %u%>"
 msgstr "токен %u имеет y-location == %u"
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "недопустимое использование атрибута %<fallthrough%>"
@@ -24991,7 +25044,7 @@ msgstr "Границы массива не совпадают"
 msgid "the extra base is defined here"
 msgstr "дополнительная база определена здесь"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -24999,7 +25052,7 @@ msgstr[0] "Декларирование типа %qD final включит дев
 msgstr[1] "Декларирование типа %qD final включит девиртуализацию %i вызовов"
 msgstr[2] "Декларирование типа %qD final включит девиртуализацию %i вызовов"
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -25007,7 +25060,7 @@ msgstr[0] "Декларирование типа %qD final включит дев
 msgstr[1] "Декларирование типа %qD final включит девиртуализацию %i вызова, выполненного %lli раза"
 msgstr[2] "Декларирование типа %qD final включит девиртуализацию %i вызова, выполненного %lli раза"
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -25015,7 +25068,7 @@ msgstr[0] "Декларирование виртуального деструк
 msgstr[1] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызовов"
 msgstr[2] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызовов"
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -25023,7 +25076,7 @@ msgstr[0] "Декларирование метода %qD final включит д
 msgstr[1] "Декларирование метода %qD final включит девиртуализацию %i вызовов"
 msgstr[2] "Декларирование метода %qD final включит девиртуализацию %i вызовов"
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -25031,7 +25084,7 @@ msgstr[0] "Декларирование виртуального деструк
 msgstr[1] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
 msgstr[2] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -25039,13 +25092,13 @@ msgstr[0] "Декларирование метода %qD final включит д
 msgstr[1] "Декларирование метода %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
 msgstr[2] "Декларирование метода %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid fnsummary in LTO stream"
 msgstr "некорректная функция в gimple вызове"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "во входном файле отсутствует информация о межпроцедурных inline-подстановках"
@@ -25076,38 +25129,38 @@ msgstr "функции, возможно, следует задать атриб
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "сводка ссылок межпроцедурного анализа отсутствует в модуле ltrans"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "HSA SSA verification failed"
 msgid "IPA-SRA access verification failed"
 msgstr "неудача верификации HSA SSA"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -25160,57 +25213,57 @@ msgstr "некорректные ограничители операндов в
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Макс. number of generated reload insns per insn is achieved (%d)\n"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "поток байткода: найдено несколько экземпляров cgraph узла с uid %d"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "поток байткода: не найден вызывающий при чтении дуги"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "поток байткода: не найден вызываемый при чтении дуги"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "поток байткода: найден пустой cgraph узел"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Данные профилирование в %s испорчены"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "не найден граф вызовов LTO в %s"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "невозможно найти ссылки на LTO секцию в %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "некорректная таблица разгрузки в %s"
@@ -25482,54 +25535,54 @@ msgstr "%<depend(sink)%> клаузула ждет лексически боле
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr "%<depend(sink)%> ссылается на итерацию отсутствующую в пространстве итераций"
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "previously used here"
 msgid "... to the previous %qs clause here"
 msgstr "которое ранее использовано здесь"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "switch starts here"
 msgid "... with %qs clause here"
 msgstr "начало переключателя здесь"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> переопределяет другие OpenACC спецификаторы циклов"
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> конфликтует с другими OpenACC спецификаторами циклов"
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "внутренний цикл использует тот же OpenACC параллелизм, что и объемлющий"
@@ -25766,53 +25819,53 @@ msgstr "некорректный вход в %s структурный блок"
 msgid "invalid branch to/from %s structured block"
 msgstr "некорректное ветвление в/из %s структурного блока"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "-fopenacc-dim operand is malformed at '%s'"
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr "-fopenacc-dim операнд искажен в '%s'"
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr "вызов подпрограммы использует тот же OpenACC параллелизм, что и объемлющий цикл"
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr "объемлющий цикл здесь"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr "вызов подпрограммы использует OpenACC параллелизм, запрещенный объемлющей подпрограммой"
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr "цикл использует OpenACC параллелизм, запрещенный объемлющей подпрограммой"
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "программа %qD декларирована здесь"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr "некорректно вложенный OpenACC параллелизм циклов"
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr "недостаточно разбиений для распараллеливания элементарного цикла"
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr "недостаточно разбиений для распараллеливания мозаичного цикла"
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr "недостаточно разбиений для распараллеливания цикла"
@@ -27238,142 +27291,142 @@ msgstr ""
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> больше не поддерживается"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "планирование команд для этой платформы не поддерживается"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "эта машина не имеет задержек переходов"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore не поддерживается для этой целевой машины"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "ошибка закрытия дамп-файла %qs: %m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "целевая система не поддерживает %qs отладочный формат"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "отслеживание переменных бесполезно без генерации отладочной информации"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "запрошено отслеживание переменных, но оно не поддерживается этого формата отладочной информации"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "присваивания с отслеживанием переменных влияют на селективное планирование"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections не поддерживается для этой целевой машины"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections не поддерживается для этой целевой машины"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays не поддерживается для этой целевой машины"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays не поддерживается для этой целевой машины"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays не поддерживается с -Os"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math отменен в пользу более приоритетных ключей"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector не поддерживается для этой целевой платформы"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fsanitize=address и -fsanitize=kernel-address не поддерживаются для этой целевой платформы"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "ошибка записи в %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "ошибка закрытия %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "self-tests incompatible with -E"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "тесты самопроверки несовместимы с -E"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "self-tests не включены в этой сборке"
@@ -27471,193 +27524,193 @@ msgstr "%Kasm не допускается в %<transaction_safe%> функции
 msgid "ignoring loop annotation"
 msgstr "игнорирование аннотации цикла"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "константа не перевычислена после изменения ADDR_EXPR"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "побочные эффекты не перевычислены после изменения ADDR_EXPR"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "DECL_GIMPLE_REG_P set on a variable with address taken"
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "DECL_GIMPLE_REG_P установлен для переменной, от которой берется адрес"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "адрес был взят, а бит ADDRESSABLE не установлен"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "некорректное выражение в левой части операции min"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "некорректный операнд в косвенной ссылке"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "non-scalar type"
 msgid "non-scalar %qs"
 msgstr "нескалярный тип"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "некорректная позиция или размер для BIT_FIELD_REF"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "integral result type precision does not match field size of BIT_FIELD_REF"
 msgid "integral result type precision does not match field size of %qs"
 msgstr "точность целочисленного типа результата не соответствует размеру поля в BIT_FIELD_REF"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
 #| msgid "mode size of non-integral result does not match field size of BIT_FIELD_REF"
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "размер режима нецелочисленного результата не соответствует размеру поля в BIT_FIELD_REF"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs of non-mode-precision operand"
 msgstr "сдвиг нецелого операнда"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
 #| msgid "position plus size exceeds size of referenced object in BIT_FIELD_REF"
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "позиция плюс размер превышает размер указуемого объекта в BIT_FIELD_REF"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "несоответствие типов в ссылке на массив"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "некорректный операнд для %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in parameter %i"
 msgid "type mismatch in %qs"
 msgstr "несоответствие типов в параметре %i"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offset operand of MEM_REF"
 msgid "invalid %qs offset operator"
 msgstr "некорректный операнд смещения для MEM_REF"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of an SSA_NAME on the left hand side"
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "преобразование SSA_NAME в левой части"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of register to a different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "преобразование регистра к другому размеру"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address operand in MEM_REF"
 msgid "invalid address operand in %qs"
 msgstr "некорректный операнд адреса в MEM_REF"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offset operand in MEM_REF"
 msgid "invalid offset operand in %qs"
 msgstr "некорректный операнд отступа в MEM_REF"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "некорректное использование %qD"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "простой IF"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "gimple вызов имеет две цели"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "gimple вызов не имеет цели"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "некорректная функция в gimple вызове"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "не функция в gimple вызове"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "некорректное состояние pure const для функции"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "некорректная левая часть в gimple вызове"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, fuzzy, gcc-internal-format
 #| msgid "LHS in noreturn call"
 msgid "LHS in %<noreturn%> call"
 msgstr "левая часть в вызове без возврата (noreturn)"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "некорректное преобразование в gimple вызове"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "некорректная статическая цепочка в gimple вызове"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "статическая цепочка с функцией, которая не использует ее"
@@ -27668,546 +27721,546 @@ msgstr "статическая цепочка с функцией, котора
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_unreachable or __builtin_trap call with arguments"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "вызов __builtin_unreachable или __builtin_trap с аргументами"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "некорректный аргумент в gimple вызове"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "некорректные операнды в gimple сравнении"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "несоответствие типов операндов сравнения"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "неподдерживаемая операция или тип для векторного сравнения, возвращающего boolean"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "невекторные операнды в векторном сравнении"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "некорректный тип результата в векторном сравнении"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "фиктивный тип результата в векторном сравнении"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "не-регистр в левой части унарной операции"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "неверные операнды унарной операции"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "неверные типы в nop-преобразовании"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "неверные типы в nop-преобразовании"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "неверные типы в преобразовании адресного пространства"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "неверные типы в преобразовании с фиксированной точкой"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "некорректные типы в преобразовании к типу с плавающей точкой"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "некорректные типы в преобразовании к целочисленному типу"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in sad expression"
 msgid "type mismatch in %qs expression"
 msgstr "несоответствие типов в sad выражении"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid prototype for '%s'"
 msgid "invalid types for %qs"
 msgstr "некорректный прототип для '%s'"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "нетривиальное преобразование в унарной операции"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "не регистр в левой части бинарной операции"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "неверные операнды в бинарной операции"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-vector operands to vector valued plus"
 msgid "invalid non-vector operands to %qs"
 msgstr "неверные невекторные операнды векторной операции плюс"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "неизвестная машинный режим %qs для указателя"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "vector type expected in %qs"
 msgstr "ожидались векторные типы в sad выражении"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "несоответствие типов в бинарном выражении"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "не регистр в левой части тернарной операции"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "неверные операнды тернарной операции"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, fuzzy, gcc-internal-format
 #| msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "первый аргумент VEC_COND_EXPR должен быть boolean векторного типа с тем же числом элементов, что и результат"
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 #| msgid "vector types expected in sad expression"
 msgid "vector types expected in %qs"
 msgstr "ожидались векторные типы в sad выражении"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 #| msgid "vectors with different element number found in vector permute expression"
 msgid "vectors with different element number found in %qs"
 msgstr "в векторном выражении перестановки обнаружены векторы с разным числом элементов"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid offload table in %s"
 msgid "invalid mask type in %qs"
 msgstr "некорректная таблица разгрузки в %s"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "not allowed type combination in BIT_INSERT_EXPR"
 msgid "not allowed type combination in %qs"
 msgstr "недопустимая комбинация типов в BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size in BIT_INSERT_EXPR"
 msgid "invalid position or size in %qs"
 msgstr "некорректная позиция или размер в BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 #| msgid "'h' applied to non-register operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "'h' применено к нерегистровому операнду"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "insertion out of range in BIT_INSERT_EXPR"
 msgid "insertion out of range in %qs"
 msgstr "вставка вне диапазона в BIT_INSERT_EXPR"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 #| msgid "vector insertion not at element boundary"
 msgid "%qs not at element boundary"
 msgstr "векторная вставка не на границе элемента"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "нетривиальное преобразование в присваивании"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "non-decl/MEM_REF LHS in clobber statement"
 msgid "%qs LHS in clobber statement"
 msgstr "non-decl/MEM_REF LHS в затирающем операторе"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "некорректный операнд для %%R"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "Некорректная правая часть в gimple операции записи в память"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect type of vector CONSTRUCTOR elements"
 msgid "incorrect type of vector %qs elements"
 msgstr "некорректный тип элементов векторного CONSTRUCTOR"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect number of vector CONSTRUCTOR elements"
 msgid "incorrect number of vector %qs elements"
 msgstr "некорректное число элементов векторного CONSTRUCTOR"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "некорректный тип элементов векторного CONSTRUCTOR"
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR with non-NULL element index"
 msgid "vector %qs with non-NULL element index"
 msgstr "векторный CONSTRUCTOR с non-NULL индексом элемента"
 
 #
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "vector CONSTRUCTOR element is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "элемент векторного CONSTRUCTOR не есть GIMPLE-значение"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "non-vector CONSTRUCTOR with elements"
 msgid "non-vector %qs with elements"
 msgstr "non-vector CONSTRUCTOR с элементами"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR с тождественно ложным условием"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "некорректный операнд в операторе return"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "некорректное преобразование в операторе return"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "цель оператора goto не является ни меткой, ни указателем"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "некорректный операнд для оператора switch"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "оператор switch с нецелочисленным типом"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "некорректная default case метка в операторе switch"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "invalid CASE_CHAIN"
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "некорректная CASE_CHAIN"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "некорректная case метка в операторе switch"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "некорректный case диапазон в операторе switch"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "несоответствие типов для case метки в операторе switch"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "несоответствие точности типов в операторе switch"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case метки не отсортированы в операторе switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "label's context is not the current function decl"
 msgid "label context is not the current function declaration"
 msgstr "контекст метки не есть декларация текущей функции"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "некорректный элемент в label_to_block_map"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "некорректная установка номера landing pad"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "некорректный код сравнения в gimple условном выражении"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "некорректные метки в gimple условном выражении"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "некорректный результат PHI"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "отсутствует определение PHI"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "некорректный аргумент PHI"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in PHI argument %u"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "несовместимые типы в аргументе PHI %u"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "процедура verify_gimple выявила ошибки"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
 #| msgid "dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "мертвый оператор в таблице EH"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "расположения блока ссылок не в дереве блоков"
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "Local declaration from a different function"
 msgid "local declaration from a different function"
 msgstr "Локальная декларация из другой функции"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) указывает не на тот блок"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "PHI узел с расположением"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "недопустимое разделение узлов дерева"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "виртуальный PHI с расположениями аргументов"
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) указывает не на тот блок"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "оператор помечен как throw, но не является таковым"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "оператор помечен как throw в середине блока"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "процедура verify_gimple выявила ошибки"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "с ENTRY_BLOCK ассоциирован IL"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "с EXIT_BLOCK ассоциирован IL"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "сквозной выход из блока %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "нелокальная метка "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH landing pad метка "
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "метка "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "инструкция управления потоком выполнения внутри блока %d"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "сквозная дуга после оператора управления в блоке %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "дуга true/false после не GIMPLE_COND в блоке %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "некорректные флаги выходной дуги в конце блока %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "явный переход goto в конце блока %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "дуга return не указывает на конец блока %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "случай default - не в начале case-вектора"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case-метки не отсортированы: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "лишняя исходящая дуга %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "отсутствует дуга %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "выход из функции с атрибутом %<noreturn%>"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "управление достигает конца не-void функции"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -28223,48 +28276,48 @@ msgstr "в определении макроса %qs"
 msgid "in expansion of macro %qs"
 msgstr "в расширении макроса %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "блок %i имеет множественные EH-дуги"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has an EH edge"
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "блок %i не может выдавать исключений, но имеет EH-дугу"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "в последнем операторе блока %i некорректно установлен lp"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "в блоке %i отсутствует EH-дуга"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "некорректная EH-дуга %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "в блоке %i отсутствует дуга"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "в блоке %i слишком много сквозных дуг"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "блок %i содержит некорректную дугу"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "блок %i содержит некорректную сквозную дугу"
@@ -28819,12 +28872,12 @@ msgstr "оператор (%p) помечен как измененный пос
 msgid "verify_ssa failed"
 msgstr "процедура verify_ssa выявила ошибки"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "машинно независимый встроенный код вне диапазона"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "специфическая для целевой платформы встроенная функция недоступна"
@@ -28892,7 +28945,7 @@ msgstr "значение индекс массива %qE вне границ т
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "значение индекс массива %qE вне границ типа массива %qT"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28903,29 +28956,29 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "объединение определено здесь"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "значение индекс массива %qE вне границ типа массива %qT"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "значение индекс массива %qE вне границ типа массива %qT"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -29004,32 +29057,32 @@ msgstr "дерево: доступ к операнду %d функции %s с %
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции omp_clause %s с %d операндами в %s, в %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD устарело: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD устарело"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE устаревшее: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "имя %qE будет исключено в будущих версиях"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "поддержка данного типа будет исключена в будущих версиях: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "поддержка данного типа будет исключена в будущих версиях"
@@ -29054,273 +29107,273 @@ msgstr "поддержка данного типа будет исключена
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "вариант типа имеет другой TYPE_SIZE_UNIT"
 
-#: tree.c:13926
+#: tree.c:13937
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_SIZE_UNIT"
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT варианта типа"
 
-#: tree.c:13928
+#: tree.c:13939
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_SIZE_UNIT"
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT типа"
 
-#: tree.c:13951
+#: tree.c:13962
 #, fuzzy, gcc-internal-format
 #| msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "вариант типа с TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13964
+#: tree.c:13975
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_VFIELD"
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "вариант типа имеет другой TYPE_VFIELD"
 
-#: tree.c:14000
+#: tree.c:14011
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "вариант типа имеет другой TYPE_BINFO"
 
-#: tree.c:14002
+#: tree.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_BINFO"
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO варианта типа"
 
-#: tree.c:14004
+#: tree.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_BINFO"
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO типа"
 
-#: tree.c:14043
+#: tree.c:14054
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_FIELDS"
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "вариант типа имеет другой TYPE_FIELDS"
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "первое несоответствие является полем"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr "и поле"
 
-#: tree.c:14064
+#: tree.c:14075
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TREE_TYPE"
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "вариант типа имеет другой TREE_TYPE"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE варианта типа"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, fuzzy, gcc-internal-format
 #| msgid "type's TREE_TYPE"
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE типа"
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "тип не совместим со своим вариантом"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "Main variant is not defined"
 msgid "main variant is not defined"
 msgstr "Главный вариант не определен"
 
-#: tree.c:14392
+#: tree.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_MAIN_VARIANT имеет другой TYPE_MAIN_VARIANT"
 
-#: tree.c:14404
+#: tree.c:14415
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "TYPE_CANONICAL имеет другой TYPE_CANONICAL"
 
-#: tree.c:14423
+#: tree.c:14434
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL несовместим"
 
-#: tree.c:14431
+#: tree.c:14442
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_MODE от TYPE_CANONICAL несовместим"
 
-#: tree.c:14437
+#: tree.c:14448
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL of main variant is not main variant"
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "TYPE_CANONICAL от главного варианта не есть главный вариант"
 
-#: tree.c:14453
+#: tree.c:14464
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "TYPE_VFIELD не есть ни FIELD_DECL ни TREE_LIST"
 
-#: tree.c:14463
+#: tree.c:14474
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "TYPE_NEXT_PTR_TO не есть POINTER_TYPE"
 
-#: tree.c:14473
+#: tree.c:14484
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "TYPE_NEXT_REF_TO не есть REFERENCE_TYPE"
 
-#: tree.c:14494
+#: tree.c:14505
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO is not TREE_BINFO"
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "TYPE_BINFO не есть TREE_BINFO"
 
-#: tree.c:14500
+#: tree.c:14511
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_BINFO тип не есть TYPE_MAIN_VARIANT"
 
-#: tree.c:14511
+#: tree.c:14522
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE не есть ни record ни union"
 
-#: tree.c:14522
+#: tree.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE не есть ни record ни union"
 
-#: tree.c:14540
+#: tree.c:14551
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "TYPE_ARRAY_MAX_SIZE не INTEGER_CST"
 
-#: tree.c:14547
+#: tree.c:14558
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VALUES_RAW field is non-NULL"
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "TYPE_VALUES_RAW поле не-NULL"
 
-#: tree.c:14554
+#: tree.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "TYPE_LANG_SLOT_1 (binfo) поле не-NULL"
 
-#: tree.c:14570
+#: tree.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "Enum значение не есть CONST_DECL или INTEGER_CST"
 
-#: tree.c:14578
+#: tree.c:14589
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "Тип enum значения не есть ни INTEGER_TYPE ни преобразуемый в enum"
 
-#: tree.c:14586
+#: tree.c:14597
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value name is not IDENTIFIER_NODE"
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "Имя enum значения не есть IDENTIFIER_NODE"
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "Array TYPE_DOMAIN is not integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Массивный TYPE_DOMAIN не есть целочисленный тип"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_FIELDS defined in incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "TYPE_FIELDS определено в неполном типе"
 
-#: tree.c:14627
+#: tree.c:14638
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Неверное дерево в TYPE_FIELDS списке"
 
-#: tree.c:14642
+#: tree.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "TYPE_CACHED_VALUES_P есть %i, в то время как TYPE_CACHED_VALUES есть %p"
 
-#: tree.c:14649
+#: tree.c:14660
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "TYPE_CACHED_VALUES не есть TREE_VEC"
 
-#: tree.c:14662
+#: tree.c:14673
 #, fuzzy, gcc-internal-format
 #| msgid "wrong TYPE_CACHED_VALUES entry"
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "неверный TYPE_CACHED_VALUES элемент"
 
-#: tree.c:14675
+#: tree.c:14686
 #, fuzzy, gcc-internal-format
 #| msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "TREE_PURPOSE не-NULL в TYPE_ARG_TYPES списке"
 
-#: tree.c:14681
+#: tree.c:14692
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Неверный элемент в TYPE_ARG_TYPES списке"
 
-#: tree.c:14688
+#: tree.c:14699
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VALUES_RAW field is non-NULL"
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "TYPE_VALUES_RAW поле не-NULL"
 
-#: tree.c:14700
+#: tree.c:14711
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "TYPE_CACHED_VALUES_P установлен хотя не должен"
 
-#: tree.c:14710
+#: tree.c:14721
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
@@ -29449,87 +29502,87 @@ msgstr "запрошенное выравнивание для %q+D превыш
 msgid "storage size of %q+D isn%'t known"
 msgstr "размер %q+D в памяти неизвестен"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "слишком сложное инициализирующее выражение для целого или значения с фиксированной точкой"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "инициализирующее выражение для плавающего не является плавающей константой"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "некорректное начальное значение для элемента %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "weak декларация %q+D применяется к уже существующему static определению"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "weak декларация %q+D должна быть public"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "weak декларация %q+D не поддерживается"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "в данной конфигурации поддерживаются только слабые алиасы"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref в данной конфигурации не поддерживается"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "ifunc не поддерживается на этой платформе"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "-pg для данной платформы не поддерживается"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "слабая ссылка %q+D в конечном счёте направлена на себя"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "слабая ссылка %q+D должна иметь статическое связывание"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "в данной конфигурации определения алиасов не поддерживаются"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s для этой конфигурации не поддерживается"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видимости не поддерживается в данной конфигурации; определение игнорируется"
@@ -30155,7 +30208,7 @@ msgstr "атрибут %qE следует после %qE"
 msgid "type was previously declared %qE"
 msgstr "тип был ранее декларирован как %qE"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> может задаваться только для виртуальной функции"
@@ -30175,7 +30228,7 @@ msgstr "%qD не совместим с %qD"
 msgid "%qE argument is not a function"
 msgstr "аргумент %qE не функция"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "сообщение для атрибута deprecated не является строковой константой"
@@ -30581,12 +30634,12 @@ msgstr "?: использование целых констант в булев
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "компилятор может предполагать, что адрес %qD всегда будет давать значение %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "присваивание, используемое как логическое выражение, рекомендуется "
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
@@ -30745,12 +30798,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%> атрибут задан с параметром"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -30852,7 +30905,7 @@ msgstr "индекс %E обозначает смещение, превышаю
 msgid "size of array is too large"
 msgstr "размер массива слишком велик"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "тип операнда %qT несовместим с аргументом %d для %qE"
@@ -30863,133 +30916,133 @@ msgstr "тип операнда %qT несовместим с аргументо
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "при передаче аргумента %d %qE целое преобразуется в указатель без приведения типа"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "левый аргумент должен быть вырезкой"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "неправильное число аргументов в вызове функции %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент 1 для %qE должен быть не-void указателем"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "аргумент 1 для %qE должен быть типом с константным размером"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "аргумент 1 для %qE должен быть указателем на объект ненулевого размера"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "аргумент %d для %qE должен быть указателем на тип константного размера"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "аргумент %d для %qE не должен быть указателем на функцию"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "несоответствие размера в аргументе %d для %qE"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "нецелочисленный аргумент %d модели памяти для %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "некорректный аргумент %d модели памяти для %qE"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "значение индекса вне диапазона"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "преобразование скаляра %qT в вектор %qT включает усечение"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "размер массива %qE отрицательный"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "размер массива отрицательный"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "%Kаргумент %i значение %qE превышает максимальный размер объекта %E"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "%Kаргумент %i значение %qE превышает максимальный размер объекта %E"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "size of array exceeds maximum object size %qE"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
@@ -31046,532 +31099,532 @@ msgstr "%qE некорректный вид функции форматиров
 msgid "format string argument follows the arguments to be formatted"
 msgstr "аргумент с форматной строкой после аргументов, подлежащих форматированию"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "функция %qD может быть кандидатом на %qs форматный атрибут"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "отсутствует номер операнда (с символом $)"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s не поддерживает номера операндов %%n$ в форматах"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "номер операнда в формате вне диапазона"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "аргумент формата %d использован более одного раза в формате %s"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$ номер операнда использован после формата без номера операнда"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "неиспользованный аргумент %d функции форматирования перед использованным %d в $-формате"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "формат не является строкой константой, проверка формата не выполнена"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "формат не является строковой константой, и не заданы аргументы форматирования"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "формат не является строковой константой, проверка типов аргументов не выполнена"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "слишком много аргументов для форматирования"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "неиспользованные аргументы в $-формате"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "форматная строка %s нулевой длины"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "формат задан как строка широких символов"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string argument is not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "аргумент, задающий формат, имеет не строковый тип"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "не терминирована строка формата"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s употреблен с %<%%%c%> в формате %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s не поддерживает %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s не поддерживает %s с %<%%%c%> в формате %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "повторный %s в формате"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "не задан символ-заполнитель в конце формата strfmon"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "нулевая ширина в формате %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "пустая точность левой части в формате %s"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "пустая точность в формате %s"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s не поддерживает модификатор размера %qs в %s"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s не поддерживает %<%%%c%> в формате %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s в сочетании с %s и %<%%%c%> в формате %s игнорируется"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s в сочетании с %s в формате %s игнорируется"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "%s и %s использованы с %<%%%c%> в формате %s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "%s и %s использованы вместе в формате %s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> в некоторых локализациях дает только две последние цифры года"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> только две последние цифры года"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "отсутствует %<]%> для формата %<%%[%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "использование %qs модификатора длины с %qc символом типа или не имеет эффекта или дает неопределенное поведение"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s не поддерживает %<%%%s%c%> в формате %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "номер операнда указан без подавления присваивания"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "номер операнда указан в формате без аргументов"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "повторный %s в формате"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "повторный %s в формате"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "символ %<\\0%> в форматной строке"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "попробуйте задать %qE"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "unquoted attribute in format"
 msgstr "несовпадение атрибутов функции"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<*%> before %qE"
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr "ожидался идентификатор или %<*%> перед %qE"
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "символ %<%%%> в конце формата"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "inconsistent capitalization in format"
 msgstr "неконстантное инициализационное выражение в %L"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "символ %<%%%> в конце формата"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "повторный %s в формате"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "повторный %s в формате"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "повторный %s в формате"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "символ %<%%%> в конце формата"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "символ %<%%%> в конце формата"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "Nonconforming tab character in format at %C"
 msgid "unquoted non-graph characters in format"
 msgstr "Неподходящий символ табуляции в формате в %C"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "неопознанный символ преобразования %qc в формате"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "символ %<%%%> в конце формата"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "в преобразовании в конце формата не указан тип"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "символ %<\\0%> в форматной строке"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr ""
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "запись по пустому указателю (аргумент %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "чтение по пустому указателю (аргумент %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "запись в константный объект (аргумент %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "избыточные квалификаторы типа в аргументе форматирования (аргумент %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> ожидает аргумент типа %<%s%s%>, но аргумент %d имеет тип %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> ожидает соответствующий %<%s%s%> аргумент"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> ожидает аргумент типа %<%T%s%>, но аргумент %d имеет тип %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> ожидает соответствующий %<%T%s%> аргумент"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> не определен как тип"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> не определен как %<long%> или %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "имя %<locus%> не определено как тип"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "имя %<locus%> не определено как тип"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> не определен как тип"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "имя %<tree%> не определено как тип"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "имя %<tree%> не определено как указательный тип"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "аргументы, подлежащие форматированию, должны соответствовать %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "форматы strftime нельзя использовать для форматирования аргументов"
@@ -31739,7 +31792,7 @@ msgstr "%<depend(source)%> клаузула задана вместе с %<depen
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "некорректный тип итерационной переменной %qE"
@@ -31754,17 +31807,17 @@ msgstr "%<_Atomic%> итерационная переменная %qE"
 msgid "%qE is not initialized"
 msgstr "%qE не инициализирован"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "отсутствует управляющий предикат"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный управляющий предикат"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "отсутствует инкрементальное выражение"
@@ -31774,7 +31827,7 @@ msgstr "отсутствует инкрементальное выражение
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "некорректное инкрементальное выражение"
@@ -32417,7 +32470,7 @@ msgid "wrong type argument to %s"
 msgstr "неверный аргумент типа для %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "переполнение при вычислении константного выражения"
@@ -33095,7 +33148,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr "%<memset%> использовано с длиной равной числу элементов без умножения на размер элемента"
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "сравнение между типами %qT и %qT"
@@ -33180,7 +33233,7 @@ msgstr[0] "передача аргумента %i в restrict-квалифици
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "это условие имеет идентичные ветвления"
@@ -33200,7 +33253,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
@@ -33221,7 +33274,7 @@ msgid "too many input files"
 msgstr "слишком много входных файлов"
 
 #
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -33255,14 +33308,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "допустимые аргументы: %s; имелось в виду %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -33824,432 +33877,442 @@ msgstr "псевдонимы не поддерживаются для Mach-O; и
 msgid "profiler support for VxWorks"
 msgstr "поддержка профилирования для VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kаргумент %d должен быть непосредственной константой"
 
 #
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kиндекс прохода должен быть непосредственной константой"
 
 #
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "%Kобщий размер и размер элемента должны быть ненулевыми непосредственными константами"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%Kаргумент %d должен быть непосредственной константой"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support %<-mfp32%>"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "архитектура %qs не поддерживает %<-mfp32%>"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "%Kаргумент %d должен быть непосредственной константой"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "ожидался тип %qT, но аргумент имеет тип %qT"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "ожидался тип %qT, но аргумент имеет тип %qT"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> не строка и не число"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "неизвестный #pragma GCC intrinsic %E"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new нельзя применять к типу функции"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "ожидался %<for%> после %qs"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the SVE ISA extension"
 msgstr "Не использовать расширения SPE ABI."
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "аргумент decltype должен быть выражением"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Использовать расширения SPE ABI."
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, fuzzy, gcc-internal-format
 #| msgid "unknown flag passed in -moverride=%s (%s)"
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "неизвестный флаг переданный в -moverride=%s (%s)"
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for sve_width"
 msgstr "некорректный формат %s"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "некорректное значение %%h"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "строка настройки отсутствует в опции (%s)"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "неизвестная опция настройки (%s)"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Порядок выделения регистров"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "отсутствует имя процессора в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "некорректный модификатор возможности в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function %s"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "некорректный аргумент встроенной функции %s"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "отсутствует имя архитектуры в %<-march=%s%>"
 
 #
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "неизвестное значение %qs для -march"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid feature modifier in %<-march=%s%>"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "некорректный модификатор возможности в %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "отсутствует имя процессора в %<-mtune=%s%>"
 
 #
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "неизвестное значение %qs для -mtune"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support %<-mfp32%>"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "архитектура %qs не поддерживает %<-mfp32%>"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "модель кода %qs с -f%s"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент атрибута %<target%> не строка"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, fuzzy, gcc-internal-format
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+#, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+#, fuzzy
+#| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kпроход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "проход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "неподдерживаемая simdlen %d"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -34450,17 +34513,17 @@ msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -34618,13 +34681,13 @@ msgstr "неизвестный вывод ассемблерного флага
 msgid "invalid type for %<asm%> flag output"
 msgstr "некорректный тип для вывода ассемблерного флага"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "coprocessor not enabled"
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "сопроцессор не включен"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -34632,201 +34695,201 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%Kаргумент %d должен быть непосредственной константой"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "эта внутренняя функция не поддерживается для этой платформы"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s ожидает целый литерал в диапазоне [%d, %d]"
 
 #
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "%Klane index must be a constant immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "%Kиндекс прохода должен быть непосредственной константой"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, fuzzy, gcc-internal-format
 #| msgid "You must enable VFP instructions to use these intrinsics."
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr "Вы должны включить NEON инструкции для использования этих встроенных функций."
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, fuzzy, gcc-internal-format
 #| msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr "Вы должны включить NEON инструкции (например, -mfloat-abi=softfp -mfpu=neon) для использования этих встроенных функций."
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Вы должны включить NEON инструкции для использования этих встроенных функций."
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, fuzzy, gcc-internal-format
 #| msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr "Вы должны включить крипто инструкции (например, включить -mfloat-abi=softfp -mfpu=neon...) для использования этих встроенных функций."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор должен быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "диапазон селектора должен быть от 0 до 7"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "диапазон селектора должен быть от 0 до 3"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "диапазон селектора должен быть от 0 до 1"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "диапазон маски должен быть от 0 до 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -34837,300 +34900,300 @@ msgid "argument %u to function %qE is of type %qT which is not known to be 128 b
 msgstr ""
 
 #
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt и NEON несовместимы"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "целевой процессор не поддерживает режим ARM"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "поддержка backtrace имеет смысл только для Thumb"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "-mcallee-super-interworking имеет смысл только при компиляции для Thumb"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g с -mno-apcs-frame может создать проблемы при отладке"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt не поддерживается в Thumb режиме"
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "недопустимо использовать -mtp=cp15 с 16-битным Thumb"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "позиционно-независимый RTP несовместим с Thumb"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-fjni несовместимо с -freduced-reflection"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "целевой процессор не поддерживает команды THUMB"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "целевой процессор не поддерживает невыровненные доступы"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "ключ -mapcs-stack-check несовместим с -mno-apcs-frame"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "ключи -fpic и -mapcs-reent несовместимы"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "граница размера структуры может быть только 8, 32 или 64"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "граница размера структуры может быть только 8 или 32"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "позиционно-независимый RTP несовместим с -msingle-pic-base"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= не имеет смысла без -fpic"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "использование '%s' как PIC-регистра невозможно"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition не поддерживается на этой архитектуре"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "выбранные fp16 опции несовместимы"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt требует AAPCS совместимого ABI для правильной работы"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "для работы с iwmmxt ABI требуется процессор с поддержкой iwmmxt"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "целевой процессор не поддерживает interworking"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS не поддерживает -mcaller-super-interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS не поддерживает -mcaller-super-interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 и нет ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "целевой процессор не поддерживает ARMv8-M Security Extensions"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard: в выбранном процессоре нет FPU"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mflat-abi=hard и VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS производный PCS вариант"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "вариантные функции должны использовать базовый AAPCS вариант"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS вариант"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 аппаратный плавающий VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "атрибут %qE не доступен для функций с аргументами переданными на стеке"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "атрибут %qE не доступен для функций с переменным числом аргументов"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "атрибут %qE не доступен для функций, которые возвращают значение на стеке"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored without -mcmse option."
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "атрибут %qE игнорируется без -mcmse опции."
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "атрибут %qE не действует на функции со статической компоновкой"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qE применим только к базовому типу указателя на функцию"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, fuzzy, gcc-internal-format
 #| msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "доступ к локальной памяти потока в настоящее время не поддерживается с -mpure-code или -mslow-flash-data"
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd вне диапазона %wd - %wd"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd вне диапазона %wd - %wd"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "невозможно вычислить фактическое положение параметра в стеке"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Неожиданный thumb1 далекий переход"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нет свободных low-регистров для выталкивания high-регистров"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific для Thumb-1"
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -35138,22 +35201,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "auto fpu выбор в настоящее время здесь не допускается"
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -35237,17 +35300,17 @@ msgstr "-fpie не поддерживается"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE не поддерживается"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs функция не может иметь аргументы"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs функция не может возвращать значение"
@@ -35522,7 +35585,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "вызов требует ifunc, которая не поддерживается этой целью"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "некорректный аргумент встроенной функции"
@@ -35870,59 +35933,59 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "Передавать аргументы на регистрах"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "wrong type of argument %s"
 msgstr "неверный аргумент типа для %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "nested function trampolines not supported on this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "трамплины вложенных функций не поддерживается для этой платформы"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "TLS is not implemented for GCN."
 msgstr "DW_LOC_OP %s не реализован"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "Builtin not implemented"
 msgstr "DW_LOC_OP %s не реализован"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "using vector_length (%d), ignoring %d"
 msgid "using vector_length (64), ignoring %d"
 msgstr "использование vector_length (%d), игнорирование %d"
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, fuzzy, gcc-internal-format
 #| msgid "using vector_length (%d), ignoring runtime setting"
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr "использование vector_length (%d), игнорирование установок времени выполнения"
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "использование num_workers (%d), игнорирование %d"
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "номер операнда вне диапазона"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -36072,134 +36135,134 @@ msgstr "Параметр для внутренней функции должен
 msgid "parameter to builtin not valid: %s"
 msgstr "Параметр для внутренней функции некорректен: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't be called directly"
 msgid "interrupt service routine cannot be called directly"
 msgstr "программа обслуживания прерываний не может вызываться напрямую"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "последний аргумент должен быть 2-битным непосредственным"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "пятый аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "третий аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "последний аргумент должен быть 3-битным непосредственным"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "следующий за последним аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "третий аргумент должен быть константой сравнения"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "некорректный режим сравнения"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "некорректный операнд округления"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "непосредственный аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "непосредственный аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "непосредственный аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE требует неизвестную isa опцию"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE требует isa опцию %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "последний аргумент должен быть непосредственным"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "последний аргумент должен быть масштабом 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "четвертый аргумент должен быть масштабом 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "некорректный операнд подсказки"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -36609,150 +36672,150 @@ msgstr "Только отладочный формат DWARF поддержив
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s инструкции не допускаются в функции с no_caller_saved_registers атрибутом"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE используется для неклассового метода"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргументом атрибута %qE должна быть строковая константа"
 
 #
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "программа обслуживания прерываний должна иметь указатель первым аргументом"
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "программа обслуживания прерываний должна иметь беззнаковый %sint вторым аргументом"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "программа обслуживания прерываний может иметь только указательный аргумент и необязательный целочисленный аргумент"
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
@@ -37228,7 +37291,7 @@ msgstr "%qE не может иметь оба атрибута: %qs и %qs"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "повторная декларация %qE с конфликтующими атрибутами %qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE атрибут требует строковый аргумент"
@@ -38368,59 +38431,59 @@ msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "__delay_cycles ограничено 32-битными счетчиками циклов"
 
 #
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown cpu %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "неизвестный процессор %qs для -mtune"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv требует -march, чтобы понять %<M%> расширение"
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "запрошенный ABI требует -march, чтобы понять %qc расширение"
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI требует -march=rv%d"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -38545,347 +38608,348 @@ msgstr "число должно быть 0 или 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "мусор в конце #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl устарело для little endian; используйте присваивание для невыровненных загрузок и сохранений"
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr устарело для little endian; используйте присваивание для невыровненных загрузок и сохранений"
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s для этой конфигурации не поддерживается"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, возвращенный по ссылке: нестандартное расширение ABI без гарантий совместимости"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI для передачи агрегатов с %d-байтным выравниванием изменен в GCC 5"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "ABI для передачи однородных плавающих агрегатов изменен в GCC 5"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, переданный по ссылке: нестандартное расширение ABI без гарантий совместимости"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs для этой платформы не поддерживается"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 должен быть 8-битным значением поля"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%Kаргумент %d должен быть непосредственной константой"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return не поддерживается для этой платформы"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "Аргумент ACOS в %L должен быть между -1 и 1"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_set_thread_pointer не поддерживается для этой платформы"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return не поддерживается для этой платформы"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "Аргумент ACOS в %L должен быть между -1 и 1"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 1 должен быть 6-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "аргумент 2 должен быть 7-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент %d должен быть беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент %d есть беззнаковый литерал вне диапазона"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 должен быть 4-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 должен быть 2-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент 1 должен быть 0 или 2"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 1 должен быть 1-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 должен быть 6-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "аргумент 2 должен быть 0 или 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "аргумент 3 должен быть в диапазоне 0..15"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешенная перегрузка Altivec builtin %qF"
 
 #
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to vec_vextract4b must be 0..12"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "второй аргумент vec_vextract4b должен быть 0..12"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to vec_vinsert4b must be 0..12"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "третий аргумент vec_vextract4b должен быть 0..12"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s is only valid for the cell processor"
 msgid "%qs is only valid for the cell processor"
 msgstr "Встроенная функция %s допустима только для процессора cell"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "%qs requires the %qs option"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires branch-likely instructions"
 msgid "%qs requires the %qs and %qs options"
 msgstr "%qs поддерживается только для процессоров, имеющих команды branch likely"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "Включить использование инструкций IEEE 128-битной плавающей точки."
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s is not supported with the current options"
 msgid "%qs is not supported with the current options"
 msgstr "Встроенная функция %s не поддерживается с текущими опциями"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -38906,224 +38970,229 @@ msgstr ""
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Кадр стека больше 2G не поддерживается для -fsplit-stack"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec не поддерживается на этой целевой платформе"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "target attribute или pragma изменяет размер long double"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "-mfloat128-hardware требует полной ISA 3.0 поддержки"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "использование IEEE extended precision long double"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "использование IBM extended precision long double"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target attribute или pragma изменяет AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target attribute или pragma изменяет darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "расположение агрегатов содержащих векторы с %d-байтным выравниванием изменилось в GCC 5"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "мультиверсионность требует ifunc, что не поддерживается на этой платформе"
 
 #
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "мультиверсионность виртуальной функции не поддерживается"
@@ -39464,145 +39533,145 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "суммарный размер локальных переменных превышает архитектурный предел"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "размер кадра %qs равен %wd байт"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs использует динамическое размещение стека"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "%<__RTL%> функция не может компилироваться с %<-flto%>"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битный ABI в режиме ESA/390 не поддерживается"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "аппаратная поддержка векторов отсутствует на %s"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
 #| msgid "hardware vector support not available with -msoft-float"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "аппаратная поддержка векторов недоступна с -msoft-float"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют в режиме ESA/390"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "ключ -mhard-dfp не может быть использован вместе с -msoft-float"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "сочетание ключей -mbackchain -mpacked-stack -mhard-float не поддерживается"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "размер стека должен быть больше чем охраняющее значение стека"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "размер стека должен быть больше чем 64k"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "ключ -mstack-guard влечет использование ключа -mstack-size"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "атрибут %qE поддерживается только для SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргументы для %qs должны быть неотрицательными целыми числами"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "значение %qs не поддерживается атрибутом %<target%>"
@@ -40043,8 +40112,8 @@ msgstr "атрибут %qs применим только к массивным 
 msgid "could not read the BRIG file"
 msgstr "не удалось прочитать BRIG файл"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "использование пустого (void) значения"
@@ -40329,7 +40398,7 @@ msgstr "декларация %q+D перекрывает предшествую
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларация %qD перекрывает параметр"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларация %qD перекрывает глобальную декларацию"
@@ -40399,7 +40468,7 @@ msgstr "%qE не описан (первое использование в это
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "сообщение о каждом неописанном идентификаторе выдается один раз в каждой функции, где он встречается"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ссылка на метку %qE вне функции"
@@ -40429,7 +40498,7 @@ msgstr "переход в выражение-оператор"
 msgid "duplicate label declaration %qE"
 msgstr "повторная декларация метки %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "дублирование метки %qD"
@@ -40643,7 +40712,7 @@ msgstr "некорректная попытка разместить в реги
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неинициализированная константа %qD не допускается в C++"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D в declare target директиве не имеет отображаемого типа"
@@ -40984,7 +41053,7 @@ msgstr "имя типа объявлено как функция, возвращ
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
@@ -41291,7 +41360,7 @@ msgstr "вложенное переопределение %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "определение типа в выражении %qs некорректно в C++"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
@@ -41341,7 +41410,7 @@ msgstr "структура не содержит именованных элем
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "регулируемый элемент-массив в объединении"
@@ -41377,7 +41446,7 @@ msgstr "вложенное переопределение %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "повторная декларация %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -41408,7 +41477,7 @@ msgstr "переполнение значений перечислимого т
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -41439,7 +41508,7 @@ msgstr "прототип для %qD не был предварительно о
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD использована без прототипа, до её определению"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %qD"
@@ -41554,12 +41623,12 @@ msgstr "аргумент %qD не соответствует встроенно
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметру %qD присвоено значение, но он не использован"
@@ -41567,259 +41636,259 @@ msgstr "параметру %qD присвоено значение, но он н
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "декларации в заголовке %<for%>-цикла допускаются только в C99 или C11 режиме"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "используйте опцию -std=c99, -std=gnu99,-std=c11 или -std=gnu11 для компиляции вашей программы"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 не поддерживает конструкцию %<for%> в декларациях циклов"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларация статической переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<struct %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<union %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<enum %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %qD, не являющегося переменной, в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "несовместимые квалификаторы адресного пространства %qs и %qs"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "повторный %qE  спецификатор декларации"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не поддерживает типы с насыщением"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "дублирование %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не поддерживает типы %<__int%d%>"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 не поддерживает булевы типы"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C не поддерживает тип %<_Float%d%s%>"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C не поддерживает десятичный тип с плавающей точкой"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "типы с фиксированной точкой не поддерживаются для этой целевой платформы"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не поддерживает типы с фиксированной точкой"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "в C++ результатом поиска %qD будет поле, а не тип"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE не является встроенным типом или typedef-типом"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE - не в начале декларации"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE использован с %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE использован с %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE использован с %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 не поддерживает %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 не поддерживает %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> перед %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "повторение %<_Thread_local%> или %<__thread%>"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "в декларации задано более одного класса хранения"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs использован с %qE"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> использован без %<_Fract%> или %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%> объединитель ссылается на переменную %qD, которая не %<omp_out%> и не %<omp_in%>"
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%> инициализатор ссылается на переменную %qD, которая не %<omp_priv%> и не %<omp_orig%>"
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "сдвиг влево отрицательного значения"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "величина сдвига влево больше или равна ширине данного типа"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "величина сдвига вправо больше или равна ширине данного типа"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "счетчик сдвига влево >= ширине элемента вектора"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "счетчик сдвига вправо >= ширине элемента вектора"
@@ -41840,7 +41909,7 @@ msgstr "противоречивый маркер управления верс
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -41887,7 +41956,7 @@ msgid "unknown type name %qE"
 msgstr "неизвестное имя типа %qE"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
@@ -41908,7 +41977,7 @@ msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидалось %<;%>, идентификатор или %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префиксные атрибуты для методов игнорируются"
@@ -41923,8 +41992,8 @@ msgstr "префиксные атрибуты для реализаций игн
 msgid "unexpected attribute"
 msgstr "неожиданный атрибут"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
@@ -41962,7 +42031,7 @@ msgstr "%<__auto_type%> требует инициализированной де
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> может использоваться только с одним декларатором"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "ожидалось %<,%> или %<;%>"
@@ -41990,7 +42059,7 @@ msgstr "ISO C99 не поддерживает %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 не поддерживает %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "ожидался строковый литерал"
@@ -42021,7 +42090,7 @@ msgstr "выражение в статическом утверждении не
 msgid "static assertion failed: %E"
 msgstr "не выполнено статическое утверждение: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "нарушено статическое утверждение"
@@ -42067,14 +42136,14 @@ msgstr "пустое перечисление некорректно"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "запятая в конце списка значений перечислимого типа"
@@ -42161,7 +42230,7 @@ msgstr "ожидались спецификаторы декларации ил
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "parameter packs должны быть в конце списка параметров"
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "the %qE attribute requires arguments"
 msgid "%qE attribute does not take any arguments"
@@ -42173,7 +42242,7 @@ msgstr "%qE атрибуту требуются аргументы"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 не поддерживает конструкцию %<[*]%> в декларациях массивов"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "атрибут %<deprecated%> может появляться не более одного раза в списке атрибутов"
@@ -42235,7 +42304,7 @@ msgstr "ISO C90 запрещает смешение деклараций и ко
 msgid "expected %<}%> before %<else%>"
 msgstr "ожидалось %<}%> перед %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> без предшествующего %<if%>"
@@ -42250,7 +42319,7 @@ msgstr "метка в конце составного оператора"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "ожидался оператор"
@@ -42275,17 +42344,17 @@ msgstr "метка может быть частью оператора, а де
 msgid "expected identifier or %<*%>"
 msgstr "ожидался идентификатор или %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<if%>"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<else%>"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "используйте фигурные скобки во избежание неоднозначной трактовки %<else%>"
@@ -42305,12 +42374,12 @@ msgstr "несколько переменных-итераторов в быст
 msgid "invalid iterating variable in fast enumeration"
 msgstr "некорректная переменная-итератор в быстром перечислении"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "отсутствует условие цикла в цикле с %<GCC ivdep%> pragma"
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42326,8 +42395,8 @@ msgstr "отсутствует составной объект в быстром
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "повторный cv-qualifier"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -42356,12 +42425,12 @@ msgstr "ISO C не поддерживает выражения ?: с пусты
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -42755,62 +42824,62 @@ msgstr "ожидалась декларация метода objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "в этом месте не может указываться ни тип, ни класс хранения,"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<setter%>)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "атрибут %<setter%> может быть задан только один раз"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "имя setter должно заканчиваться %<:%>"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "атрибут %<getter%> может быть задан только один раз"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> должна быть в контексте файла"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
@@ -42821,18 +42890,18 @@ msgstr "%<#pragma omp section%> может использоваться толь
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for, while или do оператор ожидался"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много конструкций %qs"
@@ -42852,53 +42921,53 @@ msgstr "ожидалась %<)%> или %<,%>"
 msgid "%qD is not a variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD не указательная переменная"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ожидалось %<data%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "слишком много %<if%> клаузул"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "слишком много %<if%> клаузул без модификатора"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "если какая-либо %<if%> клаузула имеет модификатор, то все %<if%> должны использовать модификатор"
@@ -42920,12 +42989,12 @@ msgstr "значение %<num_threads%> должно быть положите
 msgid "%<num_tasks%> value must be positive"
 msgstr "значение %<num_tasks%> должно быть положительным"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значение %<grainsize%> должно быть положительным"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значение %<priority%> должен быть неотрицательным"
@@ -42936,25 +43005,25 @@ msgstr "значение %<priority%> должен быть неотрицате
 msgid "expected constant integer expression"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%> before %<decltype%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "ожидалось %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%> перед %<decltype%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with unspecified category"
@@ -42970,54 +43039,54 @@ msgstr "%qs выражение должно быть целочисленным"
 msgid "%qs value must be positive"
 msgstr "значение %qs должно быть положительным"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "слишком много %<static%> аргументов"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "неожиданный аргумент"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%> аргумент требует положительной целочисленной константы"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%>"
 msgid "expected %<concurrent%>"
 msgstr "ожидалось %<new%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "заданы оба модификатора %<monotonic%> и %<nonmonotonic%>"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<runtime%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<auto%> не имеет параметра %<chunk_size%>"
@@ -43027,7 +43096,7 @@ msgstr "расписание %<auto%> не имеет параметра %<chunk
 msgid "chunk size value must be positive"
 msgstr "значение размера чанка должно быть положительным"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный тип планирования"
@@ -43062,23 +43131,23 @@ msgstr "%<safelen%> клаузула выражения должна быть п
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%> клаузула выражения должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "некорректный depend вид"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "некорректный map вид"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "некорректный dist_schedule вид"
@@ -43094,81 +43163,81 @@ msgstr "некорректный proc_bind вид"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ожидалась %<#pragma acc%> клаузула"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным для %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs должна быть первой клаузулой %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "нет допустимых клаузул заданных в %<#pragma acc declare%>"
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "секция массива в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "некорректная OpenACC клаузула в контексте файла"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<extern%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<global%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "переменная %qD использована более одного раза с %<#pragma acc declare%>"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ожидалось %<data%> после %<#pragma acc %s%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> не содержит клаузулу перемещения данных"
@@ -43183,7 +43252,7 @@ msgstr "%qE не был декларирован"
 msgid "expected function name"
 msgstr "ожидалось имя функции"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD не ссылается на функцию"
@@ -43193,73 +43262,73 @@ msgstr "%qD не ссылается на функцию"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение функции"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение одиночной функции"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> должна быть применена до использования"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> должна быть применена до определения"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> должна содержать по крайней мере одну %<device%>, %<host%> или %<self%>клаузулу"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> использует два различных выражения для памяти"
@@ -43269,63 +43338,63 @@ msgstr "%<#pragma omp atomic capture%> использует два различ
 msgid "expected %<(%> or end of line"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "ожидалась клаузула %<depend%>, %<destroy%> или %<update%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, fuzzy, gcc-internal-format
 #| msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<nonmonotonic%> модификатор планирования задан вместе с %<ordered%> предложением"
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%> before %<decltype%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "ожидалось %<while%> перед %<decltype%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%> параметр клаузулы меньше чем %<collapse%>"
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%> клаузула не может задаваться вместе с %<ordered%> клаузулой с параметром"
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация итерации или инициализация"
@@ -43335,73 +43404,73 @@ msgstr "ожидалась декларация итерации или иниц
 msgid "not enough perfectly nested loops"
 msgstr "недостаточно аккуратно вложенные циклы"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "сливаемые циклы не являются идеально вложенными"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> с %<depend%> клаузулой может использоваться только в составных операторах"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ожидался %<for%> после %qs"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ожидалось %<point%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> с map-type отличном от %<to%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> с map-type отличном от %<from%>, %<release%> или %<delete%> на %<map%> клаузуле"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
@@ -43418,66 +43487,66 @@ msgstr "за %<#pragma omp declare simd%> должна следовать дек
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "за %<#pragma omp declare simd%> должна следовать декларация или определение функции"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "ожидался selection-statement"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> не принимает аргументы"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "%qs в %L должен быть неотрицательным"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "ожидался строковый литерал"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, fuzzy, gcc-internal-format
 #| msgid "property %qs already specified in %<@synthesize%>"
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "свойство %qs уже специфицировано в %<@synthesize%>"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -43489,13 +43558,13 @@ msgstr "ожидалось %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "%qs в %L не есть функция"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43506,33 +43575,33 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно декларация функции или определение"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно одиночная декларация функции или определение"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD задан и в declare target %<link%> и в %<to%> клаузулах"
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ожидалось %<target%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ожидалось %<declare%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
@@ -43587,46 +43656,46 @@ msgstr "ожидалось имя функции %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "одним из аргументов вызова инициализатора должен быть %<&omp_priv%>"
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "ожидалось %<simd%> или %<reduction%> или %<target%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
 #
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "модель кода %<large%> пока не поддерживается"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<pragma omp requires%> requires at least one clause"
@@ -43644,27 +43713,27 @@ msgstr "%<_Atomic%> %qE в %<reduction%> клаузуле"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE объявлена %<threadprivate%> после первого использования"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE имеет неполный тип"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без включения транзакционной памяти"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
@@ -43675,7 +43744,7 @@ msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> вызов функции не внутри внешней транзакции или %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не внутри %<__transaction_atomic%>"
@@ -43690,7 +43759,7 @@ msgstr "нет закрывающей скобки"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD имеет неполный тип %qT"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неправильное использование void-выражения"
@@ -43815,7 +43884,7 @@ msgstr "доступ по указателю %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексируемый объект не является ни массивом, ни указателем, ни вектором"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс массива не является целым значением"
@@ -43840,7 +43909,7 @@ msgstr "в ISO C индексирование не-lvalue массива зап
 msgid "enum constant defined here"
 msgstr "константа перечислимого типа определена здесь"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> от массивного параметра функции %qE вернет размер от %qT"
@@ -43955,17 +44024,17 @@ msgstr "неявная конверсия из %qT в %qT при передач
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "сравнение со строковым литералом приводит к неопределенному поведению"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "сравнение указателя и нулевой символьной константы"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "вы хотели перейти по указателю?"
@@ -43990,7 +44059,7 @@ msgstr "указатель на функцию в операции вычита
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "арифметическая операция над указателем на пустой агрегат"
@@ -44240,7 +44309,7 @@ msgstr "приведение указателя к целому другого 
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведение к типу указателя от целого другого размера"
@@ -44409,7 +44478,7 @@ msgstr "левой части присваивания, вероятно, мож
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
@@ -44572,7 +44641,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "инициализация массива несоответствующего типа строковой константой"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "некорректное использование массива, не являющегося левой частью присваивания"
@@ -44603,7 +44672,7 @@ msgstr "инициализирующий элемент не может быть
 msgid "invalid initializer"
 msgstr "неверный инициализатор"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
@@ -44749,7 +44818,7 @@ msgstr "избыточные элементы в инициализаторе с
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
@@ -44789,7 +44858,7 @@ msgstr "в ISO C %<long%>-выражение в операторе switch не 
 msgid "case label is not an integer constant expression"
 msgstr "case-метка не является целочисленным константным выражением"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-метка вне оператора switch"
@@ -44799,17 +44868,17 @@ msgstr "case-метка вне оператора switch"
 msgid "%<default%> label not within a switch statement"
 msgstr "метка %<default%> вне оператора switch"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "оператор continue вне цикла"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "оператор break использован с OpenMP для цикла"
@@ -44824,7 +44893,7 @@ msgstr "оператор break внутри тела %<#pragma simd%> цикла
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "оператор continue внутри тела %<#pragma simd%> цикла"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "оператор без побочного эффекта"
@@ -44834,22 +44903,22 @@ msgstr "оператор без побочного эффекта"
 msgid "expression statement has incomplete type"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "сравнение векторов с разными типами элементов"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "сравнение векторов с разным числом элементов"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "невозможно найти целый тип того же размера, что и %qT"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -44901,7 +44970,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "упорядоченное сравнение указателя с нулевым указателем"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
@@ -44931,53 +45000,53 @@ msgstr "объединение употреблено в контексте, г
 msgid "used vector type where scalar is required"
 msgstr "векторный тип использован в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "ожидался %<parallel%> или %<target%> модификатор %<if%> клаузулы"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE в %qs клаузуле"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE является элементом объединения"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qE in %qs clause"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD не есть переменная в %qs клаузуле"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE не есть переменная в %qs клаузуле"
@@ -44987,8 +45056,8 @@ msgstr "%qE не есть переменная в %qs клаузуле"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD в %qs клаузуле"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD есть threadprivate переменная в %qs клаузуле"
@@ -45171,12 +45240,12 @@ msgstr "определенная пользователем редукция н
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE должно быть %<threadprivate%> для %<copyin%>"
@@ -45201,8 +45270,8 @@ msgstr "%<_Atomic%> %qD в предложении %<linear%>"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "шаг предложения %<linear%> %qE не является ни константой, ни параметром"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE не является переменной в предложении %qs"
@@ -45217,19 +45286,19 @@ msgstr "%qD многократно встречается в предложен
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE многократно встречается в предложениях данных"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD многократно встречается в предложениях данных"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD встречается в предложениях данных и сопоставления"
@@ -45302,120 +45371,120 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr "секция массива не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD многократно встречается в предложениях движения"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD многократно встречается в предложениях сопоставления"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE не является ни переменной, ни именем функции в предложении %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE многократно встречается в одной директиве %<declare target%><)%>"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "источник не есть указатель"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs переменная не является ни указателем, ни массивом"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "предложение %<inbranch%> несовместимо с %<notinbranch%>"
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE является предопределённым %qs для %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "значение предложения %<simdlen%> больше значения %<safelen%> предложения"
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%> модификатор планирования задан вместе с %<ordered%> предложением"
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "шаг %<linear%> предложения является параметром %qD, который не указан в %<uniform%> предложении"
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "нельзя использовать %<va_arg%> с обратным порядком хранения"
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "второй аргумент %<va_arg%> имеет неполный тип %qT"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "в C++ требуется расширенный тип, а не перечислимый тип в %<va_arg%>"
@@ -45617,30 +45686,30 @@ msgid "expected case label"
 msgstr "ожидалась метка"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "  передача %qT как аргумент %<this%> отбрасывает квалификаторы"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -45648,765 +45717,765 @@ msgstr[0] "  кандидат ожидает %d аргумент, %d предо
 msgstr[1] "  кандидат ожидает %d аргумента, %d предоставлено"
 msgstr[2] "  кандидат ожидает %d аргументов, %d предоставлено"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr ""
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr ""
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr ""
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr ""
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  возвращаемый тип %qT функции явного преобразования не может быть преобразован в %qT посредством квалификационного преобразования"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  преобразование из возвращаемого типа %qT спецификации шаблона функции преобразования в %qT не есть точное соответствие"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  подстановка выведенных аргументов шаблона приводит к ошибкам обнаруженных ранее"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  вывод/подстановка аргумента шаблона неудачна:"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  конструктор, принимающий единственный аргумент собственного класса некорректен"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "вызов перегруженной функции %<%D(%A)%> неоднозначен"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "не найден метод для преобразования в %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "вызов %<(%T) (%A)%> неоднозначен"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "тернарный %<operator?:%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> в %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> в %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs в %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> в %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> в %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> в %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ запрещает опускать средний операнд выражения ?:"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, fuzzy, gcc-internal-format
 #| msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "выведенный скалярный тип %qT не есть целый или плавающий тип того же размера, что и %qT"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "несовместимые векторные типы в условном выражении: %qT, %qT и %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "второй операнд условного оператора имеет тип %<void%>, но третий операнд не является ни throw-expression, ни элементом типа %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "третий операнд условного оператора имеет тип %<void%>, но второй операнд не является ни throw-expression, ни элементом типа %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "операнды для ?: имеют разные типы %qT и %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs, пробуем применить префиксный оператор"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "возвращаемое значение функции %qD - не %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "сравнение между %q#T и %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, fuzzy, gcc-internal-format
 #| msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "очистка исключений для этого размещения new выбирает неразмещенный оператор delete"
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD есть обычная (неразмещенная) функция освобождения в C++14 (или с -fsized-deallocation)"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD есть обычная (неразмещенная) функция освобождения"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "нет соответствующей функции освобождения для %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нет подходящего %<operator %s%> для %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D private в данном контексте"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "декларировано private здесь"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D protected в данном контексте"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "декларировано protected здесь"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D недоступно в данном контексте"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "передача NULL в неуказательный аргумент %P в %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid " declared here"
 msgid "  declared here"
 msgstr " объявлено здесь"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "преобразование в неуказательный тип %qT из NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "преобразование %<false%> в указательный тип для аргумента %P в %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "преобразование %<false%> в указательный тип %qT"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  при инициализации %P -го аргумента %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "слишком много фигурных скобок вокруг инициализатора для %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "преобразование в %qT из списка инициализации будет использовать явный конструктор %qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "в C++11 и выше подразумеваемый конструктор может быть явным"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "недопустимое связывание битового поля %qE с %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "недопустимое связывание упакованного  поля %qE с %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "scoped enum %qT передан дальше ... как %qT перед fabi-version=6, %qT после"
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "передача объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "невозможно принять ссылочный тип %q#T через %<...%>"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "прием объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "рекурсивное вычисление подразумеваемого аргумента для %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "вызов %qD использует подразумеваемый аргумент для параметра %P, который еще не определен"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент вызова функции мог быть кандидатом для атрибута формата"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "использование мультиверсионной функции без подразумеваемой"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как аргумент %<this%> отбрасывает квалификаторы"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в вызове %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "передача аргументов в многоточие унаследованного конструктора %qD"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "конструктор делегирует к себе"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "для приведения типов в функциональном стиле удалите избыточные %<::%D%>"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%s(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "вызов перегруженной %<%s(%A)%> имеет неоднозначную трактовку"
 
 #
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "чисто виртуальная %q#D вызвана из инициализатора нестатического элемента данных"
 
 #
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "чисто виртуальная %q#D вызвана из конструктора"
 
 #
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "чисто виртуальная %q#D вызвана из деструктора"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "некорректный вызов элемента-функции %qD без объекта"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "при передаче %qT предпочтение отдается %qT, а не %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "предпочтение отдается %qD (а не %qD)"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  поскольку это дает лучшую последовательность преобразований аргумента"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "несоответствие подразумеваемого аргумента при разрешении перегрузки"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "временная граница %qD сохраняется, пока существует конструктор"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -46436,532 +46505,532 @@ msgstr "невозможно преобразовать из базового к
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "невозможно преобразовать из базового класса %qT в производный класс %qT, так как база является виртуальной"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr ""
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "предыдущая декларация %q#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "противоречивые спецификации доступа для метода %q+D, игнорируются"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "противоречивые спецификации доступа для поля %qE, игнорируются"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD наследует %E ABI тэг, который имеет %qT (использованный в его типе возврата)"
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT декларировано здесь"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD наследует %E ABI тэг, который имеет %qT (использованный в его типе)"
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT не имеет %E ABI тэг, который имеет базовый %qT"
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT не имеет %E ABI тэг, который имеет %qT (использованный в типе %qD)"
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "ошибка вывода из %<final%> base %qT в производном типе %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "все элементы-функции в классе %qT - частные (private)"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "в %q#T определен только private деструктор и нет друзей"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "в %q#T определен только private конструктор и нет друзей"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "отсутствует уникальное переопределение %qD в %qT"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q#D может быть помечен override"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D помечен %<override%>, но не делается override"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D помечен %<final%>, но не является virtual"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD было скрыто"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "многоточие в %qD не наследуется"
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "битовое поле %q+#D с нецелым типом"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битового поля %q+D не является целой константой"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "отрицательная ширина битового поля %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулевая ширина битового поля %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "ширина %qD превышает его тип"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD слишком мало для хранения всех значений %q#T"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "элемент %q+#D с конструктором не допускается в объединении"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "элемент %q+#D с деструктором не допускается в объединении"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "элемент %q+#D с операцией присваивания путем копирования не допускается в объединении"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "в C++98 %q+D может не быть статическим, поскольку это элемент объединения"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатический элемент данных %q+D в объединении может не иметь ссылочный тип %qT"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "поле %q+D ошибочно декларировано с типом функции"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "атрибут packed проигнорирован из-за неупакованного не-POD поля %q#D"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "элемент %q+D не может быть декларирован как %<mutable%> ссылка"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "элемент %q+D не может быть декларирован и как %<const%>, и как %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "инициализация нескольких полей в объединении %qT"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "поле %q#D с тем же именем, что и класс"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q+#T содержит элементы данных типа указатель"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  но не переопределяет %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  но не переопределяет %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "выравнивание %qD увеличено в -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD will increase in -fabi-version=9"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "выравнивание %qD увеличится в -fabi-version=9"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "инициализатор задан для невиртуального метода %q+D"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "метод перебивает оба метода %<transaction_pure%> и %qE"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "описанный метод %qE перебивает метод %qE"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T не является литералом, поскольку:"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  базовый класс %qT %q+T не литерал"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "базовый класс %q#T имеет доступный невиртуальный деструктор"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатическая ссылка %q#D в классе без конструктора"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "нестатический константный элемент %q#D в классе без конструктора"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредственная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуальная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "смещение %qD несовместимо с ABI и может измениться в будущих версиях GCC"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "размер типа %qT слишком велик (%qE байт)"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "некорректное использование %q#T с массивом нулевого размера в %q#D"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "недопустимое использование %q#T с элементом регулируемого массива в %q#T"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "элемент массива %q#D объявлен здесь"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "элемент массива нулевого размера %qD не в конце %q#T"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "элемент массива нулевого размера %qD в другом пустом %q#T"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "в определении %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "элемент регулируемого массива %qD не в конце %q#T"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "элемент регулируемого массива %qD в другом пустом %q#T"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T содержит виртуальные функции и доступный невиртуальный деструктор"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "тип transparent %q#T не имеет полей"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "type transparent класс %qT имеет базовые классы"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "в типе прозрачного класса %qT есть виртуальные функции"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "type transparent %q#T не может быть сделан прозрачным, так как тип первого поля имеет ABI, отличный от класса в целом"
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "определение %qD не соответствует %<#include <initializer_list>%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "не удалось завершить структуру из-за предыдущих грамматических ошибок"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "некорректная строка %<\"%E\"%>, задающая язык"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ошибка при выборе перегруженной функции %qD при преобразовании к типу %qT"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нет способа для преобразования функции %qD к типу %q#T"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "преобразование перегруженной функции %qD к типу %q#T неоднозначно"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "предполагается указатель на элемент %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "недостаточная информация о типе"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -47042,7 +47111,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "%q+E не есть константное выражение"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "вызов внутренней функции %qE"
@@ -47104,7 +47173,7 @@ msgstr "Попытка разместить уже размещенную пер
 msgid "deallocation of storage that was not previously allocated"
 msgstr "декларация %qD перекрывает декларированную ранее локальную переменную"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
@@ -47161,395 +47230,394 @@ msgstr "переполнение выражения сдвига %q+E"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "вычисления включающие пустой указатель в %qE"
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "значение индекс массива %qE вне границ типа массива %qT"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "доступ к неинициализированному элементу массива"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "доступ по пустому указателю в %qE"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "mutable %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "доступ к неинициализированному элементу %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "обращение к элементу %qD вместо инициализированного элемента %qD в константном выражении"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "доступ по пустому указателю"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "обращение к значению %qE через %qT glvalue в константном выражении"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "объявлено здесь"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "использование значения конструируемого объекта в константном выражении"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD использована в своем собственном инициализаторе"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D не есть const"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D переменная"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD не была инициализирована константным выражением"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD не была декларирована %<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "оператор не является константным выражением"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значение %qE типа %qT не есть константное выражение"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "преобразование %qT пустого указателя в %qT не является константным выражением"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "ожидался template-id"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неожиданное выражение %qE вида %s"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from integer to pointer"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast из целого в указатель"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "использование %<this%> в константном выражении"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "приведение к нецелочисленному типу %qT в константном выражении"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не есть константное выражение"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантная инициализация массива"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не есть константное выражение"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "throw will always call terminate()"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "throw будет всегда вызывать terminate()"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "in C++11 destructors default to noexcept"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "в C++11 деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "в C++11 это throw терминируется, поскольку деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes in template argument %qE"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD не является типом"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE не имеет тип указателя или массива"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -47593,7 +47661,7 @@ msgstr "преобразование к неконстантной ссылки
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "преобразование %qT в %qT не снимает указатель"
@@ -47632,298 +47700,298 @@ msgstr "%q#T использовано там, где ожидалось плав
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "игнорирование возвращаемого значения от %qD, декларированной с атрибутом nodiscard"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "игнорирование возвращаемого значения от %qD, декларированной с атрибутом nodiscard"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "в вызове %qD, декларированной здесь"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "псевдо-деструктор не вызывается"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "преобразование к void не даст доступ к объекту неполного типа %qT"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT во втором операнде условного выражения"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в третьем операнде условного выражения"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в правом операнде оператора запятая"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в левом операнде оператора запятая"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в операторе"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в for инкрементном выражении"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "преобразование к void не даст доступ к объекту типа %qT"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT во втором операнде условного выражения"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в третьем операнде условного выражения"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в правом операнде оператора запятая"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в левом операнде оператора запятая"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в операторе"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в for инкрементном выражении"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "преобразование к void не даст доступ к объекту нетривиально копируемого типа %qT"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT во втором операнде условного выражения"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в третьем операнде условного выражения"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в правом операнде оператора запятая"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в левом операнде оператора запятая"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в операторе"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в for инкрементном выражении"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "преобразование к void не даст доступ к объекту %qE неполного типа %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "переменная %qE неполного типа %qT не будет доступна во втором операнде условного выражения"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "переменная %qE неполного типа %qT не будет доступна в третьем операнде условного выражения"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "переменная %qE неполного типа %qT не будет доступна в правом операнде оператора запятая"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "переменная %qE неполного типа %qT не будет доступна в левом операнде оператора запятая"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "переменная %qE неполного типа %qT не будет доступна в операторе"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "переменная %qE неполного типа %qT не будет доступна в for инкрементном выражении"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "преобразование к void не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "второй операнд условного выражения не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "третий операнд условного выражения не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "правый операнд оператора запятая не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "левый операнд оператора запятая не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "оператор не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "for инкрементное выражение не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "второй операнд условного выражения ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "третий операнд условного выражения ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "правый операнд оператора запятая ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "левый операнд оператора запятая ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "оператор ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "for инкрементное выражение ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "второй операнд условного выражения ссылка не имеет эффекта"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "третий операнд условного выражения ссылка не имеет эффекта"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "правый операнд оператора запятая не имеет эффекта"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "левый операнд оператора запятая не имеет эффекта"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "оператор не имеет эффекта"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for инкрементное выражение не имеет эффекта"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "преобразование NULL к неуказательному типу"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "default type conversion can't deduce template argument for %qD"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "преобразование подразумеваемого типа не может вывести аргумент шаблона для %qD"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "неоднозначное преобразование из типа %qT по умолчанию"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  возможные преобразования - %qD и %qD"
@@ -47991,7 +48059,7 @@ msgstr "из предыдущей декларации %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "редекларация %qD отличается в %<constexpr%> от предыдущей декларации"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "предыдущая декларация %qD"
@@ -48186,12 +48254,12 @@ msgstr "предыдущая декларация %qD была здесь"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "избыточная повторная декларация %qD в той же области видимости"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %q+D"
 msgid "deleted definition of %qD"
@@ -48205,44 +48273,44 @@ msgstr "удаленное определение %q+D"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "явная специализация %qD после первого использования"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: атрибут видимости проигнорирован, так как он конфликтует с предыдущей декларацией"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "переопределение %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD противоречит использованной функции"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D не декларировано в классе"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline с %<gnu_inline%> атрибутом"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline без %<gnu_inline%> атрибута"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48250,666 +48318,666 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "редекларация friend %q#D не может иметь подразумеваемые аргументы шаблона"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "локальная для потока декларация %q#D следует за не локальной для потока декларацией"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не локальная для потока декларация %q#D следует за локальной для потока декларацией"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "редекларация %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "избыточное переопределение %<constexpr%> элемента статических данных %qD"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "локальная метка %qE конфликтует с существующей меткой"
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr "предыдущая метка"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  отсюда"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  покидает OpenMP структурный блок"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  пересекает инициализацию %q#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  входит в контекст %q#D, имеющий нетривиальный деструктор"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  входит в try-блок"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  входит в catch-блок"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  входит в OpenMP структурный блок"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  входит в синхронизируемый или атомарный оператор"
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "  enters %<constexpr%> if statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "  входит в %<constexpr%> оператор if"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  пропускает инициализацию %q#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  входит в контекст %q#D, имеющий нетривиальный деструктор"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "некорректный выход из OpenMP структурного блока"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "использование %qD без параметров шаблона"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T не является классом"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "шаблон класса с именем %q#T' отсутствует в %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нет имени типа %q#T в %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "просмотр %qT в %qT неоднозначен"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именует %q#T, который не является шаблоном класса"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> именует %q#T, который не является типом"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "параметры шаблона не соответствуют шаблону %qD"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "-faligned-new=%d is not a power of two"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-faligned-new=%d не есть степень двойки"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с конструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с деструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с операцией присваивания-копирования недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q#T должен следовать за %qs ключевым словом"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "несколько типов в одной декларации"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторная декларация внутреннего типа C++ %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "отсутствует имя типа в typedef-декларации"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "в ISO C++ анонимные структуры запрещены"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> может задаваться только для функций"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> может задаваться только для функций"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> может быть задан только для конструкторов"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> может задаваться только для объектов и функций"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> в этой декларации отброшен"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут игнорируется в явной конкретизации %q#T"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "никакой атрибут не может применяться к явной конкретизации"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "игнорирование атрибутов примененных к классу %qT вне определения"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "игнорирование атрибутов примененных к зависимому типу %qT без ассоциированной декларации"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD инициализирован (используйте decltype взамен)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларация %q#D содержит %<extern%> и инициализирована"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D не есть статический элемент данных %q#T"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "non-member-template декларация %qD"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "не соответствует декларации элемента шаблона здесь"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не разрешает определять %<%T::%D%> как %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "повторная инициализация %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD декларирована %<thread_local%> я %<constexpr%> функции"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<static%> in %<constexpr%> function"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD декларирована %<static%> я %<constexpr%> функции"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "переменная %q#D инициализирована, хотя имеет неполный тип"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегатный тип %q#D неполон и не может быть определён"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "переменная %qD декларирована как ссылка, но не инициализирована"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "имя использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривиально определенные инициализаторы не поддерживаются"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99 обозначение %qE не является целочисленным константным выражением"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "массив %qD имеет нулевой размер"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "размер памяти %qD неизвестен"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "размер памяти %qD не константа"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики inline переменной %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики статических данных inline функции %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "это можно обойти, удалив инициализатор"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированная переменная %qD в %<constexpr%> функции"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T не имеет предоставленный пользователем подразумеваемый конструктор"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "конструктор не является предоставленным пользователем, поскольку он явно подразумевался в теле класса"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "и неявно определенный конструктор не инициализирует %q#D"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "некорректный тип %qT является инициализатором для вектора типа %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> использовано в определенном в GNU-стиле инициализаторе для класса %qT"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "некорректный инициализатор для %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 обозначение %qE вне инициализатора агрегата"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "элементы массива %q#T имеют неполный тип"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "составной литерал переменного размера"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D имеет неполный тип"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "в инициализаторе скалярного объекта %qD должен быть только один элемент"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "в C++98 %qD следует инициализировать при помощи конструктора, а не %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "массив %qD инициализируется строковой константой %qE, заключённой в скобки"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "инициализатор недопустим для статического элемента с конструктором"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для non-inline статического элемента %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(запрошена инициализация вне класса)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "ссылка %qD инициализируется собой"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "повторная декларация перечислимого типа %q+D"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "использован %<register%> спецификатор класса хранения"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "инициализатор для %<decltype(auto) %D%> имеет тип функции (вы забыли %<()%> ?)"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "перекрытие предыдущей декларации %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "атрибут %qE применим только к переменным в статической памяти"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он содержит анонимный элемент структуры"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он имеет анонимный элемент объединения"
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: и он и его базовый класс %qT имеют нестатические элементы данных"
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: его базовые классы %qT и %qT имеют нестатические элементы данных"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "невозможна декомпозиция массива переменной длины %qT"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -48917,7 +48985,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -48925,7 +48993,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -48933,177 +49001,177 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не является целочисленным константным выражением"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "невозможна декомпозиция типа объединения %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "невозможна декомпозиция non-array non-class типа %qT"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "невозможна декомпозиция типа lambda замыкания %qT"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT без нестатических элементов данных"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> требует динамической инициализации"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> имеет нетривиальный деструктор"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> допускает динамическую инициализацию и уничтожение"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qT"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива в %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "нулевой размер массива %qT"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирована как %<virtual%> переменная"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации переменной"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> параметр"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> параметр"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации параметра"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> тип"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> тип"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации типа"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> поле"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> поле"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации поля"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключений"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "concept %q#D декларирован с параметрами функциями"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "concept %q#D декларирован с выведенным типом возврата"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "concept %q#D с non-%<bool%> типом возврата %qT"
@@ -49380,7 +49448,7 @@ msgstr "переполнение в размерности массива"
 msgid "%qD declared as array of %qT"
 msgstr "%qD декларировано как массив %qT"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
@@ -49550,7 +49618,7 @@ msgstr "декларатор отсутствует; используется з
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
@@ -49761,839 +49829,839 @@ msgstr "атрибут проигнорирован"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-клаузула для типа возврата"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs функция использует %<auto%> спецификатор типа без завершающего типа возврата"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "выведенный тип возврата доступен только с -std=c++14 или -std=gnu++14"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуальная функция не может иметь выведенный тип возврата"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "руководство вывода для %qT должно иметь завершающий тип возврата"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "хвостовой тип возврата %qT руководства вывода не есть специализация %qT"
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs функция с завершающим типом возврата не декларирована с %<auto%> спецификатором типа"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функция с атрибутом noreturn возвращает не-void значение"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT как тип а не плоский %<decltype(auto)%>"
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "деструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "конструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструкторы не могут быть декларированы %<virtual%>"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "невозможно определить friend-функцию %qs в определении локального класса"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "функция преобразования не может иметь завершающий тип возврата"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> вне декларации класса"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> в friend декларации"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "только декларации конструкторов и операторов преобразования могут быть %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "ссылка %qs не может быть декларирована %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef декларирован %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-клаузула для typedef"
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-клаузула для идентификатора типа"
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-клаузула в декларации нефункционального типа %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "невозможно декларировать параметр с абстрактным типом %qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "нестатический элемент данных декларирован с заполнителем %qT"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ запрещает элемент регулируемый массив %qs"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ запрещает элементы регулируемые массивы"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация функции %qD в неверном контексте"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не может быть декларирована %<virtual%>, поскольку она всегда статическая"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для деструктора %qD"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для конструктора %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "конструктор не может быть %<concept%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "ошибка открытия %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "специализация переменного шаблона %qD декларирована как функция"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "переменный шаблон декларирован здесь"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qE declared %<concept%>"
 msgid "static data member %qE declared %qs"
 msgstr "статический элемент данных %qE декларирован %<concept%>"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "класс хранения %<thread_local%> недопустим для функции %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-спецификаторы в %qs не допускаются вне определения класса"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> спецификатор некорректен для функции %qs декларированной вне глобального контекста"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs определен не в контексте класса"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs декларирован не в контексте класса"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D не имеет инициализатора"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
 #
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "некорректное использование cv-квалифицированного типа %qT в декларации параметра"
 
 #
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "некорректное использование типа %<void%> в декларации параметра"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<_Atomic%>-квалифицированный параметр типа %qT для %q+D"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает указатель на массив с неизвестной границей %qT"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает ссылку на массив с неизвестной границей %qT"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "преобразование к void никогда не использует операцию преобразования типа"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к ссылке на тот же тип никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "преобразование к тому же типу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к ссылке на базовый класс никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к базовому классу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "использование синонима специализации шаблона %qT после %qs"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD ранее декларирован здесь"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT ранее декларирован здесь"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -50605,95 +50673,95 @@ msgstr "ссылка на %qT как на enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "возможно вы хотите явно добавить %<%T::%>"
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT определен с многими непосредственными базами"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT определен с непосредственной виртуальной базой"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "рассогласование основного типа в enum %q#T"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "отличающийся основной тип в enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -50702,72 +50770,72 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "значение перечислимого типа для %qD должно иметь целочисленный или unscoped перечислимый тип"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<long%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "нет операторов возврата в функции возвращающей %qT"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "только плоский %<auto%> тип возврата может быть приведен к %<void%>"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "использование %qD до приведения %<auto%>"
@@ -50807,7 +50875,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "удаление %qT не определено"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонная декларация %q#D"
@@ -50817,7 +50885,7 @@ msgstr "шаблонная декларация %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "предоставленные списки параметров шаблона не соответствуют параметрам шаблона %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD объявлен как шаблон элемента"
@@ -51154,166 +51222,166 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "использование удаленной функции %qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr ""
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "явные операции преобразования доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11 auto доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 #| msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "scoped enums доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "override controls (override/final) доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "инициализаторы нестатических элементов данных доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "определенные пользователем литералы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 #| msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11 атрибуты доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-квалификаторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "неполный тип %qT использован во вложенном спецификаторе имени"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "ссылка на %<%T::%D%> неоднозначна"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE; did you mean %qE?"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD не является элементом %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE; did you mean %qE?"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD не является элементом %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> не был декларирован"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> не был декларирован"
@@ -51500,344 +51568,344 @@ msgstr "инициализация значения ссылочного тип
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "инициализатор для элемента регулируемого массива %q#D"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD следует инициализировать в списке инициализации элементов"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD инициализируется самим собой"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "неинициализированный const элемент в %q#T"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D должен быть инициализирован"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "неинициализированный ссылочный элемент в %q#T"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD будет инициализирован после"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "базовый класс %qT будет инициализирован после"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  базового класса %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  если инициализирован здесь"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "повторные инициализации заданы для %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "повторные инициализации заданы для базового класса %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "инициализации для нескольких элементов %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "базовый класс %q#T должен быть явно инициализирован в копирующем конструкторе"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "в классе %qT нет поля с именем %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D есть статический элемент данных; он может быть инициализирован только при своем определении"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D не есть нестатический элемент данных %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "безымянный инициализатор для %qT, не имеющего базовых классов"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "безымянный инициализатор для %qT, имеющего множественное наследование"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD - непосредственный базовый тип, а также косвенный виртуальный базовый тип"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT не является непосредственной или виртуальной базой %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "неполный тип %qT не имеет элемента %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "некорректный указатель на битовое поле %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "некорректное использование нестатического элемента %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный const элемент в %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неинициализированный const элемент в базе %q#T от %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "размещение new создает объект типа %<%T [%wu]%> и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "размещение new создает массив объектов типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "размещение new создает объект типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "целочисленное переполнение в размере массива"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "размер массива в new-выражении должно быть константным"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "переменно модифицированный тип не допускается в new-выражении"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant array new length must be specified directly, not by typedef"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "неконстантная длина массива new должна быть задана непосредственно, не с помощью typedef"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "неконстантная длина new массива должна быть задана без скобок вокруг идентификатора типа"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "некорректный тип %<void%> задан для new"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "непроинициализированная константа в %<new%> от %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "не найдено подходящего %qD в классе %qT"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "запрос элемента %qD неоднозначен"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> типа %qT с расширенным выравниванием %d"
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "использует %qD, который не имеет параметра выравнивания"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "используйте %<-faligned-new%>, чтобы включить C++17 поддержку over-aligned new"
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "инициализатор со скобками в new массива"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new нельзя применять к ссылочному типу"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new нельзя применять к типу функции"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete [] не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "преждевременное завершение инициализатора"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "неизвестный размер массива в операторе delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "удаление объекта абстрактного типа класса %qT, имеющего невиртуальный деструктор, вызовет неопределенное поведение"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "удаление объекта полиморфного типа класса %qT, имеющего невиртуальный деструктор, может вызвать неопределенное поведение"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
@@ -52006,13 +52074,13 @@ msgstr "скорректированное имя для %qD изменяетс
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "скорректированное имя переменной руководства инициализации для %qD изменяется между -fabi-version=%d и -fabi-version=%d"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "нестатический константный элемент %q#D, использование операции присваивания по умолчанию недопустимо"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -52042,162 +52110,169 @@ msgstr "неверный аргумент типа для %s"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD должен иметь список параметров %<void%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+#| msgid "non-member function %qD cannot have ref-qualifier"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "non-member функция %qD не может иметь ref-квалификатор"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD уже friend для %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose union type %qT"
 msgid "cannot default compare union %qT"
 msgstr "невозможна декомпозиция типа объединения %qT"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgid "cannot default compare anonymous union member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он имеет анонимный элемент объединения"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "элемент объединения %q+D с нетривиальным %qD"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "инициализатор для %q#D некорректен"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "сведенный к подразумеваемому подразумеваемый конструктор не инициализирует %q#D"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "копирование нестатического элемента данных %q#D rvalue типа ссылки"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "сведенный к подразумеваемому подразумеваемый конструктор не инициализирует нестатические элементы данных"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "подразумеваемое move присваивание для %qT вызывает оператор нетривиального move присваивания для виртуальной базы %qT"
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "тип замыкания lambda имеет удаленный подразумеваемый конструктор"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "тип замыкания lambda имеет удаленный оператор присваивания с копированием"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D неявно декларирован как удаленный, поскольку %qT декларирует перемещающий конструктор или перемещающий оператор присваивания"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D наследует из нескольких базовых подобъектов"
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D неявно удален, поскольку подразумеваемое определение будет синтаксически некорректным:"
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F неявно удалено, так как его спецификация исключительных ситуаций не соответствует неявной спецификации исключительных ситуаций %qX"
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr ""
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "шаблон не может быть подразумеваемым"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD не может быть подразумеваемым"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
@@ -52239,138 +52314,138 @@ msgstr "некорректная декларация параметра %qD с
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларация %q#D перекрывает параметр"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларация %qD перекрывает элемент %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "повторная декларация перечислимого типа %q+D"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> обозначает деструктор"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> обозначает конструктор в %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "невозможно унаследовать конструкторы от косвенной базы %qT"
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qE"
 msgstr "%qE не был декларирован"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration of namespace %q+D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "противоречивая декларация %q#D"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларация %qD вне пространства имён, объемлющего %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "явные квалификаторы в декларации %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD следовало объявить внутри %qD"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD атрибут требует единственный NTBS аргумент"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD атрибут не имеет смысла, поскольку элементы анонимного пространства имен получают локальные символы"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "игнорирование %qD атрибута в анонимном пространстве имен"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "игнорирование %qD атрибута в non-inline пространстве имен"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибут %qD игнорируется"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "максимальное число %d пространств имен просмотрено для %qE"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -52378,82 +52453,82 @@ msgstr[0] "предлагаемый вариант:"
 msgstr[1] "предлагаемые варианты:"
 msgstr[2] "предлагаемые варианты:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "определение %qD не соответствует %<#include <initializer_list>%>"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fabi-version=1%> is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<-fabi-version=1%> больше не поддерживается"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%qs в %L неоднозначно"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "использование пространства имён %qD здесь недопустимо; предполагается %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX вход в pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -52481,7 +52556,7 @@ msgstr "идентификатор %qE является ключевым сло
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P не установлено в true"
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -52507,7 +52582,7 @@ msgstr "%<::%E%> не был декларирован"
 msgid "request for member %qE in non-class type %qT"
 msgstr "запрос элемента %qE в неклассовом типе %qT"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> не был декларирован"
@@ -52587,7 +52662,7 @@ msgstr "некорректный идентификатор шаблона"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ запрещает использование литералов с плавающей точкой в константном выражении"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "приведение к типу, отличному от целого или перечисления, не может появляться в константном выражении"
@@ -52714,7 +52789,7 @@ msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<concept%> доступно только с -fconcepts"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 #| msgid "%<requires%> only available with -fconcepts"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
@@ -52837,7 +52912,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "невозможно найти оператор строкового литерала %qD с аргументами %qT, %qT"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "ожидалась декларация"
@@ -52940,12 +53015,12 @@ msgstr "декларация %<~%T%> как элемента %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-имя %qD использовано как декларатор деструктора"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ожидался unqualified-id"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не является шаблоном"
@@ -52982,7 +53057,7 @@ msgstr "идентификатор переменного шаблона %qD в
 msgid "expected nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "типы нельзя определять в приведении типов"
@@ -52997,7 +53072,7 @@ msgstr "типы нельзя определять в %<typeid%> выражен
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неверное число аргументов для %<__builtin_addressof%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неверное число аргументов для %<__builtin_launder%>"
@@ -53012,7 +53087,7 @@ msgstr "в ISO C++ составные литеральные конструкц
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "два последовательных %<[%> только введут атрибут"
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "некорректное использование %qD"
@@ -53037,962 +53112,968 @@ msgstr "ISO C++ не допускает %<alignof%> с не-типом"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "типы не могут быть определены в %<noexcept%> выражениях"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
 msgstr "типы не могут быть определены в new-выражении"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+#| msgid "__builtin_thread_pointer is not supported on this target"
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "__builtin_thread_pointer не поддерживается для этой платформы"
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "типы не могут быть определены в new-выражении"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница массива не допускается после идентификатора типа в скобках"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "попробуйте убрать скобки вокруг идентификатора типа"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "инициализация new-выражения для типа %<auto%> требует ровно один элемент"
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "ожидался список выражений или идентификатор типа"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "типы не могут быть определены в new-type-id"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "оператор %<>>%> трактуется в C++11 как две правые угловые скобки"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "рекомендуется окружать скобками выражение %<>>%>"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ не допускает ?: с опущенным средним операндом"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, fuzzy, gcc-internal-format
 #| msgid "the lambda has no capture-default"
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "lambda не имеет подразумеваемого захвата"
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ожидался конец capture-list"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "явное by-copy capture %<this%> избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "уже захваченное %qD в lambda выражении"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture %qE by reference"
 msgid "%<this%> cannot be captured by reference"
 msgstr "невозможно захватить %qE по ссылке"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambda-захватывающие инициализаторы доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "пустой инициализатор для lambda init-capture"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D декларировано здесь"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture переменной  %qD с неавтоматическим сроком хранения"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "слишком много %<if%> клаузул"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "явное by-copy capture %qD избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "явное by-reference capture %qD избыточно с by-reference capture умолчанием"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "задан аргумент по умолчанию для lambda-параметра"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "повторное %<mutable%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "атрибуты в начале оператора игнорируются"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ожидался помеченный оператор"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-метка %qE вне оператора switch"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "требуется %<typename%> перед %qE, поскольку %qT зависимый контекст"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> обозначает конструктор, а не тип"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 #| msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидался selection-statement"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "функция возвращает массив"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "поле %qE описано как функция"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "типы нельзя определять в условиях"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "ожидался инициализатор"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> выражение типа %qT имеет неполный тип"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "противоречивые begin/end типы в range-based %<for%> операторе: %qT и %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидался iteration-statement"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "диапазонные %<for%> циклы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "диапазонные %<for%> циклы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> в %<constexpr%> функции"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор перехода"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "избыточная %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> не в начале блока"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "непеременная %qD в декларации с более чем одним декларатором с типом заполнителем"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "смешивание деклараций и определений функций запрещено"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "типы нельзя определять в декларации for-диапазона"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "инициализатор в диапазонном %<for%> цикле"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "несколько деклараций в диапазонном %<for%> цикле"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "некорректный инициализатор для структурированной связывающей декларации"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> использовано вне класса"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> меняет смысл в C++11; пожалуйста удалите его"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD некорректно в lambda"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier invalid in condition"
 msgid "type-specifier invalid in lambda"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "определение класса не должно содержать friend"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in an exception-specification"
 msgid "types may not be defined in explicit-specifier"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "некорректная linkage-specification"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "типы нельзя определять в %<decltype%> выражениях"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "типы не могут быть определены в conversion-type-id"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "использование %<auto%> в операторе преобразования элемента шаблона не может быть приведено"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "только конструкторы берут инициализаторы элементов"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "устаревший стиль инициализатора базового класса"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (инициализатор квалифицированного элемента неявно является типом)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "неожиданное ключевое слово; удалите пробел между кавычками и суффикс идентификатором"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ожидался суффикс-идентификатор"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "ожидалась пустая строка после ключевого слова %<operator%>"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "некорректный префикс кодировки в литеральном операторе"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "ожидался оператор"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некорректный constrained type параметр"
 
 #
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualified type параметр"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "некорректное использование %<auto%> в подразумеваемом аргументе шаблона"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "pack параметр шаблона %qD не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "pack параметры шаблона не могут иметь аргументы по умолчанию"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "ожидался template-id"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "список аргументов шаблона не должен начинаться с %<<::%>"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(если вы используете %<-fpermissive%> или %<-std=c++11%> или %<-std=gnu++11%> G++ примет ваш код)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-type template argument"
 msgid "invalid template-argument-list"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "ошибка разбора в списке аргументов шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "ожидалось template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "используйте нотацию %<%T::template %D%> для указания о том, что это шаблон"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ожидался pack параметр перед %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "явная конкретизация не должна использовать %<inline%> спецификатор"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "ожидался спецификатор типа"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "использование %<auto%> в декларации lambda параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "ожидался template-id для типа"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "ожидалось имя типа"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE не является именем типа"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "объединение определено здесь"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%> after %qE"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "ожидалась %<,%> или %<)%> перед %qE"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, fuzzy, gcc-internal-format
 #| msgid "placeholder constraints not satisfied"
 msgid "unexpected placeholder in constrained result type"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "декларация %qD ничего не декларирует"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибуты игнорируются для неконкретизированного типа"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибуты игнорируются для конкретизации шаблона"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибуты игнорируются для elaborated-type-specifier, который не является forward декларацией"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD является шаблоном перечисления"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD не именует перечисление в %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "неименованный scoped enum не допускается"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ожидалось %<;%> или %<{%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "невозможно добавить enumerator список к конкретизации шаблона"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "вложенный спецификатор имени %qT для enum декларации не именует класс или пространство имен"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларация %qD в пространстве имен %qD, которое не включает %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "избыточная квалификация не допускается"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ запрещает пустой неименованный enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier без имени"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier должен использовать простой идентификатор"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type; did you mean %qs?"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qE не является именем типа; имелось в виду %qs?"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD не есть namespace-name"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ожидалось namespace-name"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "определение вложенного пространства имен не может иметь атрибуты"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "определение вложенного пространства имен не может быть inline"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "вход в пространство имен %qD"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "декларациям доступа следует предпочесть using-declarations; предлагается: добавьте ключевое слово %<using%>"
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "типы нельзя определять в алиасных декларациях шаблонов"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT не является пространством имён"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter outside function body"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "использование параметра вне тела функции"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition здесь не допускается"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "ожидался конструктор, деструктор или преобразование типа"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "инициализатор задан для функции"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "не-функция %qD декларирована как неявный шаблон"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница массива не является целой константой"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "невозможно определить элемент зависимого typedef %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не является типом"
@@ -54001,441 +54082,441 @@ msgstr "%<%T::%E%> не является типом"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "некорректная декларация"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "некорректное использование конструктора как шаблона"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "используйте %<%T::%D%> вместо %<%T::%D%> для именования конструктора в имени с квалификатором"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "квалифицированный идентификатор в декларации"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD является пространством имён"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "невозможно сформировать указатель на элемент не класса %q#T"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ожидался ptr-operator"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "несколько ref-квалификаторов"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "повторный virt-specifier"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "отсутствуют аргументы шаблона после %qT"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "некорректное использование %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "типы нельзя определять в аргументах шаблона"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "некорректное использование %<auto%> в аргументе шаблона"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ожидался type-specifier"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ожидалось %<,%> или %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "аргументы по умолчанию разрешены только для параметров функций"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameter pack %qD не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "pack параметр шаблона не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameter pack не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 #| msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ не поддерживает C99 назначенные инициализаторы"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "ожидалось class-name"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "ожидалось %<;%> после определения класса"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "ожидалось %<;%> после определения структуры"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ожидалось %<{%> или %<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "невозможно задать %<override%> для класса"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "global квалификация имени класса некорректна"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "квалифицированное имя не именует класс"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "некорректное имя класса в декларации %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "перед явной специализацией должно быть %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "невозможно разрешить typename type"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "предыдущее определение %q#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ожидалось %<class%> или %<typename%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "в C++03 class-key должен использоваться при декларировании friend"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "класс хранения для анонимного агрегата в контексте класса недопустим"
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "битовое поле %qD не целочисленного типа"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "спецификатор pure в определении функции"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "случайная %<,%> в конце декларации элемента"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "некорректный спецификатор pure (только %<= 0%> допускается)"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "инициализатор в фигурных скобках здесь не допускается"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> задано более одного раза в base-спецификаторе"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "более одного спецификатора access в base-спецификаторе"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (базовый класс неявно является типом)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "динамические спецификации исключительных ситуаций считаются устаревшими в C++11"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "некорректное использование %<auto%> в спецификации исключительной ситуации"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "атрибутный using префикс использован вместе с scoped attribute token"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "ожидался идентификатор для имени атрибута"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "атрибут %<noreturn%> может появляться не более одного раза в списке атрибутов"
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr "атрибут %<deprecated%> может появляться не более одного раза в списке атрибутов"
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ожидался атрибут перед %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 #| msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 атрибуты доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "expression must be integral"
 msgid "expression must be enclosed in parentheses"
 msgstr "выражение должно быть целочисленным"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "заданная позиция не является целой константой"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "запрошенное выравнивание не является целочисленной константой"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "специализация элемента %<%T::%E%> требует %<template<>%> синтаксис"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -54444,559 +54525,559 @@ msgstr "недостаточно списков параметров шабло
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "нет подходящего concept для template-introduction"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона элемента в локальном классе"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная явная специализация"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "декларация шаблона класса не должна декларирован ничего иного"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация шаблона не может иметь класс хранения"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "аргумент %<sizeof...%> должен быть окружен скобками"
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректное использование %qD в спецификации привязки"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не поддерживает %<long long%>"
 
 #
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "заданы и %<__thread%> и %<thread_local%>"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублирование %qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидалось %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "ожидалось %<data%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидалось %<__transaction_atomic%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидалось %<__transaction_relaxed%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "ожидалось %<@end%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag использован в именовании %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "метка %qD определена здесь"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qT декларировано здесь"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD редекларирован с другим доступом"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "в C++98 %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ получатель сообщения ожидался"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "некорректное Objective-C++ имя селектора"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидалась objective-c++ декларация метода"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибуты метода должны задаваться в конце"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "случайное %qs между Objective-C++ методами"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "некорректный тип для instance переменной"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "ожидался идентификатор после %<@protocol%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибуты нельзя задавать до %<@%D%> Objective-C++ ключевого слова"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "префиксные атрибуты игнорируются до %<@%D%>"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип для property"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "ожидалось целочисленное выражение"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "некорректный reduction-инициализатор"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
 #| msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "недостаточно для сжатия циклов"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "некорректная клаузула инициализатора"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ожидалось id-выражение (аргументы)"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "один из аргументов вызова инициализатора должен быть %<omp_priv%> или %<&omp_priv%>"
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "типы не могут определяться в declare reduction списке типов"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "предекларированный арифметический тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "функциональный или массивный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "тип ссылки %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, fuzzy, gcc-internal-format
 #| msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const, volatile или __restrict квалифицированный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> именует множество перегрузок"
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD не ссылается на функцию в контексте пространства имен"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, fuzzy, gcc-internal-format
 #| msgid "atomic_cancel"
 msgid "%<atomic_cancel%>"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "внешний %<__transaction_cancel%> не внутри внешнего %<__transaction_atomic%>"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  либо %<transaction_may_cancel_outer%> функция"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "мусор в конце директивы %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> должна быть внутри функций"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "неявные шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -55275,7 +55356,7 @@ msgstr "не параметрический %qs не может содержат
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "packs параметров не расширены с %<...%>:"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -55301,68 +55382,68 @@ msgstr "декларация %q+#D перекрывает параметр ша
 msgid "template parameter %qD declared here"
 msgstr "параметр шаблона %qD декларирован здесь"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "параметры шаблона не выводимы в частичной специализации:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "первичный шаблон здесь"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "частичная специализация не более специальна чем первичный шаблон, так как она замещает несколько параметров пакетным расширением"
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "частичная специализация %qD не более специальна чем"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "первичный шаблон %qD"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qE должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qT должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -55370,17 +55451,17 @@ msgstr[0] "тип %qT аргумента шаблона %qE зависит от
 msgstr[1] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 msgstr[2] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "декларация %qD делает неоднозначной более раннюю конкретизацию шаблона для %qD"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "частичная специализация %qD после конкретизации %qD"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нет подразумеваемого аргумента для %qD"
@@ -55388,48 +55469,48 @@ msgstr "нет подразумеваемого аргумента для %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %q+D должен быть в конце списка параметров шаблона"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в редекларации friend шаблона функции"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в шаблонах функций без -std=c++11 или -std=gnu++11"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в частичных специализациях"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "шаблон %qD декларирован"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблон класса без имени"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "элемент-шаблон %qD не может иметь virt-спецификаторы"
@@ -55439,57 +55520,57 @@ msgstr "элемент-шаблон %qD не может иметь virt-спец
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "определение шаблона для не-шаблона %q#D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "ожидалось %d уровней параметров шаблона для %q#D, дано %d"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "дано %d параметров шаблона для %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "дано %d параметров шаблона для %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  вместо требуемых %d"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "аргументы шаблона для %qD не соответствуют первоначальному шаблону %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "используйте %<template<>%> для явной специализации"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не является шаблонным типом"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "спецификаторы шаблона не заданы в декларации %qD"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -55497,7 +55578,7 @@ msgstr[0] "редекларировано с %d параметром шабло
 msgstr[1] "редекларировано с %d параметрами шаблона"
 msgstr[2] "редекларировано с %d параметрами шаблона"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -55505,134 +55586,134 @@ msgstr[0] "предыдущая декларация %qD использовал
 msgstr[1] "предыдущая декларация %qD использовала %d параметра шаблона"
 msgstr[2] "предыдущая декларация %qD использовала %d параметра шаблона"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблона %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "редекларирован здесь как %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "исходная декларация находится здесь"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "редекларация аргумента по умолчанию для %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "исходное определение находится здесь"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%E не является корректным аргументом шаблона для типа %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "это должно быть адресом функции с внешней привязкой"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "это должно быть именем функции с внешней привязкой"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "это должно быть указателем на элемент вида %<&X::Y%>"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  невозможно вывести параметр шаблона %qD"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  несоответствие типов %qT и %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  параметр шаблона %qD не есть parameter pack, но аргумент %qD таковым является"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE не эквивалентно %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  противоречивый вывод parameter pack с %qT и %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  выведены конфликтующие типы для параметра %qT (%qT и %qT)"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  выведены конфликтующие значения для нетипового параметра %qE (%qE и %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  тип элемента-функции %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -55640,304 +55721,304 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  невозможно преобразовать %qE (типа %qT) к типу %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT является неоднозначным базовым классом %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT не является производным от %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  параметры шаблона для шаблона аргумента шаблона несовместимы с другими выведенными аргументами шаблона"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 #| msgid "  can't deduce a template for %qT from non-template type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  невозможно вывести шаблон для %qT из нешаблонного типа %qT"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qE не переменная"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "адрес %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "адрес %qT подобъекта %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "адрес %qD не есть корректный аргумент шаблона, так как он не имеет статический срок хранения"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD не есть корректный аргумент шаблона, поскольку %qD переменная, а не адрес переменной"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE не есть корректный аргумент шаблона для %qT, поскольку не является адресом переменной"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку строковые литералы не могут быть использованы в этом контексте"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT из-за конфликтов в cv-qualification"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он не есть lvalue"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D не есть корректный аргумент шаблона для типа %qT, поскольку ссылочная переменная не имеет постоянного адреса"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он является указателем"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он имеет тип %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD использовано как шаблон аргумента шаблона"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qE в качестве типа"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствие ограничений в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "ошибка при преобразовании аргумента шаблона %qE из %qT в %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть по крайней мере %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "предоставлено для %qD"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack expansion аргумент для non-pack параметра %qD алиасного шаблона %qD"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack expansion аргумент для non-pack параметра %qD concept %qD"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "так что любая конкретизация с непустым пакетом параметров была бы синтаксически некорректной"
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не является шаблоном функции"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
 msgstr "нарушение ограничения шаблона"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "использование некорректного переменного шаблона %qE"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "свертка пустого расширения над %O"
 
 #
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a potential constant expression"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE не есть потенциальное константное выражение"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
@@ -55955,296 +56036,296 @@ msgstr "создание указателя на элемент-функцию 
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qD имеет тип функции"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает массив"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "формирование указателя на квалифицированный тип функции %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "формирование ссылки на квалифицированный тип функции %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "пустой инициализатор в lambda init-capture"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD декларировано здесь, позднее в единице трансляции"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неверное число аргументов в вызове %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT есть/использует неименованный тип"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона для %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#D"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of variable concept %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of function concept %qD"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "явная специализация function concept %qD"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -56256,140 +56337,140 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT не является пространством имен или unscoped enum"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "неклассовый шаблон %qT использован без аргументов шаблона"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "невозможно вывести аргументы шаблона для инициализации копированием %qT, поскольку он имеет неявное руководство вывода или декларированные пользователем конструкторы"
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "явные руководства вывода не рассматриваются для copy-инициализации"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization %<auto%> требует ровно один элемент"
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "для вывода к %<std::initializer_list%> используйте copy-list-initialization (то есть добавьте %<=%> перед %<{%>)"
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "не удается вывести возвращаемый тип lambda из %qE"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "выведенный инициализатор не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "выведенный тип возврата не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "выведенный тип выражения не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -56604,7 +56685,7 @@ msgstr "некорректное использование %<this%> на вне
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "некорректный квалифицированный контекст в имени псевдодеструктора"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
@@ -56654,7 +56735,7 @@ msgstr "некорректная спецификация базового кл
 msgid "cannot capture member %qD of anonymous union"
 msgstr "невозможно захватить элемент %qD анонимного объединения"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
@@ -56754,7 +56835,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> допускается в OpenMP только в %<declare simd%> клаузулах"
@@ -56794,7 +56875,7 @@ msgstr "linear клаузула применена к нецелой, неука
 msgid "linear step expression must be integral"
 msgstr "выражение линейного шага должно быть целочисленным"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не есть переменная в клаузуле %qs"
@@ -56922,122 +57003,122 @@ msgstr "%qD появляется более одного раза в %<aligned%>
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD не есть переменная в %<depend%> клаузуле"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "шаблон %qE в клаузуле %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "перегрузка имени функции %qE в клаузуле %qs"
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%> аргумент требует целочисленный тип"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не есть переменная файла, пространства имен или контекста блока"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE директива не в %qT определении"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "разность между %qE и %qD не имеет целый тип"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> использована с итерационной переменной класса %qE"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> использует два различных выражения для памяти"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "неудача static assertion: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантное условие для static assertion"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "аргумент decltype должен быть выражением"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "decltype cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "decltype не может разрешить адрес перегруженной функции"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "операнд выражения свертки не имеет нерасширенных пакетов параметров"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "оба аргумента в бинарной свертке имеют нерасширенные пакеты параметров"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "нет нерасширенных пакетов параметров в бинарной свертке"
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "неуказательный аргумент для %<__builtin_launder%>"
@@ -57292,814 +57373,814 @@ msgstr "преобразование между различными pointer-to-
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "условное выражение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "некорректное применение %qs к элементу-функции"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "недопустимое применение %<sizeof%> к битовому полю"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<sizeof%> к выражению функционального типа"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "недопустимое применение %<__alignof%> к битовому полю"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<__alignof%> к выражению функционального типа"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "%<alignas%> аргумент имеет нецелочисленный тип %qT"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "некорректное использование нестатической функции-элемента типа %qT"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "взятие адреса от временного массива"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ запрещает преобразование строковой константы в %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "устаревшее преобразование из строковой константы в %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "запрос на элемент %qD в %qE, который имеет указательный тип %qT (возможно вы хотели использовать %<->%> ?)"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "запрос элемента %qD в %qE, имеющего не классовый тип %qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "некорректное использование нестатического элемента данных %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "недопустимый доступ к нестатическому элементу данных в %qD в виртуальной базе NULL объекта"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "объектный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "разрушаемый тип %qT, а деструктор относится к %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "поле %q#D доступно через %q#D"
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T не содержит элемента с именем %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> не является элементом %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD не является шаблонным элементом-функцией"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT не является типом указателя на объект"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "некорректное использование индексирования массива к указателю на элемент"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "некорректное использование унарной %<*%> к указателю на элемент"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "некорректное использование неявного преобразования к указателю на элемент"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "левый операнд %<->*%> должен быть указателем на класс, но является указателем на элемент типа %qT"
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "отсутствует индекс массива"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексируемый массив объявлен как %<register%>"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексируемый объект не является ни массивом, ни указателем"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "не задан объект при использовании %qE"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ запрещает использование %<::main%> из программы"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "необходимо использовать %<.*%> или %<->*%> для вызова pointer-to-member функции в %<%E (...)%>, например %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD нельзя использовать как функцию"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "выражение нельзя использовать как функцию"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "слишком много аргументов для конструктора %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "слишком мало аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "слишком много аргументов для функции %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "слишком мало аргументов для функции %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "слишком много аргументов для метода %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "слишком мало аргументов для метода %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "для функции задано слишком много аргументов"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "слишком мало аргументов функции"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметр %P %qD имеет неполный тип %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметр %P имеет неполный тип %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адрес %qD никогда не будет NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "компилятор может предположить, что адрес %qD не может быть NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "предполагается приведение к типу %qT из перегруженной функции"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL в арифметическом выражении"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ не поддерживает сравнение между указателем и целым"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "типы операндов %qT и %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "некорректные операнды типов %qT и %qT для бинарной операции %qO"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя %<void *%> в вычитании"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на функцию в вычитании"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на метод в вычитании"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "некорректное использование указателя на неполный тип в вычислениях с указателями"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "некорректное использование %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  qualified-id требуется"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "нельзя использовать скобки вокруг %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ не поддерживает взятие адреса от функции %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "попытка взять адрес битового поля"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to member function %q#D"
 msgid "taking address of an immediate function %qD"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "%<~%> on an expression of type bool"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> от выражения типа bool"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "имелось в виду использовать логическое отрицание (%<!%>)?"
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ запрещает инкрементирование enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ запрещает декрементирование enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "невозможно инкрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "невозможно декрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает инкрементирование указателя типа %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает декрементирование указателя типа %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "использование операнда типа %qT в %<operator--%> запрещено"
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "использование операнда типа %qT в %<operator++%> устарело"
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "нельзя взять адрес от %<this%>, поскольку это rvalue-выражение"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "запрошен адрес явной регистровой переменной %qD"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "запрошен адрес для %qD, которая декларирована как %<register%>"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer для неклассового типа не должен быть заключен в скобки"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "список выражений рассматривается как составное выражение в инициализаторе"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "список выражений рассматривается как составное выражение в mem-initializer"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "список выражений рассматривается как составное выражение в функциональном приведении типов"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "нет контекста для разрешения типа %qE"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "приведение от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
 #
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "тип класса %qT неполный"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "приведение указателя на функцию к указателю на объект условно поддерживается"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "некорректное приведение из типа %qT к типу %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "некорректное применение const_cast с типом %qT, не являющимся ни указателем, ни ссылкой, ни  указателем на элемент данных"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "некорректное применение const_cast с типом %qT, являющимся указателем или ссылкой на функцию"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "некорректное применение const_cast от rvalue-выражения типа %qT к типу %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "некорректное применение const_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ не поддерживает приведение к типу массива %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "некорректное приведение к типу функции %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  в вычислении %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "присваивание массиву из списка инициализатора"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несовместимые типы в присваивании %qT -> %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "массив использован как инициализатор"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "некорректное присваивание массива"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   в преобразовании указателя на элемент-функцию"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "преобразование указателя к элементу через виртуальную базу %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   в преобразовании указателя на элемент"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "параметр %qP %qD мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "параметр мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "цель преобразования могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "цель инициализации могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "левая часть присваивания могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "при передаче аргумента %P от %qD"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "возвращена ссылка на локальную переменную %qD"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "возвращен адрес метки %qD"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "возвращен адрес локальной переменной %qD"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
 #
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "недостаточно значений в операторе возврата"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "возвращен результат деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "возврат в обработчике try-блока конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "возврат результата конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "возврат списка инициализатора"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "противоречивые типы %qT и %qT выведены для возвращаемого типа lambda"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "противоречивый вывод для auto return type: %qT и затем %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не должен возвращать NULL, если только он не декларирован %<throw()%> (или задан ключ -fcheck-new)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -58368,108 +58449,108 @@ msgstr "фигурные скобки вокруг скалярного иниц
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "невозможно инициализировать агрегат типа %qT составным литералом"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "элемент %qD с неинициализированными ссылочными полями"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поле %qD не найдено в инициализируемом объединении"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд %<->%> имеет неуказательный тип %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "невозможно применить элементный указатель %qE к %qE, который имеет неклассовый тип %qT"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "тип указатель на элемент-функцию %qT требует rvalue"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функциональное приведение к массивному типу %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 #| msgid "cannot deduce template arguments for %qT from ()"
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "невозможно вывести аргументы шаблона для %qT из ()"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа %q#T"
@@ -58697,10 +58778,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "Ссылка на массив в %C не может иметь больше чем %d измерений"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -58868,7 +58949,7 @@ msgstr "[...] стиль конструкторов массива в %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Конструктор массива, включающий спецификацию типа в %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Type-spec в %L не может содержать параметр отложенного типа"
@@ -58989,7 +59070,7 @@ msgstr "Список имен %qs не может быть аргументом
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "%<I%> в %L и %<J%> в %L не могут обе быть BOZ литеральными константами"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -59031,7 +59112,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть встроенного типа"
@@ -59046,7 +59127,7 @@ msgstr "%qs аргумент %qs встроенной функции в %L до
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER или PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть константой"
@@ -59166,167 +59247,168 @@ msgstr "Неравные character длины (%ld/%ld) в %s в %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "%qs и %qs аргументы %qs встроенной функции в %L должны иметь одинаковый тип"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "Различные виды типов в %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента %qs встроенной функции"
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть POINTER"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "%qs аргумент %qs встроенной функции в %L не должен быть коиндексирован"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть указателем или целевой VARIABLE или FUNCTION"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть POINTER или TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "Секция массива с векторным индексом в %L не должна быть целью указателя"
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента %qs встроенной функции"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "ATOM аргумент в %L для встроенной функции %s должен быть целым ATOMIC_INT_KIND или логическим ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "ATOM аргумент в %L для %s встроенной функции должен быть комассивом или коиндексированным"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "%qs аргумент %qs встроенной функции в %L должен иметь тот же тип, что и %qs в %L"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "STAT= аргумент для %s в %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "ATOM аргумент для %s встроенной функции в %L должен быть определяемым"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "ATOM аргумент в %L для встроенной функции %s должен быть целым ATOMIC_INT_KIND"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "VALUE аргумент для %s встроенной функции в %L должен быть определяемым"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "%qs аргумент %qs встроенной функции в %L пока не поддерживается"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "%qs аргумент %qs встроенной функции в %L должен задавать корректный целый вид"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "OLD аргумент для %s встроенной функции в %L должен быть определяемым"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "EVENT аргумент в %L для встроенной функции EVENT_QUERY должен быть типа EVENT_TYPE"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "COUNT аргумент для EVENT_QUERY встроенной функции в %L должен быть определяемым"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "COUNT аргумент для EVENT_QUERY встроенной функции в %L должен иметь по крайней мере диапазон подразумеваемых целых"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Отрицательный аргумент N в %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "%qs аргумент %qs встроенной функции в %L не должен присутствовать, если %<x%> есть COMPLEX"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "%qs аргумент %qs встроенной функции в %L должен иметь тип либо REAL либо INTEGER"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr "Преобразование из %s в COMPLEX(%d) подразумеваемого вида в %L может привести к потере точности, попробуйте использовать KIND аргумент"
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr "Аргумент %<A%> с INTENT(INOUT) в %L от встроенной подпрограммы %s не будет иметь индекс вектора"
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "A аргумент в %L встроенной функции %s не должен быть коиндексирован"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "stat= аргумент в %L должна быть kind=4 integer переменной"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "errmsg= аргумент в %L должен быть подразумеваемого вида character переменной"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "Комассивы выключены в %L, используйте %<-fcoarray=%> для включения"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr "Поддержка для A аргумента в %L, который есть полиморфный A аргумент или имеет размещаемые компоненты пока не реализована"
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "A аргумент в %L для CO_REDUCE не должен быть полиморфным"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr "Поддержка для A аргумента в %L с размещаемыми компонентами пока не реализована"
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "OPERATOR Аргумент в %L должен быть PURE функцией"
@@ -59334,706 +59416,706 @@ msgstr "OPERATOR Аргумент в %L должен быть PURE функци
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Встроенная функция %s в %L не разрешена для CO_REDUCE"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr "Функция переданная как OPERATOR в %L должна иметь два аргумента"
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr "Функция переданная как OPERATOR в %L имеет аргументы типа %s и %s, но должна иметь тип %s"
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr "Функция переданная как OPERATOR в %L должна иметь скалярные, неразмещаемые, неуказательные аргументы и возвращать неразмещаемый неуказательные скаляр"
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr "Функция переданная как OPERATOR в %L должна иметь VALUE атрибут либо ни для одного, либо для обоих аргументов"
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr "Функция переданная как OPERATOR в %L должна иметь TARGET атрибут либо ни для одного, либо для обоих аргументов"
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr "Функция переданная как OPERATOR в %L должна иметь ASYNCHRONOUS атрибут либо ни для одного, либо для обоих аргументов"
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr "Функция переданная как OPERATOR в %L должна иметь OPTIONAL атрибут либо ни для одного, либо для обоих аргументов"
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr "Символьная длина A аргумента в %L и аргументов OPERATOR в %L должна быть одинаковой"
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr "Символьная длина A аргумента в %L и результата функции OPERATOR в %L должна быть одинаковой"
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть типа integer, real или character"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "%qs встроенная функция с KIND аргументом в %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "%qs аргумент %qs встроенной функции в %L имеет некорректную форму в измерении %d (%ld/%ld)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "%qs аргумент %qs встроенной функции в %L должен иметь ранг %d или быть скаляром"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть числовым или LOGICAL"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "Разная форма для аргументов %qs и %qs в %L для встроенной функции %<dot_product%>"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть подразумеваемым вещественным"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr ""
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "неподразумеваемый INTEGER вида аргумент для %s встроенной функции в %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "COMPLEX аргумент %qs %qs встроенной функции в %L"
 
 #
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "arguments 1 and 2 have different types"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "Аргументы 1 и 2 имеют разные типы"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Аргумент %s в %L должен быть длины один"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть того же вида, что и %qs"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "SIZE в %L должен быть положительным"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "Абсолютная величина SHIFT в %L должна быть меньше или равна SIZE в %L"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a variable"
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "%qs в %C не является переменной"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть сущностью данных"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Встроенная функция %qs в %L должна иметь по крайней мере два аргумента"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Отсутствует %qs аргумент для %s встроенной функции в %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Повторяющийся аргумент %qs в %L для встроенной функции %s"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Неизвестный аргумент %qs в %L для встроенной функции %s"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "%<a%d%> аргумент %qs встроенной функции в %L должен быть %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "%qs встроенная функция с CHARACTER аргументом в %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "%<a1%> аргумент %qs встроенной функции в %L должен быть INTEGER, REAL или CHARACTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Типы аргументов %qs встроенной функции в %L должны соответствовать (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "Разная форма по измерению 1 для аргументов %qs и %qs в %L для встроенной функции matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "Разная форма по измерению 2 для аргументов %qs и %qs в %L для встроенной функции matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть ранга 1 или 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть интероперабельной сущностью данных: %s"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "FROM аргумент для MOVE_ALLOC в %L не должен быть коиндексирован"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "TO аргумент для MOVE_ALLOC в %L не должен быть коиндексирован"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "TO аргументы в MOVE_ALLOC в %L должны быть полиморфными, если FROM является полиморфным"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "FROM и TO аргументы MOVE_ALLOC встроенной функции в %L должны иметь одинаковый ранг %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "FROM и TO аргументы MOVE_ALLOC встроенной функции в %L должны иметь одинаковый коранг %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr "Аргументы FROM и TO в %L нарушают ограничения синонимии (F2003 12.4.1.7)"
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "Аргумент %<S%> NEAREST в %L не должен быть нулем"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть POINTER, ALLOCATABLE или процедурным указателем"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "NULL встроенная функция с размещаемым MOLD в %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть формальной переменной"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть OPTIONAL формальной переменной"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "%qs аргумент %qs встроенной функции в %L не должен быть подобъектом %qs"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Аргумент RANK встроенной функции в %L должен быть объектом данных"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "%<shape%> аргумент %<reshape%> встроенной функции в %L должен быть массивом константного размера"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "%qs аргумент %qs встроенной функции в %L пуст"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "%<shape%> аргумент %<reshape%> встроенной функции в %L имеет больше чем %d элементов"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "%qs аргумент %qs встроенной функции в %L имеет отрицательный элемент (%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Элемент %d фактического аргумента RESHAPE в %L не может быть отрицательным"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "%qs аргумент %qs встроенной функции в %L имеет неверное число элементов (%d/%d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "%qs аргумент %qs встроенной функции в %L имеет измерение вне диапазона (%d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "%qs аргумент %qs встроенной функции в %L имеет некорректную перестановку измерений (измерение %qd дублировано)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Без дополнения не хватает элементов во встроенной функции RESHAPE source в %L, чтобы соответствовать форме"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "%qs аргумент %qs встроенной функции в %L не может быть типа %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть расширяемого типа"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND с аргументом не %<P%> и не %<R%> в %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%qs встроенная функция с RADIX аргументом в %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%<source%> аргумент %<shape%> встроенной функции в %L не должен быть массивом предполагаемого размера"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%qs аргумент %qs встроенной функции в %L не должен быть процедурой"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%qs аргумент %qs встроенной функции в %L не должен быть TYPE(*)"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "%qs аргумент %qs встроенной функции в %L не должен быть массивом предполагаемого размера"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr потерпело неудачу"
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть интероперабельной сущностью данных: %s"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "Аргумент C_PTR_1 в %L для C_ASSOCIATED должен иметь тип TYPE(C_PTR) или TYPE(C_FUNPTR)"
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "Аргумент C_PTR_2 в %L для C_ASSOCIATED должен иметь тот же тип, что и C_PTR_1: %s вместо %s"
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "Аргумент CPTR в %L для C_F_POINTER должен иметь тип TYPE(C_PTR)"
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Аргумент FPTR в %L для C_F_POINTER должен быть указателем"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "FPTR аргумент в %L для C_F_POINTER должен быть полиморфным"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "Аргумент FPTR в %L для C_F_POINTER не должен быть коиндексирован"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Неожиданный SHAPE аргумент в %L для C_F_POINTER со скалярным FPTR"
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "Ожидался SHAPE аргумент для C_F_POINTER с массивным FPTR в %L"
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "SHAPE аргумент в %L для C_F_POINTER должен иметь тот же размер, что и RANK FPTR"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "Полиморфный FPTR в %L для C_F_POINTER"
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Неинтероперабельный массив FPTR в %L для C_F_POINTER: %s"
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "Аргумент CPTR в %L для C_F_PROCPOINTER должен иметь тип TYPE(C_FUNPTR)"
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "Аргумент FPTR в %L для C_F_PROCPOINTER должен быть указателем на процедуру"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "Аргумент FPTR в %L для C_F_PROCPOINTER должен быть коиндексирован"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Неинтероперабельный указатель на процедуру в %L для C_F_PROCPOINTER"
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "Аргумент X в %L для C_FUNLOC не должен быть коиндексирован"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Результат функции %qs в %L не годится как X аргумент для C_FUNLOC"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "Аргумент X в %L для C_FUNLOC должен быть процедурой или указателем на процедуру"
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Неинтероперабельная процедура в %L для C_FUNLOC"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "Аргумент X в %L для C_LOC не должен быть коиндексирован"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "X аргумент в %L для C_LOC не должен быть полиморфным"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Аргумент X в %L для C_LOC должен иметь POINTER или TARGET атрибут"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "Аргумент X в %L для C_LOC не должен быть строкой нулевого размера"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Аргумент в %L для C_LOC не должен быть полиморфным"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Неинтероперабельный массив в %L как аргумент для C_LOC: %s"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Массив неинтероперабельного типа в %L для C_LOC, который является неразмещаемым и не подразумеваемого и не явного размера"
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Секция массива в %L для C_LOC"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "не двойной точности REAL аргумент для %s встроенной функции в %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть меньше чем ранг %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "%qs аргумент %qs встроенной функции в %L не есть корректный индекс измерения"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "'%s' аргумент для IMAGE_INDEX должен быть массивом ранга один в %L"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Число элементов массива SUB аргумента для IMAGE_INDEX в %L должно быть %d (коранг) а не %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "DISTANCE= аргумент для NUM_IMAGES в %L"
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "FAILED= аргумент в NUM_IMAGES в %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM аргумент без COARRAY аргумента не допускается для THIS_IMAGE встроенной функции в %L"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "DISTANCE аргумент не должен быть задан вместе с COARRAY или DIM аргументом во встроенной функции в %L"
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Неожиданный DIM аргумент с некомассивным аргументом в %L"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "DISTANCE= аргумент для THIS_IMAGE в %L"
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "%<MOLD%> аргумент %<TRANSFER%> встроенной функции в %L не должен быть %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "%<MOLD%> аргумент %<TRANSFER%> встроенной функции в %L не должен быть %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "%<MOLD%> аргумент %<TRANSFER%> встроенной функции в %L не должен быть %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Встроенная функция TRANSFER в %L имеет частично неопределенный результат: исходный размер %ld < размера результата %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "%qs аргумент %qs встроенной функции в %L должен иметь тот же ранг, что и %qs или быть скаляром"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "%qs и %qs аргументы %qs встроенной функции в %L должны иметь идентичную форму."
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Размер %qs аргумента %qs встроенной функции в %L слишком мал (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "fe_runtime_error цепочка должна быть null-терминирована"
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Неправильное число аргументов (%d вместо %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "COUNT аргумент для SYSTEM_CLOCK в %L имеет неподразумеваемый вид"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Вещественный COUNT_RATE аргумент для SYSTEM_CLOCK в %L"
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "COUNT_RATE аргумент для SYSTEM_CLOCK в %L имеет неподразумеваемый вид"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "COUNT_MAX аргумент для SYSTEM_CLOCK в %L имеет неподразумеваемый вид"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть вида не шире чем подразумеваемый вид (%d)"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "ATOM аргумент в %L для %s встроенной функции должен быть комассивом или коиндексированным"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER или LOGICAL"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "Встроенная функция NULL в %L не может быть фактическим аргументом для STORAGE_SIZE, так как она возвращает неассоциированный указатель"
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "Предполагаемый размер полиморфных объектов или компонентов, таких как в %C, пока не реализован"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Максимальный уровень расширения достигнут с типом %qs в %L"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "%qs от %qs является PRIVATE в %L"
@@ -60228,758 +60310,758 @@ msgstr "Некорректная INTENT спецификация в %C"
 msgid "deferred type parameter at %C"
 msgstr "отложенный параметр типа в %C"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Скалярное INTEGER выражение ожидалось в %L"
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Старый стиль длины строки в %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Синтаксическая ошибка в спецификации длины строки в %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Процедура %qs в %C уже определена в %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Имя %qs в %C уже определено как обобщенный интерфейс в %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Процедура %qs в %L должна иметь BIND(C) атрибут, чтобы быть C-совместимой"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Переменная %qs в %L является формальным аргументом BIND(C) процедуры %qs, но не является C-совместимой, поскольку производный тип %qs не является C-совместимым"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Переменная %qs в %L является формальным аргументом BIND(C) процедуры %qs, но не является C-совместимой, поскольку та полиморфна"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Переменная %qs в %L является формальным аргументом BIND(C) процедуры %qs, но может не быть C-совместимой"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Character аргумент %qs в %L должен быть длины 1, поскольку процедура %qs является BIND(C)"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Переменная %qs в %L с ALLOCATABLE атрибутом в процедуре %qs с BIND(C)"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Переменная %qs в %L с POINTER атрибутом в процедуре %qs с BIND(C)"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Переменная %qs в %L не может иметь оба атрибута OPTIONAL и VALUE, поскольку процедура %qs является BIND(C)"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Переменная %qs в %L с OPTIONAL атрибутом в процедуре %qs являющейся BIND(C)"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Массив предполагаемого размера %qs в %L как формальный аргумент в BIND(C) процедуре %qs в %L"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Символ %qs в %C декларирован так же, как тип в %L"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Переменная %qs в common блоке %qs в %C должна быть декларирована с C совместимым видом, поскольку common блок %qs является BIND(C)"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "CHARACTER длина должна быть константой в %L"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER выражение в %L усекается (%ld/%ld)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "CHARACTER элементы конструктора массива в %L должны иметь одинаковую длину (%ld/%ld)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Инициализатор не допускается для PARAMETER %qs в %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER в %L остался без инициализатора"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Переменная %qs в %C с инициализатором уже появлялась в DATA операторе"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Невозможно инициализировать parameter массив в %L с элементами переменной длины"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't initialize implied-shape array at %L with scalar"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "Невозможно инициализировать массив выводимой формы в %L с помощью скаляра"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_array_dimen_size(): Bad dimension"
 msgid "gfc_array_size failed"
 msgstr "gfc_array_dimen_size(): Некорректная размерность"
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Неконстантная нижняя граница декларации выводимой формы в %L"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Компонент %qs с CLASS в %C должен быть размещаемым или указателем"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Компонент-массив структуры в %C должен иметь явную или отложенную форму"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Компонент %qs в %C уже декларирован в %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Компонент-массив указателей структуры в %C должен иметь отложенную форму"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Размещаемый компонент структуры в %C должен иметь отложенную форму"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Компонент-массив структуры в %C должен иметь явную форму"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL() инициализация в %C неоднозначна"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL() инициализация в %C не может иметь MOLD"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Инициализация указателя в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Ошибка в инициализации указателя в %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "не-NULL инициализация указателя в %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Некорректный символ в имени в %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 #| msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Не-PARAMETER символ %qs в %L не может быть выводимой формы"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Массив выводимой формы в %L"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs в %C есть переопределение декларации в соответствующем интерфейсе для MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Повторная спецификация массива для Cray указателя в %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "Couldn't set pointee array spec."
 msgid "Cannot set pointee array spec."
 msgstr "Невозможно установить спецификацию указуемого массива"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Старомодная инициализация в %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "некорректная старомодная инициализация для компонента производного типа в %C"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Синтаксическая ошибка в старомодной инициализации %s в %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Инициализация в %C не для указательной переменной"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Инициализация указателя в %C требует %<=>%>, не %<=%>"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ожидалось инициализационное выражение в %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Инициализация переменной в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Инициализация размещаемого компонента в %C не допускается"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of allocatable component at %C is not allowed"
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "Инициализация размещаемого компонента в %C не допускается"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External %qs at %L cannot have an initializer"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старомодная декларация типа %s*%d не поддерживается в %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандартная декларация типа %s*%d в %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Отсутствует правая скобка в %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Явное инициализационное выражение в %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ожидалось скалярное инициализационное выражение в %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Вид %d не поддерживается для типа %s в %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C вид параметра типа задан для типа %s, но тип в %L есть %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Отсутствует правая скобка или запятая в %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Вид %d не поддерживается для CHARACTER в %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксическая ошибка в CHARACTER декларации в %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, fuzzy, gcc-internal-format
 #| msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "RECORD в %C является расширением, включите его посредством -fdec-structure"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Имя структуры ожидалось после RECORD в %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE тип в %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE тип использованный в %C не доступен на целевой машине"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Предполагаемый тип в %C не допускается для компонентов"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Предполагаемый тип в %C"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE с intrinsic-type-spec в %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid type-spec at %C"
 msgid "Malformed type-spec at %C"
 msgstr "Некорректная спецификация типа в %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX в %C"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Имя типа %qs в %C неоднозначно"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS оператор в %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Имя типа %qs в %C конфликтует с ранее декларированной сущностью в %L, которая имеет то же имя"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Повторный IMPLICIT NONE оператор в %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE со списком спецификаций в %C"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Отсутствует символьный диапазон в IMPLICIT в %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Буквы должны быть в алфавитном порядке в IMPLICIT операторе в %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT оператор в %C следует за IMPLICIT NONE (тип) оператором"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Пустой IMPLICIT оператор в %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT оператор в %C допустим только в INTERFACE теле"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT оператор в %C не допускается в теле интерфейса процедуры модуля"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT оператор в %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Невозможно IMPORT %qs из единицы компиляции уровня хоста в %C - не существует."
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs уже IMPORTed из единицы компиляции уровня хоста в %C."
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксическая ошибка в IMPORT операторе в %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Отсутствует спецификатор коизмерения в %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Отсутствует спецификатор измерения в %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Повторный %s атрибут в %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "ALLOCATABLE атрибут в %C в TYPE определении"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "ALLOCATABLE атрибут в %C в TYPE определении"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Атрибут %s в %L в TYPE определении"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "ALLOCATABLE атрибут в %C в TYPE определении"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Атрибут %s в %L в TYPE определении"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s атрибут в %L не допускается вне спецификационной части модуля"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "ASYNCHRONOUS атрибут в %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "CONTIGUOUS атрибут в %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED в %C допускается только в спецификационной части модуля"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "PROTECTED атрибут в %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "VALUE атрибут в %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "VOLATILE атрибут в %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Некорректный атрибут"
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Несколько идентификаторов задано с одним NAME= спецификатором в %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Неявно декларированная BIND(C) функция %qs в %L может не быть C совместимой"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Переменная %qs в common блоке %qs в %L может не быть C совместимого вида хотя common блок %qs есть BIND(C)"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Декларация типа %qs at %L не является C совместимой, но является BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Переменная %qs в %L может не быть C совместимого вида, но является BIND(C)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Переменная %qs в common блоке %qs в %L не может быть декларирована с BIND(C), поскольку она не является глобальной"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Переменная %qs в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Переменная %qs в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Возвращаемый тип BIND(C) функции %qs в %L не может быть массивом"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
@@ -60987,1023 +61069,1023 @@ msgstr "Возвращаемый тип BIND(C) функции %qs в %L не м
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Символ %qs в %L помечен как PRIVATE, но получил связывающую метку %qs"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Требуется имя либо сущности либо common блока для оператора спецификации атрибутов в %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Отсутствует имя сущности или common блока для оператора спецификации атрибутов в %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Отсутствует символ"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C) оператор в %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Производный тип в %C не был ранее определен и поэтому не может появляться в определении производного типа"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксическая ошибка в декларации анонимной структуры в %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксическая ошибка в декларации данных в %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE префикс в %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "MODULE PROCEDURE в %C должна быть в generic module interface"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE процедура в %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE и IMPURE не должны оба появляться в %C"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL префикс в MODULE интерфейсе отсутствует в %L"
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE префикс в MODULE PROCEDURE интерфейсе отсутствует в %L"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE префикс в MODULE PROCEDURE интерфейсе отсутствует в %L"
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A type parameter list is required at %C"
 msgstr "Левая скобка требуется после %<*%>"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Аргумент альтернативного возврата в %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Имя %qs в %C есть имя процедуры"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неожиданный мусор в списке формальных аргументов в %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Повторяющийся символ %qs в списке формальных аргументов в %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Несоответствие в MODULE PROCEDURE именах формальных аргументов (%s/%s) в %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Несоответствие в числе MODULE PROCEDURE формальных аргументов в %C"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT переменная в %C должна отличаться от имени функции"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неожиданный мусор после декларации функции в %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "BIND(C) атрибут в %L не может быть специфицирован для внутренней процедуры"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C) атрибут в %C требует интерфейс с BIND(C)"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C) процедура с NAME не может иметь POINTER атрибут в %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Формальным процедура в %C не может иметь BIND(C) атрибут с NAME"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Процедура %qs в %L уже имеет базовый тип %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксическая ошибка в операторе PROCEDURE в %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Ожидалось %<::%> после атрибутов связывания в %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS или явный интерфейс требуются в %C"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Компонент указатель на процедуру в %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксическая ошибка в компоненте указателя на процедуру в %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE в %C должна быть в generic интерфейсе"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "двойное двоеточие в MODULE PROCEDURE операторе в %L"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE оператор в %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Ожидался список формальный аргументов в определении функции в %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C) атрибут в %L может использоваться только для переменных или common блоков"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, fuzzy, gcc-internal-format
 #| msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr "Несоответствие в MODULE PROCEDURE именах формальных аргументов (%s/%s) в %C"
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY оператор в %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY оператор в %C не может появляться внутри PROGRAM"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY оператор в %C не может появляться внутри MODULE"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY оператор в %C не может появляться внутри SUBMODULE"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY оператор в %C не может появляться внутри BLOCK DATA"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY оператор в %C не может появляться внутри STRUCTURE блока"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY оператор в %C не может появляться внутри DERIVED TYPE блока"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY оператор в %C не может появляться внутри IF-THEN блока"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY оператор в %C не может появляться внутри DO блока"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY оператор в %C не может появляться внутри SELECT блока"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY оператор в %C не может появляться внутри FORALL блока"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY оператор в %C не может появляться внутри WHERE блока"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней подпрограммы"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Неожиданный ENTRY оператор в %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней процедуры"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Отсутствуют обязательные скобки перед BIND(C) в %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней процедуры"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return cannot appear in operator interface at %L"
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "Альтернативный возврат не может появляться в интерфейсе оператора в %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Некорректный C идентификатор в NAME= спецификаторе в %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксическая ошибка в NAME= спецификаторе для связывающей метки в %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "NAME= спецификатор в %C должен быть константным выражением"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME= спецификатор в %C должен быть скаляром подразумеваемого character вида"
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Отсутствует закрывающая скобка для связывающей метки в %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Связывающее имя не допускается в BIND(C) в %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Для формальной процедуры %s связывающее имя не допускается в BIND(C) в %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME не допускается в BIND(C) для ABSTRACT INTERFACE в %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неожиданный END оператор в %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END оператор вместо %s оператора в %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s оператор ожидался в %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "Ожидается %s оператор в %L"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Ожидалось имя блока от %qs в %s операторе в %L"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Ожидалось завершающее имя в %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Ожидалась метка %qs для %s оператора в %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Отсутствует спецификация массива в %L в DIMENSION операторе"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Измерения специфицированы для %s в %L после его инициализации"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Отсутствует спецификация массива в %L в CODIMENSION операторе"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Спецификация массива должна быть отложенной в %L"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate POINTER attribute at %C"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Повторный POINTER атрибут в %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неожиданный символ в списке переменных в %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "Ожидалась %<(%> в %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Ожидалось имя переменной в %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray указатель в %C должен быть целым"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray указатель в %C имеет %d байт точности; адреса памяти требуют %d байт"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Ожидалась \",\" в %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "Couldn't set Cray pointee array spec."
 msgid "Cannot set Cray pointee array spec."
 msgstr "Невозможно установить Cray спецификацию указуемого массива"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Ожидалась \")\" в %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Ожидалась %<,%> или окончание оператора в %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "Декларация Cray указателя в %C требует -fcray-pointer флаг"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS оператор в %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Спецификация доступа %s оператора в %C уже была специфицирована"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED оператор в %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксическая ошибка в PROTECTED операторе в %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE оператор в %C допустим только в спецификационной части модуля"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC оператор в %C допустим только в спецификационной части модуля"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Ожидалось имя переменной в %C в PARAMETER операторе"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Ожидался = знак в PARAMETER операторе в %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ожидалось выражение в %C в PARAMETER операторе"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Инициализация уже инициализированной переменной в %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER без '()' в %C"
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неожиданные символы в PARAMETER операторе в %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Ожидался список сущностей в AUTOMATIC операторе в %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксическая ошибка в AUTOMATIC операторе в %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Ожидался список сущностей в STATIC операторе в %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксическая ошибка в STATIC операторе в %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Общий SAVE оператор в %C следует за предыдущим SAVE оператором"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE оператор в %C следует за общим SAVE оператором"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксическая ошибка в SAVE операторе в %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE оператор в %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксическая ошибка в VALUE операторе в %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE оператор в %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Задание VOLATILE для комассивной переменной %qs в %C, которая является use-/host-associated"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксическая ошибка в VOLATILE операторе в %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS оператор в %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксическая ошибка в ASYNCHRONOUS операторе в %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE PROCEDURE декларация в %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE в %C должна быть в generic module interface"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Встроенная процедура в %L не может быть MODULE PROCEDURE"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Неоднозначный символ в TYPE определении в %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Символ %qs в %C не был ранее определен"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs в EXTENDS выражении в %C не есть производный тип"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs не может быть расширено в %C, поскольку оно BIND(C)"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs не может быть расширено в %C, поскольку оно SEQUENCE тип"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Производный тип в %C может быть только PRIVATE в спецификационной части модуля"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Производный тип в %C может быть только PUBLIC в спецификационной части модуля"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT тип в %C"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Не удалось создать тип структуры '%s' в %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Определение типа %qs в %C уже было определено в %L"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Мусор после MAP оператора в %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Мусор после UNION оператора в %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s в %C является DEC расширением, включите его посредством %<-fdec-structure%>"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Имя структуры ожидалось в декларации невложенной структуры в %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Мусор после невложенного STRUCTURE оператора в %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Имя структуры %qs в %C не может быть тем же, что у встроенного типа"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Ожидалось :: в TYPE определении в %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CONTAINS block in derived type definition at %C"
 msgid "Mangled derived type definition at %C"
 msgstr "CONTAINS блок в определении производного типа в %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Имя типа в %qs в %C не может быть тем же, что у встроенного типа"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Имя производного типа %qs в %C уже имеет базовый тип в %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr ""
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "Формальный аргумент %qs в %L не может быть OPTIONAL"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Определение производного типа %qs at %C уже было определено"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray указуемое в %C не может быть массивом предполагаемой формы"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM и ENUMERATOR в %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Перечислитель превосходит целый тип C в %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L не инициализирован целым выражением"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM оператор определения ожидался до %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксическая ошибка в ENUMERATOR определении в %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Повторный спецификатор доступа в %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Связывающие атрибуты уже специфицировали passing, некоректный NOPASS в %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Связывающие атрибуты уже специфицировали passing, некоректный PASS в %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Повторный POINTER атрибут в %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Повторный NON_OVERRIDABLE в %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Повторный DEFERRED в %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Ожидался спецификатор доступа в %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Ожидался связывающий атрибут в %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE и DEFERRED не могут оба появляться в %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER атрибут требуется для компонента указателя на процедуру в %C"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Имя интерфейса ожидалось после %<(%> в %C"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> ожидалась в %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Интерфейс должен быть специфицирован для DEFERRED связывания в %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) at %C следует декларировать DEFERRED"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Ожидалось связывающее имя в %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE список в %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> некорректно для DEFERRED связывания в %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> требуется в PROCEDURE связывании с явной целью в %C"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Ожидалась цель связывания после %<=>%> в %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Тип %qs, содержащий DEFERRED связывание в %C, не есть ABSTRACT"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Уже есть процедура со связывающим именем %qs для производного типа %qs в %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC в %C должно быть внутри производного типа CONTAINS"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Ожидалось %<::%> в %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Ожидалось generic имя или дескриптор оператора в %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Некорректная форма GENERIC оператора в %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Ожидалось %<=>%> в %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Уже есть не-generic процедура со связывающим именем %qs для производного типа %qs в %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Связывание в %C должно иметь тот же доступ, что и уже определенное связывание %qs"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Ожидалось конкретное связывающее имя в %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs уже определено как конкретное связывание для generic %qs в %C"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Мусор после GENERIC связывания в %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL декларация в %C должна быть внутри секции CONTAINS производного типа"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Декларация производного типа с FINAL в %C должна быть в спецификационной части модуля"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Пустое FINAL в %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Ожидалось имя модульной процедуры в %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "Ожидалась %<,%> в %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Неизвестное имя процедуры %qs в %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неизвестный атрибут в !GCC$ ATTRIBUTES операторе в %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Синтаксическая ошибка в !GCC$ ATTRIBUTES операторе в %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$ACC DECLARE list at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Синтаксическая ошибка в !$ACC DECLARE списке в %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$ACC DECLARE list at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Синтаксическая ошибка в !$ACC DECLARE списке в %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$ACC DECLARE list at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -62130,13 +62212,13 @@ msgstr "индекс размерности %d выходит за границ
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "Число элементов (%d) в конструкторе массива в %L требует увеличения допустимой %d верхней границы.  См. опцию %<-fmax-array-constructor%>"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE prefix at %C"
 msgid "LEN part_ref at %C"
 msgstr "MODULE префикс в %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE prefix at %C"
 msgid "KIND part_ref at %C"
@@ -62214,7 +62296,7 @@ msgstr "трансформационная встроенная функция %
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Вычисление нестандартного инициализационного выражения в %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "Функция %qs в инициализационном выражении в %L должна быть встроенной функцией"
@@ -62483,7 +62565,7 @@ msgstr "Несоответствие интерфейсов в присваив
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Явный интерфейс требуются для %qs в %L: %s"
@@ -62542,176 +62624,176 @@ msgstr "Цель, переотображающая ранг, не ранга 1 
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Целевые данные в %L не должны иметь коиндекс"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Цель инициализации указателя в %L должна иметь TARGET атрибут"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Цель присваивания указателя не TARGET и не POINTER в %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Некорректная цель в присваивании указателя в PURE процедуре в %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Присваивание указателя с индексом вектора в правой части в %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Цель присваивания указателя имеет PROTECTED атрибут в %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Указатель в %L в присваивании указателя может пережить цель указателя"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Цель инициализации указателя в %L должна иметь TARGET атрибут"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Цель инициализации указателя в %L должна иметь SAVE атрибут"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Цель инициализации указателя на процедуру в %L не может быть указателем на процедуру"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Внутренняя процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Внутренняя процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Указательные функции в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable выражение в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Именованная константа %qs в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs в контексте определения переменных (%s) в %L не есть переменная"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Тип недоступен в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Формальный аргумент %qs с INTENT(IN) в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Формальный аргумент %qs с INTENT(IN) в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Переменная %qs является PROTECTED и не может появляться в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Переменная %qs является PROTECTED и не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Переменная %qs не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs в %L ассоциированное с векторно индексированной целью не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Имя ассоциации %qs не может появляться в контексте определения переменных (%s) в %L, поскольку его цель в %L также не может"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Элементы с одинаковым значением в %L и %L в векторном индексе в контексте определения переменной (%s)"
@@ -62740,7 +62822,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Некорректный идентификатор в copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -62934,12 +63016,12 @@ msgstr "Первый аргумент определенного присваи
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -63009,592 +63091,592 @@ msgstr "Неоднозначные интерфейсы в %s для %qs в %L 
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Хотя на нее нет ссылки, %qs имеет неоднозначные интерфейсы в %L"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs в %L не есть процедура модуля"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Массив предполагаемого ранга в %L требует, чтобы формальный аргумент %qs имел предполагаемый ранг"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (скаляр и ранг-%d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и скаляр)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и ранг-%d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (скаляр и ранг-%d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и скаляр)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и ранг-%d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Некорректный аргумент процедуры в %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Несоответствие интерфейса в формальной процедуре %qs в %L: %s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Фактический аргумент для непрерывного указательного формального параметра %qs в %L должен быть просто непрерывным"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) фактические аргументы в %L могут противоречить фактическим аргументам в %L."
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Несоответствие типа в аргументе %qs в %L; передано %s в %s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Фактический аргумент предполагаемого типа в %L требует, чтобы формальный аргумент %qs был предполагаемого типа"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Фактический аргумент для %qs в %L должен быть полиморфным"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Фактический аргумент для %qs в %L должен иметь тот же декларированный тип"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Фактический аргумент для %qs в %L должен быть неограниченно полиморфным, так как формальный аргумент есть указатель или размещаемая неограниченно полиморфная сущность [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Фактический аргумент для %qs в %L должен быть комассивом"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Несоответствие корангов в аргументе %qs в %L (%d и %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Фактический аргумент для %qs в %L должен быть просто непрерывным или элементом такого массива"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть EVENT_TYPE или имеет EVENT_TYPE компонент"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Формальный аргумент %qs должен быть указателем или массивом предполагаемой формы или ранга без CONTIGUOUS атрибута - поскольку фактический аргумент в %L не является просто непрерывным и оба являются ASYNCHRONOUS или VOLATILE"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Передача комассива в %L в allocatable, noncoarray, INTENT(OUT) формальный аргумент %qs"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Передача комассива в %L в allocatable, noncoarray формальный аргумент %qs, что некорректно, если статус размещения модифицирован"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Полиморфный скаляр передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 #| msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Расширение: Скалярный неподразумеваемого вида, не-C_CHAR-вида CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Скалярный CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Аргумент с ключевым словом %qs в %L не в процедуре"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Аргумент с ключевым словом %qs в %L уже ассоциирован с другим фактическим аргументом"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Больше фактических чем формальных аргументов в вызове процедуры в %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Отсутствует спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неожиданная спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Неожиданная NULL() встроенная функция в %L для формального параметра %qs"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Пустой указатель в %L в неуказательный формальный параметр %qs"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Фактический аргумент в %L для формального параметра предполагаемого типа имеет производный тип с type-bound или FINAL процедурами"
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и указательным или размещаемым формальным аргументом %qs в %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и формальным аргументом предполагаемой формы %qs в %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Фактический аргумент в %L в размещаемый или указательный формальный аргумент %qs должен иметь типовый параметр отложенной длины тогда и только тогда, когда таковой имеется у формального"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Character длина фактического аргумента короче чем у формального аргумента %qs (%lu/%lu) в %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Фактический аргумент содержит слишком мало элементов для формального аргумента %qs (%lu/%lu) в %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Ожидался указатель на процедуру для аргумента %qs в %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Ожидалась процедура для аргумента %qs в %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Фактический аргумент для %qs не может быть массивом предполагаемого размера в %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Фактический аргумент для %qs должен быть указателем в %L"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Неуказательный фактический аргумент в %L в указательный формальный параметр %qs"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Коиндексированный фактический аргумент в %L в указательный формальный параметр %qs"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Коиндексированный фактический аргумент в %L в размещаемый формальный параметр %qs требует INTENT(IN)"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Коиндексированный ASYNCHRONOUS или VOLATILE фактический аргумент в %L требует, чтобы формальный параметр %qs не имел ни ASYNCHRONOUS ни VOLATILE"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Коиндексированный фактический аргумент в %L с размещаемым окончательным компонентом для формального параметра %qs требует либо VALUE либо INTENT(IN)"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Фактический аргумент CLASS массив для %qs должен быть полным массивом в %L"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Фактический аргумент для %qs должен быть ALLOCATABLE в %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Фактический аргумент секция массива с векторными индексами в %L несовместим с INTENT(OUT), INTENT(INOUT), VOLATILE или ASYNCHRONOUS атрибутом формального аргумента %qs"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент предполагаемой формы в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент секция массива в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Фактический аргумент pointer-array в %L требует assumed-shape или pointer-array формальный аргумент %qs из-за VOLATILE атрибута"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Отсутствует спецификация альтернативного возврата в вызове подпрограммы в %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Отсутствует фактический аргумент для аргумента %qs в %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Некорректный код компонента"
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Несоответствие списка"
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): поврежденные данные"
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Один и тот же фактический аргумент ассоциирован с INTENT(%s) аргументом %qs и INTENT(%s) аргументом %qs в %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Несоответствие списка"
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуры в %L локален в PURE процедуре и имеет POINTER атрибут"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Коиндексированный фактический аргумент в %L в процедуре PURE передан в аргумент INTENT(%s)"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Коиндексированный фактический аргумент в %L в PURE процедуре передан в POINTER формальный аргумент"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Коиндексированный полиморфный фактический аргумент в %L передан в полиморфный формальный аргумент %qs"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура %qs вызванная в %L не декларирована явно"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура %qs вызвана с неявным интерфейсом в %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Указательный объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Размещаемый объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Размещаемая функция %qs в %L должна иметь явный функциональный интерфейс"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Explicit interface required for component %qs at %L: %s"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Аргумент с ключевым словом требует явный интерфейс для процедуры %qs в %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Аргумент предполагаемого типа %s в %L требует явный интерфейс"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Фактический аргумент LOCK_TYPE или с LOCK_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Фактический аргумент EVENT_TYPE или с EVENT_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD аргумент в NULL требуется в %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Аргумент предполагаемого ранга требует явный интерфейс в %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Компонент указатель на процедуру %qs вызван с неявным интерфейсом в %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Аргумент с ключевым словом требует явный интерфейс для компонента указателя на процедуру %qs в %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= требуется в NULL() аргументе в %L: Неоднозначность между конкретными функциями %s и %s"
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Не удается найти символ %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Сущность %qs в %L уже присутствует в интерфейсе"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Некорректный тип интерфейса"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC %qs at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Не удалось перебить GENERIC %qs в %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs в %L перебивает связывание процедуры декларированной NON_OVERRIDABLE"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs в %L не должно быть DEFERRED, поскольку это перебивает не-DEFERRED связывание"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs в %L перебивает PURE процедуру и должна также быть PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs в %L перебивает ELEMENTAL процедуру и должна также быть ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs в %L перебивает не-ELEMENTAL процедуру и не должна быть ELEMENTAL, также"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs в %L перебивает SUBROUTINE и должна также быть SUBROUTINE"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs в %L перебивает FUNCTION и должна также быть FUNCTION"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Несоответствие результатов для перебивающей процедуры %qs в %L: %s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs в %L перебивает PUBLIC процедуру и не должна быть PRIVATE"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Формальный аргумент %qs от %qs в %L должен именоваться %qs, чтобы подходить соответствующему аргументу перебиваемой процедуры"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Несоответствие аргументов для перебивающей процедуры %qs в %L: %s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs в %L должен иметь то же число формальных аргументов, что и перебиваемая процедура"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs в %L перебивает NOPASS связывание и должен также быть NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs в %L перебивает связывание с PASS и должен также быть PASS"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object формальный аргумент от %qs в %L должен быть на той же позиции, что и passed-object формальный аргумент перебиваемой процедуры"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO формальный аргумент в %L должен быть типа %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO формальный аргумент в %L должен быть KIND = %d"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO формальный аргумент в %L должен быть скаляром"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO формальный аргумент в %L должен быть ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO формальный аргумент в %L должен иметь INTENT %s"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Альтернативный возврат в %L не допускается в DTIO процедуре"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO процедура %qs в %L должна быть подпрограммой"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Слишком мало формальных аргументов в DTIO процедуре %qs в %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Слишком много формальных аргументов в DTIO процедуре %qs в %L"
@@ -63706,74 +63788,74 @@ msgstr "ALTERNATE RETURN не разрешается в %L"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "Несоответствие типа в аргументе %qs в %L; передано %s в %s"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr "resolve_intrinsic(): Слишком много аргументов для встроенной функции"
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "do_simplify(): Слишком много аргументов для встроенной функции"
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "init_arglist(): слишком много аргументов"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "Некорректный стандартный код во встроенной функции %qs (%d)"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "Встроенная функция %qs (есть %s) использована в %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "Функция %qs как инициализационное выражение в %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "трансформационная встроенная функция %qs в %L некорректна в инициализационном выражении"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Элементная функция как инициализационное выражение с non-integer/non-character аргументами в %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Вызов подпрограммы во встроенную функцию %qs в DO CONCURRENT блоке в %L не есть PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Вызов подпрограммы во встроенную функцию %qs в %L не есть PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Расширение: Преобразование из %s в %s в %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Преобразование из %s в %s в %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Возможное изменение значения в преобразовании из %s в %s в %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Преобразование из %s в %s в %L"
@@ -63781,24 +63863,24 @@ msgstr "Преобразование из %s в %s в %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Не удалось преобразовать %s в %s в %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %qs to %qs at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Не удалось преобразовать %qs в %qs в %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -64168,13 +64250,13 @@ msgstr "ACTION тип конфликтует с READONLY спецификато
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "BLANK= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -64186,7 +64268,7 @@ msgstr "DECIMAL= в %C не допускается в Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "ENCODING= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -64236,7 +64318,7 @@ msgstr "CLOSE оператор в %L требует UNIT номер"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT номер в CLOSE операторе в %L должен быть неотрицательным"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s оператор не допускается в PURE процедуре в %C"
@@ -64332,7 +64414,7 @@ msgstr "NAMELIST %qs в READ операторе в %L содержит симв
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L является полиморфным и требует определенную процедуру ввода/вывода"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L с ALLOCATABLE или POINTER компонентами"
@@ -64401,7 +64483,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Ожидалось выражение в %s операторе в %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "синтаксическая ошибка в %s операторе в %C"
@@ -64417,87 +64499,87 @@ msgstr "Внутренний файл в %L со списком имен"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "DATA оператор в %C не допускается в PURE процедуре"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "PAD= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "DELIM= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT список имен в %C является расширением"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "END тег в %C не допускается в операторе вывода"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Ожидалась запятая в I/O списке в %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT оператор в %C не допускается внутри PURE процедуры"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE оператор не допускается в PURE процедуре в %C"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH тег некорректен в INQUIRE операторе в %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE оператор в %L не может содержать оба спецификатора FILE и UNIT"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE оператор в %L требует либо FILE либо UNIT спецификатор"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "UNIT номер в INQUIRE операторе в %L должен быть %d"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE оператор в %L требует PENDING= спецификатор с ID= спецификатором"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT в %C не допускается в Fortran 95"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT оператор не допускается в PURE процедуре в %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -64756,509 +64838,509 @@ msgstr "Мусор после ASSOCIATE оператора в %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Производный тип %qs в %L не может быть ABSTRACT"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Некорректная спецификация типа в %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Синтаксическая ошибка в FORALL итераторе в %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "DO CONCURRENT конструкция в %C"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Имя %qs в %s операторе в %C неизвестно"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Имя %qs в %s операторе в %C не является именем конструкции"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s оператор в %C покидает CRITICAL конструкцию"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s оператор в %C покидает DO CRITICAL конструкцию"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%s оператор в %C не внутри конструкции"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s оператор в %C не внутри конструкции %qs"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "CYCLE оператор в %C не применим к нециклической конструкции %qs"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "EXIT оператор без имени do-конструкции в %C"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s оператор в %C не применим к конструкции %qs"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s оператор в %C, покидающий OpenACC структурный блок"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "%s оператор в %C, покидающий OpenMP структурный блок"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "EXIT оператор в %C, терминирующий !$ACC LOOP цикл"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "CYCLE оператор в %C для не самого внутреннего сжатого !$ACC LOOP цикла"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "CYCLE оператор в %C для не самого внутреннего сжатого !$ACC LOOP цикла"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "EXIT оператор в %C, терминирующий !$OMP DO цикл"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "CYCLE оператор в %C для не самого внутреннего сжатого !$OMP DO цикла"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "Пробел требуется в %s операторе около %C"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "STOP код в %C не может быть отрицательным"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr "STOP код в %C содержит слишком много цифр"
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "%s оператор в %C в PURE процедуре"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "Оператор управления внешним видом STOP в %C в CRITICAL блоке"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "Оператор управления внешним видом STOP в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr "STOP код в %L должен быть скалярной CHARACTER константой или digit[digit[digit[digit[digit]]]]"
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "STOP код в %L должен быть скалярной CHARACTER константой или digit[digit[digit[digit[digit]]]]"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "STOP код в %L должен быть либо INTEGER либо CHARACTER типа"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "STOP код в %L должен быть скаляром"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "STOP код в %L должен быть default character KIND=%d"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP код в %L должен быть default integer KIND=%d"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "PAUSE оператор в %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ERROR STOP оператор в %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "Оператор управления внешним видом EVENT %s в %C в PURE процедуре"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "Оператор управления внешним видом EVENT %s в %C в CRITICAL блоке"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "Оператор управления внешним видом EVENT %s в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr "Избыточный STAT тег найден в %L"
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "Избыточный ERRMSG тег найден в %L"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "Избыточный UNTIL_COUNT тег найден в %L"
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "EVENT POST оператор в %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "EVENT WAIT оператор в %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "FAIL IMAGE оператор в %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "Оператор FROM TEAM в %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "Оператор CHANGE TEAM в %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Оператор управления внешним видом %s в %C в PURE процедуре"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Оператор управления внешним видом %s в %C в CRITICAL блоке"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Оператор управления внешним видом %s в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "Избыточный ACQUIRED_LOCK тег найден в %L"
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "LOCK оператор в %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "UNLOCK оператор в %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Оператор управления внешним видом SYNC в %C в PURE процедуре"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "SYNC оператор в %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "Оператор управления внешним видом SYNC в %C в CRITICAL блоке"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "Оператор управления внешним видом SYNC в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ASSIGN оператор в %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Assigned GOTO оператор в %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Список меток операторов в GOTO в %C не может быть пустым"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Вычисляемый GOTO в %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Ошибка в спецификации типа в %L"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "typespec в ALLOCATE в %L"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "Неожиданный %s оператор в %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Некорректный allocate-object в %C для PURE процедуры"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE комассива в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE комассива в %C в CRITICAL блоке"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "Allocate-object в %L не есть ни указатель на данные ни размещаемая переменная"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Тип сущности в %L есть тип несовместимый с typespec"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Вид параметра типа для сущности в %L отличается от вида параметра типа из typespec"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Спецификация формы для размещаемого скаляра в %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "STAT tag at %L cannot be a constant"
 msgstr "Переменная цикла в %C не может быть комассивом"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG тег в %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE тег в %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr "Избыточный SOURCE тег найден в %L"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "SOURCE тег в %L конфликтует с typespec в %L"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "SOURCE тег в %L с более чем одним размещаемым объектом"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD тег в %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "Избыточный MOLD тег найден в %L"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "MOLD тег в %L конфликтует с typespec в %L"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object в %L с параметром отложенного типа требует либо type-spec либо SOURCE тег либо MOLD тег"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Неограниченный полиморфный allocate-object в %L требует или спецификацию типа или SOURCE тег или MOLD тег"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "Указательный объект в %C не должен быть коиндексирован"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Некорректный allocate-object в %C для PURE процедуры"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE комассива в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE комассива в %C в CRITICAL блоке"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allocate-object в %C не есть непроцедурный указатель или размещаемая переменная"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG в %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "Оператор управления внешним видом RETURN в %C в CRITICAL блоке"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "Оператор управления внешним видом RETURN в %C в DO CONCURRENT блоке"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Alternate RETURN оператор в %C допускается только внутри SUBROUTINE"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN оператор в главной программе в %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Ожидалась ссылка на компонент в %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Мусор после CALL в %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Ожидалась type-bound процедура или компонент указатель на процедуру в %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Синтаксическая ошибка в имени common блока в %C"
@@ -65266,227 +65348,227 @@ msgstr "Синтаксическая ошибка в имени common блок
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "Переменная %qs в %L в common блоке %qs at %C должна быть декларирована с C совместимым видом, поскольку common блок %qs есть bind(c)"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "Переменная %qs в common блоке %qs at %C не может быть bind(c), поскольку она не является глобальной"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Символ %qs в %C уже в COMMON блоке"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Инициализированный символ %qs в %C может быть только COMMON в BLOCK DATA"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Спецификация массива для символа %qs в COMMON в %C должна быть явной"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Символ %qs в COMMON в %C не может быть POINTER массивом"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Символ %qs в COMMON блоке %qs в %C становится косвенно эквивалентным другому COMMON блоку %qs"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "BLOCK DATA construct at %L"
 msgstr "BLOCK конструкция в %C"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Имя NAMELIST группы %qs в %C уже имеет базовый тип %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Имя NAMELIST группы %qs в %C уже USE ассоциировано и не может быть респецифицировано."
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Массив предполагаемого размера %qs в списке имен %qs в %C не допускается"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Компонент производного типа %C не есть разрешенный EQUIVALENCE член"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Ссылка на массив в EQUIVALENCE в %C не может быть секцией массива"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE в %C требует два или более объектов"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Попытка косвенно перекрыть COMMON блоки %s и %s посредством EQUIVALENCE в %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Ожидается запятая в EQUIVALENCE в %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "VALUE statement at %C"
 msgid "EQUIVALENCE statement at %C"
 msgstr "VALUE оператор в %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Оператор функция в %L рекурсивна"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Оператор функция %qs в %L не допускается в качестве фактического аргумента"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "Оператор функция в %L не может появляться внутри INTERFACE"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Оператор функция в %C"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "Выражение в CASE селекторе в %L не может быть %s"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Ожидалось инициализационное выражение в CASE в %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Ожидалось имя блока %qs SELECT конструкции в %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "SUBMODULE декларация в %C не может появляться внутри другой области видимости"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "ошибка разбора в SELECT TYPE операторе в %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Селектор в SELECT TYPE в %C не есть именованная переменная; используйте associate-name=>"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "LOCK оператор в %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in SELECT TYPE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "ошибка разбора в SELECT TYPE операторе в %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неожиданный CASE оператор в %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксическая ошибка в CASE спецификации в %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неожиданный TYPE IS оператор в %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Спецификация типа не должна специфицировать sequence производный тип или тип с BIND атрибутом в SELECT TYPE в %C [F2003:C815]"
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксическая ошибка в TYPE IS спецификации в %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксическая ошибка в CLASS IS спецификации в %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Неожиданный END оператор в %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Синтаксическая ошибка в CASE спецификации в %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE оператор в %C не заключен в WHERE блок"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Метка %qs в %C не соответствует WHERE метке %qs"
@@ -65527,12 +65609,12 @@ msgstr "match_level_4(): Некорректный оператор"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Неопределенный тип"
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Неопределенный тип"
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Некорректный код"
@@ -66229,8 +66311,8 @@ msgstr "Неявно декларированная подпрограмма %s
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "параметр ORDERED клаузулы меньше чем COLLAPSE в %L"
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF клаузула в %L требует скалярное LOGICAL выражение"
@@ -67654,177 +67736,177 @@ msgstr "Неожиданный %<%c%> для переменной непроиз
 msgid "Expected structure component name at %C"
 msgstr "Ожидалось имя компонента структуры в %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "UNTIL_COUNT= аргумент в %L должен быть скалярным INTEGER выражением"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Ожидался список аргументов в %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "KIND параметр %s в %L должен быть инициализационным выражением"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "Компонент указатель на процедуру %qs требует список аргументов в %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "Неполиморфная ссылка на абстрактный тип в %C"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Внутренний компонент указатель на процедуру в %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): Выражение не является переменной"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_caf_attr(): Выражение не является переменной"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_caf_attr(): Некорректная ссылка на массив"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Конструктор структуры с отсутствующими необязательными аргументами в %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "Нет инициализатора для размещаемого компонента %qs данного в конструкторе структуры в %C"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "Нет инициализатора для компонента %qs данного в конструкторе структуры в %C"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 #| msgid "Can't construct ABSTRACT type %qs at %L"
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "Невозможно сконструировать ABSTRACT тип %qs в %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "Конструктор структуры с именованными аргументами в %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr "Инициализатор компонента без имени после компонента именуемого %s в %L"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "Слишком много компонентов в конструкторе структуры в %L"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "CHARACTER выражение будет усечено в присваивании (%ld/%ld) в %L"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Компонент %qs инициализирован дважды в конструкторе структуры в %L"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Коиндексное выражение для компонента указателя %qs в конструкторе структуры в %L"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "компонент %qs в %L уже был установлен конструктором родительского производного типа"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr "%%LOC() как rvalue в %C"
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "%qs в %C является именем рекурсивной функции и ссылается на результирующую переменную. Используйте явную переменную RESULT для прямой рекурсии (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Символ в %C не годится для выражения"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Неожиданное использование имени подпрограммы %qs в %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Оператор функция %qs требует список аргументов в %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "Функция %qs требует список аргументов в %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Отсутствует аргумент для %qs в %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The leftmost part-ref in a data-ref can not be a function reference at %C"
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr "Самый левый part-ref в data-ref не может быть ссылкой на функцию в %C"
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Отсутствует список аргументов в функции %qs в %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Производный тип %qs не может быть использован как переменная в %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Именованная константа в %C в EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%qs в %C не является переменной"
@@ -68159,499 +68241,499 @@ msgstr "%qs в %L неоднозначно"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC процедура %qs не допускается как фактический аргумент в %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Тип специфицированный для встроенной функции %qs в %L игнорируется"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Встроенная подпрограмма %qs в %L не должна иметь спецификатор типа"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%qs декларированная INTRINSIC в %L не существует"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Встроенная %qs декларированная INTRINSIC в %L недоступна в установках текущего стандарта кроме %s. Используйте подходящую %<-std=*%> опцию или включите %<-fall-intrinsics%>, чтобы использовать её."
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Не-RECURSIVE процедура %qs в %L возможно вызывает себя рекурсивно.  Объявите её RECURSIVE или используйте %<-frecursive%>"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %d используемая в %L нигде не определяется"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is used as actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Внутренняя процедура %qs использована как фактический аргумент в %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Оператор функция %qs в %L не допускается в качестве фактического аргумента"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Встроенная %qs в %L не допускается в качестве фактического аргумента"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Внутренняя процедура %qs использована как фактический аргумент в %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL не-INTRINSIC процедура %qs не допускается в качестве фактического аргумента в %L"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Невозможно найти конкретную INTRINSIC процедуру для ссылки %qs в %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Символ %qs в %L неоднозначен"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Аргумент по значению в %L нечислового типа"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Аргумент по значению в %L не может быть массивом или секцией массива"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Аргумент по значению в %L не допускается в этом контексте"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Передача внутренней процедуры в %L по расположению не допускается"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Компонент указатель на ELEMENTAL процедуру %qs не допускается в качестве фактического аргумента в %L"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Коиндексированный фактический аргумент в %L с окончательным компонентом указателем"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%qs в %L есть массив и OPTIONAL; ЕСЛИ ОН ОПУЩЕН, он не может быть фактическим аргументом ELEMENTAL процедуры кроме случая, когда есть обязательный аргумент того же ранга (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Фактический аргумент в %L для INTENT(%s) формального параметра %qs ELEMENTAL подпрограммы %qs есть скаляр, но другой фактический аргумент является массивом"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Несоответствие возвращаемого типа функции %qs в %L (%s/%s)"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Несоответствие интерфейса в глобальной процедуре %qs в %L: %s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Нет конкретной функции для generic %qs в %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generic функция %qs в %L несовместима с конкретным встроенным интерфейсом"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Функция %qs в %L есть INTRINSIC, но не является совместимой со встроенной"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не удается разрешить конкретную функцию %qs в %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип. Может имелось в виду %qs?"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Ссылка на impure функцию %qs в %L внутри FORALL %s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Ссылка на impure функцию %qs в %L внутри DO CONCURRENT %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Ссылка на impure функцию %qs в %L внутри PURE процедуры"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after NOWAIT clause at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Неожиданный мусор после NOWAIT клаузулы в %C"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs в %L не есть функция"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs не должна фигурировать в %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Функция %qs декларирована CHARACTER(*) и не может использоваться в %L, поскольку это не формальный аргумент"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): некорректный тип функции"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Определенная пользователем не-ELEMENTAL функция %qs в %L не допускается в WORKSHARE конструкции"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs в %L не может вызываться рекурсивно, поскольку функция %qs не есть RECURSIVE"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Функция %qs в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Вызов подпрограммы %qs в FORALL блоке в %L не есть PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Вызов подпрограммы %qs в DO CONCURRENT блоке в %L не есть PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Вызов подпрограммы %qs в %L не есть PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Нет конкретной подпрограммы для generic %qs в %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generic подпрограмма %qs в %L несовместима с интерфейсом встроенной подпрограммы"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Подпрограмма %qs в %L есть INTRINSIC, но несовместима со встроенной"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Не удается разрешить конкретную подпрограмму %qs в %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs в %L имеет тип, который несовместим с CALL в %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs в %L не может вызываться рекурсивно, поскольку подпрограмма %qs не есть RECURSIVE"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): некорректный тип функции"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Формы для операндов в %L и %L не являются подобными"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Некорректная встроенная функция"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "always_inline function might not be inlinable"
 msgid "Impure function at %L might not be evaluated"
 msgstr "always_inline функция, возможно, не годится для подстановки"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Аргумент по значению в %L не может быть массивом или секцией массива"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Некорректная встроенная функция"
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Некорректное выражение"
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в коизмерении %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в коизмерении %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Некорректный нулевой шаг в %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Некорректная ссылка на массив"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Самая правая верхняя граница секции массива предполагаемой формы не задана в %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие коиндексных рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Коиндекс коразмерности %d должен быть скаляром в %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс массива в %L должен быть скаляром"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс массива в %L должен быть INTEGER типа, найдено %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL индекс массива в %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент dim в %L должен быть скаляром"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент dim в %L должен быть INTEGER типа"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Отсутствует спецификация"
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): неиспользуемый as(1)"
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): неиспользуемый as(2)"
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс массива в %L является массивом ранга %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Начальный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Начальный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Начальный индекс подстроки в %L меньше единицы"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Конечный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Конечный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Конечный индекс подстроки в %L превышает длину строки"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Конечный индекс подстроки в %L слишком велик"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Некорректная ссылка на массив"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь POINTER атрибут в %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь ALLOCATABLE атрибут в %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Две или больше частичные ссылки с ненулевым рангом не должны быть заданы в %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, fuzzy, gcc-internal-format
 #| msgid "expression_rank(): Two array specs"
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "expression_rank(): Две спецификации массива"
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом может использоваться только как фактический аргумент"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Переменная предполагаемого типа %s в %L может использоваться только как фактический аргумент"
@@ -68660,12 +68742,12 @@ msgstr "Переменная предполагаемого типа %s в %L м
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Переменная предполагаемого типа %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Переменная предполагаемого ранга %s в %L может использоваться только как фактический аргумент"
@@ -68674,284 +68756,284 @@ msgstr "Переменная предполагаемого ранга %s в %L
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Переменная предполагаемого ранга %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого типа %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого ранга %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs, использованная в спецификационном выражении, фигурирует в %L до ENTRY оператора, в котором она является параметром"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs используется в %L до оператора ENTRY, в котором она является параметром"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Полиморфный подобъект коиндексированного объекта в %L"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коиндексированный объект с полиморфным размещаемым подкомпонентом в %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Ошибка в спецификации типа в %L"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Передаваемый объект в %L должен быть скаляром"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип %qs'"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип %qs"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовый объект для вызова NOPASS type-bound процедуры в %L должен быть скаляром"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC %qs в %L"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs в %L должна быть SUBROUTINE"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Некорректный тип выражения"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "'%s' в %L должна быть скаляром"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s в %L должен быть integer"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s в %L должна быть INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Шаговое выражение в DO цикле в %L не может быть нулевым"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO цикл в %L будет выполнен ноль раз"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO цикл в %L является неопределенным, так как он переполняется"
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO цикл в %L является неопределенным, так как он теряет значимость"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL стартовое выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL конечное выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL шаговое выражение в %L не может быть нулевым"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL индекс %qs не может появляться в спецификации триплета в %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object в %L должен быть ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коиндексированный размещаемый объект в %L"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг, что и allocate-object в %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr в %L и allocate-object в %L должны иметь одинаковую форму"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сущности в %L есть тип несовместимый с source-expr в %L"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allocate-object в %L и source-expr в %L должны иметь одинаковый вид параметра типа"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа EVENT_TYPE и не должно иметь EVENT_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Размещение %s ABSTRACT базового типа в %L требует type-spec или source-expr"
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Размещение %s в %L с type-spec требует того же character-length параметра, что и в декларации"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Спецификация массива или SOURCE= выражение со значением массивом требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Спецификация комассива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация массива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Ожидалась '*' в спецификации коиндекса в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация комассива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG в %L бесполезно без STAT тега"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG переменная в %L должна быть стандартной скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Переменная Errmsg в %L не должна быть %sd в том же операторе %s"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object в %L также появляется в %L"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object в %L есть подобъект объекта в %L"
@@ -68960,287 +69042,287 @@ msgstr "Allocate-object в %L есть подобъект объекта в %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Выражение в CASE операторе в %L должно быть типа %s"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Выражение в CASE операторе в %L должно быть вида %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Выражение в CASE операторе в %L должно быть скаляром"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Выражение выбора в вычисляемом GOTO операторе в %L должно быть скалярным integer выражением"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Выражение в CASE операторе в %L не находится в диапазоне %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "За DEFAULT CASE в %L не может следовать второй DEFAULT CASE в %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логический диапазон в CASE операторе в %L не допускается"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константное логическое значение в CASE операторе повторяется в %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Спецификации диапазона в %L невозможно найти соответствие"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логический SELECT CASE блок в %L имеет более двух случаев"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Встроенная функция %qs в %L некорректна в присваивании указателя на процедуру"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs cannot be used as a variable at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Производный тип %qs не может быть использован как переменная в %C"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name %qs at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Селектор в %L не может быть NULL()"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Селектор в %L не имеет типа"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS селектор в %L требует временной переменной, которая пока не реализована"
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор должен быть полиморфным в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Селектор в %L не должен быть коиндексирован"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS в %L перекрывается с TYPE IS в %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Производный тип %qs в %L должен быть расширением %qs"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неожиданный встроенный тип %qs в %L"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Спецификация типа в %L должна специфицировать, что каждый параметр длины типа является предполагаемым"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Двойной CLASS IS блок в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Некорректный контекст для NULL () встроенной в %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s процедура в %L должна быть рекурсивной"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может быть полиморфным, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь ALLOCATABLE компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Элемент передачи данных в %L не может быть полной ссылкой на массив предполагаемого размера"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Event переменная в %L должна быть скаляром типа EVENT_TYPE"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом или коиндексированным"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом, но не коиндексированным"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG= аргумент в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK= аргумент в %L должна быть скалярной LOGICAL переменной"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT= аргумент в %L должен быть скалярным INTEGER выражением"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset аргумент в %L должен быть между 1 и num_images()"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %L не есть корректный оператор цели перехода для оператора перехода в %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Переход в %L может вызвать зацикливание"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO оператор в %L покидает CRITICAL конструкцию для метки в %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO оператор в %L покидает DO CONCURRENT конструкцию для метки в %L"
@@ -69248,188 +69330,189 @@ msgstr "GOTO оператор в %L покидает DO CONCURRENT констр
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Метка в %L не находится в том же блоке, что GOTO оператор в %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE маска в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE цель присваивания в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL определенное пользователем присваивание в WHERE в %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый оператор внутри WHERE в %L"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL с индексом %qs не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "BLOCK конструкция в %C"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL имя индекса в %L должно быть скалярной переменной типа integer"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Внешняя FORALL конструкция уже имеет индекс с этим именем %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE клаузула в %L требует LOGICAL массив"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Некорректный тип блока"
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER выражение будет усечено в присваивании (%ld/%ld) в %L"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коиндексированное выражение в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присваивание коиндексированной переменной в %L в PURE процедуре"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Присваивание полиморфному комассиву в %L не допускается"
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Присваивание размещаемой полиморфной переменной в %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Присваивание размещаемой полиморфной переменной в %L требует %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Неразмещаемая переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте, что имеется соответствующая конкретная подпрограмма для '=' оператора"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коиндексированная переменная не должна иметь размещаемых окончательных компонентов в присваивании в %L"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: type-bound определенные присваивания в %L не выполнены, так как несколько ссылок на части массива появятся в промежуточных выражениях."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Присваивание указателя на процедуру в %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Результат функции в левой части присваивания в %L должен иметь pointer атрибут."
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO оператор в %L требует INTEGER переменной"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Переменной %qs не присвоили целевую метку в %L"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternate RETURN оператор в %L требует SCALAR-INTEGER спецификатор возврата"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN оператор в %L требует скалярную подразумеваемого INTEGER переменную"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Некорректный NULL в %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Оператор арифметического IF в %L требует скалярное REAL или INTEGER выражение"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Нет выражения в DO WHILE"
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Условие выхода из DO WHILE цикла в %L должно быть скалярным LOGICAL выражением"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL клаузула маски в %L требует скалярное LOGICAL выражение"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Некорректный код оператора"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Переменная %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Переменная %qs из модуля %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L из модуля %qs"
@@ -69437,960 +69520,960 @@ msgstr "Переменная %qs из модуля %qs со связывающе
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Процедура %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Длина строки в %L слишком велика"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Размещаемый массив %qs в %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скалярный объект %qs в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Указатель на массив %qs at %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Массив %qs at %L не может иметь отложенную форму"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Тип %qs CLASS переменной %qs at %L не является расширяемым"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS переменная %qs в %L должна быть формальным параметром, размещаемой или указателем"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %qs не может быть host ассоциированным в %L, поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Выведенный SAVE для переменной модуля %qs в %L необходим из-за подразумеваемой инициализации"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сущность %qs в %L имеет параметр отложенного типа и требует либо POINTER либо ALLOCATABLE атрибут"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Массив из модуля или главной программы %qs в %L должен иметь константную форму"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сущность с предполагаемой character длиной в %L должна быть формальным аргументом или PARAMETER"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs в %L должна иметь константную character длину в этом контексте"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON переменная %qs в %L должна иметь константную character длину"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Размещаемая %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Формальный параметр %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Встроенная %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Результат функции %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Автоматический массив %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s в %L"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Оператор функция с character значением %qs в %L должна иметь константную длину"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs имеет PRIVATE тип и не может быть формальным аргументом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Процедура %qs в PUBLIC интерфейсе %qs в %L берет формальные аргументы %qs, который PRIVATE"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Функция %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Внешний объект %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL функция %qs в %L должна иметь скалярный результат"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Оператор функция %qs в %L не может иметь pointer или allocatable атрибут"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение массив"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) функция %qs в %L не может быть pure"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) функция %qs в %L не может быть рекурсивной"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) функция %qs в %L"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Указатель на процедуру %qs в %L не должен быть элементным"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Формальная процедура %qs в %L не должна быть элементной"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Переменная результата функции %s в %L элементной функции %qs не должна иметь атрибут ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в %qs в %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Результат указатель на процедуру %qs в %L оказался без pointer атрибута"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в ELEMENTAL атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в PURE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в RECURSIVE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s между MODULE PROCEDURE декларацией в MODULE %qs и декларацией в %L в (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL процедура %qs в %L не есть SUBROUTINE"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура в %L должна иметь ровно один аргумент"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент FINAL процедуры в %L должен быть типа %qs"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедуры в %L не должен быть POINTER"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедуры в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедуры в %L не должен быть OPTIONAL"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедуры в %L не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярная FINAL процедура в %L должна иметь аргумент предполагаемой формы"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL процедура %qs декларированная в %L имеет тот же ранг (%d), что и %qs"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Только массивные FINAL процедуры декларированные для производного типа %qs определенного в %L, предлагают также скалярный тип"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs и %qs не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC %qs в %L"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs и %qs для GENERIC %qs в %L неоднозначны"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Неопределенное конкретное связывание %qs как цели GENERIC %qs в %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs в %L должен нацеливаться на конкретное связывание, %qs также GENERIC"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs в %L не может перебить конкретное связывание с тем же именем"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound оператор в %L не может быть NOPASS"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Процедура %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура %qs с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Неполиморфный passed-object формальный аргумент %qs в %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object формальный аргумент %qs в %L должен быть скаляром"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть POINTER"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и компонент %qs"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и унаследованный компонент %qs"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Производный тип %qs декларированный в %L должен быть ABSTRACT, поскольку %qs есть DEFERRED и не перебивается"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Комассивный компонент %qs в %L должен быть размещаемым с отложенной формой"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Компонент %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Компонент %qs в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Компонент %qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Компонент %qs типа BIND(C) в %L должен иметь единичную длину"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Компонент указателя на процедуру %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Компонент указателя на процедуру %qs с PASS в %L должен иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть скаляром"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может иметь POINTER атрибут"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Компонент %qs от %qs в %L имеет то же имя, что и унаследованная type-bound процедура"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Character длина компонента %qs должна быть константным спецификационным выражением в %L"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Character компонент %qs от %qs в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "компонент %qs имеет PRIVATE тип и не может быть компонентом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Полиморфный компонент %s в %L в SEQUENCE или BIND(C) типе %s"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s SEQUENCE типа декларированный в %L не имеет SEQUENCE атрибут"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Конфликтующие инициализаторы в объединении в %L и %L"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Поскольку расширяющий тип %qs в %L имеет комассивный компонент, родительский тип %qs должен также иметь его"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Нерасширяемый производный тип %qs в %L не должен быть ABSTRACT"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Generic имя %qs функции %qs в %L то же, что и имя производного типа в %L"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Массив предполагаемого размера %qs в списке имен %qs в %L не допускается"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с предполагаемой формой в списке имен %qs в %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с неконстантной формой в списке имен %qs в %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST объект %qs с неконстантной character длиной в списке имен %qs в %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs был декларирован PRIVATE и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет use-associated PRIVATE компоненты и не может быть членом списка имен %qs в %L"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в %qs в %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter массив %qs at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно типизированный PARAMETER %qs в %L не соответствует более позднему IMPLICIT типу"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS переменная %qs в %L не может иметь PARAMETER атрибут"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Простите, размещаемые/указательные компоненты в комассивах полиморфных (CLASS) типов в %L не поддерживаются"
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив или массивом предполагаемой формы или предполагаемого ранга"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Массив предполагаемого ранга в %L не может иметь VALUE или CODIMENSION атрибут"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs в %L не может иметь VALUE атрибут, поскольку он не является формальным аргументом"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Character формальная переменная %qs в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C совместимая character формальная переменная %qs в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Производный тип %qs в %L имеет тип %qs, который не был определен"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутов должна быть формальным аргументом"
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть типа TYPE(*) или числового встроенного типа"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть или скаляром или массивом предполагаемого размера"
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Предполагаемый тип переменной %s в %L разрешен только для формальных переменных"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Переменная предполагаемого типа %s в %L не должна быть массивом явной формы"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Переменная %qs at %L не может быть BIND(C), поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs в %L PRIVATE производного типа %qs"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) формальный аргумент %qs в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа EVENT_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функции %qs в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Переменная %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Переменная %qs в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром, который не есть комассив"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Переменная %qs в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комассивная переменная %qs в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Размещаемая комассивная переменная %qs в %L должна иметь отложенную форму"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Переменная %qs в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная %qs в %L не допускается в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL формальная переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL результирующая переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Список имен %qs не может быть аргументом для подпрограммы или функции в %L"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET переменная %qs в %L не есть SAVEd"
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA элемент %qs в %L должен быть в COMMON"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA массив %qs в %L должен быть указан в предыдущей декларации"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA элемент %qs в %L не может иметь коиндекс"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA элемент %qs в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Метка %d в %L определена, но не используется"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Метка %d в %L определена, но не может быть использована"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L должна иметь SEQUENCE атрибут, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L не может иметь ALLOCATABLE компоненты, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Переменная производного типа %qs в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L с указательным(и) компонент(ами) не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Все или никакие объекты в EQUIVALENCE установленной в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именованная константа %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Массив %qs at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структуры %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC функция %qs в %L PRIVATE типа %qs"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура пользовательского оператора %qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура пользовательского оператора %qs в %L не может быть предполагаемой character длиной"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура пользовательского оператора %qs в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Внутренняя процедура %qs в %L PURE процедуры должна также быть PURE"
@@ -71086,154 +71169,154 @@ msgstr "%qs в %L имеет атрибуты специфицированные
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Символ %qs в %L конфликтует с символом из модуля %qs, use-associated в %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Символ %qs в %L уже имеет базовый тип %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Процедура %qs в %L не может иметь базовый тип %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Символ %qs в %L не может иметь тип"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Компонент %qs в %C уже в родительском типе в %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Символ %qs в %C неоднозначен"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Производный тип %qs в %C используется до своего определения"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонент %qs в %C есть PRIVATE компонент %qs"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs в %C не является элементом структуры %qs. Может имелось в виду %qs?"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs в %C не является элементом структуры %qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Повторная метка оператора %d в %L и %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Метка %d в %C уже фигурирует как цель перехода"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Метка %d в %C уже фигурирует как метка формата"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "завершающий оператор DO цикла не END DO или CONTINUE с меткой %d в %C"
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Метка %d в %C ранее использована как FORMAT метка"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Метка %d в %C ранее использована как цель перехода"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Разделяемая DO терминирующая метка %d в %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "LOCK оператор в %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Имя %qs в %C является неоднозначной ссылкой на %qs из модуля %qs"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Имя %qs в %C является неоднозначной ссылкой на %qs из текущей программной единицы"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Символ %qs в %C уже был host ассоциирован"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Данный символ неожиданно оказался NULL"
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Производный тип %qs декларированный в %L должен иметь BIND атрибут, чтобы быть C совместимым"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Производный тип %qs с BIND(C) атрибутом в %L пуст и может быть недоступен для C парного процессора"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент %qs в %L не может иметь POINTER атрибут, поскольку он является элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент указатель на процедуру %qs в %L не может быть элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент %qs в %L не может иметь ALLOCATABLE атрибут, поскольку он является элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Компонент %qs в производном типе %qs в %L может не быть C совместимым хотя производный тип %qs есть BIND(C)"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Компонент %qs в производном типе %qs в %L может не быть C совместимым"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Производный тип %qs в %L не может иметь SEQUENCE атрибут, поскольку он есть BIND(C)"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Символ %qs используется до своего типизирования в %L"
@@ -71270,85 +71353,85 @@ msgstr "Перекрывающиеся неравные инициализато
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Создание временного массива в %L для аргумента %qs"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Некорректный тип выражения при проходе (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "Именованный COMMON блок %qs at %L везде должен быть одного размера (%lu против %lu байт)"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "get_mpz(): Не целая константа"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr "element_number(): Некорректный тип размерности"
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Некорректная ссылка на массив в %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Некорректный тип ссылки в %L как EQUIVALENCE объект"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Противоречивые правила эквивалентности включающие %qs в %L и %qs в %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "Эквивалентность установленная для переменной %qs декларированной в %L нарушает требования выравнивания"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "Эквивалентность для %qs не соответствует упорядочению COMMON %qs в %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "Эквивалентность установленная для %qs вызывает некорректное расширение COMMON %qs at %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use -fno-align-commons"
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Заполнитель в %d байт требуется перед %qs в COMMON %qs в %L; измените порядок элементов или используйте -fno-align-commons"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use -fno-align-commons"
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Заполнитель в %d байт требуется перед %qs в COMMON в %L; измените порядок элементов или используйте -fno-align-commons"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr "COMMON %qs в %L не существует"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON %qs в %L требует %d байт заполнителя; измените порядок элементов или используйте %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON в %L требует %d байт заполнителя; измените порядок элементов или используйте %<-fno-align-commons%>"
@@ -71368,72 +71451,72 @@ msgstr "неконстантное инициализационное выраж
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "встроенная переменная, которая не является процедурой"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Возвращаемое значение функции %qs в %L не установлено"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Параметр отложенного типа пока не поддерживается"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "backend декларация для переменной модуля %qs уже существует"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Неиспользуемая PRIVATE переменная модуля %qs декларирована в %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Формальный аргумент %qs в %L был декларирован INTENT(OUT), но не был установлен"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Формальный аргумент производного типа %qs в %L был декларирован INTENT(OUT), но не был установлен и не имеет подразумеваемого инициализатора"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Неиспользуемый формальный аргумент %qs в %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Неиспользуемая переменная модуля %qs, которая была явно импортирована в %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Неиспользуемая переменная %qs декларирована в %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Неиспользуемый параметр %qs, который был явно импортирован в %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Возвращаемое значение %qs функции %qs декларированное в %L не установлено"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Извините, !$ACC DECLARE в %L не допускается в конструкции BLOCK"
@@ -71449,27 +71532,27 @@ msgstr "Не могу вычислить длину char массива в %L."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Код для переразмещения размещаемой переменной в %L будет добавлен"
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному объекту в %L не поддерживается"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному компоненту в %L не поддерживается"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Неизвестная встроенная операция"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Неизвестная функция списка аргументов в %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -71505,24 +71588,24 @@ msgstr "build_dt: формат со списком имен"
 msgid "Bad IO basetype (%d)"
 msgstr "Некорректный базовый тип ввода-вывода (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr "неявное отображение массива предполагаемого размера %qD"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "optional argument"
 msgid "optional class parameter"
 msgstr "необязательный аргумент"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "unhandled derived-type component"
 msgstr "аргумент параметризованного производного типа"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Некорректный код оператора"
@@ -71632,84 +71715,84 @@ msgstr "несоответствие скобок"
 msgid "unable to open file"
 msgstr "не удалось открыть файл"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "поток байткода: мусор в конце секции символов"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "невозможно разобрать шестнадцатеричное число"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "невозможно разобрать файловое смещение"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "неожиданное смещение"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "некорректная строка в файле разрешений"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "некорректное разрешение в файле разрешений"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "разрешение sub id %wx не в объектном файле"
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, fuzzy, gcc-internal-format
 #| msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "поток байткода в файле %qs сгенерирован с LTO версии %d.%d вместо ожидаемой %d.%d"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "cannot read LTO decls from %s"
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "ошибка чтения LTO деклараций из %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Ошибка открытия %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Ошибка отображения %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Ошибка чтения %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "ошибка открытия файла разрешения символов: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "ошибки при слиянии единиц трансляции"
@@ -72862,7 +72945,7 @@ msgstr "не задано имя макроса после %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "не задано имя файла после %qs"
@@ -73066,17 +73149,17 @@ msgstr "неизвестный алгоритм переупорядочения
 msgid "unknown TLS model %qs"
 msgstr "неизвестная модель генерации кода TLS %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "неизвестная ценовая модель векторизатора %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "некорректный тип видимости %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "неизвестный vtable verify приоритет инициализации %qs"
diff --git a/gcc/po/sr.po b/gcc/po/sr.po
index 6d52172ade5..2d47f5f14cb 100644
--- a/gcc/po/sr.po
+++ b/gcc/po/sr.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -2124,18 +2124,18 @@ msgstr "модификатор дужине у формату strfmon"
 msgid "<command-line>"
 msgstr "<командна-линија>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
@@ -2143,76 +2143,76 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "invalid operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "недостаје операнд"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "неисправна ија:"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "неисправан %%d операнд"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "неисправна адреса"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2228,18 +2228,18 @@ msgid "invalid %%r value"
 msgstr "неисправна %%r вредност"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "неисправна %%R вредност"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
@@ -2269,7 +2269,7 @@ msgstr "неисправна %%M вредност"
 msgid "invalid %%U value"
 msgstr "неисправна %%U вредност"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
@@ -2279,7 +2279,7 @@ msgstr "неисправна %%s вредност"
 msgid "invalid %%C value"
 msgstr "неисправна %%C вредност"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
@@ -2289,10 +2289,10 @@ msgstr "неисправна %%E вредност"
 msgid "unknown relocation unspec"
 msgstr "непознато unspec релокације"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "неисправан %%xn кôд"
@@ -2381,36 +2381,36 @@ msgstr "неисправан УНСПЕЦ као операнд"
 msgid "unrecognized supposed constant"
 msgstr "непрепозната претпостављена константа"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "неисправан операнд помака"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикатна инструкција Тамба"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикатна инструкција у условном редоследу"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2418,14 +2418,14 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "инструкција се никад не извршава"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2562,7 +2562,7 @@ msgstr "неочекиван операнд"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2781,27 +2781,27 @@ msgstr "лош операнд output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "лош операнд output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand %%xn code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "c4x_operand_subword: invalid mode"
 msgid "operand %%xn code invalid for QImode"
 msgstr "c4x_operand_subword: неисправан режим"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid fp constant"
@@ -2965,7 +2965,7 @@ msgstr "неисправна операција на %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неисправан %%P операнд"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -3023,7 +3023,7 @@ msgid "post-increment address is not a register"
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -3080,8 +3080,8 @@ msgstr "‘%s’ није исправно име класе"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -3224,182 +3224,236 @@ msgstr "Нема места на стеку.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Покушајте да покренете ‘%s’ у шкољци да повећате ограничење.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Користи хардверски покретан зарез"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "Искључи индексно адресирање"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%H value"
+msgid "invalid %%A value"
+msgstr "неисправна %%H вредност"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "неисправна %%D вредност"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "неисправно претварање из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "неисправно претварање у %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "неисправно претварање из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "неисправно претварање у %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "неисправно претварање из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "неисправно претварање у %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "неисправно претварање из %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "неисправно претварање у %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3410,102 +3464,102 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "не могу да разложим адресу"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "неисправан операнд за модификатор ‘O’"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "неисправан кôд излаза операнада"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "неисправан израз као операнд"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "циљеви показивача у повратку разликују се у означености"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3790,8 +3844,8 @@ msgstr "<анонимно>"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
@@ -3811,7 +3865,7 @@ msgstr "очекивано је %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -3820,7 +3874,7 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -3841,13 +3895,13 @@ msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -3855,8 +3909,8 @@ msgstr "очекивано је %<{%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -3867,13 +3921,13 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -3883,7 +3937,7 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -3895,20 +3949,20 @@ msgstr "очекивано је %<{%>"
 msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -3917,20 +3971,20 @@ msgstr "очекивано је %<,%> или %<;%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
@@ -3941,7 +3995,7 @@ msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -3954,19 +4008,19 @@ msgstr "очекивано је %<{%>"
 msgid "expected label"
 msgstr "Очекивано је име"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "type %qs has a user-defined constructor"
 msgid "  after user-defined conversion:"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -3976,19 +4030,19 @@ msgstr[1] "кандидат 1:"
 msgstr[2] "кандидат 1:"
 msgstr[3] "кандидат 1:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "скок на етикету %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "скок на етикету случаја"
 
@@ -4098,7 +4152,7 @@ msgstr "шаблонски параметар %q+#D"
 msgid "<statement>"
 msgstr "очекивана је наредба"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown src"
 msgid "<unknown>"
@@ -4296,50 +4350,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "погрешан тип аргумента уз унарно минус"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "погрешан тип аргумента уз битски комплемент"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "погрешан тип аргумента за abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "погрешан тип аргумента за конјугацију"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4383,19 +4437,19 @@ msgstr "Недозвољени знак у БОЗ константи код %C"
 msgid "elemental binary operation"
 msgstr "Елементална бинарна операција"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "различити облици аргумената ‘%s’ и ‘%s’ код %L за сопствено ‘dot_product’"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "различити облици аргумената ‘%s’ и ‘%s’ код %L за сопствено ‘dot_product’"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
@@ -4471,7 +4525,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Погон:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -4488,7 +4542,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4594,11 +4648,11 @@ msgstr "блоковско IF"
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "додела показивача"
 
@@ -4606,250 +4660,250 @@ msgstr "додела показивача"
 msgid "simple IF"
 msgstr "једноставно IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 #, fuzzy
 #| msgid "elemental subroutine"
 msgid "elemental procedure"
 msgstr "елементални потпрограм"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "додела показивача"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "без аргумената"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "неисправан типски аргумент"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарног бројевног оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди бинарног бројевног оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнди оператора надовезивања ниски код %%L су %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди логичког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Операнд оператора .NOT. код %%L је %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Комплексне величине се не могу поредити код %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логичке код %%L морају бити поређене са %s уместо %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди оператора поређења ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд корисничког оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди корисничког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4862,27 +4916,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 #, fuzzy
 #| msgid "assignment of read-only location"
 msgid "Assignment of scalar to unallocated array"
@@ -4966,7 +5020,7 @@ msgstr "Синтаксна грешка у наредби %s код %C"
 msgid "Assigned label is not a target label"
 msgstr "Додељена етикета није етикета циља"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5459,7 +5513,7 @@ msgstr "Упозори на аритметику са функцијским п
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6102,8 +6156,8 @@ msgstr "Додај подвлаке споља видљивим именима"
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
@@ -8841,109 +8895,103 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr ""
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Упозори на променљиве које се саме успостављају"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "Попиши разне унутрашње ствари компилатора у датотеку"
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "Dump various analyzer internals to stderr."
 msgstr "Попиши разне унутрашње ствари компилатора у датотеку"
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13901,10 +13949,9 @@ msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:572
-#, fuzzy, no-c-format
-#| msgid "Use Branch Likely instructions, overriding the architecture default"
-msgid "Use instructions for a future architecture."
-msgstr "Користи инструкције извесног гранања, потискујући подразумевано за архитектуру"
+#, no-c-format
+msgid "Use instructions added in ISA 3.1."
+msgstr ""
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13917,6 +13964,12 @@ msgstr "Не стварај инструкције стопљеног множе
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate load/store with update instructions"
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Стварај инструкције учитавања/складиштења са ажурирањем"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -19456,7 +19509,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -20187,409 +20240,409 @@ msgstr "Одмотај петљу када се зна број итерациј
 msgid "Perform loop unrolling for all loops."
 msgstr "Одмотај све петље"
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Дозволи математичке оптимизације које могу прекршити ИЕЕЕ или ИСО стандарде"
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Изврши одусловљавање петљи"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Изврши љушћење петљи"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Само створи табеле одмотавања за руковање изузецима"
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, fuzzy, no-c-format
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
-#: common.opt:2987
+#: common.opt:2991
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Укључи распростирање копирања за складиштења и учитавања"
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Додај допунске коментаре у испису асемблера"
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Користи профиле вредности израза у оптимизацијама"
 
-#: common.opt:3048
+#: common.opt:3052
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Конструиши мреже и подели неповезане употребе једне променљиве"
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Изврши оптимизације целог програма"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Стави податке успостављене на нулу у одељак bss"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Стварај исправљачке информације у формату ДВАРФа 2"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Стварај исправљачке информације у подразумеваном проширеном формату"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Створи јединствену излазну тачку за сваку функцију"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Стварај исправљачке информације у формату СТАБСа"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Стварај исправљачке информације у проширеном формату СТАБСа"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Стварај исправљачке информације у формату ИксКОФФа"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Стварај исправљачке информације у проширеном формату ИксКОФФа"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Стварај инструкције isel"
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Стави излаз у <file>"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "Укључи профилисање функција"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Као -pedantic али их издај као грешке"
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Не приказуј компиловане функције или протекло време"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Укључи опширан излаз"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Прикажи верзију компилатора"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Сузбиј упозорења"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library."
 msgstr "Укључи дељене библиотеке на основу ИДа"
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21846,8 +21899,8 @@ msgstr "Граница броја провера током извршавања
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Граница броја провера током извршавања које умеће векторизаторово верзионисање петљи"
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "израчуната вредност се не користи"
@@ -21883,7 +21936,7 @@ msgid "expected boolean type"
 msgstr "Очекиван је тип израза"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -21970,7 +22023,7 @@ msgstr "без аргумената"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -22426,7 +22479,7 @@ msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -22517,12 +22570,12 @@ msgstr "атрибути типа игноришу се пошто је тип 
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -22540,8 +22593,8 @@ msgstr "атрибут %qE се игнорише"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -22675,7 +22728,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr "померај ван граница константне ниске"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -22985,7 +23038,7 @@ msgstr "недостаје аргумент за „%s“"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -23300,13 +23353,13 @@ msgstr "сукоб asm продрмавања са излазним операн
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "сукоб asm продрмавања са улазним операндом"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "not protecting local variables: variable length buffer"
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "не штитим локалне променљиве: бафер променљиве величине"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not protecting function: no buffer at least %d bytes long"
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
@@ -23851,313 +23904,313 @@ msgstr "основни блокови нису положени надовезу
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "број об. белешки у ланцу ија (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "број ивица позивача је негативан"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "missing direct call for speculation %i"
 msgstr "Недостаје одредница димензија код %C"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use control speculation"
 msgid "missing ref for speculation %i"
 msgstr "Направи спекулацију контроле"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "елемент успостављача није константан"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Претпостави да симболи могу бити неважећи"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "PIC code generation is not compatible with fast indirect calls"
 msgid "edge count is not compatible with function count"
 msgstr "стварање ПИЦ кôда није сагласно са брзим посредним позивима"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "показивач inlined_to је погрешан"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "вишеструки уткани позивачи"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "показивач inlined_to постављен за неуткане позиваче"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "показивач inlined_to постављен али нема претходника"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "показивач inlined_to упућује на самог себе"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "дељени call_stmt:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "ивица показује на погрешну декларацију:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "недостаје графпоз ивица за call_stmt:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "очекивана је наредба"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node није успело"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -24256,12 +24309,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F употребљено али недефинисано"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
@@ -24434,7 +24487,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
@@ -24786,22 +24839,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "неисправно rtl дељење нађено у ији"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "дељено rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ИЦЕ: emit_insn употребљено где је потребно emit_jump_insn:\n"
@@ -24867,7 +24920,7 @@ msgstr "низ не одговара стаблу области"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "низ не одговара стаблу области"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -24897,13 +24950,13 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: expr.c:11123
+#: expr.c:11128
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute warning: %s"
@@ -24921,7 +24974,7 @@ msgstr "Неисправан тип аргумента %qs за %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "величина %q+D је већа од %wd бајтова"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
@@ -24944,39 +24997,39 @@ msgstr "велики целобројни имплицитно подсечен
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "поређење је увек %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> непоклопљених тестова неједнакости је увек 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> међусобно искључивих тестова једнакости је увек 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "провера сажимања: првобитно дрво измењено сажимањем"
@@ -25666,13 +25719,13 @@ msgstr "функција враћа адресу на локалну проме
 msgid "function returns address of local variable"
 msgstr "функција враћа адресу на локалну променљиву"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -26295,10 +26348,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -26485,7 +26538,7 @@ msgstr "%qs није наведено у обухватајућем парале
 msgid "enclosing %<target%>"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
@@ -26542,13 +26595,13 @@ msgstr "%qE није променљива у одредби %<lastprivate%>"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -26558,152 +26611,152 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "неисправна декларација шаблона %qD"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "уређена област мора бити блиско угњеждена унутар петље са одредбом уређености"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "гимплификација није успела"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT се унапређује у %qT при прослеђивању кроз %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(стога би требало да проследите %qT уместо %qT за %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "ако се овај кôд досегне, програм ће се прекинути"
@@ -26783,7 +26836,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -27068,7 +27121,7 @@ msgstr "Неслагање граница низа"
 msgid "the extra base is defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -27077,7 +27130,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -27086,7 +27139,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -27095,7 +27148,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -27104,7 +27157,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -27113,7 +27166,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -27122,12 +27175,12 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -27161,38 +27214,38 @@ msgstr "%Jфункција може бити кандидат за атрибу
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification failed: %s"
 msgid "IPA-SRA access verification failed"
 msgstr "овера није успела: %s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -27245,59 +27298,59 @@ msgstr "неусаглашена ограничења операнда у %<asm%
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "не могу да нађем класу %qs"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "не могу да нађем декларацију протокола за %qs"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -27571,54 +27624,54 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr ""
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "... with %qs clause here"
 msgstr "  %q+#D декларисано овде"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -27856,53 +27909,53 @@ msgstr "неисправан улаз у структуирани блок Оп
 msgid "invalid branch to/from %s structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "routine %qD declared here"
 msgstr "%q+D декларисано овде"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -29348,143 +29401,143 @@ msgstr "-fstack-protector није подржано за овај циљ"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "распоређивање инструкција није подржано на овој циљној машини"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "ова циљна машина нема одгођена гранања"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore није подржано на овој циљној машини"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "нисам могао да отворим датотеку пописа %qs: %s"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the \"%s\" debug format"
 msgid "target system does not support the %qs debug format"
 msgstr "циљни систем не подржава исправљачки формат „%s“"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "праћење променљивих затражено, али бескорисно без стварања исправљачких података"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "праћење променљивих затражено, али неподржано овим исправљачким фоматом"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections није подржано за овај циљ"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ (покушајте нешто од -march)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays није подржано уз -O варијанте"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector није подржано за овај циљ"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attributes are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "%Jатрибути одељка нису подржани за овај циљ"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "грешка при упису у %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "грешка при затварању %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -29587,193 +29640,193 @@ msgstr "%<[*]%> није дозвољено другде осим у декла
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "константа није поново израчуната када се ADDR_EXPR промени"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "споредни ефекти нису поново израчунати када се ADDR_EXPR промени"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "адреса узета, али бит ADDRESSABLE није постављен"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression for min lvalue"
 msgstr "неисправан израз као операнд"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in indirect reference"
 msgstr "неисправан операнд у инструкцији"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr ""
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid position or size operand to %qs"
 msgstr "неисправна ограничења за операнд"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in %qs reference"
 msgstr "неслагање типова у условном изразу"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "неисправан операнд за %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "%s:profile mismatch for '%s'\n"
 msgid "type mismatch in %qs"
 msgstr "%s:неслагање профила за ‘%s’\n"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid shift operand"
 msgid "invalid %qs offset operator"
 msgstr "неисправан операнд помака"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "претапање из показивача у целобројни различите величине"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid address operand in %qs"
 msgstr "неисправни операнди за бинарно %s"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid offset operand in %qs"
 msgstr "неисправни операнди за бинарно %s"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "неисправна употреба %qD"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "једноставно IF"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "invalid function in gimple call"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "function not inlinable"
 msgid "non-function in gimple call"
 msgstr "функција се не може уткати"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid pure const state for function"
 msgstr "неисправна складишна класа за функцију %qs"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PC in line number table"
 msgid "invalid LHS in gimple call"
 msgstr "неисправан ПЦ у табели бројева линија"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion in gimple call"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PC in line number table"
 msgid "invalid static chain in gimple call"
 msgstr "неисправан ПЦ у табели бројева линија"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -29784,568 +29837,568 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument to gimple call"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operands in gimple comparison"
 msgstr "неисправан операнд у инструкцији"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "invalid vector comparison resulting type"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in unary operation"
 msgstr "неисправан операнд у инструкцији"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid vector types in nop conversion"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid type expression"
 msgid "invalid types in nop conversion"
 msgstr "Неисправан типски израз"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid types in address space conversion"
 msgstr "неисправан израз као операнд"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid type expression"
 msgid "invalid types in fixed-point conversion"
 msgstr "Неисправан типски израз"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid types in conversion to floating-point"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid types in conversion to integer"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in %qs expression"
 msgstr "неслагање типова у условном изразу"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid types for %qs"
 msgstr "неисправан апстрактни тип за %q+D"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "Elemental binary operation"
 msgid "non-register as LHS of binary operation"
 msgstr "Елементална бинарна операција"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid operands in binary operation"
 msgstr "неисправни операнди за бинарно %s"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid non-vector operands to %qs"
 msgstr "неисправан операнд за %%R"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "неисправан режим показивача %qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in binary expression"
 msgstr "неслагање типова у условном изразу"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operands in ternary operation"
 msgstr "неисправан операнд у инструкцији"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr ""
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid mask type in %qs"
 msgstr "неисправан апстрактни тип за %q+D"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "'&' not allowed by itself in line %d"
 msgid "not allowed type combination in %qs"
 msgstr "‘&’ не може бити само у линији %d"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "invalid position or size in %qs"
 msgstr "неисправан аргумент опције %qs"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number `%s'"
 msgid "non-trivial conversion in %qs"
 msgstr "неисправан број верзије ‘%s’"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "Missing return statement"
 msgid "%qs LHS in clobber statement"
 msgstr "Недостаје наредба повратка"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid operand in %qs"
 msgstr "неисправни операнди за бинарно %s"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for %q+D"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "неисправно име регистра за %q+D"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect number of vector %qs elements"
 msgstr "нетачно дељење чворова стабла"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "PHI def is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "ПХИ дефиниција није ГИМПЛЕ вредност"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR са увек нетачним условом"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in return statement"
 msgstr "неисправан операнд у инструкцији"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "invalid conversion in return statement"
 msgstr "Неисправна успостављачка наредба"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "goto destination is neither a label nor a pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to switch statement"
 msgstr "неисправан операнд за %%s кôд"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code for huge switch statements"
 msgid "non-integral type switch statement"
 msgstr "Створи кôд за огромне наредбе прекидача"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "етикета %<default%> није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "invalid case range in switch statement"
 msgstr "Неисправна успостављачка наредба"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "форматирајућа ниска има неисправан број операнада"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid comparison code in gimple cond"
 msgstr "неисправан операнд за %%p кôд"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid labels in gimple cond"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%j code"
 msgid "invalid %<PHI%> result"
 msgstr "неисправан %%j кôд"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid %<PHI%> argument"
 msgstr "неодговарајући аргумент за IACC"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "несагласни типови у додели"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_stmts није успело"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "local declaration from a different function"
 msgstr "декларација %qF баца различите изузетке"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (phi) is set to a wrong basic block"
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "bb_for_stmt (phi) постављено на погрешан основни блок"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "PHI node with location"
 msgstr "на овој локацији"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "нетачно дељење чворова стабла"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (stmt) is set to a wrong basic block"
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "bb_for_stmt (stmt) постављено на погрешан основни блок"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "наредба означена за бацање, али не чини то"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "наредба означена за бацање усред блока"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "verify_gimple failed"
 msgstr "verify_stmts није успело"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY_BLOCK has a statement list associated with it"
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK има придружену листу наредби"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, fuzzy, gcc-internal-format
 #| msgid "EXIT_BLOCK has a statement list associated with it"
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK има придружену листу наредби"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "пропад до излаза из об. %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "нелокална етикета "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "етикета "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "контролни ток усред основног блока %d"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "пропадна ивица после контролне наредбе у об. %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "true/false edge after a non-COND_EXPR in bb %d"
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "ивица тачно/нетачно после не-COND_EXPR у об. %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "погрешне заставице излазне ивице на крају об. %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "експлицитно goto на крају об. %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "повратна ивица не показује на излаз у об. %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "found default case not at end of case vector"
 msgid "found default case not at the start of case vector"
 msgstr "нађен подразумевани случај који није на крају вектора случаја"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "етикете случајева нису сортиране: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "сувишна излазна ивица %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "недостаје ивица %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> функција ипак враћа"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcontrol reaches end of non-void function"
 msgid "control reaches end of non-void function"
 msgstr "%Hконтрола стиже до краја функције непразног типа"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -30362,53 +30415,53 @@ msgstr "поновљена дефиниција %q+D"
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i has multiple EH edges"
 msgstr "Об. %i не може да баци али има ЕХ ивице"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "Об. %i не може да баци али има ЕХ ивице"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "Последња наредба у об. %i има неисправно постављену област"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unnecessary EH edge %i->%i"
 msgid "Incorrect EH edge %i->%i"
 msgstr "непотребна ЕХ ивица %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "погрешна ија у пропадном потегу"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i has incorrect edge"
 msgstr "Последња наредба у об. %i има неисправно постављену област"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -30956,12 +31009,12 @@ msgstr "наредба (%p) означена измењеном после оп
 msgid "verify_ssa failed"
 msgstr "verify_ssa није успело"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -31029,7 +31082,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -31040,28 +31093,28 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "Недефинисана променљива %qs"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "индекс низа није целобројан"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -31141,37 +31194,37 @@ msgstr "провера стабла: приступих операнду %d од
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од omp_clause %s са %d операнада у %s, код %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.c:13103
+#: tree.c:13105
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.c:13106
+#: tree.c:13108
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.c:13112
+#: tree.c:13114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "тип је превазиђен"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип је превазиђен"
@@ -31196,236 +31249,236 @@ msgstr "тип је превазиђен"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "main variant is not defined"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -31559,93 +31612,93 @@ msgstr "захтевано равнање за %q+D веће је од импл
 msgid "storage size of %q+D isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for integer value is too complicated"
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "успостављач за целобројну вредност је превише компликован"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "успостављач за реалну вредност није реална константа"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initial value for member %qE"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D декларисано уткано пошто је већ позвано"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "слаба декларација %q+D мора претходити дефиницији"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "слаба декларација %q+D мора бити јавна"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "слаба декларација %q+D није подржана"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "само слаби алијаси су подржани у овој конфигурацији"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref is not supported in this configuration"
 msgid "weakref is not supported in this configuration"
 msgstr "%Jслаби упућивач није подржан у овој конфигурацији"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "-pg није подржано на овој платформи"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "слаби упућивач %q+D на крају циља самог себе"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "слаби упућивач %q+D мора имати статичку повезивост"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "alias definitions not supported in this configuration"
 msgstr "%Jдефиниције алијаса нису подржане у овој конфигурацији"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s није подржано овом конфигурацијом"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видљивости није подржан у овој конфигурацији, игноришем"
@@ -32300,7 +32353,7 @@ msgstr "атрибут %qE се игнорише за %qE"
 msgid "type was previously declared %qE"
 msgstr "%q+#D претходно декларисано овде"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -32324,7 +32377,7 @@ msgstr "%qD није декларисано у %qD"
 msgid "%qE argument is not a function"
 msgstr "чистачки аргумент није функција"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
@@ -32725,12 +32778,12 @@ msgstr "недостаје %<@end%> у контексту имплементац
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "предлажем заграде око израза употребљеног као истинитосна вредност"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неисправна употреба %<restrict%>"
@@ -32898,12 +32951,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -33016,7 +33069,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -33028,84 +33081,84 @@ msgstr "несагласни тип за аргумент %d у %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "прослеђивање аргумента %d од %qE прави показивач од целобројног без претапања"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "types are not quite compatible"
 msgid "both arguments must be compatible"
 msgstr "типови нису сасвим сагласни"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "index value is out of bound"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -33113,58 +33166,58 @@ msgstr "двосмислено претварање из %qT у %qT"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "built-in function %qE must be directly called"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "величина низа %qs је негативна"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "негативна величина низа"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "величина низа %qs је негативна"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -33222,540 +33275,540 @@ msgstr "%qE је непрепознат тип форматирајуће фун
 msgid "format string argument follows the arguments to be formatted"
 msgstr "аргумент форматирајуће ниске прати аргументе које треба форматирати"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "функција може бити могући кандидат за форматски атрибут %qs"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "недостаје број операнда $ у формату"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s не подржава формат %%n$ за број операнда"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "број операнда ван опсега у формату"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "форматирајући аргумент %d употребљен више од једанпут у формату %s"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "број операнда $ употребљен после формата без броја операнда"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "форматирајући аргумент %d није употребљен пре употребљеног аргумента %d у формату типа $"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "формат није дословна ниска, формат није проверен"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "формат није дословна ниска и нема форматирајућих аргумената"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "формат није дословна ниска, типови аргумената нису проверени"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "превише аргумената за формат"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "неупотребљени аргументи у формату типа $"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "форматирајућа ниска %s нулте дужине"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "формат је широкознаковна ниска"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string argument not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "аргумент форматирајуће ниске није типа ниске"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "неодређена форматирајућа ниска"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s употребљено уз %<%%%c%> формат за %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s не подржава %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s не подржава %s са %<%%%c%> форматом за %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "поновљено %s у формату"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "недостаје знак попуне на крају формата strfmon"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "нулта дужина у формату %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "празна лева тачност у формату %s"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "празна тачност у формату %s"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s не подржава модификатор дужине %qs за %s"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s не подржава %<%%%c%> формат за %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s игнорисано са %s и %<%%%c%> форматом за %s"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s игнорисано са %s у формату %s"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "употреба %s и %s заједно са %<%%%c%> форматом за %s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "употреба %s и %s заједно у формату %s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> даје само последње две цифре године у неким локалитетима"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> даје само последње две цифре године"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "нема затварајућег %<]%> за формат %<%%[%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "употреба модификатора дужине %qs са знаком типа %qc"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s не подржава %<%%%s%c%> формат за %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "број операнда наведен са сузбијеном доделом"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "број операнда наведен за формат који не узима ниједан аргумент"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "поновљено %s у формату"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "поновљено %s у формату"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "угњеждено %<\\0%> у формату"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "unquoted attribute in format"
 msgstr "атрибут %qE се игнорише"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "не могу да искључим уграђену функцију %qs"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "сувишно пратеће %<%%%> у формату"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "inconsistent capitalization in format"
 msgstr "додела (не успостављање) у декларацији"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "сувишно пратеће %<%%%> у формату"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "поновљено %s у формату"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "поновљено %s у формату"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "поновљено %s у формату"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "сувишно пратеће %<%%%> у формату"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "сувишно пратеће %<%%%> у формату"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph characters in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Do not generate #line directives"
 msgid "unterminated quoting directive"
 msgstr "Не стварај директиве #line"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "непознат знак типа претварања %qc у формату"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "сувишно пратеће %<%%%> у формату"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "претварању недостаје тип на крају формата"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "Обради директиве #ident"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "угњеждено %<\\0%> у формату"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "неодређена алтернатива дијалекта асемблера"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "писање кроз нулти показивач (аргумент %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "читање кроз нулти показивач (аргумент %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "писање у константан објекат (аргумент %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "сувишна одредба типа у форматирајућем аргументу (аргумент %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%s%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "формат %q.*s очекује тип %<%s%s%>, али аргумент %d је типа %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs очекује константан аргумент"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "формат %q.*s очекује тип %<%T%s%>, али аргумент %d је типа %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs очекује константан аргумент"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> није дефинисано као тип"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> није дефинисано као %<long%> или %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> није дефинисано као тип"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> није дефинисано као тип"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> није дефинисано као тип"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> није дефинисано као тип"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "аргументи за форматирање нису %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "формати strftime не могу форматирати аргументе"
@@ -33924,7 +33977,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -33942,19 +33995,19 @@ msgstr "%Hнеисправан тип променљиве итерације %q
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
@@ -33965,7 +34018,7 @@ msgstr "%Hнедостаје израз увећања"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -34625,7 +34678,7 @@ msgid "wrong type argument to %s"
 msgstr "погрешан тип аргумента за abs"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "преливање у константном изразу"
@@ -35377,7 +35430,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
@@ -35467,7 +35520,7 @@ msgstr[1] "прослеђивање аргумента %d од %qE одбацу
 msgstr[2] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 msgstr[3] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -35487,7 +35540,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "defined here"
@@ -35509,7 +35562,7 @@ msgstr "„%s“ није исправна опција предобрађива
 msgid "too many input files"
 msgstr "превише улазних датотека"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -35543,15 +35596,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -36118,421 +36171,428 @@ msgstr "дефиниције алијаса нису подржане у Мах
 msgid "profiler support for VxWorks"
 msgstr "подршка профилисања за ВиксВоркс"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "аргумент %qd није константа"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "смеће на крају #pragma GCC java_exceptions"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code for the counting ISA extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Емитуј кôд за бројачко ИСА проширење"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "неисправна ограничења за операнд"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "неисправна %%h вредност"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "непозната функција навода ‘%s’"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "Одредите редослед резервисања регистара"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s;"
 msgstr "неисправан аргумент типа за %qs"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to '%s' option"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "опцији „%s“ недостаје аргумент"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-march%>"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "прекидач -mcpu=%s коси се са -march="
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s не подржава %s"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "лоше формирано %<#pragma init%>"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподржана комбинација: %s"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -36733,17 +36793,17 @@ msgstr "аргумент атрибута %qs није „ilink1“ или „il
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -36908,12 +36968,12 @@ msgstr ""
 msgid "invalid type for %<asm%> flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -36921,197 +36981,197 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "селектор мора бити непосредни"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор мора бити непосредни"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -37121,309 +37181,309 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC и -G нису сагласни"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support ARM mode"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "укључивање подршке за контраход има смисла само када се компилује за Тамб"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "укључивање подршке за интерворкинг позваних има смисла само када се компилује за Тамб"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g уз -mno-apcs-frame може дати бесмислено исправљање"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with -mthumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "не може се користити -mtp=cp15 уз -mthumb"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-fjni није сагласно са -freduced-reflection"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check није сагласно са -mno-apcs-frame"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic и -mapcs-reent нису сагласни"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "Вишеулазни кôд АПЦСа није подржан, игноришем"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "граница величине структура може бити постављена само на %s"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "граница величине структура може бити постављена само на %s"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= је бескорисно без -fpic"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "не могу да користим „%s“ за ПИЦ регистар"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition не ради на овој архитектури"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable и -msdata=%s нису сагласни"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iWMMXt захтева ААПЦС-сагласан АБИ за правилан рад"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iWMMXt АБИ захтева iWMMXt-способан ЦПУ"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard и ВФП"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "не могу да срачунам стварну локацију параметра на стеку"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Неочекиван крај модула"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нема доступних ниских регистара за подизање високих регистара"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -37432,24 +37492,24 @@ msgstr "неисправан тип вектора за атрибут %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "непознато име регистра: %s"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -37541,19 +37601,19 @@ msgstr "-pipe није подржано"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G и -static су међусобно искључиви"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -37848,7 +37908,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "Уткане функције Ц-а 99 нису подржане; користим Гну 89"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument to built-in function"
@@ -38205,56 +38265,56 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "Прослеђуј све аргументе у регистрима"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type of argument %s"
 msgstr "погрешан тип аргумента за abs"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "TLS is not implemented for GCN."
 msgstr "DW_LOC_OP %s није имплементирано"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "Builtin not implemented"
 msgstr "DW_LOC_OP %s није имплементирано"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "број операнда изван опсега"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "parse error; also virtual memory exhausted"
 msgid "local data-share memory exhausted"
@@ -38408,153 +38468,153 @@ msgstr "аргумент за %qs мора бити двобитна неозн
 msgid "parameter to builtin not valid: %s"
 msgstr "Аргумент за -ffpe-trap није исправан: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "помак мора бити непосредни"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "нетачна ија:"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "нетачно дељење чворова стабла"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "нетачна ија:"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -38977,159 +39037,159 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -39615,7 +39675,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -40783,54 +40843,54 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "%qs function cannot have different interrupt type"
@@ -40953,360 +41013,361 @@ msgstr "број мора бити 0 или 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "смеће на крају #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s није подржано овом конфигурацијом"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "неисправна комбинација параметара за алтивек сопствену"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор враћен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор прослеђен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs није подржано овим подциљем"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%Hпоследњи аргумент за %D није целобројна константа између 0 и 3"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент %qd није константа"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%qs очекује константан аргумент"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "неисправан аргумент за уграђену функцију"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "број мора бити 0 или 1"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "број мора бити 0 или 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "Аргумент у ATANH код %L мора бити у опсегу -1 до 1"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "други аргумент за %q+D треба да је %<char **%>"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid option to the preprocessor"
 msgid "%qs is only valid for the cell processor"
 msgstr "„%s“ није исправна опција предобрађивача"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported with the current options"
 msgstr "%s није подржано овом конфигурацијом"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -41327,240 +41388,245 @@ msgstr "Користи регистре r2 и r5"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 захтева архитектуру ПауерПЦ-64, укључујем"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power није подржано на 64-битном Дарвину; није сагласно са инсталираним Ц и Ц++ библиотекама"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring није подржано на системима мале крајности"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-fjni није сагласно са -freduced-reflection"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT се помиње као %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Користим ИЕЕЕ дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Користим ИБМов дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s не подржава %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Потребан је позивом продрман циљни регистар"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "неисправан апстрактни тип %qT за %qE"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not initialized"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%qE није успостављено"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
@@ -41911,146 +41977,146 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "укупна величина локалних променљивих премашује ограничење архитектуре"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "величина оквира за %qs је "
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs користи динамичко резервисање стека"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ограничи употребу хардверских инструкција покретног зареза на 32-битне операције"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float нису подржани у комбинацији"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "величина стека мора бити већа од вредности браника стека"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard имплицира коришћење -mstack-size"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -42513,8 +42579,8 @@ msgstr "атрибут %qs примењује се само на променљ
 msgid "could not read the BRIG file"
 msgstr "нисам могао да нађем датотеку навода %s\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "празна вредност није игнорисана а требало би"
@@ -42808,7 +42874,7 @@ msgstr "декларација %q+D заклања претходну не-пр
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларација %qD заклања глобалну декларацију"
@@ -42886,7 +42952,7 @@ msgstr "%H%qE недекларисано (прва употреба у овој
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Сваки недекларисани идентификатор пријављен је само једном"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "на етикету %qE упућено ван било које функције"
@@ -42918,7 +42984,7 @@ msgstr "скок у наредбени израз"
 msgid "duplicate label declaration %qE"
 msgstr "Удвостручена декларација етикете %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "удвостручена етикета %qD"
@@ -43141,7 +43207,7 @@ msgstr "не могу да ставим објекат са непостојан
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неуспостављена константа %qD"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -43525,7 +43591,7 @@ msgstr "%qs декларисано као функција која враћа 
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
@@ -43864,7 +43930,7 @@ msgstr "угњеждена поновна дефиниција %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
@@ -43916,7 +43982,7 @@ msgstr "структура нема именованих чланова"
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -43956,7 +44022,7 @@ msgstr "угњеждена поновна дефиниција %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "поновљена декларација %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -43988,7 +44054,7 @@ msgstr "преливање у вредностима набрајача"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -44022,7 +44088,7 @@ msgstr "нема претходног прототипа за %q+D"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -44153,12 +44219,12 @@ msgstr "аргумент %qD не одговара уграђеном прото
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -44167,281 +44233,281 @@ msgstr "параметар %qD је успостављен"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Почетна декларација у %<for%> петљи употребљена ван режима Ц-а 99"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларација статичке променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> декларисан у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларација не-променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "удвостручено %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ИСО Ц не подржава децимални покретни зарез"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE није ни по дефиницији типа ни уграђени тип"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE није на почетку декларације"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> употребљено уз %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не подржава %s"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> пре %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> пре %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "вишеструке складишне класе у наводиоцима декларације"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@try%> без %<@catch%> или %<@finally%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "негативан десни помак"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "десни помак >= од ширине типа"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -44462,7 +44528,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -44512,7 +44578,7 @@ msgid "unknown type name %qE"
 msgstr "непознато име регистра: %s"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -44534,7 +44600,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -44552,8 +44618,8 @@ msgstr "атрибут се игнорише при извођењу шабло
 msgid "unexpected attribute"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -44595,7 +44661,7 @@ msgstr "%<auto%> у празној декларацији у досегу дат
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "очекивано је %<,%> или %<;%>"
@@ -44625,7 +44691,7 @@ msgstr "ИСО Ц 90 не подржава %<long long%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "очекивана је дословна ниска"
@@ -44660,7 +44726,7 @@ msgstr "интегрални израз %qE није константа"
 msgid "static assertion failed: %E"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
@@ -44710,14 +44776,14 @@ msgstr "неисправан шаблонски аргумент %d"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "зарез на крају листе набрајања"
@@ -44804,7 +44870,7 @@ msgstr "очекивани су наводиоци декларације или
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute does not take any arguments"
@@ -44816,7 +44882,7 @@ msgstr "атрибут %qs захтева целобројну констант
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -44878,7 +44944,7 @@ msgstr "%HИСО Ц 90 забрањује мешање декларација и
 msgid "expected %<}%> before %<else%>"
 msgstr "очекивано је %<,%> или %<}%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -44893,7 +44959,7 @@ msgstr "етикета на крају сложене наредбе"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "очекивана је наредба"
@@ -44918,19 +44984,19 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr "очекиван је идентификатор или %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hпразно тело у наредби if"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%Hпразно тело у наредби else"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -44952,12 +45018,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "неисправан регистар у инструкцији"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -44974,8 +45040,8 @@ msgstr "недостаје стражар у позиву функције"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "удвостручена кн-одредба"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
 #| msgid "%J  first type here"
 msgid "first seen here"
@@ -45007,12 +45073,12 @@ msgstr "ИСО Ц забрањује изостављање средњег чл
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -45442,68 +45508,68 @@ msgstr "Очекивана је декларација класе или суч
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jадресна област атрибута не може бити наведена за функције"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
@@ -45514,19 +45580,19 @@ msgstr "%<#pragma omp section%> може бити употребљено сам
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
@@ -45549,60 +45615,60 @@ msgstr "очекивано је %<,%> или %<;%>"
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -45625,13 +45691,13 @@ msgstr "вредност %<num_threads%> мора бити позитивна"
 msgid "%<num_tasks%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
@@ -45643,24 +45709,24 @@ msgstr "вредност %<num_threads%> мора бити позитивна"
 msgid "expected constant integer expression"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -45677,60 +45743,60 @@ msgstr "израз за num_threads мора бити интегрални"
 msgid "%qs value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Неочекивани елемент"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "и %<long%> и %<void%> у наводиоцима декларације"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
@@ -45742,7 +45808,7 @@ msgstr "распоред %<runtime%> не узима параметар %<chunk_
 msgid "chunk size value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -45780,25 +45846,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -45816,83 +45882,83 @@ msgstr "неисправна врста распореда"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "неисправна употреба %<--%> на логичкој променљивој %qD"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Променљива %qs употребљена више од једном у листи аргумената метода %qs"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -45909,7 +45975,7 @@ msgstr "%qD није декларисано"
 msgid "expected function name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -45920,72 +45986,72 @@ msgstr "%q+D није функција,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -45995,63 +46061,63 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "очекивано је %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
@@ -46061,77 +46127,77 @@ msgstr "очекивано је успостављање или декларац
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -46147,61 +46213,61 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "expected trait selector name"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "score argument must be non-negative"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "очекивана је дословна ниска"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr ""
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
@@ -46213,13 +46279,13 @@ msgstr "очекивано је %<{%>"
 msgid "variant %qD is not a function"
 msgstr "%q+D није функција,"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -46229,34 +46295,34 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -46314,45 +46380,45 @@ msgstr "очекиван је идентификатор или %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "модела кôда %<large%> још увек није подржан"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -46368,27 +46434,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -46398,7 +46464,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -46415,7 +46481,7 @@ msgstr "%Hобухватајуће паралелно"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD има непотпун тип"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неисправна употреба израза празног типа"
@@ -46545,7 +46611,7 @@ msgstr "разрешавање %<void *%> показивача"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс низа није целобројан"
@@ -46570,7 +46636,7 @@ msgstr "ИСО Ц 90 забрањује индексирање не-л-вред
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -46691,19 +46757,19 @@ msgstr "захтев за имплицтно претварање из %qT у %q
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "премало аргумената за функцију %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "comparison with string literal results in unspecified behaviour"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "поређење са дословном ниском резултује неодређеним понашањем"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "поређење између показивача и целобројног"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -46730,7 +46796,7 @@ msgstr "показивач на функцију употребљен у оду
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -46997,7 +47063,7 @@ msgstr "претапање из показивача у целобројни р
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "претапање из целобројног у показивач различите величине"
@@ -47192,7 +47258,7 @@ msgstr "лева страна доделе може бити кандидат з
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
@@ -47370,7 +47436,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "низ неподесног типа успостављен константном ниском"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "неисправна употреба не-л-вредносног низа"
@@ -47402,7 +47468,7 @@ msgstr "елемент успостављача се не може израчу
 msgid "invalid initializer"
 msgstr "неисправан успостављач"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
@@ -47550,7 +47616,7 @@ msgstr "сувишни елементи у успостављачу скалар
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ИСО Ц забрањује %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
@@ -47593,7 +47659,7 @@ msgstr "%<long%> израз у прекидачу не претвара се у
 msgid "case label is not an integer constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
@@ -47603,17 +47669,17 @@ msgstr "етикета случаја није у оквиру наредбе п
 msgid "%<default%> label not within a switch statement"
 msgstr "етикета %<default%> није у оквиру наредбе прекидача"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "наредба искакања употребљена са ОпенМПом за петљу"
@@ -47630,7 +47696,7 @@ msgstr "наредба искакања није у оквиру петље ил
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "наредба без ефекта"
@@ -47640,22 +47706,22 @@ msgstr "наредба без ефекта"
 msgid "expression statement has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -47709,7 +47775,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "поређење уређености показивача са целобројном нулом"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "поређење уређености показивача са целобројном нулом"
@@ -47741,56 +47807,56 @@ msgstr "употребљена вредност унијског типа где
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD није чланска шаблонска функција"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -47802,8 +47868,8 @@ msgstr "%qE није променљива у одредби %qs"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
@@ -47987,12 +48053,12 @@ msgstr "Није нађена дефиниција етикете за %qs"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
@@ -48017,8 +48083,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
@@ -48034,19 +48100,19 @@ msgstr "%qD се појављује више од једном у одредба
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
@@ -48122,128 +48188,128 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%qs variable is not a pointer"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "први аргумент за %<va_arg%> није типа %<va_list%>"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -48456,35 +48522,35 @@ msgid "expected case label"
 msgstr "очекивано је име класе"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -48493,841 +48559,841 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T, %T) <уграђено>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T) <уграђено>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s %D(%T) <уграђено>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s %T <претварање>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D <near match>"
 msgid "%s%#qD (near match)"
 msgstr "%s %+#D <приближно поклапање>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 #| msgid "%J  other type here"
 msgid "  inherited here"
 msgstr "%J  други тип овде"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "не могу да претворим %qE у %qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%D(%A)%> "
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "показивач на чланску функцију %E не може бити позван без објекта; покушајте помоћу .* или ->*"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "нема поклапања за позив %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "двосмислен позив %<(%T) (%A)%>"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "двосмислено претварање за индекс низа"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid " (operand types are %qT and %qT)"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Кориснички оператори:\n"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s за тернарно %<operator?:%> у %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s за %<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s за %<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s за %qs у %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "  or %<operator=(const %T&)%>"
 msgid "%<operator %s%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%s за %<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s за %<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s за %<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ИСО Ц++ забрањује изостављање средњег члана израза ?:"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "поређење између %q#T и %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for `%D'"
 msgid "no corresponding deallocation function for %qD"
 msgstr "нема одговарајуће функције за ослобађање меморије за ‘%D’"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нема погодног %<operator %s%> за %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D није приступно"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "прослеђивање NULL непоказивачком аргументу %P од %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "претварање у непоказивачки тип %qT из NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  успостављање аргумента %P од %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не може се повезати битско поље %qE са %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "не може се повезати паковано поље %qE са %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не може се повезати д-вредност %qE са %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "не могу се проследити објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "не могу се примати објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "подразумевани аргумент за параметер %d у %qD још увек није рашчлањен"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  у позиву %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT није приступна основа од %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%s(%A)%>"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "враћање вредности из конструктора"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "враћање вредности из деструктора"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "чланска функција %qD не може се позвати без објекта"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "прослеђивање %qT бира %qT пре него %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "бирам %qD пре него %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  зато што је редослед претварања за аргумент бољи"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid " candidate 1: %q#F"
 msgstr "кандидат 1:"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 2:"
 msgid " candidate 2: %q#F"
 msgstr "кандидат 2:"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -49363,573 +49429,573 @@ msgstr "не може се претворити из основе %qT у изв
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr ""
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
 msgstr "претходна декларација %q+D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "сукобљене одреднице приступа за метод %q+D, игноришем"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "сукобљене одреднице приступа за поље %qE, игноришем"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  због истоименог локалног метода %q+#D"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local method %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  због истоименог локалног члана %q+#D"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "све чланске функције у класи %qT су приватне"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T дефинише само приватни деструктор и нема пријатељâ"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T дефинише само приватне конструкторе и нема пријатељâ"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "нема јединственог коначног потискивача за %qD у %qT"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D је сакривено"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  овим %q+D"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "битско поље %q+#D неинтегралног типа"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битског поља %q+D није целобројна константа"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "негативна ширина у бистком пољу %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулта ширина за битско поље %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "ширина %q+D премашује свој тип"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D је премало да садржи све вредности за %q#T"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "члан %q+#D са конструктором није дозвољен у унији"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "члан %q+#D са деструктором није дозвољен у унији"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у унији"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D не може бити статичко зато што је члан уније"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "поље %q+D неисправно декларисан функцијски тип"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "игноришем атрибут паковања због непакованог не-ПОД поља %q+#D"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "успостављена вишеструка поља у унији %qT"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "поље %q+#D истог имена као и класа"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T има показивачке чланске податке"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  али не потискује %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  али не потискује %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "успостављач наведен за невиртуелни метод %q+D"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T није класа"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "Java class %qT cannot have a destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "јаванска класа %qT не може имати деструктор"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD has non-integral type %qT"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "  non-static data member %qD has volatile type"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатички упућивач %q+#D у класи без конструктора"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуелна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "помак за %q+D можда не поштује АБИ и може се изменити у будућим верзијама ГЦЦа"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "величина низа %qs је превелика"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T има виртуелне функције, али невиртуелни деструктор"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "тип %qs има виртуелне чланске функције"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#D is marked %<dllimport%>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "у покушају да довршим структуру, али избачен услед претходних грешака у рашчлањивању"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "језичка ниска %<\"%E\"%> није препозната"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "не могу да разрешим препуњену функцију %qD на основу претварања у тип %qT"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нема поклапања за претварање функције %qD у тип %q#T"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "двосмислено претварање препуњене функције %qD у тип %q#T"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "претпостављам показивач на члан %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "нема довољно података о типу"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "не може се претворити %qE из типа %qT у тип %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -50017,7 +50083,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
@@ -50080,7 +50146,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr "декларација %qD заклања претходну локалну"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
@@ -50144,414 +50210,413 @@ msgstr "интегрални израз %qE није константа"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "позвано одавде"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "array used as initializer"
 msgid "%qD used in its own initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D је приватно"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "inline assembly is not a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
 msgstr "Неочекиван крај датотеке у ‘%s’"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD није тип"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not a class type"
 msgstr "%qD није тип"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE нема класни тип"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have integral type"
 msgstr "%qE нема класни тип"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -50605,7 +50670,7 @@ msgstr "неисправно успостављање неконстантног
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "претапање %qT у %qT не разрешава показивач"
@@ -50649,328 +50714,328 @@ msgstr "%q#T употребљено где је очекивана вредно
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "захтевано претварање из %qT у нескаларни тип %qT"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "псеудодеструктор се не позива"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "претварање у непотпун тип"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "неисправна примена %qs на непотпун тип %qT"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "претварање у непотпун тип"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "наредба без ефекта"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "двосмислено подразумевано претварање типа из %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  могућа претварања укључују %qD и %qD"
@@ -51043,7 +51108,7 @@ msgstr "од претходне декларације %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Декларација %qs заклања претходну декларацију етикете"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -51256,12 +51321,12 @@ msgstr "претходна декларација %q+D беше овде"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD"
@@ -51275,50 +51340,50 @@ msgstr "поновљена дефиниција %q+D"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: атрибут видљивости игнорисан зато што"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD није декларисано у %qD"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -51326,719 +51391,719 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "нитно-локална декларација %q+D прати не-нитно-локалну декларацију"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не-нитно-локална декларација %q+D прати нитно-локалну декларацију"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  одавде"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  излази из структуираног блока ОпенМПа"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  пресеца успостављање %q+#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  улази у блок покушаја"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  улази у блок хватања"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  улази структуирани блок ОпенМПа"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  прескаче успостављање %q+#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T није класа"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "нема шаблона класе по имену %q#T у %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именује %q#T, што није шаблон класе"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> именује %q#T, што није тип"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "захтевано равнање није степен двојке"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са конструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са деструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут за %q+#T мора пратити кључну реч %qs"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "вишеструки типови у једној декларацији"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "недостаје име типа у наредби typedef"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ИСО Ц++ забрањује анонимне структуре"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бити наведено само за конструкторе"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ИСО Ц++ не дозвољава да %<%T::%D%> буде дефинисано као %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "удвостручено успостављање %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "променљива %q#D има успостављач али је непотпуног типа"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "скупина %q#D има непотпун тип и не може се дефинисати"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривијални утврђени успостављачи нису подржани"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  можете ово заобићи уклањањем успостављача"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "неисправан тип %qT као успостављач за вектор типа %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "неисправан успостављач"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ИСО Ц 90 забрањује сложене дословне ниске"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скаларни објекат %qD захтева један елемент у успостављачу"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD мора бити успостављен конструктором, не помоћу %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "низ %qD успостављен заграђеном константном ниском %qE"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "успостављач неисправан за статички члан са конструктором"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потребно је успостављање изван класе)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "параметар %qD је успостављен"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "could not find variant declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: рекурзивно позивање конструктора %qs"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "поновљена декларација набрајача %q+D"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "заклањање претходне декларације типа за %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare variable %q+D to be of abstract type %qT"
 msgid "cannot decompose variable length array %qT"
 msgstr "не може се декларисати променљива %q+D апстрактног типа %qT"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -52048,7 +52113,7 @@ msgstr[1] "успостављач дат за функцију"
 msgstr[2] "успостављач дат за функцију"
 msgstr[3] "успостављач дат за функцију"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -52057,7 +52122,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -52066,201 +52131,201 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не могу да разложим адресу"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -52556,7 +52621,7 @@ msgstr "преливање у димензији низа"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
@@ -52739,7 +52804,7 @@ msgstr "недостаје ид. декларатора; користи се р
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
@@ -52960,886 +53025,886 @@ msgstr "атрибут %qE се игнорише"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неисправна употреба %<restrict%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функција са %<noreturn%> враћа непразну вредност"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a member function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "не може се декларисати параметар %q+D апстрактног типа %qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "не могу да отворим %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -53851,97 +53916,97 @@ msgstr "%qT се помиње као набрајање"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "underlying type %qT of %qT must be an integral type"
@@ -53951,79 +54016,79 @@ msgstr "Крејов показивач код %C мора бити целобр
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "вредност набрајача за %qD није целобројна константа"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -54064,7 +54129,7 @@ msgstr "не може се обрисати функција. Само пока
 msgid "deleting %qT is undefined"
 msgstr "брисање %qT није дефинисано"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "декларација шаблона %q#D"
@@ -54075,7 +54140,7 @@ msgstr "декларација шаблона %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD декларисан као члански шаблон"
@@ -54431,154 +54496,154 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "употреба %<typename%> изван шаблона"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "без аргумената"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "двосмислено упућивање на %<%T::%D%>"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD није члан у %qT"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD није члан у %qD"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD није члан у %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> није декларисано"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> није декларисано"
@@ -54775,366 +54840,366 @@ msgstr "%Jподразумевано успостављање %q#D, које ј
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "успостављање флексибилног чланског низа"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD треба да се успостави у листи успостављања чланова"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "класа %qT је имплицитно сама себи пријатељска"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "неуспостављени константни члан %qD"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "основно %qT ће бити успостављено после"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  основног %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  када се успостави овде"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%Jвишеструка успостављања дата за %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jвишеструка успостављања дата за основно %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%Jуспостављања за више чланова из %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D је статички члански податак; може се успостављати само при дефинисању"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "неименовани успостављач за %qT, која нема основних класа"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "неименовани успостављач за %qT, која користи вишеструко наслеђивање"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD је и непосредна основа и посредна виртуелна основа"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%qT is not a class type"
 msgstr "%q#T није класа"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "непотпун тип %qT нема члан %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "неисправан показивач на битско поље %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "целобројно преливање у изразу"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "неисправан тип %<void%> за new"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ниједно погодно %qD није нађено у класи %qT"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "двосмислен захтев за чланом %qD"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new се не може применити на упућивачки тип"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "успостављач се прерано окончава"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "непозната величина низа за delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
@@ -55302,13 +55367,13 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can't use default assignment operator"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "нестатички константни члан %q#D, не може се користити подразумевани оператор доделе"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can't use default assignment operator"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -55337,171 +55402,175 @@ msgstr "сукобљени типови за %q+D"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "атрибут %qE може се применити само на јаванске дефиниције класа"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "атрибут %qE може се применити само на јаванске дефиниције класа"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD мора узимати %<void%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr ""
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD је већ пријатељ од %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot default compare union %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "не може се створити показивач на упућивачки члан %qD"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T member"
 msgid "cannot default compare anonymous union member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsynthesized method %qD first required here "
 msgid "synthesized method %qD first required here"
 msgstr "%Hсамосачињени метод %qD прво захтеван овде "
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "union member %q+D with non-trivial %qD"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "initializer for %q#D is invalid"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "неисправан приступ нестатичком чланском податку %qD нултог објекта"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "спољашња декларација %q#D не слаже се"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "unparseable signature: '%s'"
 msgid "expected signature: %qD"
 msgstr "нерашчлањив потпис: ‘%s’"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "%q+#D се не може декларисати"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "file ends in default argument"
 msgid "defaulted function %q+D with default argument"
@@ -55548,145 +55617,145 @@ msgstr "параметар %qD неисправно декларише тип м
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларација %q#D заклања параметар"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "глобална декларација %q+#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
 msgstr "коси се са претходном декларацијом %q+#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "декларација коришћења %q+D коси се са претходном декларацијом коришћења"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "поновљена декларација набрајача %q+D"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> именује деструктор"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared in %qE"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD треба да је декларисано унутар %qD"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибутска директива %qD игнорисана"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -55695,87 +55764,87 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "алијас именског простора %qD није дозвољен овде, претпостављам %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entering pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -55802,7 +55871,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -55830,7 +55899,7 @@ msgstr "%<::%D%> није декларисано"
 msgid "request for member %qE in non-class type %qT"
 msgstr "захтев за члан %qD у некласном типу %qT"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -55922,7 +55991,7 @@ msgstr "неисправан ид. шаблона"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "претапање у тип који није ни интегрални ни набројиви не може се јавити у изразу константе"
@@ -56057,7 +56126,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -56188,7 +56257,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -56299,13 +56368,13 @@ msgstr "декларација %<~%T%> као члана у %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-име %qD употребљено као декларатор деструктора"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "очекивана је листа наводилаца-одредби"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD није шаблон"
@@ -56345,7 +56414,7 @@ msgstr "непотпун тип %qT употребљен у угњежденом
 msgid "expected nested-name-specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
@@ -56363,7 +56432,7 @@ msgstr "не могу се дефинисати нови типови у пов
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -56379,7 +56448,7 @@ msgstr "ИСО Ц++ забрањује сложене константе"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "неисправна употреба %qD"
@@ -56407,1001 +56476,1006 @@ msgstr "ИСО Ц++ не дозвољава утврђене успостављ
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница низа забрањена је после заграђеног ид. типа"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "употреба старовремског претапања"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "предложи заграде око && унутар ||"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not allow extra %<;%> outside of a function"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ИСО Ц не дозвољава додатно %<;%> изван функције"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Неочекиван крај модула"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a reference type"
 msgid "%<this%> cannot be captured by reference"
 msgstr "new се не може применити на упућивачки тип"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "удвостручено %<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "етикета случаја %qE ван наредбе пребацивања"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "функција враћа низ"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "condition declares a function"
 msgstr "поље %qs декларисано као функција"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "сувишно %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "забрањено је мешање декларација и дефиниција функција"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "празна декларација"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> употребљено изван класе"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D неисправно у %q#T"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "type-specifier invalid in lambda"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in explicit-specifier"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "само конструктори узимају успостављаче основе"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "анахронистични старовремски успостављач основне класе"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (успостављач одређеног члана имплицитно је тип)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неисправан операнд услова"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "неочекиван операнд"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> је другачије написано %<[%>. Убаците размак између %<<%> и %<::%>"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(Г++ ће прихватити ово ако задате -fpermissive)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid template-argument-list"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "%<<::%> cannot begin a template-argument list"
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
 msgstr "очекивана је наредба"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "употребите %<%T::template %D%> да назначите да је шаблон"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "очекивани су наводиоци декларације или %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специјализација шаблона са Ц повезивошћу"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE не именује тип"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "Recognize GNU-defined keywords"
 msgid "concept defined here"
 msgstr "Препознаје кључне речи које дефинише Гну"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибут се игнорише при предоченом-наводиоцу-типа који није унапредна декларација"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD није шаблон функције"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Инструкције min/max нису дозвољене"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "сувишне одредбе се игноришу"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD није дефинисано изван досега функције"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT није именски простор"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD није дефинисано изван досега функције"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: дефиниција функције није претворена\n"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "успостављач дат за функцију"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -57411,478 +57485,478 @@ msgstr "%<%T::%D%> није тип"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid declarator"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "неисправна употреба конструктора као шаблона"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "употреба %<%T::%D%> уместо %<%T::%D%> за именовање конструктора у одређеном имену"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD је именски простор"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "недостаје справљачки циљ после %qs"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "подразумевани аргументи су дозвољени само за параметре функција"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "неисправно име класе у декларацији %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "експлицитној специјализацији мора претходити %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "претходна дефиниција %q+#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "при декларацији пријатеља мора бити употребљена кључна реч class"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (основна класа је имплицитно тип)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD in linkage specification"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "очекиван је идентификатор или %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "expression must be enclosed in parentheses"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "захтевани положај није целобројна константа"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "захтевано равнање није константа"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -57891,607 +57965,607 @@ msgstr "премало листа параметара шаблона"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "шаблонска класа без имена"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qT defined as %qs here"
 msgstr "%qT се помиње као %qs"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "очекиван је целобројни израз"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD није чланска шаблонска функција"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -58783,7 +58857,7 @@ msgstr ""
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -58812,73 +58886,73 @@ msgstr "декларација %q+D заклања параметар"
 msgid "template parameter %qD declared here"
 msgstr "шаблонски параметарски тип %qT декларисан пријатељским"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments for partial specialization %qT"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -58888,19 +58962,19 @@ msgstr[1] "тип %qT шаблонског аргумента %qE зависи 
 msgstr[2] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 msgstr[3] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нема подразумеваног аргумента за %qD"
@@ -58908,53 +58982,53 @@ msgstr "нема подразумеваног аргумента за %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумевани аргумент за параметар типа %qT има тип %qT"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "параметар %qD декларисан празним"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблонска класа без имена"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -58965,59 +59039,59 @@ msgstr "%sчланска функција %qD не може имати кн-од
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "неисправна декларација шаблона %qD"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "шаблонска дефиниција нешаблонског %q#D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очекивах %d нивоа шаблонских параметара за %q#D, добих %d"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  а потребно је %d"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "наводиоци шаблона нису задати у декларацији %qD"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -59027,7 +59101,7 @@ msgstr[1] "%qD употребљено без параметара шаблона
 msgstr[2] "%qD употребљено без параметара шаблона"
 msgstr[3] "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -59037,148 +59111,148 @@ msgstr[1] "претходном декларацијом %q+#D овде"
 msgstr[2] "претходном декларацијом %q+#D овде"
 msgstr[3] "претходном декларацијом %q+#D овде"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "шаблонски параметар %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT није члан из %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs није исправно за %qs"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -59187,328 +59261,328 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се константне ниске не могу користити у овом контексту"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "template argument for %qD uses local type %qT"
 msgid "in template argument for type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "акумулатор није целобројна константа"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "ignoring attributes in template argument %qE"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очекивах шаблон типа %qD, добих %qD"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE није на почетку декларације"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
@@ -59526,313 +59600,313 @@ msgstr "стварање показивача на чланску функциј
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -59845,147 +59919,147 @@ msgstr "експлицитна специјализација %qD после п
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "непрозирни векторски типови не могу бити успостављени"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT није именски простор"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -60214,7 +60288,7 @@ msgstr "неисправна употреба %<this%> на највишем н
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неисправан одредбени досег у имену псеудодеструктора"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
@@ -60265,7 +60339,7 @@ msgstr "неисправан навод основне класе"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
@@ -60372,7 +60446,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -60415,7 +60489,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
@@ -60561,133 +60635,133 @@ msgstr "%qD се појављује више од једном у одредба
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "поновљена имплементација класе %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "други аргумент за %<__builtin_expect%> мора бити константа"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -60967,888 +61041,888 @@ msgstr "недостаје претапање за %s између различ
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "неисправна примена %qs на чланску функцију"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "неисправна примена %<sizeof%> на битско поље"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<sizeof%> на израз функцијског типа"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "неисправна примена %<__alignof%> на битско поље"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<__alignof%> на израз функцијског типа"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "неисправна употреба нестатичког чланског податка %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "неисправан приступ нестатичком чланском податку %qD нултог објекта"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "тип који се уништава је %qT, али деструктор упућује на %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT није основа за %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD није чланска шаблонска функција"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT није типа показивач-на-објекат"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "недостаје објекат у употреби %qE"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ИСО Ц++ забрањује звање %<::main%> унутар програма"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "мора се употребити или %<.*%> или %<->*%> за позив показивача на чланску функцију у %<%E (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметар %P за %qD непотпуног је типа %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "претпоставља се претапање у тип %qT из препуњене функције"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL употребљено аритметички"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ИСО Ц++ забрањује поређење показивача и целобројног"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "неисправни операнди типова %qT и %qT за бинарно %qO"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача типа %<void *%> у одузимању"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на метод у одузимању"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "неисправна употреба показивача на непотпун тип у аритметици са показивачима"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "неисправна употреба %qE за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  неопходан је одређен ид."
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "заграде око %qE не могу бити коришћене за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе неодређене или заграћене нестатичке чланске функције, за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе везане чланске функције за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ИСО Ц++ забрањује узимање адресе функције %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "не може се створити показивач на упућивачки члан %qD"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "не може се узети адреса битског поља %qD"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "taking address of an immediate function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "затражена је адреса експлицитне регистарске променљиве %qD"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "затражена је адреса од %qD, а декларисано је као %<register%>"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "претварање из %qT у %qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "претапање из %qT у %qT губи на тачности"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "претапање из %qT у %qT повећава неопходно равнање циљног типа"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ИСО Ц++ забрањује претапање између показивача на функцију и показивача на објекат"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "неисправно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "неисправна употреба константног претапања са типом %qT, који није показивач, нити показивач на члански податак"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "неисправна употреба константног претапања са типом %qT, који је показивач или упућивач на функцијски тип"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "неисправно константно претапање д-вредности типа %qT у тип %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "неисправно константно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ИСО Ц++ забрањује претапање у низовни тип %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  у израчунавању %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "неисправна додела низа"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   у претварању показивача на чланску функцију"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "претварање показивача на члан преко виртуелне основе %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   у претварању показивача на члан"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "у прослеђивању аргумента %P за %q+D"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "враћање упућивача на локалну променљиву %q+D"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "Missing return statement"
 msgid "redundant move in return statement"
 msgstr "Недостаје наредба повратка"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "враћање вредности из деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не може се враћати из руковаоца у блоку покушаја у конструктору"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "враћање вредности из конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "недостаје успостављач"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не сме вратити NULL, осим ако је декларисан уз %<throw()%> (или је задато -fcheck-new)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -62143,114 +62217,114 @@ msgstr "витичасте заграде око скаларног успост
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "прототип за %q#D не одговара ниједном у класи %qT"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -62489,10 +62563,10 @@ msgstr "Упућивач низа код %C не може имати више о
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "Упућивач низа код %C не може имати више од %d димензија"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -62674,7 +62748,7 @@ msgstr "Ново у фортрану 2003: [...] конструктори низ
 msgid "Array constructor including type specification at %C"
 msgstr "Синтаксна грешка у одредници знаковне дужине код %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
@@ -62799,7 +62873,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -62847,7 +62921,7 @@ msgstr "Недостају аргументи за сопствено %s код
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити целобројан или реалан"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
@@ -62865,7 +62939,7 @@ msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L м
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или процедура"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -63006,186 +63080,186 @@ msgstr "Различите знаковне дужине у додели пок
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Different type kinds at %L"
 msgid "Different type kinds at %L"
 msgstr "Проширење: Различите врсте типова код %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "Нулти показивач код %L није дозвољен као стварни аргумент сопствене функције ‘%s’"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити врсте %d"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити показивач или циљна променљива или функција"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER or a TARGET"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач или циљ"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "Одељак низа са векторским индексом код %L неће бити циљ показивача"
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "Нулти показивач код %L није дозвољен као стварни аргумент сопствене функције ‘%s’"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити истог типа и врсте као ‘%s’"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "STAT= argument to %s at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Negative argument N at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be present if 'x' is COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити присутан ако је ‘x’ комплексно"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of type REAL or COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или реалан"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити врсте %d"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "OPERATOR argument at %L must be a PURE function"
@@ -63194,771 +63268,771 @@ msgstr "Аргумент за %s код %L мора бити дужине јед
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic function %s(%d) not recognized"
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Сопствена функција %s(%d) није препозната"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити ранга 1 или 2"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be numeric or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити бројеван или логички"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "различити облици аргумената ‘%s’ и ‘%s’ код %L за сопствено ‘dot_product’"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити исте врсте као ‘%s’"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "SIZE at %L must be positive"
 msgstr "Ознака %s код %L мора бити типа %s"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of LOG at %L cannot be less than or equal to zero"
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "Аргумент у LOG код %L не може бити мањи или једнак нули"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити константа"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Сопствено ‘%s’ код %L мора имати бар два аргумента"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "Аргумент ‘a%d’ сопственог ‘%s’ код %L мора бити %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 #| msgid "'a1' argument of '%s' intrinsic at %L must be INTEGER or REAL"
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "Аргумент ‘a1’ сопственог ‘%s’ код %L мора бити целобројан или реалан"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Аргумент ‘a%d’ сопственог ‘%s’ код %L мора бити %s(%d)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 #| msgid "different shape on dimension 1 for arguments '%s' and '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "различити облици по димензији 1 аргумената ‘%s’ и ‘%s’ код %L за сопствено ’matmul’"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 #| msgid "different shape on dimension 2 for argument '%s' and dimension 1 for argument '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "различити облици по димензији 2 аргумента ‘%s’ и димензији 1 аргумента ‘%s’ код %L за сопствено ’matmul’"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити ранга 1 или 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити истог типа и врсте као ‘%s’"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог ранга %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог ранга %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити истог типа и врсте као ‘%s’"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити од лажне променљиве"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an OPTIONAL dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити од опционе лажне променљиве"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be a sub-object of '%s'"
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити подобјекат од ‘%s’"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "Аргумент ‘shape’ сопственог ‘reshape’ код %L мора бити низ константне величине"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "Аргумент ‘shape’ сопственог ‘reshape’ код %L има више од %d елемената"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "Аргумент ‘a%d’ сопственог ‘%s’ код %L мора бити %s(%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити ранга %d"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Без уметања нема довољно елемената да подрже облик у сопственом RESHAPE код %L"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити бројевног типа"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "Аргумент ‘source’ сопственог ‘shape’ код %L не сме бити низ претпостављене величине"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не може бити намере-у"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "Аргумент ‘source’ сопственог ‘shape’ код %L не сме бити низ претпостављене величине"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити мање ранга од %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити исте врсте као ‘%s’"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити врсте %d"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или логички"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, fuzzy, gcc-internal-format
 #| msgid "Result of %s is NaN at %L"
 msgid "%qs of %qs is PRIVATE at %L"
@@ -64178,1927 +64252,1927 @@ msgstr "Лоша одредница намере код %C"
 msgid "deferred type parameter at %C"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal character in BOZ constant at %C"
 msgid "Old-style character length at %C"
 msgstr "Недозвољени знак у БОЗ константи код %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Синтаксна грешка у одредници знаковне дужине код %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Процедура ‘%s’ код %C већ је дефинисана код %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Процедура ‘%s’ код %C већ је дефинисана код %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Процедура ‘%s’ код %C има експлицитно сучеље и не може имати атрибуте декларисане код %L"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Симбол ‘%s’ код %L не може имати тип"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Знаковни елементи конструктора низа код %L морају имати исту дужину (%d/%d)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Успостављач није дозвољен за параметар ‘%s’ код %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Недостаје успостављач за параметар код %L"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Променљива ‘%s’ код %C са успостављачем већ се појављује у наредби DATA"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "у успостављачу се не могу успостављати вишедимензиони низови"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан или одложени облик"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Показивачка низовна компонента структуре код %C мора имати одложен облик"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Резервљива компонента структуре код %C мора имати одложен облик"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан облик"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "листа параметара са тротачком не може поклопити декларацију празне листе имена параметара"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "Двосмислено успостављање NULL() код %C"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "Двосмислено успостављање NULL() код %C"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Успостављање показивача код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected character in variable list at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Неочекиван знак у листи променљивих код %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Удвостручена одредница низа за Крејов показиваног код %C."
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "не могу да претворим у показивачки тип"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Успостављање код %C није за показивачку променљиву"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Успостављање променљиве код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Успостављање резервљиве компоненте код %C није дозвољено"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of allocatable component at %C is not allowed"
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "Успостављање резервљиве компоненте код %C није дозвољено"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Показивачка компонента ‘%s’ у ‘%s’ код %L припада типу који није декларисан"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старовремска декларација типа %s*%d није подржана код %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандардна декларација типа %s*%d код %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Очекиван је скаларни успостављачки израз код %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Израз код %L мора бити целобројног типа"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Параметар врсте за %s код %L мора бити инцијализовани израз"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Проширење: тип BYTE код %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Тип BYTE употребљен код %C није доступан на циљној машини"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument list function at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Функција листе аргумената код %L није дозвољена у овом контексту"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "malformed spec function name"
 msgid "Malformed type-spec at %C"
 msgstr "лоше формирано име функције навода"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Удвостручена наредба IMPLICIT NONE код %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Недостаје знаковни опсег за имплицитно код %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Слова морају бити у алфабетском поретку у наредби IMPLICIT код %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Атрибут %s код %L није дозвољен изван модула"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "Линија одсечена код %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr ""
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Недостаје генеричка одредница у наредби USE код %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "недостаје име"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Изведени тип код %C није претходно дефинисан и зато се не може појавити у дефиницији изведеног типа."
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer expression required at %C"
 msgid "A type parameter list is required at %C"
 msgstr "Неопходан целобројни израз код %C"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Очекивана је етикета алтернативног повратка код %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "A parameter name is required at %C"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Име ‘%s’ код %C је име процедуре"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Очекивана је друга димензија у декларацији низа код %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "Променљива RESULT код %C мора бити различита од имена функције"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксна грешка у конструктору структуре код %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Очекивана је формална листа аргумената у дефиницији функције код %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "Наредба ENTRY код %C не може бити унутар PROGRAM"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "Наредба ENTRY код %C не може бити унутар BLOCK DATA"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DERIVED TYPE"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока IF-THEN"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока FORALL"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока WHERE"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "Наредба ENTRY код %C не може бити унутар садржаног потпрограма"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "Наредба ENTRY код %C не може бити у садржаној процедури"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "Наредба ENTRY код %C не може бити у садржаној процедури"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return cannot appear in operator interface at %L"
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "Алтернативно враћање не може да се јави у сучељу оператора код %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Недостаје етикета формата код %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Име функције ‘%s’ није дозвољено код %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
 msgstr "Наредба %s код %C не може пратити наредбу %s код %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Очекивана је наредба %s код %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Очекивана је етикета ‘%s’ за наредбу %s код %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Одредница низа мора бити одложена код %L"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неочекиван знак у листи променљивих код %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Очекивано је име променљиве код %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Крејов показивач код %C има %d бајтова тачности; меморијска адреса захтева %d бајтова."
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "не могу да претворим у показивачки тип"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Очекивано је ‘)’ код %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Очекивано је ‘,’ или крај наредбе код %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "Декларација Крејовог показивача код %C захтева заставицу -fcray-pointer."
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Одредница приступа оператора %s код %C је већ наведена"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Одредница приступа оператора .%s. код %C је већ наведена"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Очекивано је име променљиве код %C у наредби PARAMETER"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Очекиван је знак = у наредби PARAMETER код %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Очекиван је израз код %C у наредби PARAMETER"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
 msgstr "Успостављач није дозвољен за заједничку променљиву ‘%s’ код %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Покривачка наредба SAVE код %C прати претходну наредбу SAVE"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD не може бити нитно-локално зато што је не-ПОД типа %qT"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Изведени тип код %C може бити само приватан унутар модула"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Изведени тип код %C може бити само јаван унутар модула"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Удвостручена етикета конструкције ‘%s’ код %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Mangled derived type definition at %C"
 msgstr "Дефиниција изведеног типа код %C нема компонената"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити опцион"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Крејов показивани код %C не може бити низ претпостављеног облика"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Ново у фортрану 2003: ENUM и ENUMERATOR код %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Набрајач премашује Ц-ов целобројни тип код %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "Набрајач %L није успостављен целобројним изразом"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Очекивана је наредба дефиниције ENUM пре %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксна грешка у дефиницији ENUMERATOR код %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "Очекивано је безимено сучеље код %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Очекиван је индекс низа код %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Неисправан облик наредбе PROGRAM код %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected module procedure name at %C"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Синтаксна грешка у итератору FORALL код %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in ENUMERATOR definition at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -66229,12 +66303,12 @@ msgstr "Индекс у димензији %d је ван граница код
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr ""
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid KIND parameter of %s at %L"
 msgid "KIND part_ref at %C"
@@ -66314,7 +66388,7 @@ msgstr "трансформационо сопствено ‘%s’ код %L н
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Проширење: Израчунавање нестандардног успостављачког израза код %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -66618,7 +66692,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -66681,177 +66755,177 @@ msgstr "Циљ доделе показивача није показивач к
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Циљ доделе показивача није ни циљ ни показивач код %L"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Циљ доделе показивача није ни циљ ни показивач код %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Лош циљ у додели показивача у чистој процедури код %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Додела показивача са векторским индексом на десној страни код %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -66880,7 +66954,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
@@ -67091,12 +67165,12 @@ msgstr "Први аргумент дефинисане доделе код %L м
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -67173,634 +67247,634 @@ msgstr "Двосмислена сучеља ‘%s’ и ‘%s’ у %s код %L
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Иако се другде не помиње, ‘%s’ код %L има двосмислена сучеља"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "Име ‘%s’ код %C је име процедуре"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "Неисправан трећи аргумент у IBITS код %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Кључна реч ‘%s’ код %L је већ придружена другом стварном аргументу"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Више стварних него формалних аргумената у позиву процедуре код %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неочекивана одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L не може бити низ претпостављене величине"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити резервљив"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Недостаје одредница алтернативног враћања у позиву потпрограма код %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Недостаје стварни аргумент за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Исти стварни аргумент придружен намере-%s аргументу ‘%s’ и намере-%s аргументу ‘%s’ код %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и има атрибут показивача"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Аргумент процедуре код %L је локалан у чистој процедури и прослеђује се аргументу намере-%s"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic character length function '%s' at %L must have an explicit interface"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Аутоматска функција знаковне дужине ‘%s’ код %L мора имати експлицитно сучеље"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Кључна реч ‘%s’ код %L није у процедури"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D удволичено са недефинисаним симболом %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Ентитет ‘%s’ код %C је већ присутан у сучељу"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Садржана процедура ‘%s’ код %L у чистој процедури мора такође бити чиста"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "Ознака %s код %L мора бити типа %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Унутрашња функција знаковне вредности ‘%s’ код %L не може бити претпостављене дужине"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Процедура ‘%s’ у %s код %L није ни функција ни потпрограм"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Превише аргумената у позиву ‘%s’ код %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -67917,80 +67991,80 @@ msgstr "Алтернативно враћање није дозвољено ко
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used with too many arguments"
 msgid "init_arglist(): too many arguments"
 msgstr "%<va_start%> употребљено са превише аргумената"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Function %qs as initialization expression at %L"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 #| msgid "transformational intrinsic '%s' at %L is not permitted in an initialization expression"
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "трансформационо сопствено ‘%s’ код %L није дозвољено у успостављачком изразу"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Позив потпрограма сопственог ‘%s’ код %L није чист"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Позив потпрограма сопственог ‘%s’ код %L није чист"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Проширење: Претварање из %s у %s код %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Претварање из %s у %s код %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Проширење: Претварање из %s у %s код %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Претварање из %s у %s код %L"
@@ -67998,24 +68072,24 @@ msgstr "Претварање из %s у %s код %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -68413,13 +68487,13 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -68431,7 +68505,7 @@ msgstr "Ознака END код %C није дозвољена у излазно
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -68481,7 +68555,7 @@ msgstr "Наредба ASSIGNED GOTO код %L захтева целобројн
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
@@ -68585,7 +68659,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -68656,7 +68730,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Очекиван је израз у наредби %s код %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
@@ -68673,91 +68747,91 @@ msgstr "Сопствено код %L не постоји"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "Листа имена PRINT код %C је проширење"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Очекиван је зарез у У/И листи код %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "%s не може да се јави у константном изразу"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "Наредба INQUIRE код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "Неисправна ознака IOLENGTH у наредби INQUIRE код %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "Наредба INQUIRE код %L не може садржати и наводилац FILE и UNIT"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -69035,552 +69109,552 @@ msgstr "Удвостручена наредба PRIVATE код %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "неисправан типски аргумент"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Синтаксна грешка у итератору FORALL код %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Име ‘%s’ у наредби %s код %C није име петље"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Име ‘%s’ у наредби %s код %C није име петље"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "%s statement at %C is not within a construct"
 msgstr "Наредба %s код %C није унутар петље"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "Наредба %s код %C није унутар петље ‘%s’"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "Наредба %s код %C није унутар петље ‘%s’"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "Наредба %s код %C није унутар петље ‘%s’"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C leaving OpenMP structured block"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "Наредба %s код %C напушта структуирани блок ОпенМПа"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "Наредба EXIT код %C окончава петљу !$OMP DO"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "неопходна л-вредност у asm наредби"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "STOP code at %C cannot be negative"
 msgstr "Одредница облика код %L не може бити негативна"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT POST statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT WAIT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "FAIL IMAGE statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "FORM TEAM statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CHANGE TEAM statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "END TEAM statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC TEAM statement at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "LOCK statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC statement at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Застарело: наредба ASSIGN код %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Застарело: Додељена наредба GOTO код %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Листа етикета наредби у GOTO код %C не може бити празна"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad allocate-object in ALLOCATE statement at %C for a PURE procedure"
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Лоша објекат у наредби ALLOCATE код %C у чистој процедури"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs cannot be used with a constant"
 msgid "STAT tag at %L cannot be a constant"
 msgstr "%qs не може бити употребљено са константом"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "Празно BLOCK DATA код %C коси се са претходним BLOCK DATA код %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Недозвољени израз у DEALLOCATE код %C за чисту процедуру"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Алтернативна наредба RETURN код %C дозвољена је само унутар потпрограма"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Проширење: Наредба RETURN у главном програму код %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected component reference at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Синтаксна грешка у имену заједничког блока код %C"
@@ -69588,243 +69662,243 @@ msgstr "Синтаксна грешка у имену заједничког б
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Симбол ‘%s’ код %C је већ у заједничком блоку"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Одредница низа за симбол ‘%s’ у заједничком код %C мора бити експлицитна"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Симбол ‘%s’ у заједничком код %C не може бити низ показивача"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Симбол ‘%s’ у заједничком блоку ‘%s’ код %C посредно се еквивалентира са другим заједничким блоком, ‘%s’"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Име групе листе имена ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Име групе листе имена ‘%s’ код %C је већ употребно придружено и не може се поново одредити."
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Компонента изведеног типа %C није дозвољен члан у еквиваленцији"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Упућивач низа у еквивалецији код %C не може бити одељак низа"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "Еквиваленција код %C захтева два или више објеката"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Покушај посредног преклапања заједничких блокова %s и %s помоћу еквиваленције код %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Очекиван је зарез у У/И листи код %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "EQUIVALENCE statement at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Наредбена функција код %L је рекурзивна"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Наредбена функција код %L је рекурзивна"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function at %C"
 msgstr "Наредбена функција код %L је рекурзивна"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be scalar"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Очекиван је успостављачки израз у CASE код %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Статусни израз код %C мора бити променљива"
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Статусни израз код %C мора бити променљива"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Наредба ELSEWHERE код %C није обухваћена блоком WHERE"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -69868,12 +69942,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -70625,8 +70699,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
@@ -72142,191 +72216,191 @@ msgstr "Неочекиван знак у листи променљивих ко
 msgid "Expected structure component name at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected argument list at %C"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "Параметар врсте за %s код %L мора бити инцијализовани израз"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "Функција ‘%s’ захтева листу аргумената код %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "Премало компонената у конструктору структуре код %C"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "Премало компонената у конструктору структуре код %C"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "Не могу да претворим %s у %s код %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "Structure constructor with named arguments at %C"
 msgstr "атрибут %qE захтева прототипове са именованим аргументима"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many components in structure constructor at %C"
 msgid "Too many components in structure constructor at %L"
 msgstr "Превише компонената у конструктору структуре код %C"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Премало компонената у конструктору структуре код %C"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Премало компонената у конструктору структуре код %C"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Симбол код %C није подесан за израз"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected use of subroutine name '%s' at %C"
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Неочекивана употреба имена потпрограма ‘%s’ код %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Наредбена функција ‘%s’ захтева листу аргумената код %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Function %qs requires an argument list at %C"
 msgstr "Функција ‘%s’ захтева листу аргумената код %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing argument to %qs at %C"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Missing argument list in function %qs at %C"
 msgstr "Недостаје листа аргумената у функцији ‘%s’ код %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Име ‘%s’ се не може употребити као дефинисани оператор код %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Именована константа код %C у еквиваленцији"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol at %L is not a DUMMY variable"
 msgid "%qs at %C is not a variable"
@@ -72703,550 +72777,550 @@ msgstr "Двосмислен симбол ‘%s’ код %L"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Генеричка несопствена процедура ‘%s’ није дозвољена као стварни аргумент код %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Наводилац алтернативног повратка није дозвољен у функцији ‘%s’ код %L"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "Сопствено код %L не постоји"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Сопствено ‘%s’ код %L није дозвољено као стварни аргумент"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "Елементална несопствена процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Не могу да нађем одређену сопствену процедуру за упућивач ‘%s’ код %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %L"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Аргумент-по-вредности код %L није бројевног типа"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Аргумент-по-вредности код %L није дозвољен у овом контексту"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Није дозвољено прослеђивање унутрашње процедуре по локацији код %L"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "Елементална несопствена процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optionalargument with the same rank (12.4.1.5)"
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "‘%s’ код %L је низ и опцион; ако недостаје, не може бити стварни аргумент елементалне процедуре, осим ако постоји не-опциони аргумент истог ранга (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 #| msgid "coverage mismatch for function %qs while reading counter %qs"
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "неслагање покривача за функцију %qs у току читања бројача %qs"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Генеричка функција ‘%s’ код %L није у складу са одређеним сопственим сучељем"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Функција ‘%s’ код %L је сопствена али није сагласна са сопственом"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не могу да разрешим одређену функцију ‘%s’ код %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "упућивач на не-чисту функцију ‘%s’ код %L унутар FORALL %s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, fuzzy, gcc-internal-format
 #| msgid "reference to non-PURE function '%s' at %L inside a FORALL %s"
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "упућивач на не-чисту функцију ‘%s’ код %L унутар FORALL %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Не могу да пишем у унутрашњу датотеку ‘%s’ код %C унутар чисте процедуре"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "%qs at %L is not a function"
 msgstr "‘%s’ код %L није функција"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Функција ‘%s’ декларисана је као CHARACTER(*) и не може бити употребљена код %L пошто није лажни аргумент"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, fuzzy, gcc-internal-format
 #| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Кориснички дефинисана неелементална функција ‘%s’ код %L није дозвољена у конструкцији WORKSHARE"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "Потпрограм ‘%s’ код %L не може позивати самог себе, пошто није рекурзиван"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Функција ‘%s’ код %L не може позивати саму себе, пошто није рекурзивна"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ у блоку FORALL код %L није чист"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ у блоку FORALL код %L није чист"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Позив потпрограма за ‘%s’ код %L није чист"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific subroutine for the generic '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Нема одређеног потпрограма за генеричко ‘%s’ код %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Генерички потпрограм ‘%s’ код %L није у складу са сучељем сопственог потпрограма"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Потпрограм ‘%s’ код %L је сопствени али није сагласан са сопственим"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Не могу да разрешим одређени потпрограм ‘%s’ код %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "„%s“ код %L има тип који није у складу са позивом код %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 #| msgid "Call to ENTRY '%s' at %L is recursive, but subroutine '%s' is not declared as RECURSIVE"
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "Позив за унос ‘%s’ код %L јесте рекурзиван, али потпрограм ‘%s’ није декларисан као такав"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 #| msgid "SUBROUTINE '%s' at %L cannot call itself, as it is not RECURSIVE"
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Потпрограм ‘%s’ код %L не може позивати самог себе, пошто није рекурзиван"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Облици операнада код %L и %L нису усагласиви"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Shape specification at %L cannot be negative"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Одредница облика код %L не може бити негативна"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Недозвољен нулти корак код %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Није наведена десна горња граница низа претпостављене величине код %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Проширење: реални индекс низа код %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс низа код %L је низ ранга %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Индекс почетка подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Индекс почетка подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Индекс почетка подниске код %L је мањи од један"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Индекс краја подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Индекс краја подниске код %L премашује дужину ниске"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут показивача код %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут резервљивости код %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Два или више делимична упућивача са ненултим рангом не смеју бити наведени код %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -73256,12 +73330,12 @@ msgstr "Низ претпостављеног облика код %L мора б
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -73271,300 +73345,300 @@ msgstr "Низ претпостављеног облика код %L мора б
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s',used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’, употребљена у одредничком изразу, користи се код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’ употребљена је код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -73573,298 +73647,298 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Име ‘%s’ се не може употребити као дефинисани оператор код %C"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -73872,12 +73946,12 @@ msgstr "Гранање код %L води у бесконачну петљу"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -73885,199 +73959,200 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -74085,1057 +74160,1057 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "у %s, код %s:%d"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD није декларисано"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -75876,169 +75951,169 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Функција ‘%s’ код %C већ има тип %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Симбол ‘%s’ код %L не може имати тип"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %C"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонента ‘%s’ код %C је приватна компонента у ‘%s’"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Удвостручена етикета наредбе %d код %L и %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Етикета %d код %C је већ поменута као циљ гранања"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Етикета %d код %C је већ поменута код етикета формата"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Етикета %d код %C је претходно употребљена као етикета формата"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Етикета %d код %C је претходно употребљена као циљ гранања"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из модула ‘%s’"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из текуће програмске јединице"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -76078,93 +76153,93 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "лош тип израза током хода (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "Именовани заједнички блок ‘%s’ код %L ће бити исте величине"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "захтевани положај није целобројна константа"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Недозвољен тип упућивача код %L као објекат еквиваленције"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Неусаглашена правила еквиваленције у вези са ‘%s’ код %L и ‘%s’ код %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, fuzzy, gcc-internal-format
 #| msgid "The equivalence set for variable '%s' declared at %L violates alignment requirements"
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "Скуп еквиваленције за променљиву ‘%s’ декларисан код %L крши захтеве равнања"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, fuzzy, gcc-internal-format
 #| msgid "Equivalence for '%s' does not match ordering of COMMON '%s' at %L"
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "Еквиваленција за ‘%s’ не одговара поретку заједничког ‘%s’ код %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, fuzzy, gcc-internal-format
 #| msgid "The equivalence set for '%s' cause an invalid extension to COMMON '%s' at %L"
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "Скуп еквиваленције за ‘%s’ изазива неисправно проширење до заједничког ‘%s’ код %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L"
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Неопходно уметање %d бајтова пре ‘%s’ у заједничком ‘%s’ код %L"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L"
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Неопходно уметање %d бајтова пре ‘%s’ у заједничком ‘%s’ код %L"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L does not exist"
 msgid "COMMON %qs at %L does not exist"
 msgstr "Заједничко ‘%s’ код %L не постоји"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L requires %d bytes of padding at start"
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "Заједничко ‘%s’ код %L затева %d уметнутих бајтова на почетку"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L requires %d bytes of padding at start"
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
@@ -76186,84 +76261,84 @@ msgstr "Очекиван је успостављачки израз код %C"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "сопствена променљива која није процедура"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "Враћај вредности функција у регистрима ФПУа"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "декларација зачеља за модулску променљиву %s већ постоји"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "Unused variable %s declared at %L"
 msgid "Unused variable %qs declared at %L"
 msgstr "Неупотребљена променљива %s декларисана код %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Unused parameter %qs declared at %L"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Враћај вредности функција у регистрима ФПУа"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -76278,27 +76353,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Непознат сопствени оператор"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Непозната функције листе аргумената код %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -76337,24 +76412,24 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr "Лош У/И основни тип (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "implicit mapping of assumed size array %qD"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "optional class parameter"
 msgstr "неисправан параметар %qs"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_omp_workshare(): Bad statement code"
@@ -76480,92 +76555,92 @@ msgstr "недостаје отворена заграда"
 msgid "unable to open file"
 msgstr "не могу да емулирам %qs"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "could not find specs file %s\n"
 msgid "could not parse file offset"
 msgstr "нисам могао да нађем датотеку навода %s\n"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected offset"
 msgstr "неочекиван операнд"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid line in the resolution file"
 msgstr "неисправан регистар у инструкцији"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid resolution in the resolution file"
 msgstr "неисправан регистар у инструкцији"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr ""
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "%s:нисам могао да отворим излазну датотеку ‘%s’\n"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -77823,7 +77898,7 @@ msgstr "недостаје име макроа после %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "недостаје име датотеке после %qs"
@@ -78049,19 +78124,19 @@ msgstr ""
 msgid "unknown TLS model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "непрепозната вредност видљивости „%s“"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
diff --git a/gcc/po/sv.po b/gcc/po/sv.po
index 4e7e4466833..36807ff7d43 100644
--- a/gcc/po/sv.po
+++ b/gcc/po/sv.po
@@ -26,7 +26,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2020-07-08 15:44+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv-list@lists.sourceforge.net>\n"
@@ -1914,83 +1914,83 @@ msgstr "längdmodifierare i strfmon-format"
 msgid "<command-line>"
 msgstr "<kommandorad>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ej stödd operand för kod ”%c”"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ogiltig operand för ”%%%c”"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr "ogiltig vektorkonstant"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "inkompatibla flyttals-/vektorregisteroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "inkompatibla registeroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "operand saknas"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "ogiltig konstant"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "ogiltig operand"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ogiltig operandprefix ”%%%c”"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr "ogiltigt adressläge"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operationen är inte tillåten på typen %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "det går inte att kombinera GNU- och SVE-vektorer i en binär operation"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
@@ -2006,18 +2006,18 @@ msgid "invalid %%r value"
 msgstr "ogiltigt %%r-värde"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "ogiltigt %%R-värde"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
@@ -2047,7 +2047,7 @@ msgstr "ogiltigt %%M-värde"
 msgid "invalid %%U value"
 msgstr "ogiltigt %%U-värde"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
@@ -2057,7 +2057,7 @@ msgstr "ogiltigt %%s-värde"
 msgid "invalid %%C value"
 msgstr "ogiltigt %%C-värde"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
@@ -2067,10 +2067,10 @@ msgstr "ogiltigt %%E-värde"
 msgid "unknown relocation unspec"
 msgstr "okänd avspecifikation av omlokalisering"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ogiltig %%xn-kod"
@@ -2152,35 +2152,35 @@ msgstr "ogiltig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "okänd förmodad konstant"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "ogiltig skiftoperand"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "förutsade Thumb-instruktion"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "förutsade instruktion i villkorlig sekvens"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ej stödd operand för kod ”%c”"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2188,13 +2188,13 @@ msgstr "Ej stödd operand för kod ”%c”"
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktionen aldrig utförd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "föråldrad Maverick-formatkod ”%c”"
@@ -2316,7 +2316,7 @@ msgstr "ej stödd operand"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2533,25 +2533,25 @@ msgstr "felaktig operand till output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "felaktig operand till output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr "felaktig ADDR_SPACE_GLOBAL-adress"
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, c-format
 msgid "invalid operand %%xn code"
 msgstr "ogiltig operand till %%xn-kod"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr "operanden %%xn är inte giltig för QImode"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, c-format
 msgid "invalid fp constant"
 msgstr "ogiltig fp-konstant"
@@ -2695,7 +2695,7 @@ msgstr "ogiltig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ogiltig %%P-operand"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -2749,7 +2749,7 @@ msgid "post-increment address is not a register"
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -2801,8 +2801,8 @@ msgstr "%%%c är inte ett giltigt operandprefix"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "felaktig användning av ”%%%c”"
@@ -2933,165 +2933,219 @@ msgstr "Slut på stackutrymme.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Försök köra ”%s” i skalet för att öka dess gräns.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "%<-mvsx%> kräver hårdvaruflyttal"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> behöver indexerad adressering"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "%<-mvsx%> och %<-mno-altivec%> är inkompatibla"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "%<-mno-altivec%> avaktiverar vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<--mquad-memory%> kräver 64-bitarsläge"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> förutsätter 64-bitarsläge"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> är inte tillgängligt i läget med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "ogiltigt %%J-värde"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "ogiltigt %%D-värde"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, c-format
 msgid "invalid %%t value"
 msgstr "ogiltigt %%t-värde"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "ogiltigt %%V-värde"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "ogiltigt %%z-värde"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 och __ibm128 kan inte användas i samma uttryck"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 och long double inte användas i samma uttryck"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 och long double kan inte användas i samma uttryck"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to type %<bfloat16_t%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "ogiltig konvertering från %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "ogiltig konvertering till %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to type %<bfloat16_t%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "ogiltig konvertering från %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "ogiltig konvertering till %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3102,88 +3156,88 @@ msgstr "symboliska minnesreferenser stödjs endast på z10 eller senare"
 msgid "cannot decompose address"
 msgstr "kan inte dekomponera adress."
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ogiltig jämförelseoperator för utmatningsmodifieraren ”E”"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ogiltig referens för utmatningsmodifieraren ”J”"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”O”"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”R”"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "minnesreferens förväntas för utmatningsmodifieraren ”S”"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ogiltig adress för ”S”-utmatningsmodifierare"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”N”"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”M”"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ogiltig konstant för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ogiltig konstant - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ogiltig konstant vektor för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ogiltigt uttryck - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ogiltigt uttryck för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorargument skickat till funktion utan prototyp"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr "typer skiljer i teckenhet"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr "binäroperator stödjer inte två vektorbooleanoperander"
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr "den binära operatorn stödjer inte vektor-bool-operand"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binär operator stödjer inte blandning av operanderna vektorboolean och flyttalsvektor"
 
@@ -3446,8 +3500,8 @@ msgstr "({anonym})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
@@ -3467,7 +3521,7 @@ msgstr "%<;%> förväntades"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -3475,7 +3529,7 @@ msgstr "%<)%> förväntades"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -3493,21 +3547,21 @@ msgstr "%<;%>, %<,%> eller %<)%> förväntades"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -3518,12 +3572,12 @@ msgstr "%<{%> förväntades"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
@@ -3532,7 +3586,7 @@ msgstr "%<while%> förväntades"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -3541,18 +3595,18 @@ msgstr "%<,%> förväntades"
 msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
@@ -3560,19 +3614,19 @@ msgstr "%<,%> eller %<)%> förväntades"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
@@ -3581,7 +3635,7 @@ msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -3592,33 +3646,33 @@ msgstr "%<<%> förväntades"
 msgid "expected label"
 msgstr "etikett förväntades"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr "kandidat:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 msgid "  after user-defined conversion:"
 msgstr "  efter användardefinierad konvertering:"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
 msgstr[1] "kandidater är:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "hopp till etikett %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "hopp till case-etikett"
 
@@ -3707,7 +3761,7 @@ msgstr "<mallparameterfel>"
 msgid "<statement>"
 msgstr "<sats>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<okänd>"
@@ -3873,48 +3927,48 @@ msgstr "konvertering konverterar bort konstantskap"
 msgid "source type is not polymorphic"
 msgstr "källtypen är inte polymorfisk"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "fel typ på argument till unärt minus"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "fel typ på argument till unärt plus"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "fel typ på argument till bitkomplement"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "fel typ på argument till abs"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "fel typ på argument till konjunktion"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "i argument till unärt !"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "ingen pre-ökningsoperator för typen"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "ingen post-ökningsoperator för typen"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "ingen pre-minskningsoperator för typen"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "ingen post-minskningsoperator för typen"
 
@@ -3954,17 +4008,17 @@ msgstr "Otillåtet typ i teckenkonkatenering vid %L"
 msgid "elemental binary operation"
 msgstr "elementär binär operation"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "argument ”a%d” och ”a%d” för inbyggd ”%s”"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "argumenten ”%s” och ”%s” för inbyggd %s"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "argument ”%s” och ”%s” för inbyggd ”%s”"
@@ -4043,7 +4097,7 @@ msgstr "Vektorbindning stämmer inte för dimension 2 av vektorn (%ld/%ld)"
 msgid "Driving:"
 msgstr "Driver:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "aktuellt argument till INTENT = OUT/INOUT"
 
@@ -4058,7 +4112,7 @@ msgstr "intern enhet i WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s-tagg med INQUIRE"
@@ -4164,11 +4218,11 @@ msgstr "block-IF"
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
@@ -4176,199 +4230,199 @@ msgstr "pekartilldelning"
 msgid "simple IF"
 msgstr "enkelt IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "elementär procedur"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr "allokerbart argument"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr "asynkront argument"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "valfritt argument"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "pekarargument"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "målargument"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "värdeargument"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr "volatilt argument"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr "argument med antagen form"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr "argument med antagen ordning"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr "co-vektorargument"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr "parametriserat härlett typargument"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr "polymorft argument"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "attributet NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr "argument med antagen typ"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "vektorresultat"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr "pekare eller allokerbart resultat"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr "resultat med teckenlängd som inte är konstant"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr "bind(c)-procedur"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Ogiltigt sammanhang för NULL()-pekare vid %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand till unär numerisk operator %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Oväntade entiteter av härledd typ i binär inbyggd numerisk operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operander till binär numerisk operator %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanderna till strängkonkateneringsoperatorn vid %%L är %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till logiska operatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand till operatorn .not. vid %%L är %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-kvantiteter kan inte jämföras vid %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logiska vid %%L måste jämföras med %s istället för %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till jämförelseoperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Okänd operator %%<%s%%> vid %%L; menade du ”%s”?"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Okänd operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Inkonsistenta ordningar för operator vid %%L och %%L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
@@ -4381,27 +4435,27 @@ msgstr "Olika CHARACTER-längder (%ld/%ld) i vektorkonstruerare"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Heltalsspill vid beräkning av mängden minne att allokera"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Värdet på PDT LEN-parametern ”%s” stämmer inte överens med det i attrappdeklarationen"
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd matchar inte den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd är kortare än den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Målet för återavbildning av ordning är för litet (%ld < %ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr "Tilldelning av skalär till en oallokerad vektor"
 
@@ -4476,7 +4530,7 @@ msgstr "Enhetsnummer i I/O-sats är för stort"
 msgid "Assigned label is not a target label"
 msgstr "Tilldelad etikett är inte en måletikett"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Ogiltigt bildnummer %d i SYNC IMAGES"
@@ -4899,7 +4953,7 @@ msgstr "Varna om vektortemporärer skapas."
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
@@ -5481,8 +5535,8 @@ msgstr "Lägg till understrykningstecken till externt synliga namn."
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
@@ -7923,105 +7977,100 @@ msgstr "Varna för kodvägar i vilka en pekare till en förlegat stackram använ
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Varna för kodvägar i vilka ett oinitierat värde används."
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr "Varna om koden är för komplicerad för att analyseraren skall kunna utforska den fullständigt."
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr "Begränsa analyseraren till att köra just den namngivna kontrollen."
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr "Undvik att kombinera flera satser till en exploderad båge."
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr "Ge en notering när felmeddelande avdupliceras."
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr "Rensa ut tillstånd som inte behövs under analysen."
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr "Slå samman tillräckligt lika tillstånd under analysen."
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr "Aktivera transitivtet av begränsningar under analysen."
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr "Approximera effekten av funktionsanrop för att förenkla analysen."
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr "Mata ut mer utförliga beskrivningar av styrflödet i felmeddelanden."
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr "Mata ut mer utförliga beskrivningar av tillståndsändringar i felmeddelanden."
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr "Styr vilka händelser som visas i diagnostikvägar."
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "Dumpa diverse intern information om analyseraren KÄLLFIL.analyzer.txt."
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr "Dumpa diverse intern information om analyseraren till standard fel."
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr "Dumpa analyserarspecifik anropsgrafsinformation till en fil KÄLLFIL.callgraph.dot."
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr "Dumpa analyserarens exploderade graf till en fil KÄLLFIL.eg.dot."
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr "Mata ut meddelanden som visar platsen för noder i den exploderade grafen."
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr "Dumpa en textuell representation av den exploderade grafen till KÄLLFIL.eg.txt."
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr "Dumpa en textuell representation av den exploderade grafen till KÄLLFIL.eg-ID.txt."
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr "Dumpa tillståndsrensningsinformation till en fil KÄLLFIL.state-purge.dot."
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr "Dumpa analyserarens supergraf till en fil KÄLLFIL.supergraph.dot."
@@ -12452,9 +12501,10 @@ msgid "Enable default conversions between __float128 & long double."
 msgstr "Aktivera standardkonvertering mellan __float128 & long double."
 
 #: config/rs6000/rs6000.opt:572
-#, no-c-format
-msgid "Use instructions for a future architecture."
-msgstr "Använd instruktioner för en framtida arkitektur."
+#, fuzzy, no-c-format
+#| msgid "Use vector instructions added in ISA 3.0."
+msgid "Use instructions added in ISA 3.1."
+msgstr "Använd vektorinstruktioner som lades till i ISA 3.0."
 
 #: config/rs6000/rs6000.opt:576
 #, no-c-format
@@ -12466,6 +12516,12 @@ msgstr "Generera (generera inte) prefixade minnesinstruktioner."
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Generera (generera inte) pc-relativ minnesadressering."
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate (do not generate) prefixed memory instructions."
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Generera (generera inte) prefixade minnesinstruktioner."
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17406,8 +17462,9 @@ msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl leve
 msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tStyr nivån av reproducerbarhet av profilen som samlas av -fprofile-generate."
 
 #: common.opt:2213
-#, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+#, fuzzy, no-c-format
+#| msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr "Ta bort prefix från absoluta sökvägar före hantering av namn för -fprofile-generate= och -fprofile-use=."
 
 #: common.opt:2217
@@ -18050,367 +18107,367 @@ msgstr "Utför slingutrullning när iterationsantalet är känt."
 msgid "Perform loop unrolling for all loops."
 msgstr "Utför slingutrullning för alla slingor."
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Tillåt optimeringar för flyttalsaritmetik som kan ändra resultatet av operationen på grund av avrundning."
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Samma som -fassociative-math för uttryck som inkluderar division."
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Tillåt matematikoptimeringar som kan strida mot IEEE- eller ISO-standarder."
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr "Utför slingavväxling."
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr "Utför slingdelning."
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr "Versioner av slingor baserat på om indexen har steg på ett."
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr "Generera bara upprullningstabeller för undantagshantering."
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Använd bfd-länkaren istället för standardlänkaren."
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "Använd gold-länkaren istället för standardlänkaren."
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "Använd lld LLVM-länkaren istället för standardlänkaren."
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr "Utför variabelspårning."
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Utför variabelspårning genom att annotera tilldelningar."
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Växla -fvar-tracking-assignments."
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Utför variabelspårning och tagga också variabler som är oinitierade."
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "Aktivera vektorisering av träd."
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr "Aktivera slingvektorisering i träd."
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktivera grundblocksvektorisering (SLP) i träd."
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "-fvect-cost-model=[unlimited|dynamic|cheap]\tAnger kostnadsmodellen för vektorisering."
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tAnger kostnadsmodellen för vektorisering för kod markerad med ett simd-direktiv."
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Aktivera den dynamiska kostnadsmodellen för vektoriseraren.  Bevarad för bakåtkompatibilitet."
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktivera kopiepropagering av skalärutvecklingsinformation."
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr "Lägg till extra kommentarer till assemblerutdata."
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tAnge standardvärde för symbolsynlighet."
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr "Validera vtable-pekare före de används."
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr "Mata ut verifieringsräknare för vtable."
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr "Mata ut information om verifieringspekaruppsättningar för vtable."
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr "Använd uttrycksvärdeprofiler i optimeringar."
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Konstruera nät och dela orelaterade användningar av en enskild variabel."
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktivera villkorlig eliminering av död för inbyggda anrop."
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr "Utför optimering av hela program."
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr "Anta att pekarspill slår runt."
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Anta att spill vid teckenaritmetik slår runt."
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Lägg nollinitierad data i bss-sektionen."
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Generera felsökningsinformation i standardformat."
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "Anta att assemblern stödjer .loc-direktiv (DWARF2+)."
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Anta att assemblern stödjer vyer i .loc-direktiv (DWARF2+)."
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Spara DW_AT_decl_column och DW_AT_call_column i DWARF."
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Generera felsökningsinformation i standardversion av DWARF-formatet."
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Generera felsökningsinformation i DWARF v2-format (eller senare)."
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr "Generera felsökningsinformation i normalt utökat format."
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Generera utökad information om ingångspunkt för inline:ade funktioner."
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr "Beräkna locview-återställningspunkter baserat på uppskattningar av instruktionslängd."
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generera inte DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes med GNU-utvidgningar."
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Notera gcc:s kommandoradsflaggor i DWARF DW_AT_producer."
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "Generera felsökningsinformation i separata .dwo-filer."
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr "Generera felsökningsinformation i STABS-format."
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr "Generera felsökningsinformation i utökat STABS-format."
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Mata ut progressiva rekommenderade brytpunktsplatser."
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Mata inte ut DWARF-tillägg utöver vald version."
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr "Lägg till beskrivningsattribut till några DWARF DIE:er som inte har något namnattribut."
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr "Växla generering av felsökningsinformation."
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr "Utöka variabelplatslistor med progressiva vyer."
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr "Generera felsökningsinformation i VMS-format."
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr "Generera felsökningsinformation i XCOFF-format."
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Generera felsökningsinformation i utökat XCOFF-format."
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "Generera komprimerade felsökningssektioner."
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tGenerera komprimerade felsökningssektioner i formatet <format>."
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<kat>\tSätt <kat> att vara standardbibliotek för insticksmoduler."
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <kat>\tSätt <kat> att vara inkluderingsunderbiblioteket för multiarkitekturer."
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fil>\tSkriv utdata i <fil>."
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr "Aktivera funktionsprofilering."
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr "Som -pedantic men ange dem som fel."
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Visa inte kompilerade funktioner eller tiden som förbrukats."
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Aktivera utförlig utskrift."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Visa kompilatorns version."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Undertryck varningar."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Skapa ett delat bibliotek."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Skapa inte ett dynamiskt länkat positionsoberoende körbart program."
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Skapa ett dynamiskt länkat positionsoberoende körbart program."
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Skapa ett statiskt positionsoberoende körbart program."
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr "Använd anroparens sparregister mellan anrop om möjligt."
@@ -19562,8 +19619,8 @@ msgstr "Gräns för antalet körtidskontroller som läggs in av vektoriserarens
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Gräns för antalet körtidskontroller som läggs in av vektoriserarens slingversionering för justeringskontroller."
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "beräknat värde används inte"
@@ -19589,7 +19646,7 @@ msgid "expected boolean type"
 msgstr "boolesk typ förväntades"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "heltal förväntades"
@@ -19653,7 +19710,7 @@ msgstr "inte tillräckligt med argument"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "för många argument"
@@ -20007,7 +20064,7 @@ msgstr "ignorerar attributet %qE eftersom det står i konflikt med attributet %q
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20091,12 +20148,12 @@ msgstr "typattribut ignoreras efter att typen redan är definierad"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20114,8 +20171,8 @@ msgstr "attributet %qE ignorerat"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "saknat attribut %<target%> för flerversioners %qD"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidigare deklaration av %qD"
@@ -20234,7 +20291,7 @@ msgstr "det referade argumentet deklarerades här"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "index %qwi till en konstant sträng pekar utanför dess gränser"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE är deklarerad här"
@@ -20521,7 +20578,7 @@ msgstr "otillåtet argument 0 till %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack ()%>"
@@ -20811,12 +20868,12 @@ msgstr "%<asm%>-överskrivning står i konflikt med utdataoperand"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "%<asm%>-överskrivning står i konflikt med indataoperand"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "stackskyddet skyddar inte lokala variabler: buffert med variabel längd"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "stackskyddet skyddar inte funktioner: alla lokala vektorer är mindre än %d byte långa"
@@ -21326,302 +21383,302 @@ msgstr "grundblock inte utlagda i ordning"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antal gb-noter i instruktionskedjan (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "antal anropande bågar är felaktigt"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr "saknat indirekt anrop i en spekulativ anropssekvens"
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr "indirekt anrop i en spekulativ anropssekvens har ingen spekulativ flagga"
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr "spekulativa bågar är inte närliggande"
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr "direkt anrop av %s i en spekulativ anropssekven har ingen spekulativ flagga"
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr "direkt anrop av %s i en spekulativ anropssekvens har speculative_id %i utanför intervallet"
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr "dubblerat direkt anrop av %s i en spekulativ anropssekvens med spekulativ_id %i"
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr "call stmt-hachen pekar inte på den första direkta bågen av en spekulativ anropssekvens"
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr "dubblerad referens %s i en spekulativ anropssekvens med spekulativ_id %i"
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "saknade direkta anrop för spekulation %i"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr "referens saknas för spekulation %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr "antalet spekulativa mål %i stämmer inte med num_speculative_call_targets %i"
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "aux-fält satt för båge %s->%s"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "cgraph-antalet är felaktigt"
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "inline-klon i samma comdat-grupplista"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "inline-klonantal är inte kompatibelt"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "tp_first_run måste vara icke-negativt"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "lokala symboler måste vara definierade"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "externt synlig inline-klon"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "inline-klon som man tar adressen till"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "inline-klon tvingas till utdata"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr "calls_comdat_local är satt utanför någon comdat-grupp"
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr "felaktig flagga till calls_comdat_local"
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "attributet malloc skall användas på en funktion som returnerar en pekare"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux-fält satt för indirekt båge från %s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "bågräknaren är inte kompatibel med funktionsräknaren"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "En indirektbåge från %s är inte markerad som indirekt eller har associerad indirect_info, motsvarande sats är: "
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr "bågen har både call_stmt och lto_stmt_uid satta"
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "comdat-lokal funktion anropad av %s utanför dess comdat"
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to-pekare är fel"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "flera inline-anropare"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "inlined_to-pekare angiven för noninline-anropare"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "anropsbågantal stämmer inte med GB-antal"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "indirekta anropsantal stämmer inte med GB-antal"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr "referensen har både stmt och lto_stmt_uid satta"
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to-pekare är angivet men inga företrädare finns"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to-pekare refererar till sig själv"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node har fel clone_of"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node har fel klonlista"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "cgraph_node är i klonlistan men den är inte en klon"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "cgraph_node har fel prev_clone-pekare"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "dubbellänkad lista av kloner trasig"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias har anropsbågar"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias har icke-alias-referens"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias har mer än en aliasreferens"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Analyserat alias har ingen referens"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Ingen båge ut från snuttnod"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Mer än en båge ut från en snuttnod"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Snuttar får inte ha en kropp"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "delat anropssats:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "bågpekare till fel deklaration:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "ett indirekt båge med okänd anropsmål motsvarande ett call_stmt med en känd deklaration:"
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "anropsgrafsbåge saknas för anropssats:"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referens till död sats"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "båge %s->%s har ingen motsvarande anropssats"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "en indirekt båge från %s har inget motsvarande call_stmt"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr "ursprung saktas för en nod i en nästad lista"
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "ursprunget pekar på en annan förälder"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node misslyckades"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s sektion %s.%d saknas"
@@ -21707,12 +21764,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "attributet %<weakref%> ignorerat för att variabeln är initierad"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F är använd men inte definierad"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F är deklarerad %<static%> men definieras aldrig"
@@ -21864,7 +21921,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO-stöd har inte aktiverats i denna konfiguration"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "det går inte att öppna %s: %m"
@@ -22191,22 +22248,22 @@ msgstr "%<-gdwarf-6%> matas ut som version 5 med inkompatibiliteter"
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "odelegitimerad UNSPEC %s (%d) funnen på variabelplats"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "ogiltig rtl-delning hittad i instruktionen"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "delad rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "internt konsistensfel"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_insn använd där emit_jump_insn behövs:\n"
@@ -22266,7 +22323,7 @@ msgstr "%<region_array%> stämmer inte med %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> stämmer inte med %<region_tree%>"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs misslyckades"
@@ -22296,12 +22353,12 @@ msgstr "omvänd lagringsordning för %s-läget"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "skrivning av %wu-bitsdata utanför gränsen för destinationsobjektet, data avhuggen till %wu bitar"
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kanrop av %qs deklarerad med attributet error: %s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K anrop av %qs deklarerad med attributet warning: %s"
@@ -22316,7 +22373,7 @@ msgstr "ogiltigt argument %qs till %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "ramstorleken på %wu byte är större än %wu byte"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "det gick inte att öppna slutgiltig instruktionsdumpfil %qs: %m"
@@ -22336,37 +22393,37 @@ msgstr "stor fixdecimalskonstant implicit trunkerad till fixdecimaltyp"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "jämförelsen är alltid %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> mellan omatchade olikhetstester är alltid 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> mellan ömsesidigt uteslutande likhetstester är alltid 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "antar att teckenspill inte förekommer vid reduktion av konstant i jämförelse"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "antar att teckenspill inte förekommer vid kombination av konstanter runt en jämförelse"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vikningskontroll: originalträdet ändrat av vikning"
@@ -22984,13 +23041,13 @@ msgstr "funktionen kan returnera adressen till en lokal variabel"
 msgid "function returns address of local variable"
 msgstr "funktionen returnerar adress till en lokal variabel"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "deklarerad här"
@@ -23558,10 +23615,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "%G%qD på avståndet %s är utanför gränserna för objekt %qD med typen %qT"
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -23726,7 +23783,7 @@ msgstr "%qE inte angiven i omgivande %<target%>"
 msgid "enclosing %<target%>"
 msgstr "omgivande %<target%>"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabeln %qE deklarerad i omgivande %<host_data%>-region"
@@ -23776,13 +23833,13 @@ msgstr "icke-skalär variabel %qD i villkorlig %<lastprivate%>-klausul"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr "reduktionsmodifieraren %<task%> på en konstruktion med en klausul %<nowait%>"
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "en %<inscan%> %<reduction%>-klausul på en %qs-konstruktion"
@@ -23792,147 +23849,147 @@ msgstr "en %<inscan%> %<reduction%>-klausul på en %qs-konstruktion"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-klausul för en annan variabel än en slingiterator angiven vid konstruktion kombinerad med %<distribute%>"
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "avbildningsfältet %qE med variabel längds post"
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE förekommer mer än en gång i avbildningsklausuler"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate-variabel %qE är inte privat threadprivate eller private i yttre sammanhang"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s-variabel %qE är privat i yttre sammanhang"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-klausulmodifierare förväntades snarare än %qs"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr "%qD angivet i en %qs-klausul men inte i en %<inscan%> %<reduction%>-klausul av den inneslutande konstruktionen"
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD i implicit %<map%>-klausul"
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i implicit %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "samma variabel använd i %<firstprivate%>- och %<lastprivate%>-klausuler vid %<distribute%>-konstruktion"
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr "inkompatibel dataklausul med reduktion på %qE; befordrar till %<present_or_copy%>"
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr "%qD angivet i en %<inscan%> %<reduction%>-klausul men inte i en %<scan%>-direktivklausul"
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ogiltig privat reduktion av %qE"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr "en %<inscan%> %<reduction%>-klausul använd tillsammans med en %<linear%>-klausul för en annan variabel en slingitereraren"
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr "%<mutexinoutset%>-sort i %<depend%>-klausul vid %<taskwait%>-konstruktion"
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr "villkorlig %<lastprivate%>-klausul på slingitereraren %qD ignorerad"
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "%<bind%>-klausul inte angiven på en %<loop%>-konstruktion som inte är nästad inuti en annan OpenMP-konstruktion"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr "%<bind(parallel)%> på en %<loop%>-konstruktion nästad inuti en %<simd%>-konstruktion"
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "%<bind(teams)%> på en %<loop%>-region som inte är strikt nästad inuti en %<teams%>-region"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr "%<lastprivate%>-klausul på en %<loop%>-konstruktion refererar till en variabel %qD som inte är slingiteratorn"
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-konstruktion med %<depend%>-klausul måste vara nära innesluten inuti en slinga med %<ordered%>-klausul med en parameter"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "variabeln %qE är inte en iterator av den yttersta slingan %d, %qE förväntades"
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "antalet variabler i %<depend%>-klausul med %<sink%>-modifierare stämmer inte med antalet iterationsvariabler"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr "mer än en %<depend%>-klausul med %<source%>-modifierare på en %<ordered%>-konstruktion"
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr "%<depend%>-klausul med %<source%>-modifierare angiven tillsammans med %<depend%>-klausuler med %<sink%>-modifierare på samma konstruktion"
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification misslyckades"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT konverteras till %qT när det skickas via %<...%>"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(alltså skall du skicka %qT och inte %qT till %<va_arg%>)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "om denna kod nås, kommer programmet att avbryta"
@@ -24007,7 +24064,7 @@ msgstr "symbol %u har %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "symbol %u har %<y-location == %u%>"
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "ogiltigt användning av attributet %<fallthrough%>"
@@ -24279,54 +24336,54 @@ msgstr "minneslayouten stämmer inte"
 msgid "the extra base is defined here"
 msgstr "den andra basen är definierad här"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop"
 msgstr[1] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop"
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop utfört %lli gånger"
 msgstr[1] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop utförda %lli gånger"
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop"
 msgstr[1] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop"
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] "Deklaration av metoden %qD final skulle möjliggöra avvirtualisering av %i anrop"
 msgstr[1] "Deklaration av metoden %qD final skulle möjliggöra avvirtualisering av %i anrop"
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop utfört %lli gånger"
 msgstr[1] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop utförda %lli gånger"
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] "Deklaration av metoden %qD final skulle möjliggöra avvirtualisering av %i anrop utfört %lli gånger"
 msgstr[1] "Deklaration av metoden %qD final skulle möjliggöra avvirtualisering av %i anrop utförda %lli gånger"
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "ogiltig fnsummary i LTO-ström"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "ipa-inline-sammanfattning saknas i indatafil"
@@ -24356,37 +24413,37 @@ msgstr "funktionen kan vara en kandidat för attributet %qs om man vet att den r
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "ipa-referenssammanfattning saknas i ltrans-enhet"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr "Åtkomstavstånd före föräldraavståndet"
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr "Atkomststorleken är större eller lika med sin förälderstorlek"
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr "Åtkomsten slutar utanför sin förälder"
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr "Åtkomsten överlappar med sitt syskon"
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr "IPA-SRA åtmkomstverifiering misslyckades"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr "Funktionen %qs, parametern %u, har IPA-SRA-åtkomst som överlappar"
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr "Funktionen %s, parameter %u, används men har inte någon säker IPA-SRA-åtkomst"
@@ -24436,57 +24493,57 @@ msgstr "inkonsistenta operandbegränsningar i en %<asm%>"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "maximalt antal genererade omladdningsinstruktioner per instruktion uppnått (%d)"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr "funktionen %qs har refererats i avlastad kod men har inte markerats att inkluderas i den avlastade koden"
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr "variabeln %qs har refererats i avlastad kod men har inte markerats att inkluderas i den avlastade koden"
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "bytekodström: hittade multipla instanser av cgraph-nod med uid %d"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "bytekodström: ingen anropare funnen när båge lästes"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "bytekodström: ingen anropad funnen när båge lästes"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "bytekodström: tom cgraph-nod funnen"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Som mest %i profilkörningar stödjs.  Kanske en skadad profil?"
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Profilinformation i %s är skadad"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "det går inte att hitta LTO-cgraph %s"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "det går inte att hitta LTO-avsnittsreferenser i %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "ogiltig avlastningstabell i %s"
@@ -24738,52 +24795,52 @@ msgstr "%<depend%>-klausul med %<sink%>-modifireare väntar på en lexikalt sena
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr "%<depend%>-klausul med %<sink%>-modifierare refererar till en iteration som aldrig är i iterationsrymden"
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr "%qs anger en motstridig nivå av parallellism"
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr "… till den tidigare %qs-klausulen här"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr "%<%s%> kan inte används på %qD, som redan har markerats med ett OpenMC ”declare target”-direktiv"
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr "inkompatibel %qs-klausul när %<%s%> används på %qD, som redan har markerats med ett OpenACC ”routine”-direktiv"
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr "saknad %qs-klausul när %<%s%> används på %qD, som redan har markerats med ett OpenACC ”routine”-direktiv"
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "… med en %qs-klausul här"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr "… utan en %qs-klausul i närheten av här"
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> åsidosätter andra OpenACC-slingspecificerare"
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> står i konflikt med andra OpenACC-slingspecificerare"
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "den inre slingan använder samma OpenACC-parallellism som den omgivande slingan"
@@ -25004,52 +25061,52 @@ msgstr "ogiltig ingång till strukturerat %s-block"
 msgid "invalid branch to/from %s structured block"
 msgstr "ogiltig gren till/från strukturerat %s-block"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr "operand till %<-fopenacc-dim%> är felformulerad vid %qs"
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr "rutinanropet använder samma OpenACC-parallellism som den omgivande slingan"
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr "kringliggande slinga här"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr "rutinanropet använder OpenACC-parallellism som är otillåtet av den omgivande rutinen"
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr "slingan använder OpenACC-parallellism som är otillåtet av den omgivande rutinen"
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "rutinen %qD är deklarerad här"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr "felaktigt nästad OpenACC-slingeparallellism"
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr "otillräcklig partitionering tillgänglig för att parallellisera elementslinga"
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr "otillräcklig partitionering tillgänglig för att parallellisera brickslinga"
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr "otillräcklig partitionering tillgänglig för att parallellisera slinga"
@@ -26380,132 +26437,132 @@ msgstr "%<-fcf-protection=return%> stödjs inte för denna målarkitektur"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> stödjs inte längre"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "instruktionsschemaläggning stödjs inte för denna målmaskin"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "denna målmaskin har inte fördröjda grenar"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "%<-f%sleading-underscore%> stödjs inte på denna målmaskin"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "det gick inte att stänga nollställd instruktionsdumpfil %qs: %m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "målsystemet stödjer inte felsökningsformatet %qs"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "variabelspårning begärd, men oanvändbar om den inte felsökningsinformation skapas"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "variabel spårning begärd, men stödjs inte av detta felsökningsformat"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments ändrar selektiv schemaläggning"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr "utan %<-gdwarf-5%> är %<-gvariable-location-views=incompat5%> likvärdigt med %<-gvariable-location-views%>"
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr "%<-ginternal-reset-location-views%> avaktiveras tvingande utan %<-gvariable-location-views%>"
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr "%<-ginline-points%> avaktiveras tvingande utan %<-gstatement-frontiers%>"
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "%<-ffunction-sections%> stödjs inte för denna målarkitektur"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "%<-fdata-sections%> stödjs inte för denna målarkitektur"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "%<-fprefetch-loop-arrays%> stödjs inte för denna målarkitektur"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "%<-fprefetch-loop-arrays%> stödjs inte för denna målarkitektur (försök med %<-march%>-flaggor)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "%<-fprefetch-loop-arrays%> stödjs inte med %<-Os%>"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "%<-fassociative-math%> avslagen, andra flaggor går före"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr "%<-fstack-clash-protection%> stödjs inte på mål där stacken växer från lägre mot högre adresser"
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr "%<-fstack-check=%> och %<-fstack-clash_protection%> är ömsesidigt uteslutande; avaktiverar %<-fstack-check=%>"
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "%<-fstack-protector%> stödjs inte av denna målarkitektur"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "%<-fsanitize=address%> och %<-fsanitize=kernel-address%> stödjs inte för denna målarkitektur"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "fel vid skrivning till %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "fel när %s stängdes: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr "mpfr är inte konfigurerat att hantera alla flyttalslägen"
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "självtester är inkompatibla med %<-E%>"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "självtester är inte aktiverade i detta bygge"
@@ -26600,172 +26657,172 @@ msgstr "%K%<asm%> är inte tillåtet i en %<transaction_safe%>-funktion"
 msgid "ignoring loop annotation"
 msgstr "ignorerar slingannotering"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "konstant inte omräknad när %<ADDR_EXPR%> ändrades"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "sidoeffekter inte omräknade när %<ADDR_EXPR%> ändrades"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "%<DECL_GIMPLE_REG_P%> satt på en variabel vars adress tas"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "adress tagen, men %<TREE_ADDRESSABLE%>-biten är inte satt"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "ogiltigt uttryck som min-l-värde"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "ogiltig operand i indirektreferens"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr "icke skalär %qs"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "ogiltig position eller storleksoperand till %qs"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr "precisionen på typen på heltalsresultatet stämmer inte med fältstorleken på %qs"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "lägesstorleken på resultat av icke-heltalstyp stämmer inte med fältstorleken på %qs"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "%qs av icke-läges-precisionsoperand"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "position plus storlek överskrider storleken på det refererade objektet i %qs"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr "typfel i %qs-referens"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr "icke-toppnivås %qs"
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "ogiltig operand till %qs"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "typer stämmer inte i %qs"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "ogiltig %qs-avståndsoperator"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "konvertering av %qs på vänster sida av %qs"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "konvertering av register till en annan storlek i %qs"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "ogiltig adressoperand i %qs"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "ogiltig avståndsoperand i %qs"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr "felaktig klick i %qs"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr "%qs i gimple IL"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "gimple-anrop har två mål"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "gimple-anrop har inget mål"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "ogiltig funktion i gimple-anrop"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "icke-funktion i gimple-anrop"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "ogiltigt pure-const-tillstånd för funktion"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "ogiltig vänstersida i gimple-anrop"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr "LHS i %<noreturn%>-anrop"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "ogiltig konvertering i gimple-anrop"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "ogiltig statisk kedja i gimple-anrop"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "statisk kedja med funktion som inte använder en"
@@ -26776,509 +26833,509 @@ msgstr "statisk kedja med funktion som inte använder en"
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_unreachable%> eller %<__builtin_trap%> anropad med argument"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "ogiltigt argument till gimple-anrop"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "ogiltiga operander i gimple-jämförelse"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "typen på operander i jämförelse stämmer inte överens"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "ej stödd operation eller typ för vektorjämförelse som returnerar en boolean"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "icke-vektoroperander i vektorjämförelse"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "ogiltig resultattyp i vektorjämförelse"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "felaktig resultattyp i jämförelse"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "icke-register som vänstersida av unär operation"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "ogiltig operand i unär operation"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr "ogiltiga vektortyper i nop-konvertering"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "ogiltiga typer i nop-konvertering"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "ogiltiga typer adressrymdskonvertering"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "ogiltiga typer i fixdecimalskonvertering"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "ogiltiga typer i konvertering till flyttal"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "ogiltiga typer i konvertering till heltal"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "typer stämmer inte i %qs-uttryck"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "ogiltiga typer för %qs"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr "%qs skall vara från en skalär till en liknande vektor"
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "icketrivial konvertering i unär operation"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "ej register som vänstersida av binär operation"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "ogiltiga operander binär operation"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "ogiltig operander som inte är vektor till %qs"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr "ogiltiga (pekar)operander %qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "vektortyper förväntades i %qs"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "typfel i binärt uttryck"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "icke-register som vänstersida av treställig operation"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "ogiltiga operander treställig operation"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr "första argumentet till en %qs måste vara av boolesk vektortyp med samma antal element som resultatet"
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "vektortyper förväntades i %qs"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "vektorer med olika elementantal funna %qs"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "ogiltig masktyp i %qs"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr "otillåten typkombination i %qs"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "ogiltig position eller storlek i %qs"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs in i icke-läges-precisionsoperand"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr "insättning utanför intervallet i %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qs inte på elementgräns"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "icketrivial konvertering i %qs"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "%qs vänstersida i clobber-sats"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "ogiltig operand till %qs"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "ogiltig högersida för gimple-minneslagring: %qs"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "felaktig typ av vektor-%qs-element"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "felaktigt antal vektor-%qs-element"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr "felaktig typ av vektor-CONSTRUCTOR-element"
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr "vektor-%qs med elementindex som inte är NULL"
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "vektor-%qs-element är inte ett GIMPLE-värde"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "%qs för annat än en vektor med element"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "%qs med villkor som alltid är falskt"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "ogiltig operand i retursats"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "ogiltig konvertering i retursats"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto-destination är varken en etikett eller en pekare"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "ogiltig operand till switch-sats"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "annat än heltalstyp i en switch-sats"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "ogiltig standardfallsetikett i en switch-sats"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "ogiltig %<CASE_CHAIN%>"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "ogiltig case-etikett i en switch-sats"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "ogiltigt case-intervall i en switch-sats"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "typer stämmer inte för case-etikett i en switch-sats"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "typprecision stämmer inte i en switch-sats"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case-etiketter är inte sorterade i en switch-sats"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "etikettens kontext är inte den aktuella funktionsdeklarationen"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "felaktig post i %<label_to_block_map%>"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "felaktig inställning av nummer på landningsplatta"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "ogiltig jämförelsekod i gimple-villkor"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "ogiltig etikett i gimple-villkor"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "ogiltigt %<PHI%>-resultat"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "%<PHI%>-definition saknas"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "ogiltigt %<PHI%>-argument"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "inkompatibla typer i %<PHI%>-argument %u"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "%<verify_gimple%> misslyckades"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "död sats i EH-tabell"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr "platsreferensblock som inte är i blockträd"
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "lokal deklaration från en annan funktion"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) är satt till ett felaktigt grundblock"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr "PHI-nod med plats"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "felaktig delning av trädnoder"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "virtuell PHI med argumentplatser"
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (sats) är satt till ett felaktigt grundblock"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "sats markerad för att kasta, men gör inte det"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "sats markerad för att kasta i mitten av block"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple misslyckades"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK har IL associerat med sig"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK har IL associerat med sig"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fall igenom till utgång från gb %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "ickelokal etikett "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH-landningsplattas etikett "
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "etikett "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "flödesstyrning mitt i grundblock %d"
 
 # bb -> basic block -> grundblock -> gb
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fall igenom-båge efter styrsats i gb %d"
 
 # bb -> basic block -> grundblock -> gb
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "sant/falskt-båge efter en icke-GIMPLE_COND i gb %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "felaktiga utgående bågflaggor vid slutet av gb %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "uttrycklig goto vid slutet av gb %d"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "returbåge pekar inte på utgång i gb %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "hittade standardfall som inte var vid början av case-vektor"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case-etiketter är inte sorterade: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "extra utgående båge %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "båge saknas %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-funktion returnerar"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "flödet når slutet på en icke-void-funktion"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<warn_unused_result%>"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "ignorerar returvärdet av funktion deklarerad med attributet %<warn_unused_result%>"
@@ -27293,47 +27350,47 @@ msgstr "i definitionen av makrot %qs"
 msgid "in expansion of macro %qs"
 msgstr "i expansionen av makrot %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i har flera EH-bågar"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "BB %i kan inte kasta men har en EH-båge"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i:s sista sats har felaktigt satt lp"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "BB %i sakar en EH-båge"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "Felaktig EH-båge %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "BB %i saknar en båge"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i har för många fall-igenom-bågar"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i har felaktig båge"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i har felaktig fall-igenom-båge"
@@ -27840,12 +27897,12 @@ msgstr "sats (%p) markerad som modifierad efter optimeringspass: "
 msgid "verify_ssa failed"
 msgstr "verify_ssa misslyckades"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "maskinoberoende inbyggd kod utanför intervallet"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "målspecifik inbyggd funktion är inte tillgänglig"
@@ -27910,7 +27967,7 @@ msgstr "vektorindex %E är utanför gränserna för en intern vektor %qT med nol
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "vektorindex %qE är utanför gränserna för en intern vektor %qT med noll längd"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr "vid referens av %qD"
@@ -27920,27 +27977,27 @@ msgstr "vid referens av %qD"
 msgid "defined here %qD"
 msgstr "definierad här %qD"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "vektorindexen %wi är utanför vektorgränserna för %qT"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "vektorindexen [%wi, %wi] är utanför vektorgränserna för %qT"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "intermediärt vektoravstånd %wi är utanför vektorgränserna för %qT"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "vektorindex %wi är under vektorgränsen för %qT"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "vektorindex %wu är ovanför vektorgränsen för %qT"
@@ -28015,32 +28072,32 @@ msgstr "trädkontroll: använde operand %d av %s med %d operander i %s, vid %s:%
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av %<omp_clause %s%> med %d operander i %s, vid %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD bör undvikas: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD bör undvikas"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE bör undvikas: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE bör undvikas"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "typen bör undvikas: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "typen bör undvikas"
@@ -28065,232 +28122,232 @@ msgstr "typen bör undvikas"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "typvarianter skiljer i %s"
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "typvariant har en annan %<TYPE_SIZE_UNIT%>"
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "typvariantens %<TYPE_SIZE_UNIT%>"
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "typens %<TYPE_SIZE_UNIT%>"
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "typvariant med %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "typvariant har en annan %<TYPE_VFIELD%>"
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "typvariant har en annan %<TYPE_BINFO%>"
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "typvariantens %<TYPE_BINFO%>"
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "typens %<TYPE_BINFO%>"
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "typvariant har andra %<TYPE_FIELDS%>"
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "första som inte stämmer är fält"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr "och fält"
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "typvariant har en annan %<TREE_TYPE%>"
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "typvariantens %<TREE_TYPE%>"
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "typens %<TREE_TYPE%>"
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "typen är inte kompatibel med sin variant"
 
-#: tree.c:14387
+#: tree.c:14398
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "huvudvarianten är inte definierad"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_MAIN_VARIANT%> har en annan %<TYPE_MAIN_VARIANT%>"
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "%<TYPE_CANONICAL%> har en annan %<TYPE_CANONICAL%>"
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_CANONICAL%> är inte kompatibla"
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_MODE%> av %<TYPE_CANONICAL%> är inte kompatibla"
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "%<TYPE_CANONICAL%> av huvudvarianten är inte en huvudvariant"
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "%<TYPE_VFIELD%> är varken %<FIELD_DECL%> eller %<TREE_LIST%>"
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "%<TYPE_NEXT_PTR_TO%> är inte %<POINTER_TYPE%>"
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "%<TYPE_NEXT_REF_TO%> är inte %<REFERENCE_TYPE%>"
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "%<TYPE_BINFO%> är inte %<TREE_BINFO%>"
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_BINFO%>-typ är inte %<TYPE_MAIN_VARIANT%>"
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_METHOD_BASETYPE%> är inte en post eller union"
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_OFFSET_BASETYPE%> är inte en post eller union"
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "%<TYPE_ARRAY_MAX_SIZE%> inte %<INTEGER_CST%>"
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "%<TYPE_MAX_VALUE_RAW%> icke-NULL"
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "%<TYPE_LANG_SLOT_1 (binfo)%>-fält är icke-NULL"
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "enum-värde är inte %<CONST_DECL%> eller %<INTEGER_CST%>"
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "enum-värdetyp är varken %<INTEGER_TYPE%> eller konvertibel till enum"
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "enum-värdenamn är inte %<IDENTIFIER_NODE%>"
 
-#: tree.c:14596
+#: tree.c:14607
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "vektorn %<TYPE_DOMAIN%> är inte av heltalstyp"
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%<TYPE_FIELDS%> definierad i ofullständig typ"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "fel träd i %<TYPE_FIELDS%>-lista"
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "%<TYPE_CACHED_VALUES_P%> är %i medan %<TYPE_CACHED_VALUES%> är %p"
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "%<TYPE_CACHED_VALUES%> är inte %<TREE_VEC%>"
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "fel %<TYPE_CACHED_VALUES%>-post"
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "%<TREE_PURPOSE%> är icke-NULL i %<TYPE_ARG_TYPES%>-lista"
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "fel post i %<TYPE_ARG_TYPES%>-lista"
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "%<TYPE_VALUES_RAW%>-fält är icke-NULL"
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "%<TYPE_CACHED_VALUES_P%> är satt när det inte skulle vara det"
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "%<TYPE_METHOD_BASETYPE%> är inte en huvudvariant"
@@ -28415,82 +28472,82 @@ msgstr "begärd justering för %q+D är större än implementerad justering av %
 msgid "storage size of %q+D isn%'t known"
 msgstr "lagringsstorlek på %q+D är okänd"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "initierare för heltals-/fixdecimalvärde är för komplicerad"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "initierare för flyttalsvärde är inte en flyttalskonstant"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "ogiltigt startvärde för medlem %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD deklarerad svag efter att ha använts"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "svag deklaration av %q+D tillämpad på en redan befintlig, statisk definition"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "svagdeklaration av %q+D måste vara publik"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "svagdeklaration av %q+D stödjs inte"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "bara svaga alias stödjs i denna konfiguration"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref stödjs inte i denna konfiguration"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "%qs stödjs inte på denna målarkitektur"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr "symver stödjs bara på ELF-plattformar"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "%qs-symbolen %q+D är ytterst sitt eget mål"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "%qs-symbolen %q+D måste ha statisk länkklass"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "aliasdefinitioner stödjs inte i denna konfiguration"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "%qs stödjs inte i denna konfiguration"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "synlighetsattribut stödjs inte för denna konfiguration, ignoreras"
@@ -29070,7 +29127,7 @@ msgstr "attributet %qE följer %qE"
 msgid "type was previously declared %qE"
 msgstr "typen var tidigare deklarerad %qE"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kan endast anges för en virtuell funktion"
@@ -29090,7 +29147,7 @@ msgstr "%qD är inte kompatibel med %qD"
 msgid "%qE argument is not a function"
 msgstr "argumentet %qE är inte en funktion"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "deprecated-meddelande är inte en sträng"
@@ -29460,12 +29517,12 @@ msgstr "%<?:%> använder heltalskonstanter i en boolesk kontext"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "kompilatorn kan anta att adressen till %qD kommer alltid beräknas till %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "föreslår parenteser runt tilldelning som används som sanningsvärde"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ogiltigt användning av %<restrict%>"
@@ -29621,12 +29678,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "attributet %<fallthrough%> angivet med en parameter"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "för få argument till funktionen %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -29727,7 +29784,7 @@ msgstr "index %E anger ett avstånd större än storleken på %qT"
 msgid "size of array is too large"
 msgstr "storleken på vektorn är för stor"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "operandtypen %qT är inkompatibel med argument %d till %qE"
@@ -29737,124 +29794,124 @@ msgstr "operandtypen %qT är inkompatibel med argument %d till %qE"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "argument av typen pekare eller av typen heltal förväntades som argument 1"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "båda argumenten måste vara kompatibla"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "felaktigt antal argument till funktionen %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "argument 1 till %qE måste vara pekartyp som inte pekar på void"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "argument 1 till %qE måste vara en pekare till en typ med konstant storlek"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "argument 1 till %qE måste vara en pekare till ett objekt av storlek större än noll"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "argument %d till %qE måste vara en pekartyp"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argument %d till %qE måste vara en pekare till en typ med konstant storlek"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "argument %d till %qE får inte vara en pekare till en funktion"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "storleken stämmer inte i argument %d till %qE"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "minnesmodellsargument %d som inte är heltal till %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ogiltig minnesmodellsargument %d till %qE"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "detta mål definierar inte en spekulationsbarriär; ditt program kommer fortfarande fungera korrekt, men felaktig spekulation kommer kanske inte vara begränsat"
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "indexvärdet är utanför gränsen"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "konvertering av skalären %qT till vektorn %qT innebär avhuggning"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "inbyggd funktion %qE måste anropas direkt"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "storlek på vektorn %qE är inte ett konstant uttryck"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "storlek på vektorn är inte ett konstant uttryck"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "storleken %qE på vektorn %qE är negativ"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "storleken %qE på vektorn är negativ"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "storleken %qE på vektorn %qE överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "storleken %qE på vektorn överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "storleken på vektorn %qE överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "sotrleken på vektorn överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "miljövariabeln %qs måste expandera till ett ickenegativt heltal mindre än eller lika med %wd"
@@ -29909,502 +29966,502 @@ msgstr "%qE är en okänd funktionsformattyp"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "formatsträngsargumentet kommer efter argumenten som skall formateras"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "funktionen %qD kan vara en kandidat för formatattributet %qs"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "saknar numerisk $-operand i formatsträng"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s stödjer inte operandnummerformatet %%n$"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "operandnummer utanför intervallet i format"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "formatargument %d använt mer än en gång i formatet %s"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr "%<$%>-operandnummer använt efter format utan operandnummer"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "formatargument %d oanvänt för använt argument %d i %<$%>-stilsformat"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "formatet är inte en stränglitteral, formatsträngen inte kontrollerad"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "formatet är inte en stränglitteral och inga formatargument"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "formatet är inte en stränglitteral, argumenttyperna inte kontrollerade"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "för många argument för formatsträng"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr "oanvända argument i %<$%>-stilsformat"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "%s-formatsträng med längden noll"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "formatet är en sträng breda tecken"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "formatsträngen är inte en vektor av typen %qs"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "icke terminerad formatsträng"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%1$s använd med %3$s-format %<%%%2$c%>"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s stödjer inte %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%1$s stödjer inte %2$s med %4$s-formatet %<%%%3$c%>"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr "%s använd inom en citerad sekvens"
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr "%qc-konvertering använd utan citationstecken"
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "upprepat %s i format"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "utfyllnadstecken saknas vid slutet av strfmon-format"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "nollstorlek i %s formatsträng"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "tom vänsterprecision i %s-format"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "tom precision i %s-format"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%1$s stödjer inte %3$s-längdmodifieraren %2$qs"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "okänd konverteringstyptecken %qc i format"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%1$s stödjer inte %3$s-formatet %<%%%2$c%>"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%1$s ignorerad med %2$s och %4$s-format %<%%%3$c%>"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s ignorerad med %s i %s-format"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "%s och %s använda tillsammans i %<%%%c%> %s-format"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "%s och %s använda tillsammans i %s-format"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> ger bara de sista 2 siffrorna i årtalet i vissa lokaler"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> ger bara de sista två siffrorna i årtalet"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "ingen avslutande %<]%> till %<%%[%>-format"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "användning av längdmodifierare %qs med typtecken %qc har antingen ingen effekt eller odefinierat beteende"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%1$s stödjer inte %4$s-formatet %<%%%2$s%3$c%>"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "operandnummer angivet med undertryckt tilldelning"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "operandnummer angivet för format som inte tar argument"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "ej citerat typnamn %<%.*s%> i format"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "ej citerad operator %<%.*s%> i format"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "ej citerat nyckelord %<%.*s%> i format"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr "använd %qs istället"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr "attribut utan citationstecken i format"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "namn utan citationstecken i den inbyggda funktionen %<%.*s%> i format"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr "identifierare eller nyckelord utan citationstecken %<%.*s%> i format"
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr "felstavad term %<%.*s%> i format; använd %<%s%s%> istället"
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr "citerat %qs-direktiv i format; använd %qs istället"
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr "sammandragning %<%.*s%> i format; använd %qs istället"
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr "blanktecken utan citationstecken %qc i format"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr "vilsekommet avslutande mellanslag i format"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "inkonsistent användning av versaler i format"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "sekvens av %i konsekutiva blanktecken utan citationstecken i format"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "styrtecken utan citationstecken i format"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "styrtecknet %qc utan citationstecken format"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "vilsekommet alternativnamn %<%.*s%> i format"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr "obalancerat interpunktionstecken %qc i format"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr "preprocessingdirektiv utan citationstecken %<%.*s%> i format"
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr "ensam apostrof %<'%> i format"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr "om det inte är görbart att undvika apostrofen, omslut den i ett par av direktiv %qs och %qs istället"
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr "grav accent %<`%> i format"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr "använd apostrofdirektivet %qs istället"
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr "mellanslag följt av skiljetecken %<%c%>"
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr "citerat %qs-direktiv i format"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr "om det inte är görbart att använda %qs, använd %qs istället"
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "vilsekommen inledande interpunktionssekvens %<%.*s%> i format"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "vilsekommen avslutande interpunktionssekvens %<%.*s%> i format"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr "sekvens av %i konsekutiva skiljetecken utan citationstecken %q.*s i format"
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "icke-grafiska tecken utan citationstecken i format"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "icke-grafiskt tecken %qc utan citationstecken i format"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "obalanserat interpunktionstecken %<%c%> i format"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr "icke terminerat citationsdirektiv"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "oavslutat citationstecken %<%c%> i format"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "vilsekommet avslutande %<%%%> i format"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "konvertering saknar typ vid slutet av format"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr "nästade citationsdirektiv"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr "omatchat citationsdirektiv"
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr "%qc-direktiv är överflödigt efter tidigare förekomst av detsamma"
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr "omatchat färgåterställningsdirektiv"
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr "%qc-konvertering använt inuti en citerad sekvens"
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "inbäddade %<\\0%> i format"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr "oavslutat färgdirektiv"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "skriver via nollpekare (argument %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "läser via nollpekare (argument %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "skriver till konstant objekt (argument %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "extra typkvalificerare i formatargument (argument %d)"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> förväntar sig argument av typen %<%s%s%>, men argument %d har typen %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> förväntar sig ett matchande %<%s%s%>-argument"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> förväntar sig argument av typen %<%T%s%>, men argument %d har typen %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> förväntar sig ett matchande %<%T%s%>-argument"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> är inte definierad som en typ"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> är inte definierad som %<long%> eller %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> är inte definierad som en typ"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "%qs är inte definierat som en typ"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> är inte definierad som en typ"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> är inte definierad som en typ"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> är inte definierad som en pekartyp"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr "argumenten som skall formateras är inte %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-format kan inte formatera argument"
@@ -30565,7 +30622,7 @@ msgstr "%<depobj%>-beroendetyp angiven i %<depend%>-klausul på en %<depobj%>-ko
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "en %<iterator%>-modifierare får inte anges på en %<depobj%>-konstruktion"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -30580,17 +30637,17 @@ msgstr "%<_Atomic%>-iterationsvariabel %qE"
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
@@ -30600,7 +30657,7 @@ msgstr "utelämnat ökningsuttryck"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "ökningen är inte en konstant 1 eller -1 för villkoret %<!=%>"
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -31196,7 +31253,7 @@ msgid "wrong type argument to %s"
 msgstr "fel typ på argument till %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "spill i konstant uttryck"
@@ -31872,7 +31929,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr "%<memset%> använt med en längd lika med antalet element utan att multiplicera med elementstorleken"
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "jämförelse mellan typer %qT och %qT"
@@ -31948,7 +32005,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "att skicka argument %i till en %qs-kvalificerad parameter blir alias med argument %Z"
 msgstr[1] "att skicka argument %i till en %qs-kvalificerad parameter blir alias med argumenten %Z"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "detta villkor har identiska grenar"
@@ -31968,7 +32025,7 @@ msgstr "några delar av makroexpansionen är inte skyddade av denna %qs-klausul"
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr "konverterar en packad %qT-pekare (justering %d) till en %qT-pekare (justering %d) kan resultera i ett ojusterat pekarvärde"
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr "definierad här"
@@ -31988,7 +32045,7 @@ msgstr "%qs är inte en giltig flagga till preprocessorn"
 msgid "too many input files"
 msgstr "för många indatafiler"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "okänt värde %qs till %<-mcpu%>"
@@ -32019,14 +32076,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr "okänd flagga skickad till %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "giltiga argument är: %s; menade du %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "giltiga argument är: %s"
@@ -32543,391 +32600,402 @@ msgstr "aliasdefinitioner stödjs inte i Mach-O, ignoreras"
 msgid "profiler support for VxWorks"
 msgstr "profileringsstöd för VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kargument %d måste vara en konstant omedelbar"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kbanindex måste vara en konstant omedelbar"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "%Ktotal storlek och elementstorlek måste vara en konstant omedelbar skild från noll"
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%Kargument måste vara en 16-bitars konstant omedelbar"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "Memory Tagging Extension stödjer inte %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "%Kargument %d måste vara en konstant omedelbar i intervallet [0,15]"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "en 64-bitars adress förväntades men argument 1 är %d-bitars"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "en 64-bitars adress förväntades men argument 2 är %d-bitars"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> kräver en strängparameter"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "okänd %<#pragma GCC aarch64%>-flagga %qs"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "attributet %qE kan inte användas på en SVE-funktionstyp"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "oväntat %<%s%> efter %<%s%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs är inkompatibel med användningen av flyttalstyper"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs är inkompatibel med användningen av vektortyper"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "funktionsmodifieraren %qs är inkompatibel med användningen av flyttalstyper"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "funktionsmodifieraren %qs är inkompatibel med med användningen av vektortyper"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "denna operation kräver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "du kan aktivera SVE genom att använda kommandoradsflaggan %<-march%>, eller genom att använda attributet eller pragmat %<target%>"
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "argument av typen %qT kräver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "SVE-typen %qT kan inte skickas till en funktion utan prototyp"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 9.1"
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "%qE behöver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "anropt till funktioner av typen %qT behöver ISA-utökningen SVE"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "stackprov för SVE-ramar"
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr "okänd flagga skickad i %<-moverride=%s%> (%s)"
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "%s-sträng är felformad\n"
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "felaktigt format på sve_width"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "ogiltigt sve_width-värde: %d"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "trimningssträngen saknas i flaggan (%s)"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "okänd trimningsflagga (%s)"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "inkompatibla flaggor %<-mstack-protector-guard=global%> och %<-mstack-protector-guard-offset=%s%>"
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "både %<-mstack-protector-guard-offset%> och %<-mstack-protector-guard-reg%> måste användas med %<-mstack-protector-guard=sysreg%>"
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr "ange ett systemregister med en liten stränglängd."
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs är inte ett giltigt avstånd i %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr "endast värdena 12 (4 kB) och 16 (64 kB) stödjs som vaktstorlek.  Det givna värdet %d (%llu kB) är utanför intervallet"
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr "stackkrockvaktsstorlek %<%d%> måste vara lika med testintervallet %<%d%>"
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "giltiga argument är: %s;"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "cpu-namn saknas i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "ogiltig funktionsmodifierare %qs i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "ogiltigt argument %<%s%> till %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "argumentet saknas till %<-mbranch-protection=%>"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "arkitekturnamn saknas i %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "okänt värde %qs till %<-march%>"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "ogiltig funktionsmodifierare %qs i %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "cpu-namn saknas i %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "okänt värde %qs till %<-mtune%>"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "flaggan %<-mcpu=%s%> står i konflikt med flaggan %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "assemblern stödjer inte %<-mabi=ilp32%>"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr "signering av returadress stödjs endast för %<-mabi=lp64%>"
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "kodmodell %qs med %<-f%s%>"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "kodmodellen %qs stödjs inte i ilp32-läge"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "felaktig funktionsmodifierare %s på värdet (”%s”) i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "argument saknas till pragmat eller attributet %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr "felaktig skyddstyp (”%s”) i pragmat eller attributet %<target(\"branch-protection=\")%>"
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "värde saknas i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tar inte något argument"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tillåter inte en negerad form"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s=%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+#, fuzzy
+#| msgid "parameter passing for argument of type %qT changed in GCC 9.1"
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 9.1"
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+#, fuzzy
+#| msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT när C++17 är aktiverades ändrades till att matcha C++14 i GCC 10.1"
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kbana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "bana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "ej stödd simdlen: %d"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte typer av blandad storlek till %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte returtypen %qT för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "returtypen %qT stödjs ej för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "GCC stödjer för närvarande inte argumenttypen %qT för %<simd%>-funktioner"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr "GCC stödjer för närvarande inte simdlen %d för typen %qT"
@@ -33108,17 +33176,17 @@ msgstr "argumentet till attributet %qE är inte ”ilink1” eller ”ilink2”"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "argumentet till attributet %qE är inte ”ilink” eller ”firq”"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33268,12 +33336,12 @@ msgstr "okänd %<asm%>-flaggutdata %qs"
 msgid "invalid type for %<asm%> flag output"
 msgstr "ogiltig typ för %<asm%>-flaggutdata"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "%Kco-processor %d är inte aktiverad med +cdecp%d"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr "%Kcoproc måste vara en konstant omedelbar i intervallet [0-%d] aktiverat med +cdecp<N>"
@@ -33281,194 +33349,194 @@ msgstr "%Kcoproc måste vara en konstant omedelbar i intervallet [0-%d] aktivera
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%Kargument %d till %qE måste vara en konstant omedelbar i intervallet [0-%d]"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "denna inbyggda stödjs inte på denna målarkitektur"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%Kmättnatsbitsintervallet måste ligga i intervallet [%wd, %wd]"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "%Kmättnadsbitsintervallet måste vara en konstant omedelbar"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr "Du måste aktivera MVE-instruktioner för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr "Du måste aktivera NEON-instruktioner (t.ex. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Du måste aktivera VFP-instruktioner för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr "Du måste aktivera kryptoinstruktioner (t.ex. inkludera %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) för att använda dessa inbyggda."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "en väljare måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "intervallet för väljaren skall vara inom 0 till 7"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "intervallet för väljaren skall vara inom 0 till 3"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "intervallet för väljaren skall vara inom 0 till 1"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "intervallet för masken skall vara i 0 till 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_rori_si64 i koden."
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_ror_si64 i koden."
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_si64 i koden."
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_si64 i koden."
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_si64 i koden."
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_si64 i koden."
@@ -33478,283 +33546,283 @@ msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr "argument %u till funktionen %qE är av typen %qT som inte är känd för att vara 128 bitar bred"
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt och NEON är inkompatibla"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "målprocessorn stödjer inte ARM-läge"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "aktivering av stöd för bakåtspårning är endast meningsfullt vid kompilering för Thumb"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "aktivering av stöd för anroparnätverkande är endast meningsfullt vid kompilering för Thumb"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "%<-g%> med %<-mno-apcs-frame%> ger kanske inte meningsfull felsökning"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt stödjs inte i Thumb-läge"
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "det går inte att använda %<-mtp=cp15%> med 16-bitars Thumb"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC är inkompatibel med Thumb"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr "%s stödjer endast icke-pic-kod på M-profile-mål med instruktionen MOVT"
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr "%s stödjer endast icke-pic-kod på M-profile-mål"
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "%s är inkompatibel med %<-mword-relocations%>"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "målprocessorn stödjer inte THUMB-instruktioner"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessorn stödjer inte ojusterade åtkomster"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "%<-mapcs-stack-check%> är inkompatibel med %<-mno-apcs-frame%>"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "%<-fpic%> och %<-mapcs-reent%> är inkompatibla"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS-återanropsbar kod stödjs inte.  Ignoreras"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr "flaggan %<-mstructure-size-boundary%> bör undvikas"
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "storleksgräns för poster kan bara sättas till 8, 32 eller 64"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "storleksgräns för poster kan bara sättas till 8 eller 32"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC är inkompatibelt med %<-msingle-pic-base%>"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "FDPIC-läget stödjs inte i Thumb-1-läge"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "%<-mpic-register=%> är meningslös utan %<-fpic%>"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "kan inte använda %qs som PIC-register"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "%<-freorder-blocks-and-partition%> stödjs inte på denna arkitektur"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "valda fp16-alternativ är inkompatibla"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt kräver ett AAPCS-kompatibelt ABI för att fungera riktigt"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt-abi kräver en CPU som klarar iwmmxt"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "målprocessorn stödjer inte interworking"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS stödjer inte %<-mcaller-super-interworking%>"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS stödjer inte %<-mcallee-super-interworking%>"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 och ingen ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "målprocessorn stödjer inte ARMv8-M:s säkerhetstillägg"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr "ARMv8-M Security Extensions är inkompatibelt med den valda FPU:n"
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "%<-mfloat-abi=hard%>: den valda processorn saknar en FPU"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "%<-mfloat-abi=hard%> och VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "icke-AAPCS-härledd PCS-variant"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadiska funktioner måste använda bas-AAPCS-varianten"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS-variant"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 hårda flyttals VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr "argument av typen %qT är inte tillåtna med -mgeneral-regs-only"
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 7.1"
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "attributet %qE är inte tillgängligt för funktioner med argument som skickas på stacken"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "attributet %qE är inte tillgängligt för funktioner med ett variabelt antal argument"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "attributet %qE är inte tillgängligt för funktioner som returnerar ett värde på stacken"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "attributet %qE ignorerat utan flaggan %<-mcmse%>."
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "attributet %qE har ingen effekt på funktioner med statisk länkklass"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attributet %qE är bara tillämpligt på bastypen av en funktionspekare"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "att nå trådlokal lagring stödjs inte för närvarande med %<-mpure-code%> eller %<-mslow-flash-data%>"
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan inte beräkna verklig plats för stackparameter"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Oväntat långt thumb1-hopp"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "inga låga register tillgängliga för att poppa höga register"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "avbrottshanteringsrutiner kan inte kodas i Thumb-läge"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> för Thumb-1"
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ogiltig fpu för målattributet eller pragmat %qs"
@@ -33762,22 +33830,22 @@ msgstr "ogiltig fpu för målattributet eller pragmat %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatiskt fpu-val är för närvarande inte tillåtet här"
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ogiltig arkitektur för målattribut eller -pragma %qs"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "okänt målattribut eller -pragma %qs"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "asm-flaggor stödjs inte i thumb1-läge"
@@ -33856,17 +33924,17 @@ msgstr "%<-fpie%> stödjs inte"
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> stödjs inte"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "funktionsattributen %qs och %qs är ömsesidigt uteslutande"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "funktionen %qs kan inte ha argument"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktionen %qs kan inte returnera ett värde"
@@ -34128,7 +34196,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "indirekt anrop i en funktion, vilket inte stödjs av eBPF"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "ogiltigt argument inbyggd funktion"
@@ -34459,52 +34527,52 @@ msgstr "dubblerad parameterspecificerare %s i attributet amdgpu_hsa_kernel"
 msgid "too many arguments passed in sgpr registers"
 msgstr "för många argument skickade i sgpr-register"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr "En icke-standard uppsättning initialvärden har begärts, vilket strider mot ABI:et!"
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "fel sorts argument %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "nästade funktionstrampoliner stödjs inte på GCN5 på grund av icke exekverbar stack"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr "TLS är inte implementerat för GCN."
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr "Inbyggd inte implementerad"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr "använder vector_length (64), ignorerar %d"
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr "använder vector_length (64), ignorerar körtidsinställningen"
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "använder num_workers (%d), ignorerar %d"
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "avlastningsdimensionen är utanför intervallet (%d)"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr "lokalt datadelat minne uttömt"
@@ -34638,132 +34706,132 @@ msgstr "parameter till inbyggd måste vara en strängkonstant eller -litteral"
 msgid "parameter to builtin not valid: %s"
 msgstr "parameter till inbyggd är inte giltig: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "avbrottshanteringsrutiner kan inte anropas direkt"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "det sista argumentet måste vara en 2-bitars omedelbar"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "det femte argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "det tredje argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "det sista argumentet måste vara en 3-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "det sista argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "det sista argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "det näst sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "det sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "det tredje argumentet måste vara en jämförelsekonstant"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "felaktigt jämförelsesätt"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "felaktig avrundningsoperand"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "det sista argumentet måste vara en 32-bitars omedelbar"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "väljaren måste vara en heltalskonstant i intervallet [0..%wi]"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE behöver en okänd isa-flagga"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE behöver isa-flaggan %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "sista argumentet måste vara en omedelbar"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "det sista argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "det fjärde argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "felaktig tipsoperand"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "argumentet till den inbyggda %<xabort%> måste vara en 8-bitars omedelbar"
@@ -35147,145 +35215,145 @@ msgstr "endast felsökningsformatet DWARF stödjs för en avbrottshanteringsruti
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner är inte tillåtna i en undantagshanteringsrutin"
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner är inte tillåtna i en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion attributet %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attributen %qs och %qs är inte kompatibla"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha %qs som andra argument"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "avbrottshanteringsrutiner måste returnera %<void%>"
@@ -35730,7 +35798,7 @@ msgstr "%qE får inte ha båda attributet %qs och %qs"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE omdeklarerad med motstridiga %qs-attribut"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "attributet %qE behöver ett strängargument"
@@ -36810,52 +36878,52 @@ msgstr "%<__delay_cycles%> tar endast ickenegativa antal cykler"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "%<__delay_cycles%> är begränsad till 32-bitars slingräknare"
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "okänt cpu %qs till %<-mtune%>"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI:et för en tillplattad post med nollängds bitfält ändrades i GCC 10"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "argumentet till attributet %qE är inte ”user”, ”supervisor” eller ”machine”"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> kräver %<-march%> för att innefatta utökningen %<M%>"
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "begärt ABI kräver %<-march%> för att innefatta utökningen %qc"
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e kräver ABI:et ilp32e"
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI:et kräver %<-march=rv%d%>"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> måste vara mellan %d och %d"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V ELF-attribut behöver GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "funktionen %qs kan inte ha olika avbrottstyp"
@@ -36971,323 +37039,324 @@ msgstr "tal måste vara 0 eller 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "skräp vid slutet av %<#pragma longcall%>"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "den inbyggda %qs tar endast 2 argument"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "den inbyggda %qs tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "den inbyggda %qs tar endast 1 argument"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "att skicka argument %d till %qE kastar kvalificerare från pekarmåltyp"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "den inbyggda %qs behöver den inbyggda %qs"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs stödjs inte i denna kompilatorkonfiguration"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ogiltig parameterkombination för inbyggd %qs i AltiVec"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor returnerad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd %qs för att aktivera dem"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI:et för att skicka aggregat med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd %qs för att aktivera dem"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "ABI:et för att skicka homogena %<float%>-aggregat har ändrats i GCC 5"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor skickad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "internt fel: den inbyggda funktionen %qs redan bearbetad"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_mffsl%> stödjs inte med %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argument 1 måste vara ett 8-bitars fältvärde"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_mtfsb0%> och %<__builtin_mtfsb1%> stödjs inte med %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr "Argumentet måste vara en konstant mellan 0 och 31."
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_set_fpscr_rn%> stödjs inte med %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr "Argumentet måste vara ett värde mellan 0 och 3."
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "%<__builtin_set_fpscr_drn%> stödjs inte i 32-bitsläge"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "%<__builtin_set_fpscr_drn%> stödjs inte med %<-msoft-float%>"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr "Argumentet måste vara ett värde mellan 0 och 7."
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argument 1 måste vara en 5-bitars litteral med tecken"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argument 2 måste vara en 1-bits litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "argument 2 måste vara en 2-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "argument 2 måste vara en 3-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "argument 2 måste vara en 4-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argument 2 måste vara en 5-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argument 1 måste vara en 6-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argument 2 måste vara en 7-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "argument 1 till %qs måste vara en konstant"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "argument 1 till %qs är utanför sitt intervall"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "inbyggd %qs är endast giltigt i 64-bitsläge"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "argument %d måste vara en litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument %d är en litteral utan tecken som är utanför sitt intervall"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "inbyggd %qs är endast giltigt i 64-bitsläge"
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "den inbyggda %qs tar endast ett strängargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "cpu %qs är ett ogiltigt argument till den inbyggda %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs är ett ogiltigt argument till den inbyggda %qs"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "den inbyggda %qs behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argument 3 måste vara en 4-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argument 3 måste vara en 2-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argument 3 måste vara en 1-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argument 1 måste vara 0 eller 2"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argument 1 måste vara en 1-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argument 2 måste vara en 6-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argument 2 måste vara 0 eller 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "argument 3 måste vara i intervallet [0, 15]"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argument till %qs måste vara en 2-bitars litteral utan tecken"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ej upplöst överlagring för inbyggd Altivec %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr "andra argumentet till %qs måste vara [0, 12]"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "tredje argumentet till %qs måste vara [0, 12]"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "%qs är endast giltig för cell-processorn"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "%qs behöver flaggan %qs"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "%qs behöver flaggorna %qs och %qs"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "%qs behöver 128-bitars flyttal enligt ISA 3.0 IEEE"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "%qs behöver flaggorna %qs (eller senare), och %qs eller %qs"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "%qs stödjs inte med de aktuella flaggorna"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "internt fel: inbyggd funktion %qs hade en oväntad returtyp %qs"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "internt fel: inbyggd funktion %qs, argument %d har en oväntad argumenttyp %qs"
@@ -37307,219 +37376,224 @@ msgstr "%qs använder register r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Stackramar större än 2 G stödjs inte med %<-fsplit-stack%>"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs kräver %qs eller %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs kräver PowerPC64-arkitektur, aktiverar"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs stödjs inte för 64-bitars Darwin, det är inkompatibelt med de installerade C- och C++-biblioteken"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec stödjs inte på denna målarkitektur"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs stödjs inte på system med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "målflaggan för power9 är inkompatibel med %<%s=<xxx>%> för <xxx> som är mindre än power9"
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs är inkompatibel med uttryckligen avaktiverade flaggor"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs behöver %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "målattribut eller pragma ändrar storlek på %<long double%>"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%qs behöver fullt ISA 2.06-stöd"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "Använder %<long double%> med IEEE:s utökade precision"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "Använder %<long double%> med IBM:s utökade precision"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs behöver VSX-stöd"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr "Flaggan %<-mfloat128%> kanske inte stödjs fullt ut"
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs behöver fullt ISA 3.0-stöd"
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "okänd ABI-typ (%qs) till vektoriseringsbibliotek för flaggan %qs"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "målattribut eller pragma ändrar AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "målattribut eller pragma ändrar darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs är inte ett giltigt tal i %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs är inte ett giltigt basregister i %qs"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs behöver ett giltigt basregister"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "okänt alternativ till %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs bör undvikas och rekommenderas inte under några omständigheter"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "du kan inte ta adressen till en nästad funktion om du använder flaggan %qs"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan %qs"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "felaktig cpu %qs för %s%qs%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s är inte tillåtet"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s är ogiltigt"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> slår av %<-m%s%>"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "attributet %<target_clones%> behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "multiversionering behöver ifunc som inte stödjs på detta mål"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
@@ -37840,139 +37914,139 @@ msgstr "begärt attribut %qE är inte ett kommaseparerat par av ickenegativa hel
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "totala storleken på lokala variabler överskrider arkitekturens gräns"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket överskrider användarens valda stackgräns på %d byte.  En ovillkorlig fälla läggs till."
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket är mer än hälften av stackstorleken.  Den dynamiska kontrollen skulle inte vara pålitlig.  Ingen kontroll läggs ut för denna funktion."
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "ramstorlek på %qs är %wd byte"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs använder dynamisk stackallokering"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "nästade funktioner kan inte profileras med %<-fentry%> på s390"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bits ABI stödjs inte i ESA/390-läge"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline stödjs endast med %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vektorstöd i hårdvara är inte tillgängliga på %s"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "stöd för hårdvaruvektorer är inte tillgängligt med %<-msoft-float%>"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "hårdvaruinstruktioner för decimala flyttal är inte tillgängliga på %s"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "hårdvaruinstruktioner för decimalflyttal är inte tillgängliga i läget ESA/390"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> kan inte användas tillsammans med %<-msoft-float%>"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> stödjs inte i kombination"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "stackstorlek måste vara större än stackvaktsvärdet"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "stackstorlek får inte vara större än 64 k"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> implicerar användning av %<-mstack-size%>"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-check behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-prologue-target behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-check behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr "-mtpf-trace-hook-epilogue-target behöver ett heltal i intervallet 0..4095"
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> stödjs endast för 64-bitars CPU:er"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumenten till %qs skall vara ickenegativa heltal"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumentet till %qs är för stort (max. %d)"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> kan inte användas utan %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) är okänt"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "värdet %qs stödjs inte av attributet %<target%>"
@@ -38394,8 +38468,8 @@ msgstr "attributet %qs är bara tillämpbart på vektortyper"
 msgid "could not read the BRIG file"
 msgstr "det gick inte att läsa BRIG-filen"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "värdet av typen void ignoreras inte vilket bör göras"
@@ -38672,7 +38746,7 @@ msgstr "deklaration av %q+D skuggar tidigare icke-variabel"
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklaration av %qD skuggar en parameter"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklaration av %qD skuggar en global deklaration"
@@ -38743,7 +38817,7 @@ msgstr "%qE är odeklarerad (första förekomsten i denna funktion)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "varje odeklarerad identifierare rapporteras bara en gång för varje funktion den förekommer i"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "etikett %qE är refererad till utanför någon funktion"
@@ -38773,7 +38847,7 @@ msgstr "hopp in i satsuttryck"
 msgid "duplicate label declaration %qE"
 msgstr "dubbel deklaration av etikett %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "dubblerad etikett %qD"
@@ -38981,7 +39055,7 @@ msgstr "kan inte lägga objekt med volatile-fält i register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "oinitierad %<const %D%> är ogiltig i C++"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
@@ -39320,7 +39394,7 @@ msgstr "typnamn är deklarerat som en funktion som returnerar en vektor"
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
@@ -39627,7 +39701,7 @@ msgstr "nästad omdefinition av %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
@@ -39677,7 +39751,7 @@ msgstr "posten har inga namngivna medlemmar"
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
@@ -39713,7 +39787,7 @@ msgstr "nästad omdefinition av %<enum %E%>"
 msgid "redeclaration of %<enum %E%>"
 msgstr "omdeklaration av %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angiven sort för liten för uppräkningvärden"
@@ -39743,7 +39817,7 @@ msgstr "överspill i uppräkningsvärden"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%>"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline-funktionen %qD har fått attributet %qs"
@@ -39773,7 +39847,7 @@ msgstr "ingen tidigare prototyp för %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
@@ -39888,12 +39962,12 @@ msgstr "argument %qD stämmer inte med inbyggd prototyp"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
@@ -39901,257 +39975,257 @@ msgstr "parametern %qD sätts men används inte"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-slinga med startdeklaration är endast tillåtet i C99- och C11-läge"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "använd flaggan %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> eller %<-std=gnu11%> för att kompilera din kod"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 stödjer inte %<for%>-slingor med initiala deklarationer"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av statisk variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av %<extern%>-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av icke-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "inkompatibla adressrymdskvalificerare %qs och %qs"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "dubblerade %qE-deklarationsspecificerare"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 stödjer inte %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 stödjer inte komplexa typer"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C stödjer inte mättning av typer"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "dubblerad %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C stödjer inte typen %<__int%d%>"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 stödjer inte booleska typer"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C stödjer inte typen %<_Float%d%s%>"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C stödjer inte decimala flyttal före C2X"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "fixdecimaltyper stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C stödjer inte fixdecimaltyper"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++-uppslagning av %qD skulle returnera ett fält, inte en typ"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE är varken en typedef eller en inbyggd typ"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE är inte i början av deklarationen"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE använd med %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE använd med %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE använd med %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 stödjer inte %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 stödjer inte %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> före %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> före %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "dubblerat %<_Thread_local%> eller %<__thread%>"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flera lagringsklasser i deklarationsspecificerare"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs använd med %qE"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> används utan %<_Fract%> eller %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> följt av  %<[[]]%>-attribut"
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "vänsterskift med negativt värde"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vänstershiftoperanden är negativ"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "högershiftoperanden är negativ"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vänstershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "högershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "vänstershiftoperanden ≥ storleken på vektorelementet"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "högershiftoperanden ≥ storleken på vektorelementet"
@@ -40171,7 +40245,7 @@ msgstr "markör för versionshanteringskonflikt i filen"
 msgid "to match this %qs"
 msgstr "för att matcha denna %qs"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -40217,7 +40291,7 @@ msgid "unknown type name %qE"
 msgstr "okänt typnamn %qE"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -40237,7 +40311,7 @@ msgstr "attributet %<fallthrough%> på toppnivå"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -40252,8 +40326,8 @@ msgstr "prefixattribut ignoreras för implementeringar"
 msgid "unexpected attribute"
 msgstr "oväntat attribut"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "attributet %<fallthrough%> följs inte av %<;%>"
@@ -40291,7 +40365,7 @@ msgstr "%<__auto_type%> behöver en initierad datadeklaration"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kan endast användas med en ensam deklarerare"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> eller %<;%> förväntades"
@@ -40319,7 +40393,7 @@ msgstr "ISO C99 stödjer inte %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 stödjer inte %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "strängkonstant förväntades"
@@ -40349,7 +40423,7 @@ msgstr "uttryck i statisk försäkran är inte konstant"
 msgid "static assertion failed: %E"
 msgstr "statisk försäkran misslyckades: %E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statisk försäkran misslyckades"
@@ -40394,14 +40468,14 @@ msgstr "tom enum är ogiltig"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutet av uppräkningslista"
@@ -40486,7 +40560,7 @@ msgstr "deklarationsspecificerare eller %<...%> förväntades"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr "parenteser måste utelämnas om attributargumentlistan är tom"
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "attributet %qE tar inga argument"
@@ -40496,7 +40570,7 @@ msgstr "attributet %qE tar inga argument"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C stödjer inte %<[[]]%>-attribut före C2X"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "attributet %<deprecated%> kan förekomma högst en gång i en attributlista"
@@ -40556,7 +40630,7 @@ msgstr "ISO C90 förbjuder blandade deklarationer och kod"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> förväntades före %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> utan ett föregående %<if%>"
@@ -40571,7 +40645,7 @@ msgstr "etikett vid slutet av sammansatt sats"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "sats förväntades"
@@ -40596,17 +40670,17 @@ msgstr "en etikett kan endast vara en del av en sats och en deklaration är inte
 msgid "expected identifier or %<*%>"
 msgstr "identifierare eller %<*%> förväntades"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<if%>-sats"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<else%>-sats"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "föreslår uttryckliga klamrar för att undvika tvetydighet i %<else%>"
@@ -40626,12 +40700,12 @@ msgstr "flera iterationsvariabler i snabb uppräkning"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ogiltigt iterationsvariabel i snabb uppräkning"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC ivdep%>-pragma"
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC unroll%>-pragma"
@@ -40646,8 +40720,8 @@ msgstr "saknad samling i snabb uppräkning"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "upprepade %<asm%>-kvalificerare %qE"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr "först sedd här"
@@ -40674,12 +40748,12 @@ msgstr "ISO C förbjuder utelämnande av den mittersta termen i ett %<?:%>-uttry
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "divisionen %<sizeof (%T) / sizeof (%T)%> beräknar inte antalet vektorelement"
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "första %<sizeof%>-operanden deklarerades här"
@@ -41070,61 +41144,61 @@ msgstr "objective-c-metoddeklaration förväntas"
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<getter%>)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<setter%>)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "attributet %<setter%> kan bara anges en gång"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter-namn måste avslutas med %<:%>"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attributet %<getter%> kan bara anges en gång"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> kräver ett tilldelningsuttryck som beräknas till en icke-negativ heltalskonstant mindre än %u"
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> får bara användas en slingkonstruktion med %<inscan%> %<reduction%>-klausul"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
@@ -41134,18 +41208,18 @@ msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-k
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> får bara användas med filräckvidd"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
@@ -41165,53 +41239,53 @@ msgstr "%<)%> eller %<,%> förväntades"
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> eller %<present%> förväntades"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> eller %<shared%> förväntades"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> eller %<exit%> förväntades"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> förväntades"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "för många %<if%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "för många %<if%>-klausuler"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "för många %<if%>-klausuler utan modifierare"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "om någon %<if%>-klausul har en modifierare måste alla %<if%>-klausuler använda modifierare"
@@ -41233,12 +41307,12 @@ msgstr "%<num_threads%>-värdet måste vara positivt"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%>-värdet måste vara positivt"
@@ -41248,22 +41322,22 @@ msgstr "%<priority%>-värdet måste vara positivt"
 msgid "expected constant integer expression"
 msgstr "konstant heltalsuttryck förväntades"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> eller %<default%> förväntades"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<scalar%>, %<aggregate%> eller %<pointer%> förväntades"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "för många %<defaultmap%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "för många %<defaultmap%>-klausuler med ospecificerad kategori"
@@ -41278,52 +41352,52 @@ msgstr "%qs-uttrycket måste vara ett heltal"
 msgid "%qs value must be positive"
 msgstr "%qs-värdet måste vara positivt"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "för många %<static%>-argument"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "oväntat argument"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumentet till %<tile%> behöver en positiv heltalskonstant"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> förväntades"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<teams%>, %<prarallel%> eller %<thread%> förväntades"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "både %<monotonic%>- och %<nonmonotonic%>-modifierare angivna"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
@@ -41333,7 +41407,7 @@ msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 msgid "chunk size value must be positive"
 msgstr "värdet på styckesstorleken måste vara positivt"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -41368,22 +41442,22 @@ msgstr "%<safelen%>-klausulens uttryck måste vara ett positivt konstant heltals
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "modifieraren %<iterator%> är inkompatibel med %qs"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -41398,77 +41472,77 @@ msgstr "ogiltig proc_bind-sort"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> eller %<any%> förväntades"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma acc%>-klausul förväntades"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "klausuler i %<simd%>-egenskap skall separeras av %<,%>"
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%>-klausul förväntades"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "inga giltiga klausuler angivna i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "vektorsektionen i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD måste vara en global variabel i %<#pragma acc declare link%>"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ogiltig OpenACC-klausul vid filräckvidd"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<extern%>-variabel %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<global%>-variabeln %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD måste vara en variabel deklarerad i samma räckvidd som %<#pragma acc declare%>"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variabeln %qD använd mer än en gång med %<#pragma acc declare%>"
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> förväntades efter %<#pragma acc %s%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> har ingen dataflyttningsklausul"
@@ -41483,7 +41557,7 @@ msgstr "%qE har inte deklarerats"
 msgid "expected function name"
 msgstr "ett funktionsnamn förväntades"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD refererar inte till en funktion"
@@ -41493,67 +41567,67 @@ msgstr "%qD refererar inte till en funktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före användning"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före definitionen"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host%>- eller %<self%>-klausul"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<read%>-, %<write%>-, %<update%>-, %<capture%>-, %<seq_cst%>-, %<acq_rel%>-, %<release%>-, %<relaxed%>- eller %<hint%>-klausul förväntades"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "för många atomära klausuler"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "för många ordningsklausuler"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp atomic read%> är inkompatibel med en %<acq_rel%>- eller %<release%>-klausul"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic write%> är inkompatibel med en %<acq_rel%>- eller %<acquire%>-klausul"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp atomic update%> är inkompatibel med en %<acq_rel%>- eller %<acquire%>-klausul"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
@@ -41563,57 +41637,57 @@ msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "uttrycket %<depobj%> är inte ett l-värde-uttryck"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%> eller %<mutexinoutset%> förväntades"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<depend%>-, %<destroy%>- eller %<update%>-klausul förväntades"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<acq_rel%>, %<release%> eller %<acquire%> förväntades"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<flush%>-lista specificerat tillsammans med minnesordningsklausul"
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "en %<includsive%>- eller %<exclusive%>-klausul förväntades"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> förväntades"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-klausulparameter är mindre än %<collapse%>"
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "en %<linear%>-klausul får inte anges tillsammans med en %<ordered%>-klausul med en parameter"
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
@@ -41623,72 +41697,72 @@ msgstr "iterationsdeklaration eller initiering förväntades"
 msgid "not enough perfectly nested loops"
 msgstr "inte tillräckligt med perfekt nästade slingor"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "en %<ordered%>-klausul med parameter får inte anges på en %qs-konstruktion"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> med %<depend%>-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> måste innehålla åtminstone en %<map%>-, %<use_device_ptr%>- eller %<use_device_addr%>-klausul"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> med en annan map-typ än %<to%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> med en annan map-typ än %<from%>-, %<release%>- eller %<delete%> på %<map%>-klausul"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
@@ -41703,57 +41777,57 @@ msgstr "%<#pragma omp declare %s%> måste följas av funktionsdeklaration eller
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> måste följas av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "trait-väljarnamn förväntades"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr "selektorn %qs är inte tillåten för kontextselektormängd %qs"
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "väljaren %qs tar inte några egenskaper"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "värdesargument måste vara ett konstant heltalsuttryck"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "värdesargumentet måste vara ickenegativt"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "egenskaper måste vara ett konstant heltalsuttryck eller en strängkonstant"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "identifierare eller strängkonstant förväntades"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "egenskapen måste vara ett konstant heltalsuttryck"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "egenskaper för %<simd%>-väljare får inte anges i %<metadirective%>"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<construct%>, %<device%>, %<implementation%> eller %<user%> förväntades"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> förväntades"
@@ -41763,12 +41837,12 @@ msgstr "%<match%> förväntades"
 msgid "variant %qD is not a function"
 msgstr "varianten %qD är inte en funktion"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "varianten %qD och basen %qD har inkompatibla typer"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "varianten %qD är en inbyggd"
@@ -41778,32 +41852,32 @@ msgstr "varianten %qD är en inbyggd"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %<to%>-klausuler"
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr "direktiv med endast %<device_type%>-klausuler ignoreras"
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> förväntades"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%>"
@@ -41858,42 +41932,42 @@ msgstr "funktionsnamn %<(%> förväntades"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> eller %<variant%> förväntades"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<seq_cst%>, %<relaxed%> eller %<acq_rel%> förväntades"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "en klausul %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> eller %<atomic_default_mem_order%> förväntades"
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "klausulen %qs på direktivet %<requires%> stödjs inte ännu"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "klausulen %qs använd lexikalt efter första målkonstruktionern eller avlastnings-API:et"
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "mer än en klausul %<atomic_default_mem_order%> i en enskild kompileringsenhet"
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "klausulen %<atomic_default_mem_order%> använd lexikalt efter första konsstruktionen %<atomic%> utan minnesordningsklausul"
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> kräver åtminstone en klausul"
@@ -41908,27 +41982,27 @@ msgstr "nollstor typ %qT i %<reduction%>-klausul"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "typen %qT med variabel storlek i-%<reduction%>-klausul"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
@@ -41938,7 +42012,7 @@ msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "yttre %<__transaction_cancel%> som inte är inuti en yttre %<__transaction_atomic%>- eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
@@ -41953,7 +42027,7 @@ msgstr "ingen avslutande klammer"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD har en ofullständig typ %qT"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ogiltig användning av void-uttryck"
@@ -42074,7 +42148,7 @@ msgstr "derefererar %<void *%>-pekare"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "fältindex är inte ett heltal"
@@ -42099,7 +42173,7 @@ msgstr "ISO C90 förbjuder indexering av icke-l-värde-vektor"
 msgid "enum constant defined here"
 msgstr "uppräkningskonstant definierad här"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> på vektorfunktionsparametern %qE kommer returnera storleken på %qT"
@@ -42212,17 +42286,17 @@ msgstr "implicit konvertering från %qT till %qT när argument skickas till en f
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "för få argument till den inbyggda funktionen %qE, %u förväntades"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "jämförelse med stränglitteral resulterar i odefinierat beteende"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "jämförelse mellan pekare och teckenkonstanten noll"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "tänkte du dereferera pekaren?"
@@ -42247,7 +42321,7 @@ msgstr "pekare till funktion använd i subtraktion"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik på pekare till ofullständig typ"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik på pekare till ett tomt aggregat"
@@ -42495,7 +42569,7 @@ msgstr "typkonvertering från pekare till heltal av annan storlek"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "typkonvertering från funktionsanrop av typ %qT till typ %qT matchar inte"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typkonvertering till pekare från heltal med annan storlek"
@@ -42662,7 +42736,7 @@ msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatatt
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
@@ -42822,7 +42896,7 @@ msgstr "det går inte att initiera vektorn av %qT från en strängliteral med ty
 msgid "array of inappropriate type initialized from string constant"
 msgstr "vektor av typ som inte passar initierad från strängkonstant"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ogiltig användning av icke-l-värde-vektor"
@@ -42853,7 +42927,7 @@ msgstr "initierarelement är inte beräkningsbart vid laddtidpunkt"
 msgid "invalid initializer"
 msgstr "ogiltig initierare"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
@@ -42998,7 +43072,7 @@ msgstr "överflödiga element i skalärinitierare"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C förbjuder %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
@@ -43038,7 +43112,7 @@ msgstr "%<long%>-switch-uttryck konverteras inte till %<int%> i ISO C"
 msgid "case label is not an integer constant expression"
 msgstr "case-etikett är inte ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etikett är inte i en switch-sats"
@@ -43048,17 +43122,17 @@ msgstr "case-etikett är inte i en switch-sats"
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-etikett som inte ligger i en switch-sats"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sats som inte är i en loop eller switch"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sats som inte är i en loop"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sats använd med OpenMP-for-slinga"
@@ -43073,7 +43147,7 @@ msgstr "break-sats i en %<#pragma simd%>-slingas kropp"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-sats i en %<#pragma simd%>-slingas kropp"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "sats utan effekt"
@@ -43083,22 +43157,22 @@ msgstr "sats utan effekt"
 msgid "expression statement has incomplete type"
 msgstr "uttryckssats har ofullständig typ"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "jämför vektorer med skilda elementtyper"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "jämför vektorer med olika antal element"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "det går inte att hitta en heltalstyp med samma storlek som %qT"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "att jämföra flyttal med %<==%> eller %<!=%> är osäkert"
@@ -43149,7 +43223,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "ordningsjämförelse av pekare med nollpekare"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordningsjämförelse av pekare med heltalet noll"
@@ -43179,51 +43253,51 @@ msgstr "värde av uniontyp använt där skalär krävs"
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%<cancel%> %<if%>-klausulmodifierare förväntades"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE i %qs-klausul"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfältet %qE i %qs-klausul"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE är en medlem i en union"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "det går inte att dereferera %qE i en %qs-klausul"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
@@ -43233,8 +43307,8 @@ msgstr "%qE är inte en variabel i en %qs-klausul"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD i %qs-klausul"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
@@ -43402,12 +43476,12 @@ msgstr "ingen användardefinierad reduktion funnen för %qE"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "elementtyp med variabel längd i vektor-%<reduction%>-klausul"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
@@ -43432,8 +43506,8 @@ msgstr "%<_Atomic%> %qD i %<linear%>-klausul"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "%<linear%>-klausulens steg %qE är varken en konstant eller en parameter"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
@@ -43448,19 +43522,19 @@ msgstr "%qD förekommer mer än en gång i reduktionsklausuler"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD förekommer både i data- och map-klausuler"
@@ -43530,116 +43604,116 @@ msgstr "%qE skall inte ha en typ %<omp_depend_t%> i klausulen %<depend%> med ber
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE är varken en variabel eller ett funktionsnamn i klausulen %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE förekommer mer än en gång i samma %<declare target%>-direktiv"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "variabeln %qs är inte en pekare"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs-variabeln är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "en %<order%>-klausul får inte användas tillsammans med %<ordered%>"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-kvalificerad %qE kan förekomma endast i klausuler %<shared%> eller %<firstprivate%>"
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-klausulvärde är större än %<safelen%>-klausulvärde"
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-schemaläggningsmodifierare angiven tillsammans med %<ordered%>-klausul"
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "en %qs-klausul angiven tillsammans med en %<inscan%> %<reduction%>-klausul"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-klausulsteg är en parameter %qD inte angiven i %<uniform%>-klausul"
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "en %<nogroup%>-klausul får inte användas tillsammans med en %<reduction%>-klausul"
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "kan inte använda %<va_arg%> med omvänd lagringsordning"
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "andra argumentet till %<va_arg%> är av ofullständig typ %qT"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ kräver en befordrad typ, inte en uppräkningstyp, i %<va_arg%>"
@@ -43821,780 +43895,780 @@ msgid "expected case label"
 msgstr "case-etikett förväntades"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "  att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  ingen känd konvertering för implicit %<this%>-parameter från %qH till %qI"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  konvertering av argument %d vore felformaterat:"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr "  ingen känd konvertering från %qH till %qI"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  ingen känd konvertering för argument %d från %qH till %qI"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  kandidaten förväntade sig %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig %d argument, %d fanns"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T, %T)%> (inbyggd)"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T)%> (inbyggd)"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%<%D(%T)%> (inbyggd)"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr "%s%qT (konvertering)"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr "%s%#qD (nära träff)"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr "%s%#qD (raderad)"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr "%s%#qD (raderad)"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr "%s%#qD (omskriven)"
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s%#qD"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr "  ärvd här"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  returtypen %qT för en explicit konverteringsfunktion kan inte konverteras till %qT utan en kvalificerarkonvertering"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  konvertering från returtypen %qT för specialiseringen av mallkonverteringsfunktionen till %qT är inte en exakt matchning"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  substituering av härledda mallargument resulterade i felen som visas ovan"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  mallargumentshärledning/-substitution misslyckades:"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  en konstruerare som tar ett ensamt argument av sin egen klasstyp är felaktig"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  en ärvd konstruerare är inte en kandidat för initiering från ett uttryck av samma eller en härledd typ"
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "konvertering från %qH till %qI är tvetydig"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "initiering av %qH med %qI i konverterat konstantuttryck binder inte direkt"
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "konvertering från %qH till %qI i ett konverterat konstantuttryck"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr "kunde inte konvertera %qE från %qH till %qI"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%D(%A)%>"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%D(%A)%> är tvetydigt"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "pekar-till-medlemsfunktion %qE kan inte anropas utan ett objekt, överväg att använda %<.*%> eller %<->*%>"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen träff för anrop till %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "anrop av %<(%T) (%A)%> är tvetydigt"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "tvetydig överlagring för "
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr "ingen matchning för "
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (operandtyper är %qT, %qT och %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (operandtyper är %qT och %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (operandtyp är %qT)"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "treställig %<operator?:%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "treställig %<operator?:%> i %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> i %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> i %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs i %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> i %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> i %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> i %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ förbjuder uteslutande av mittersta termen i ett %<?:%> uttryck"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "den härledda skalära typen %qT är inte en heltals- eller flyttalstyp av samma storlek som %qT"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "konvertering av skalären %qH till vektorn %qI innebär avhuggning"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "inkompatibla vektortyper i villkorsuttryck: %qT, %qT och %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "andra operanden till villkorsoperatorn är av typ %<void%>, men den tredje operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "tredje operanden till villkorsoperatorn är av typ %<void%>, men den andra operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "operander till %<?:%> har olika typer %qT och %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  och båda typerna kan konverteras till den andra"
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "implicit konvertering från %qH till %qI för att stämma med andra resultat i villkor"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "uppräkningsmissmatch i villkorsuttryck: %qT kontra %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "uppräknings- och inte uppräkningstyp i villkorsuttryck"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs, försöker med prefixoperator istället"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "i C++20 anropar denna jämförelse den aktuella funktionen rekursivt med omvända argument"
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "returtypen för %qD är inte %qs"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "använd som omskriven kandidat för jämförelse mellan %qT och %qT"
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "jämförelse mellan %q#T och %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "undantagsuppstädning för denna placerande new väljer icke-placerande %<operator delete%>"
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD är som en vanlig (icke placerande) avallokeringsfunktion i C++14 (eller med %<-fsized-deallocation%>)"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD är en vanlig (utan placering) avallokeringsfunktion"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "ingen motsvarande avallokeringsfunktion för %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passande %<operator %s%> för %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D är privat inom denna kontext"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "deklarerad privat här"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D är skyddad inom denna kontext"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "deklarerad skyddad här"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D är oåtkomlig inom denna kontext"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "skickar NULL till icke-pekarargument %P till %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  deklarerad här"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "konverterar till icke-pekartyp %qT från NULL"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "konverterar %<false%> till pekartyp för argument %P till %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterar %<false%> till pekartyp %qT"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initierar argument %P till %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "konverteringar till vektorer med okänd gräns är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "för många klamrar runt initierare för %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "konvertering till %qH från %qI behöver en direktinitiering"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ogiltig användardefinierad konvertering från %qH till %qI"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "ogiltig konvertering från %qH till %qI"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "att konvertera till %qT från initierarlista skulle använda den explicita konstrueraren %qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "i C++11 och senare kan en standardkonstruerare vara explicit"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "kan inte binda r-värdesreferens av typen %qH till ett l-värde av typ %qI"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "kan inte binda icke-const-l-värde av typen %qH till ett r-värde av typ %qI"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "det går inte att binda en referens av typen %qH till %qI på grund av olika vektorgränser"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "att binda en referens av typen %qH till %qI kastar kvalificerare"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "det går inte att binda bitfält %qE till %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "det går inte att binda packat fält %qE till %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "det går inte att binda rvalue %qE till %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implicit konvertering från %qH till %qI när argument skickas till en funktion"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "enum %qT med räckvidd skickad vidare %<...%> som %qT före %<-fabi-version=6%>, %qT efter"
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "att skicka objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "det går inte att referera typen %qT via %<...%>"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "att ta emot objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursiv beräkning av standardargument till %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "anrop till %qD använder standardargumentet för parameter %P, vilket inte definierats ännu"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argument till funktionsanrop kan vara en kandidat för ett formatattribut"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "användning av multiversionsfunktion utan ett standardfall"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  i anrop till %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT är inte en åtkomlig bas till %qT"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "skickar argument till ellips av den ärvda konstrueraren %qD"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "tilldelning från en temporär %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning"
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD skriver till ett object av den icke-triviala typen %#qT%s"
 
 # %qs blir "protected" eller "private"
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD skriver till ett objekt av typen %#qT med %qs-medlem %qD"
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som innehåller en pekare till datamedlem%s"
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; använd tilldelning eller värdeinitiering istället"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; använd tilldelning istället"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; använd värdeinitiering istället"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD nollställer ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD nollställer ett objekt av den icke-triviala typen %#qT%s"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD nollställer ett objekt av typen %#qT som innehåller en pekare-till-medlem%s"
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; använd kopieringstilldelning eller kopieringsinitiering istället"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; använd kopieringstilldelning istället"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; använd kopieringsinitiering istället"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som inte är trivialt kopierbar%s"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD skriver till ett objekt med en borttagen kopieringskonstruerare"
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD kopierar ett objekt med en icke-trivial typ %#qT från en vektor av %#qT"
 
 # %qs blir "protected" eller "private"
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD kopierar ett objekt av typen %#qT med %qs-medlem %qD från en vektor av %#qT; använd tilldelning eller kopieringsinitiering istället"
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD skriver till ett objekt med en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD skriver till ett objekt av en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av en icke trivialt kopierbar typ %#qT; använd %<new%> och %<delete%> istället"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen kopieringskonstruerare; använd %<new%> och %<delete%> istället"
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen destruerare"
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD flyttar ett objekt av den icke-triviala typen %#qT och storleken %E in i en region av storleken %E"
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT är deklarerad här"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "konstruerare delegerar till sig själv"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr "det går inte att konvertera %qH till %qI"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "för en typkonvertering i funktionsstil, ta bort det överflödiga %<::%D%>"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%s(%A)%>"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%s(%A)%> är tvetydigt"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtual %q#D anropad från initierare av ickestatisk datamedlem"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtual %q#D anropad från en konstruerare"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtual %q#D anropad från en destruerare"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "det går inte att anropa medlemsfunktion %qD utan ett objekt"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "att skicka %qT väljer %qT framför %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "väljer %qD framför %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 msgid "  for conversion from %qH to %qI"
 msgstr "  för konvertering från %qH till %qI"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  för att konverteringssekvensen för argumentet är bättre"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "standardargument stämmer inte överens i upplösning av överlagring"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ säger att dessa är tvetydiga, trots att den sämsta konverteringen för den första är bättre än den sämsta konverteringen för den andra:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "en temporär bunden till %qD består endast tills konstrueraren avslutar"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ogiltig initiering av icke konstant referens av typ %qH från ett r-värde av typ %qI"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ogiltig initiering av referens av typ %qH från uttryck av typ %qI"
 
@@ -44623,519 +44697,519 @@ msgstr "kan inte konvertera från basklassen %qT till den härledda klassen %qT
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "kan inte konvertera %qT till basklassen %qT eftersom %qT är inkomplett"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D står i konflikt med versionen ärvd från %qT"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "versionen ärvd från %qT är deklarerad här"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kan inte överlagras med %q#D"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "tidigare deklaration %q#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "åtkomstspecifikationer i konflikt för metod %q+D, ignoreras"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "åtkomstspecifikationer i konflikt för fält %qE, ignoreras"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "%qD är ogiltig i %q#T på grund av lokal metod %q#D med samma namn"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "den lokala metoden %q#D är deklarerad här"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "%qD är ogiltig i %q#T på grund av lokal medlem %q#D med samma namn"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "den lokala medlemmen %q#D är deklarerad här"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr "%qD ärver ABI-etiketten %E som %qT (använd i sin returtyp) har"
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT är deklarerad här"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr "%qD ärver ABI-taggen %E som %qT (använd i dess typ) har"
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr "%qT har inte ABI-taggen %E som basen %qT har"
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr "%qT har inte ABI-taggen %E som %qT (använd i typen av %qD) har"
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan inte härleda från %<final%> bas %qT i härledd typ %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alla medlemsfunktioner i klass %qT är privata"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definierar bara en privat destruerare och har inga vänner"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definierar bara privata konstruerare och har inga vänner"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D är public, men behöver ett befintligt %q#T-objekt"
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik slutlig ersättare för %qD i %qT"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kan markeras override"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D är markerad %<override%>, men den åsidosätter inte"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D är markerad %<final%>, men är inte virtuell"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD var dold"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  av %qD"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha publika ickestatiska datamedlemmar"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "denna flexibilitet bör undvikas och kommer tas bort"
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "ellipsen i %qD ärvs inte"
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bitfält %q#D har en icke-heltalstyp %qT"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredd för bitfältet %q+D inte en heltalskonstant"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredd i bitfält %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "noll i bredd i bitfält %q+D"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "bredden på %qD är större än dess typ"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD är för liten för att få plats med alla värden hos %q#T"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlem %q+#D med konstruerare inte tillåten i union"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlem %q+#D med destruerare inte tillåten i union"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator inte tillåten i union"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "obegränsade unioner är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "i C++98 får %q+D inte vara statisk eftersom den är medlem av en union"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "icke-statisk datamedlem %q+D i en union får inte ha referenstyp %qT"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr "datamedlammen %q+D ogiltigt deklarerad funktionstyp"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr "datamedlemmen %q+D ogiltigt deklarerad metodtyp"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "ignorerar attributet packed på grund av opackat icke-POD-fält %q#D"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "medlem %q+D kan inte deklareras som en %<mutable%> referens"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmen %q+D kan inte både deklareras %<const%> och %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "flera fält i unionen %qT initierade"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "den initierade medlemmen %q+D är deklarerad här"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "fält %q#D med samma namn som en klass"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T har pekardatamedlemmar"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  men deklarerar inte %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  men deklarerar inte %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "pekarmedlemmen %q+D är deklarerad här"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "justeringen av %qD ökade i %<-fabi-version=9%> (GCC 5.2)"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "justering av %qD kommer öka i %<-fabi-version=9%>"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initierare angiven för icke-virtuell metod %q+D"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr "destrueraren för %qT är tvetydig"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "metoden åsidosätter både metoderna %<transaction_pure%> och %qE"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "metod deklarerad %qE åsidosätter %qE-metod"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "omslutande klass till %<constexpr%> icke-statisk medlemsfunktion %q+#D är inte en litteral typ"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T är inte litteral för att:"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT är en höljestyp (closure), som är litteraler endast i C++17 och senare"
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T har en icke-trivial destruerare"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T har inte en %<constexpr%>-destruerare"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T är inte ett aggregat, har inte en trivial standardkonstruerare och har ingen %<constexpr%>-konstruerare som inte är en kopierings- eller flyttningskonstruerare"
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  basklassen %qT till %q+T är inte litteral"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  den icke-statiska datamedlemmen %qD har icke-litteral typ"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  den icke-statiska datamedlemmen %qD har volatile typ"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "basklassen %q#T har en åtkomlig icke-virtuell destruerare"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "icke-statisk referens %q#D i klass utan en konstruerare"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "icke-statisk const-medlem %q#D i klass utan en konstruerare"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkt bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuell bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "förskjutningen av %qD följer inte ABI:et och kan ändras i en framtida version av GCC"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "storleken på typen %qT är för stor (%qE byte)"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ogiltig användning av %qT med en vektor av storlek noll i %q#D"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ogiltig användning av %q#T med flexibel vektormedlem i %q#T"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "vektormedlem %q#D är deklarerad här"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "vektormedlem %qD med storlek noll är inte vid slutet av %q#T"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "vektormedlem %qD med storlek noll i en i övrigt tom %q#T"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "i definitionen av %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibel vektormedlem %qD inte vid slutet av %q#T"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibel vektor medlem %qD i en i övrigt tom %q#T"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T har virtuella funktioner och åtkomlig ickevirtuell destruerare"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typgenomskinliga %q#T har inga fält"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "den typgenomskinliga klassen %qT har basklasser"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "den typgenomskinliga klassen %qT har virtuella funktioner"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparenta %q#T kan inte göras transparent eftersom typen på första fältet har ett annat ABI än klassen som helhet"
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "definitionen av %qD matchar inte %<#include <initializer_list>%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "försökte avsluta post, men hoppade ut på grund av tidigare parsningsfel"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "språksträng %<”%E”%> känns inte igen"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "det går inte att lösa upp överlagrad funktion %qD baserat på konvertering till typ %qT"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen match som konverterar funktionen %qD till typen %q#T"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering av överlagrad funktion %qD till typ %q#T är tvetydig"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "antar pekare till medlem %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en pekare på medlem kan bara skapas med %<&%E%>)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "inte tillräcklig typinformation"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan inte konvertera %qE från typ %qT till typ %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "deklaration av %q#D ändrar betydelsen av %qD"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD deklarerad här som %q#D"
@@ -45215,7 +45289,7 @@ msgstr "%<constexpr%>-anrop flödar förbi slutet på funktionen"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E är inte ett konstant uttryck"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "anrop av intern funktion %qE"
@@ -45271,7 +45345,7 @@ msgstr "avallokering av en redan avallokerad lagring"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "avallokering av lagring som inte tidigare allokerades"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "anrop av icke-%<constexpr%>-funktion %qD"
@@ -45326,370 +45400,369 @@ msgstr "skiftuttrycket %q+E spiller över"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "aritmetik som innefattar en nollpekare i %qE"
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektorn %qD av typen %qT"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med vektorn %qD av typen %qT med okända gränser"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektortypen %qT"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med en vektor av typen %qT med okända gränser"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "använder oinitierat vektorelement"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "derefererar en nollpekare i %qE"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "muterbar %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "använder oinitierad medlem %qD"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "använder medlem %qD istället för initierad medlem %qD i ett konstant uttryck"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "derefererar en nollpekare"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "innehållet av den oinitierade lagringen inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "allokerad här"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "användning av allokerad lagring efter deallokering i ett konstant uttryck"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "värdet på %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD använd i sin egen initierare"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D är inte const"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D är volatile"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD initierades inte med ett konstant uttryck"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD deklarerades inte %<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD har inte heltals- eller uppräkningstyp"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "ändring av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD under initiering"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "satsen är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "%<constexpr%>-slingiterationsantal överskrider gränsen på %d (använd %<-fconstexpr-loop-limit=%> för att öka gränsen)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "inline-assembler är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr "endast oevaluerade inline:ade assember är tillåten i en %<constexpr%>-funktion i C++2a"
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "värdet %qE av typen %qT är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "antalet %<constexpr%>-evalueringsoperationer överskrider gränsen på %wd (använd %<-fconstexpr-loop-limit=%> för att öka gränsen)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej litterala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "en %<reinterpret_cast%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "konvertering av %qT-nullpekare till %qT som inte är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "uttrycket %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "oväntat mall-id %qE"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "funktionkoncept måste anropas"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar till en ofullständigt initierad variabel"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar ett resultat av %<operator new%>"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE är inte ett konstant uttryck eftersom allokerad lagring inte har avallokerats"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "omedelbar evaluering returnerar adressen till en omedelbar funktion %qD"
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "konvertering av l-värde till r-värde av ett volatilt l-värde %qE med typen %qT"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "lambdafångst av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "för att det används som ett gl-värde"
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> från heltal till pekare"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "lambdauttryck är inte ett konstant uttryck före C++17"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "virtuella funktioner kan inte %<constexpr%> före C++2a"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD är deklarerad %<static%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD är deklarerad %<thread_local%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "division med noll är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> är inte ett konstant uttryck"
 
 # ast = abstract syntax tree
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr "båda grenarna av en %<if%>-satsen markerad som %qs"
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> kommer alltid anropa %<terminate%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "i C++11 är standard för destruerare %<noexcept%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "i C++11 kommer denna %<throw%> att anropa %<terminate%> eftersom standard för destruerare är %<noexcept%>"
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "ignorerar attributet %qE efter tidigare %qE"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD är inte en typ"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD är inte en klasstyp"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD har inte typen %<const char *%>"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD har inte heltalstyp"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> innehåller inte endast icke-statiska datamedlemmar %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> och %<_M_column%>"
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "beräknar %qs"
@@ -45730,7 +45803,7 @@ msgstr "konvertering till icke konstant referens av typ %q#T från ett r-värde
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering från %qH till %qI kastar kvalificerare"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "typkonvertering av %qT till %qT derefererar inte pekare"
@@ -45768,292 +45841,292 @@ msgstr "%q#T använt där ett flyttalsvärde förväntades"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "konvertering från %qH till icke-skalär typ %qI begärd"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<nodiscard%>: %<%s%>"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<nodiscard%>%s"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "ignorerar returnerat värde av typen %qT, deklarerat med attributet %<nodiscard%>: %<%s%>"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "ignorerar returnerat värde av typen %qT, deklarerat med attributet %<nodiscard%>%s"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "i anrop av %qD, deklarerad här"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet %<warn_unused_result%>"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "pseudodestruerare anropas inte"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konvertering till void kommer inte använda objekt av ofullständig typ %qT"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt med ofullständig typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i tredje operand till villkorligt uttryck"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i högeroperanden till kommaoperatorn"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i vänstra operand av kommaoperatorn"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i sats"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i ökningsuttryck"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "konvertering till void kommer inte använda objekt av typ %qT"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i tredje operanden till villkorligt uttryck"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i högeroperanden till kommaoperatorn"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i vänstra operanden av kommaoperatorn"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i satsen"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i for-ökningsuttryck"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "konvertering till void kommer inte använda objekt av ej trivialt kopierbar typ %qT"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt av icke trivialt kopierbar typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "en indirektion kommer inte att använda ett objekt av ej trivialt kopierbar typ %qT i tredje operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "en indirektion kommer inte att använda ett objekt av ej trivialt kopierbar typ %qT i högra operanden av en kommaoperator"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i vänstra operanden av en kommaoperator"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i sats"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i for-ökningsuttryck"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "konvertering till void kommer inte använda objekt %qE av ofullständig typ %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i andra operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i tredje operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i högra operanden av en kommaoperator"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i vänstra operanden av en kommaoperator"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i en sats"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i for-ökningsuttryck"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "konvertering till void kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "andra operanden i villkorsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "tredje operanden i villkorsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "högra operanden av kommaoperator kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "vänstra operanden av kommaoperator kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "en sats kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "for-ökningsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "andra operanden av villkorsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "tredje operanden av villkorsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "högra operanden av kommaoperator är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "vänstra operanden av kommaoperator är en referens, inte ett anrop, till funktion %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "sats är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "for-ökningsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "andra operanden av villkorsuttryck har ingen effekt"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "tredje operanden av villkorsuttryck har ingen effekt"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "höger operand av kommaoperator har ingen effekt"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "vänster operand av kommaoperator har ingen effekt"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "satsen har ingen effekt"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for-ökningsuttryck har ingen effekt"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "konvertera av NULL till icke-pekartyp"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "standardtypkonvertering kan inte härleda mallargumentet för %qD"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "tvetydig standardtypkonvertering från %qT"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  kandidater till konvertering är %qD och %qD"
@@ -46118,7 +46191,7 @@ msgstr "än tidigare deklaration av %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "omdeklaration av %qD skiljer i %qs från tidigare deklaration"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "tidigare deklaration %qD"
@@ -46299,12 +46372,12 @@ msgstr "tidigare deklaration av %qD här"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktionen %qD är deklarerad %<[[noreturn]]%> men dess första deklaration var inte det"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "överflödig omdeklaration av %qD i samma definitionsområde"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "borttagen definition av %qD"
@@ -46317,44 +46390,44 @@ msgstr "borttagen definition av %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explicit specialisering av %qD efter första användningen"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: synlighetsattributet ignoreras eftersom det står i konflikt med tidigare deklaration"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "omdefinition av %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD står i konflikt med använd funktion"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D inte deklarerad i klassen"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline med attributet %<gnu_inline%>"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline utan attributet %<gnu_inline%>"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "jämförelseoperatorn %q+D standarddefinierades efter sin första deklaration"
@@ -46362,841 +46435,841 @@ msgstr "jämförelseoperatorn %q+D standarddefinierades efter sin första deklar
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "omdeklaration av vän %q#D kan inte ha standardmallargument"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal deklaration av %q#D följer på icke trådlokal deklaration"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "icke trådlokal deklaration av %q#D följer på trådlokal deklaration"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "omdeklaration av %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "överflödig omdeklaration av statisk %<constexpr%>-datamedlem %qD"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "den lokala etiketten %qE står i konflikt med en befintlig etikett"
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr "tidigare etikett"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  härifrån"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  går ut från OpenMP-strukturerat block"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  passerar initiering av %q#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  går in i räckvidden hos %q#D, som har en icke-trivial destruerare"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  går in i %<try%>-block"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  går in i %<catch%>-block"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  går in i OpenMP-strukturerat block"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  går in i synkroniserad eller atomär sats"
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  går in %<constexpr if%>-sats"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  hoppar över initiering av %q#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  går in i räckvidden hos %q#D som har en icke-trivial destruerare"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ogiltig utgång från OpenMP-strukturerat block"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD använd utan mallargument"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T är inte en klass"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klassmall med namnet %q#T i %q#T"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "ingen typ med namnet %q#T i %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "uppslagning av %qT i %qT är tvetydig"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en klassmall"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en typ"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "mallparametrar stämmer inte med mallen %qD"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> är inte en exponent av två"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med konstruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med destruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator är inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoreras i deklaration av %q#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "attribut för %q#T måste komma efter nyckelordet %qs"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flera typer i en deklaration"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omdeklaration av inbyggd C++-typ %qT"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kan endast anges för variabler eller funktionsdeklarationer"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typnamn saknas i typedef-deklaration"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ förbjuder anonyma poster"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kan endast anges för funktioner"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kan endast anges för funktioner"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kan endast anges inuti en klass"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kan endast anges för konstruerare"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "en lagringsklass kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> ignorerades i denna deklaration"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kan inte användas till typdeklarationer"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoreras i explicit instansiering av %q#T"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "inget attribut kan användas på en explicit instansiering"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ignorerar attribut använda på klasstypen %qT utanför dess definition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ignorerar attribut använda på beroende typ %qT utan en associerad deklaration"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD är initierad (använd %qs istället)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarationen av %q#D har %<extern%> och är initierad"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definitionen av %q#D är markerad %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D är inte en statisk datamedlem i %q#T"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "icke-medlemsmalldeklaration av %qD"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "stämmer inte med medlemsmalldeklarationen här"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillåter inte %<%T::%D%> att definieras som %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubblerad initierare av %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklaration av %q#D utanför en klass är inte en definition"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qD är deklarerad %<thread_local%> i en %qs-funktion"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%qD är deklarerad %<static%> i en %qs-funktion"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabeln %q#D har initierare men ofullständig typ"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen i vektorn %q#D har ofullständig typ"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "aggregatet %q#D har ofullständig typ och kan inte definieras"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD är deklarerad som en referens men inte initierad"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "namn använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "namnet %qD använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "icketriviala designerade initierare stödjs inte"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-beteckningen %qE är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "initierare misslyckas med att bestämma storleken på %qD"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "vektorstorlek saknas i %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "vektor med storlek noll %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstorlek på %qD är inte känd"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstorlek på %qD är inte konstant"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-variabeln %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-funktioners statiska data %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "du kan gå runt detta genom att ta bort initieraren"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "oinitierad %<const %D%>"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "oinitierad variabel %qD i %<constexpr%>-kontext"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T har ingen användardefinierad standardkonstruerare"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "konstrueraren är inte användarens egna eftersom den är uttryckligen standarddefinierad i klasskroppen"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "och den implicit definierade konstrueraren initierar inte %q#D"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ogiltig typ %qT som initierare för en vektor med typ %qT"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initierare för %qT måste vara inom klamrar"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> använt i en designerad initierare i GNU-stil för klassen %qT"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT har ingen icke-statisk medlem med namnet %qD"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ogiltig initierare för %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "för många klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "klamrar saknas runt initierare för %qT"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "element i vektorn %q#T har ofullständig typ"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "sammansatta litteral med variabel storlek"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D har ofullständig typ"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalärt objekt %qD kräver ett element i initieraren"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "i C++98 måste %qD initieras med en konstruerare, inte med %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "vektor %qD initierad från strängkonstant inom parentes %qE"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initierare är ogiltig för statisk medlem med konstruerare"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ej konstant initiering inom klassen av statisk medlem %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ej konstant initiering inom klassen är felaktig för icke inline statisk medlem %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en initiering utanför klassen krävs)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "referensen %qD initieras med sig själv"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "kunde inte hitta en variantdeklaration"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> på konstrueraren %qD"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> på destrueraren %qD"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> på standarddefinierad %qD"
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> på raderad %qD"
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> på virtuell %qD"
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillåter inte specificeraren %<register%> av lagringsklass"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "specificeraren %<register%> av lagringsklass angiven"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "initieraren för %<decltype(auto) %D%> har funktionstyp; glömde du %<()%>?"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "variabelkoncept har ingen initierare"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skuggar tidigare typdeklaration av %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> kan bara tillämpas på en variabel med statisk eller trådlagringsvaraktighet"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "det går inte dekomponera klasstypen %qT för att den har en anonym struct-medlem"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "kan inte dekomponera klasstypen %qT för att den har en anonym unionsmedlem"
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "det går inte att dekomponera en oåtkomlig medlem %qD av %qT"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: både den och dess basklass %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: dess basklasser %qT och %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "strukturerad bindning refererar till ofullständig typ %qT"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u namn angivet för strukturerad bindning"
 msgstr[1] "%u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "endast %u namn angivet för strukturerad bindning"
 msgstr[1] "endast %u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "medan %qT dekomponeras till %wu element"
 msgstr[1] "medan %qT dekomponeras till %wu element"
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "medan %qT dekomponeras till %E element"
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "i initieringen av variabel %qD i strukturerad bindning"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "det går inte att dekomponera unionstypen %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "det går inte att dekomponera typen %qT som inte är en klass eller vektor"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "det går inte att dekomponera lambdahöljestypen %qT"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "strukturerad bindning refererar till ofullständig klasstyp %qT"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "det går inte att dekomponera klasstypen %qT utan icke-statiska datamedlemmar"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "konceptet %q#D deklarerad med funktionsparametrar"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "konceptet %q#D deklarerat med en härledd returtyp"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "koncept %q#D med icke-%<bool%>-returtyp %qT"
@@ -47466,7 +47539,7 @@ msgstr "spill i vektordimension"
 msgid "%qD declared as array of %qT"
 msgstr "%qD är deklarerad som en vektor av %qT"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
@@ -47631,7 +47704,7 @@ msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
@@ -47832,810 +47905,810 @@ msgstr "attributet ignorerat"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "Ett attribut som gäller en viss typspecificerare ignoreras"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "onödiga parenteser i deklaration av %qs"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-klausul på returtypen"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "härledd returtyp är endast tillgänglig med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %<decltype(auto)%> som sin typ istället för bara %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ogiltigt användning av %<decltype(auto)%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "härledd klasstyp %qD i funktionens returtyp"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "härledningsguiden för %qT måste ha en avslutande returtyp"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "den avslutande returtypen %qT hos deduktionsguiden är inte en specialisering av %qT"
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "avslutande returtyp är endast tillgänglig med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-kvalificerad returtyp bör undvikas"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> på en funktions returtyp är inte tillåtet"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "konstruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruerare kan inte deklareras %<virtual%>"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<::%>"
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<%D::%>"
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en konverteringsfunktion kan inte ha en avslutande returtyp"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef kan inte vara en funktionsdefinition"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef får inte vara en medlemsfunktionsdefinition"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> är inte tillåtet i en aliasdeklaration"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-klausul på typedef"
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-klausul på type-id"
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-klausul vid deklaration av icke-funktionstypen %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "det går inte att deklarera en parameter med %<decltype(auto)%>"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ej statisk datamedlem deklarerad med platshållaren %qT"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ förbjuder den flexibla vektormedlemmen %qs"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ förbjuder flexibla vektormedlemmar"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltigt användning av %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen %qD deklarerad %<virtual%> inuti en union"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kan inte deklareras %<virtual%>, eftersom den alltid är statisk"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "en destruerare kan inte vara %qs"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<constexpr%>-destruerare är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "en konstruerare kan inte vara %<concept%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ett koncept kan inte vara en medlemsfunktion"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kan inte vara %qs"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "ett namnlöst fält är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statiska %<constexpr%>-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ickestatisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarationen av %<constexpr%>-variabeln %qD är inte en definition"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "en variabel kan inte deklareras %<consteval%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-kvalificerad parameter bör undvikas"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ förhindrar överlagring av %<operator ?:%>"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD måste ha antingen noll eller ett argument"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD måste ha antingen ett eller två argument"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD måste ha %<int%> som sitt argument"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD måste ha %<int%> som sitt andra argument"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD får inte ha några argument"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD måste ha exakt ett argument"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD måste ha exakt två argument"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering av %qT till %<void%> kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering till %qT till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering till %qT till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering till %qT till en referens till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering till %qT till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT har en tidigare deklaration här"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -48647,95 +48720,95 @@ msgstr "%qT refererad till som enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT definierad med flera direkta baser"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT definerad med en direkt virtuell bas"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
@@ -48744,72 +48817,72 @@ msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "uppräkningsvärde för %qD är inte en heltalstyp eller uppräkningstyp utan räckviddsbegränsning"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<long%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "uppräkningsvärdet %qE är utanför intervallet för den underliggande typen %qT"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -48849,7 +48922,7 @@ msgstr "det går inte att radera en funktion.  Endast pekare till objekt är gil
 msgid "deleting %qT is undefined"
 msgstr "radera %qT är odefinierat"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malldeklaration av %q#D"
@@ -48859,7 +48932,7 @@ msgstr "malldeklaration av %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "mallparametrerlistan som ges stämmer inte mallparametrarna till %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destrueraren %qD deklarerad som medlemsmall"
@@ -49184,147 +49257,147 @@ msgstr "för att %qT ha användarleverad %qD"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "användning av funktionen %qD med ej uppfyllda begränsningar"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "användning av det inbyggda parameterpaketet %qD utanför en mall"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(inga argument)"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[…]"
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "utökade initierarlistor är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "explicita konverteringsoperatorer är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "variadiska mallar är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "lambdauttryck är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11 auto är endast tillgängligt med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "enum med räckvidd är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standarddefinierade och borttagna funktioner är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline-namnrymder är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "styrning av åsidosättande (override/final) är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "initierare av datamedlemmar som inte är statiska är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "användardefinierade litteraler är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "delegerande konstruerare är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ärvande konstruerare är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "c++11-attribut är endast tillgängligt med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-kvalificerare är endast tillgängliga med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "ofullständig typ %qT använd i nästad namnspecificerare"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "referens till %<%T::%D%> är tvetydig"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD är inte en medlem av %qT; menade du %qs?"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD har inte en medlem av %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD är inte en medlem av %qD; menade du %qs?"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD är inte en medlem av %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> har inte deklarerats; menade du %qs?"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> har inte deklarerats"
@@ -49505,338 +49578,338 @@ msgstr "värdeinitiering av referenstypen %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursiv instansiering av standardmedleminitierare för %qD"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "standardmedlemsinitieraren för %qD behövs före slutet på dess omgivande klass"
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initierare för flexibel vektormedlem %q#D"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr "initiering av %qD från %qE utökar inte livslängden på den underliggande vektorn"
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD skall initieras i medlemsinitieringslistan"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD initieras med sig själv"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ogiltig initierare för vektormedlem %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "oinitierad const-medlem i %q#T"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D borde initieras"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "oinitierad referensmedlem i %q#T"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD kommer initieras efter"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "basen %qT kommer initieras efter"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  basen %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  vid initiering här"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "flera initieringar givna för %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "flera initieringar givna för basen %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initiering av flera medlemmar av %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "basklass %q#T skulle varit explicit initierad i kopieringskonstrueraren"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "klass %qT har inget fält med namnet %qD"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D är en statisk datamedlem; den kan endast initieras vid sin definition"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D är inte en icke-statisk datamedlem i %qT"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "namnlös initierare för %qT, som inte har några basklasser"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "namnlös initierare för %qT som använder multipelt arv"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD är både en direkt bas och en indirekt virtuell bas"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typ %qT är inte en direkt eller virtuell bas till %qT"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "typ %qT är inte en direkt bas till %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT är inte en klasstyp"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ofullständig typ %qT har inte medlem %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ogiltigt pekare till bitfält %qD"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion %qD"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ogiltig användning av icke-statisk datamedlem %qD"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %<%T [%wu]%> och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar en vektor av objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "heltalsspill i vektorstorlek"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "vektorstorlek i new-uttryck måste vara en konstant"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variabelt ändrad typ inte tillåten i new-uttryck"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "en ny längd för en icke-konstant vektor måste anges direkt, inte av %<typedef%>"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "new-längden för en icke-konstant vektor måste anges utan parenteserna runt typ-id:t"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "ogiltig typ %<void%> för %<new%>"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "%<new%> av %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "oinitierad const i %<new%> av %q#T"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ingen lämplig %qD i klassen %qT"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "begäran av medlem %qD är tvetydig"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> av typ %qT med utökad justering %d"
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "använder %qD, som inte har någon justeringsparameter"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "använd %<-faligned-new%> för att aktivera stöd för C++17 överjusterade new"
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initierare inom parentes i vektor-new"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "storlek i vektor-new måste ha heltalstyp"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan inte användas på en referenstyp"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan inte användas på en funktionstyp"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "möjligt problem upptäckt vid anrop av operatorn %<delete []%>"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn %<delete []%> kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "initierare tar slut i förtid"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "okänd vektorstorlek i delete"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "möjligt problem upptäckt vid anrop av %<operator delete%>"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika %<operator delete%> kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "radering av objekt av den abstrakta klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "radering av objekt av den polymorfa klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "typ till vektor-delete är varken pekar- eller vektortyp"
@@ -49996,12 +50069,12 @@ msgstr "det manglade namnet på %qD ändras mellan %<-fabi-version=%d%> och %<-f
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "det manglade namnet på initieringsvaktsvariabeln för %qD ändras mellan %<-fabi-version=%d%> och %<-fabi-version=%d%>"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "ickestatisk const-medlem %q#D, kan inte använda standardtilldelningsoperatorn"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "ickestatisk referensmedlem %q#D, kan inte använda standardtilldelningsoperatorn"
@@ -50026,157 +50099,164 @@ msgstr "formar typen av %qs"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "standarddefinierad %qD är endast tillgänglig med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "trevägsjämförelseoperatorn kan endast standarddefinieras i en klassdefinition"
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "likhetsjämförelseoperatorn kan endast standarddefinieras i en klassdefinition"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr "standarddefinierad %qD måste returnera %<bool%>"
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, gcc-internal-format
 msgid "defaulted %qD must be %<const%>"
 msgstr "standarddefinierad %qD måste vara %<const%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+#| msgid "non-member function %qD cannot have ref-qualifier"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD är redan en vän till %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr "standarddefinerad medlem %qD måste ha parametertyp %<const %T&%>"
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr "standarddefinerad %qD måste ha parametrar av antingen typen %<const %T&%> eller %qT"
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr "standarddefinerad %qD måste ha parametrar av antingen typen %<const %T&%> eller %qT, inte båda"
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "det går inte att standardjämföra unionen %qT"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr "det går inte att standardjämföra referensmedlemmen %qD"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "det går inte att standardjämföra en anonym unions medlem"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr "syntetiserad metod %qD krävs första gången här "
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "union-medlem %q+D med icketrivial %qD"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "standarddefinierad destruerare anropar %qD som inte är %<constexpr%>"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "standarddefinierad konstruerare anropar %qD som inte är %<constexpr%>"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "initieraren för %q#D är ogiltig"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "den standarddefinierade standardkonstrueraren initierar inte %q#D"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "kopierar icke-statisk datamedlem %q#D med rvärdereferenstyp"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "den standarddefinierade standardkonstrueraren initierar inte några ej statiska datamedlemmar"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "standarddefinierad flyttningstilldelning av %qT anropar en icketrivial flyttningstilldelningsoperator för den virtuella basen %qT"
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "en lambdahöljestyp har en borttagen standardkonstruerare"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "en lambdahöljetyp har en borttagen kopieringstilldelningsoperator"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D är implicit deklarerad som borttagen för att %qT deklarerar en flyttkonstruerare eller flyttilldelningsoperator"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D ärver från flera bassubobjekt"
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D är underförstått borttagen eftersom standarddefinitionen skulle vara felformulerad:"
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F tas implicit bort för att dess undantagsspecifikation stämmer inte med den implicita undantagsspecifikationen %qX"
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "standarddeklaration %q+D stämmer inte med den förväntade signaturen"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "förväntad signatur: %qD"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "den explicit standarddefinierade funktionen %q+D kan inte deklareras som %qs för att den implicita deklarationen är inte %qs:"
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "en mall kan inte standarddefinieras"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD kan inte standarddefinieras"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "standarddefinierad funktion %q+D med standardargument"
@@ -50216,210 +50296,210 @@ msgstr "lambdaparametern %qD är deklarerad tidigare som en fångst"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklaration av %q#D skuggar en parameter"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarationen av %qD skuggar en medlem av %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "lokal extern deklaration av %q#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "matchar inte tidigare deklaration %q#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "vändeklaration %qD i lokal klass utan en tidigare lokal deklaration"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-deklaration för icke-medlem vid klassräckvidd"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "en using-deklaration får inte vara en namnuppräknare %<%E::%D%>"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "using-deklaration för medlem vid icke-klass-räckvidd"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> namnger en destruerare"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> namnger konstruerare i %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "kan inte ärva konstruerare från den indirekta basen %qT"
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "%qD har inte deklarerats i %qE"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "en using-deklaration får inte namnge namnrymden %qD"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklaration av %qD inte i namnrymd som omger %qD"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explicit-kvalifikation i deklaration av %qD"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD har inte deklarerats inom %qD"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "endast här som %<friend%>"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD borde ha deklarerats inuti %qD"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "attributet %qD kräver ett ensamt NTBS-argument"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "attributet %qD är meningslöst eftersom medlemmar av den anonyma namnrymden får lokala symboler"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "ignorerar attributet %qD på en anonym namnrymd"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ignorerar attributet %qD på en namnrymd som inte är inline"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attributdirektivet %qD ignorerat"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "maxgräns på %d namnrymder sökta %qE"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "föreslaget alternativ:"
 msgstr[1] "föreslagna alternativ:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> är definierad i huvudet %qs; glömde du %<#include %s%>?"
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> är bara tillgänglig från %s och framåt"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "makrot %qs har inte definierats ännu"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "det definierades senare här"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "definitionen av %<std::initializer_list%> matchar inte %<#include <initializer_list>%>, är inte en mall"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "ett %<strong%> using-direktiv stödjs inte längre"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "du kan använda en inline-namnrymd istället"
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> är tvetydig"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namnrymdsalias %qD inte tillåtet här, antar %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "det går inte att nästa mer än %d namnrymder"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "inline-namnrymder måste anges vid den ursprungliga definitionen"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD definierades här"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX går in i %<pop_everything ()%>"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX lämnar %<pop_everything ()%>"
@@ -50444,7 +50524,7 @@ msgstr "identifieraren %qE är ett nyckelord i C++20"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> är inte satt till true"
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -50469,7 +50549,7 @@ msgstr "%<::%E%> har inte deklarerats"
 msgid "request for member %qE in non-class type %qT"
 msgstr "begäran av medlem %qE i typ %qT som inte är en klasstyp"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> har inte deklarerats"
@@ -50549,7 +50629,7 @@ msgstr "ogiltigt mall-id"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ förbjuder användning av en flyttalslitteral i ett konstantuttryck"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "en typomvandling till en annan typ än en heltals- eller uppräkningstyp kan inte förekomma i ett konstantuttryck"
@@ -50670,7 +50750,7 @@ msgstr "C++20 %<constinit%> är endast tillgängligt med %<-std=c++2a%> eller %<
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<concept%> är endast tillgängligt med %<-std=c++2a%> eller %<-fconcepts%>"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<requires%> är endast tillgängligt med %<-std=c++2a%> eller %<-fconcepts%>"
@@ -50790,7 +50870,7 @@ msgstr "använd %<-fext-numeric-literals%> för att aktivera fler inbyggda suffi
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "kan inte hitta en stränglitteraloperator %qD med argumenten %qT, %qT"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "en deklaration förväntades"
@@ -50890,12 +50970,12 @@ msgstr "deklaration av %<~%T%> som medlem av %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-namnet %qD använt som destruerardeklarerare"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD är inte en mall"
@@ -50930,7 +51010,7 @@ msgstr "variabelmall-id %qD  i nästad namnspecificerare"
 msgid "expected nested-name-specifier"
 msgstr "nästat namn-specificerare förväntades"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "typer får inte definieras i typkonverteringar"
@@ -50945,7 +51025,7 @@ msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
@@ -50960,7 +51040,7 @@ msgstr "ISO C++ förbjuder sammansatta litteraler"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "två på varandra följande %<[%> får bara introducera ett attribut"
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ogiltigt användning av %qD"
@@ -50985,912 +51065,918 @@ msgstr "ISO C++ tillåter inte %<alignof%> med annat än en typ"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "typer får inte definieras i %<noexcept%>-uttryck"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "typer får inte definieras i en %qs-uttryck"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+#| msgid "%<__builtin_thread_pointer%> is not supported on this target"
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "%<__builtin_thread_pointer%> stödjs inte på denna målarkitektur"
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer får inte definieras i en new-uttryck"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "vektorgräns är förbjuden efter typ-id i parenteser"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "försök ta bort parenteserna runt typ-id:t"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "initiering av new-uttryck för typen %<auto%> tar precis ett element"
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "uttryckslista eller typ-id förväntades"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "typer får inte definieras i en new-type-id"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "uttryck i new-deklarerare måste ha heltals- eller uppräkningstyp"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "användning av gammaldags typkonvertering till %q#T"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "operatorn %<>>%> hanteras som två högervinkelparenteser i C++11"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "föreslår parenteser runt %<>>%>-uttryck"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ tillåter inte %<?:%> med mellersta operanden utelämnad"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr "kommauttryck på toppnivå i vektorindex bör undvikas"
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "typer får inte definieras i %<__builtin_offsetof%>"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambdauttryck i oberäknade sammanhang är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambdauttryck i mallargument är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "icke-lokala lambda-uttryck kan inte ha en standardfångst"
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "slut på fångstlista förväntades"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %<this%> överflödigt med standardfall av fångst via kopiering"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "redan infångad %qD i lambdauttryck"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fångst av %<*this%> är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "det går inte att fånga %<this%> via referens"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "pack init-fångst är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr "%<&%> skall komma före %<...%>"
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambdafångstinitierare är endast tillgängliga med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "tom initierare för lambdas init-fångst"
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "fångst av en icke-variabel %qE"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D är deklarerad här"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "fångst av variabeln %qD med ej automatisk lagringsvaraktighet"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "för många %<...%> i lambdafångst"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %qD överflödigt vid standardfångst via kopiering"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "explicit fångst via referens av %qD överflödigt med standardfångst via referens"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambdamallar är endast tillgängliga med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambdamallar är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "standardargumentet angivet för lambdaparameter"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "dubblerad %<mutable%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<constexpr%> lambda är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attribut vid början av satser ignoreras"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "etikettsats förväntades"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-etikett %qE är inte i en switch-sats"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> behövs före %qE för att %qT är en beroende räckvidd"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> namnger konstrueraren, inte typen"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "sammansatt sats i en %<constexpr%>-funktion"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<if constexpr%> är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "init-satsen i valsatser är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr "villkor deklarerar en vektor"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "villkor deklarerar en funktion"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "typer får inte definieras i villkor"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initierare förväntades"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "intervallbaserat %<for%>-uttryck av typen %qT har ofullständig typ"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserat %<for%>-sats: %qT och %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "intervallbaserade %<for%>-slingor med initierare är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "intervallbaserad %<for%>-slinga är endast tillgänglig med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> i %<constexpr%>-funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "extra %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> som inte inleder ett block"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "icke-variabel %qD i deklaration med mer än en deklarerare med platshållartyp"
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "inkonsistent härledning för %qT: %qT och sedan %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "att blanda deklarationer och funktionsdefinitioner är förbjudet"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "typer får inte definieras i en for-range-deklaration"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initierare i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flera deklarationer i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "strukturerade bindningar är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "tom deklaration av strukturerad bindning"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ogiltig initierare för deklaration av strukturerad bindning"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> använd utanför en klass"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "nyckelordet %<bool%> är inte tillåtet i en C++20 konceptdefinition"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr "syntaxen för en C++20 konceptdefinition är %<concept <namn> = <uttr>%>"
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> ändrar betydelse i C++11; var god ta bort det"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%<decl-specifier%> är ogiltigt i ett villkor"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD är ogiltigt i lambda"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "typspecificerare är ogiltig i lambda"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "klassdefinition kan inte deklareras som en vän"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "typer får inte definieras i en explicit-specificerare"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<explicit(bool)%> är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ogiltig länkklasspecifikation"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%<static_assert%> utan ett meddelande är endast tillgänglig med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "typer får inte definieras i %<decltype%>-uttryck"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "typer får inte definieras i en conversion-type-id"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ogiltig användning av %<auto%> i konverteringsoperator"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "användning av %<auto%> i medlemsmallskonverteringsoperator kan aldrig vara härledd"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "endast konstruerare tar medlemsinitierare"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "det går inte att expandera initierare för medlem %qD"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anakronistisk gammaldags basklassinitierare"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (en kvalificerad medlemsinitierare är implicit en typ)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "oväntat nyckelord; ta bort mellanrum mellan citationstecken och suffixidentifierare"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "suffixidentifierare förväntades"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "en tom sträng förväntades efter nyckelordet %<operator%>"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ogiltigt kodningsprefix i litteral operator"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operator förväntades"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "nyckelordet %<export%> är inte implementerat och kommer ignoreras"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ogiltig begränsad typparameter"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-kvalificerad typparameter"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "felaktig användning av %<auto%> i standardmallargument"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "mallparameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "mallparameterpaket kan inte ha standardargument"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "mall-id förväntades"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kan inte inleda en argumentlista till en mall"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> är en alternativ stavning av %<[%>.  Lägg in mellanrum mellan %<<%> och %<::%>"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(om du använder %<-fpermissive%> eller %<-std=c++11%> eller %<-std=gnu++11%> kommer G++ acceptera din kod)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "felaktig mallargumentlista"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr "ett funktionsnamn som vänster operand av %<<%> är felformad i C++2a; slå in funktionsnamnet i %<()%>"
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "%<(%> förväntadess efter mallargumentlista"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "parsningsfel i mallargumentlista"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "mallnamn förväntades"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "icke-mall %qD använd som mall"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "använd %<%T::template %D%> för att indikera att det är en mall"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "parameterpaket förväntades före %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "mallargument förväntades"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ogiltigt mallargument som inte är en typ"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "en explicit instansiering skall inte använda %<inline%>-specificerare"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "en explicit instansiering skall inte använda %<constexpr%>-specificerare"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "en explicit instansiering skall inte använda %<consteval%>-specificerare"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "mallspecialisering med C-länkning"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "användning av %<auto%> i lambdaparameterdeklarationer är endast tillgängligt med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med %<-fconcepts-ts%>"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "mall-id för typ förväntades"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "typnamn förväntades"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE begränsar inte en typ"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr "konceptet är definierat här"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<auto%> eller %<decltype(auto)%> förväntades efter %qE"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr "oväntad platshållare i en begränsad resultattyp"
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "beräknad typspecifikation för en enum med räckvidd får inte använda nyckelordet %qD"
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%<template%> måste följa en nästad-namnspecificerare"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklaration %qD deklarerar inte något"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributet ignorerat på oinstansierad typ"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attribut ignoreras vid mallinstansiering"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attribut ignoreras för bearbetade typspecificerare som inte är en framåtdeklaration"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD är en uppräkningsmall"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD är inte namnet på en uppräkningstyp i %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "namnlös enum med räckvidd är inte tillåtet"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> eller %<{%> förväntades"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "det går inte att lägga till en uppräkningslista till en mallinstansiering"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "nästad namnspecificerare %qT för enum-deklaration som inte namnger en klass eller namnrymd"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "deklaration av %qD i namnrymd %qD som inte innesluter %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "deklaration av %qD i %qD som inte innesluter %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "extra kvalifikation inte tillåten"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ förbjuder tomma namnlösa enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "ogenomskinlig enum-specifikation utan namn"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "en ogenomskinlig enum-specifikation måste använda en enkel identifierare"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD är inte ett namnrymdsnamn; menade du %qs?"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD är inte ett namnrymdsnamn"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "namnrymdsnamn förväntades"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "nästade inline-namnrymdsdefinitioner är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr "standardattribut på namnrymder måste föregå namnrymdsnamnet"
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "nästade namnrymdsdefinitioner är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nästat namnrymdsnamn krävs"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "namnrymdsnamn krävs"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "en nästad namnrymdsdefinition kan inte ha attribut"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "en nästad namnrymdsdefinition kan inte inline:as"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "gick in i namnrymden %qD"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-definition är inte tillåten här"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "paketexpansion i using-deklaration är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ett mall-id får inte förekomma i en using-deklaration"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "en kommaseparerad lista i using-deklaration är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "åtkomstdeklarationer bör undvikas till förmån för using-deklarationer; förslag: lägg till nyckelordet %<using%>"
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "typer får inte definieras i aliasmalldeklarationer"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<asm%> i en %<constexpr%>-funktion är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "dubblerad %<asm%>-kvalificerare %qT"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%<asm%>-kvalificeraren %qT ignoreras utanför en funktionskropp"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT är inte en %<asm%>-kvalificerare"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%<asm%>-kvalificerare utanför funktionskropp"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition är inte tillåten här"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "en %<asm%>-specifikation är inte tillåten på en funktionsdefinition"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attribut är inte tillåtna vid en funktionsdefinition"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "konstruerare, destruerare eller typkonvertering förväntades"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initierare angiven för funktion"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attribut efter initierare inom parentes ignoreras"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "icke-funktionen %qD deklarerad som implicit mall"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "vektorgräns är inte en heltalskonstant"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "det går inte att definiera medlem av beroende typedef %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> är inte en typ"
@@ -51899,430 +51985,430 @@ msgstr "%<%T::%E%> är inte en typ"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ogiltig deklarator"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ogiltig användning av konstruerare som en mall"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "använd %<%T::%D%> istället för %<%T::%D%> för att namnge konstrueraren i ett kvalificerat namn"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "kvalificerad id i deklaration"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "deklarator förväntades"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD är en namnrymd"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "kan inte skapa en pekare till medlem av %q#T som inte är en klass"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "oväntad pekaroperator"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "upprepade cv-kvalificerare"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "upprepade ref-kvalificerare"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE kräver %<-fgnu-tm%>"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "upprepade virt-specificerare"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "mallargument saknas efter %qT"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ogiltigt användning av %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "typer får inte definieras i mallargument"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "felaktig användning av %<auto%> i mallargument"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> eller %<...%> förväntades"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "typer får inte definieras i parametertyper"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardargument är endast tillåtna för funktionsparametrar"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "mallparameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "funktions-try-blockskropp av %<constexpr%>-konstruerare är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "funktions-try-blockskropp av %<constexpr%>-funktioner är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++ designerade initierare är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillåter inte GNUs designerade initierare"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillåter inte C99:s designerade initierare"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "antingen skall alla initierarklausuler vara designerade eller så skall ingen av dem vara det"
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> är inte tillåtet i en designerad initierarlista"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "designeraren %<.%s%> använd flera gånger i samma intierarlista"
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "klassnamn förväntades"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> förväntades efter klassdefinition"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> förväntades efter postdefinition"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> förväntades efter uniondefinition"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> eller %<:%> förväntades"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "det går inte att ange %<override%> för en klass"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globala kvalificering av klassnamn är ogiltigt"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "kvalificerat namn namnger inte en klass"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "nyckelordet %<template%> är inte tillåtet i klasshuvudnamn"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ogiltigt klassnamn i deklaration av %qD"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "en explicit specialisering måste föregås av %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktionsmall %qD omdeklarerad som en klassmall"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "det gick inte att lösa upp typnamnstyp"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "föregående definition av %q#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ISO C++ förbjuder nyckelordet typename i mall-mall-parameter; använd %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> eller %<typename%> förväntades"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "i C++03 måste en klassnyckel användas när en vän deklareras"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "vändeklaration som inte namnger en klass eller funktion"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "en lagringklass på ett anonymt aggregat i klassräckvidd tillåts inte"
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "standardmedlemsinitierare för bitfält är endast tillgängliga med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "standardmedlemsinitierare för namnlöst bitfält"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ tillåter endast bitfältsattribut före symbolen %<:%>"
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bitfältet %qD har icke-heltalstypen %qT"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-specificerare på funktionsdefinition"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "extra %<;%> efter funktionsdefinition i klassen"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "överblivet %<,%> vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> förväntades vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ogiltig pure-specificerare (endast %<= 0%> är tillåtet)"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "en klammeromsluten initierare är inte tillåten här"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> anges mer än en gång i basspecificerare"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mer än en åtkomstspecifikation i basspecificerare"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "nyckelordet %<typename%> är inte tillåtet utanför mallar"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (basklassen är implicit en typ)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "typer får inte definieras i en undantagsspecifikation"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 tillåter inte dynamiska undantagsspecifikationer"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamiska undantagsspecifikationer undanbedes i C++11"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ogiltig användning av %<auto%> i undantagsspecifikation"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<try%> i %<constexpr%>-funktioner är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "typer får inte definieras i undantagsdeklarationer"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "attribut som använder prefix använt tillsammans med attributsymboler med räckvidd"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "en identifierare förväntades som attributnamn"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr "parenteser måste utelämnas om %qE-attributargumentlistan är tom"
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "attributet %<noreturn%> får förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr "attributet %<nodiscard%> kan förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut förväntades före %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribut som använder prefix är endast tillgängligt med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "uttrycket måste vara inneslutet i parenteser"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "ytterligare %<requires%> saknas för att inleda ett requires-uttryck"
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "resultattypen är inte en enkel typbegränsning"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "returtybskravet är inte en typbegränsning"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -52331,544 +52417,544 @@ msgstr "för få mallparameterlistor"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ antog inte mallar för strängliteralsoperatorer som tar argumentpaket av tecken"
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista; ett mallargument som inte är en typ pack %<<char...>%> eller en ensam icke-typparameter av klasstyp förväntades"
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista; en mallparameter som inte är en typ pack %<<char...>%> förväntades"
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr "mallintroduktioner är inte en del av C++20 koncept [-fconcepts-ts]"
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "det finns inget matchande koncept för mallintroduktionen"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "en klassmallsdeklaration får inte deklarera något annat"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> förväntades"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> förväntades"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> förväntades"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> förväntades"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "överflödig enum-nyckel %<enum%s%> i referens till %q#T"
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "överflödig klassnyckel %qs i referens till %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT är deklarerad med en klassnyckel som inte stämmer %qs"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "ta bort klassnyckeln eller ersätt den med %qs"
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "ersätt klassnyckeln med %qs"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT är definierad som %qs här"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT är först deklarerad som %qs här"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-väljarnamn"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltig typ på egenskap"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "heltalsuttryckslista förväntades"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "typer får inte definieras i iteratortyp"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "en %<ordered%>-klausul med parameter på en intervallbaserat %<for%>-slinga"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "inte tillräckligt med for-slingor att kollapsa"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> följt av %<#pragma omp declare %s%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<const%>-, %<volatile%>- eller %<__restrict%>-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> namnger en mängd överlagrade"
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD refererar inte till en funktion med namnrymdsräckvidd"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "skräp vid slutet av %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<pragma omp requires%> kan endast användas med fil- eller namnrymdsräckvidd"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> måste vara inuti en funktion"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> måste vara inuti en funktion"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "intermoduloptimeringar inte implementerade för C++"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "en platshållartyp är inte tillåtet i denna kontext"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-länkning startade här"
@@ -53139,7 +53225,7 @@ msgstr "expansionsmönster %qE innehåller inga parameterpaket"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameterpaket expanderas inte med %<...%>:"
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -53164,84 +53250,84 @@ msgstr "deklaration av %q+#D skuggar en mallparameter"
 msgid "template parameter %qD declared here"
 msgstr "mallparametern %qD deklarerad här"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "specialisering av variabelkonceptet %q#D"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "mallparameter är inte härledbara i partiell specialisering:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument och är inte mer begränsad än den primära mallen; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "huvudmall här"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partiell specialisering är inte mer specialiserad än huvudmallen eftersom den ersätter flera parametrar med en paketexpansion"
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "för många argument till en partiell specialisering %qT"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partiell specialisering %qD är inte mer specialiserad än"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "huvudmallen %qD"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameterpaketargument %qE måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameterpaketargument %qT måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "mallargument %qE berör mallparametrar"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "typ %qT för mallargument %qE beror på en mallparameter"
 msgstr[1] "typ %qT för mallargument %qE beror på mallparametrar"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "deklaration av %qD gör tidigare mallinstansiering av %qD tvetydig"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "partiell specialisering %qD efter instansiering av %qD"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "inget standardargument för %qD"
@@ -53249,47 +53335,47 @@ msgstr "inget standardargument för %qD"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameterpaket %q+D måste vara vid slutet av mallens parameterlista"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardmallargument får inte användas i vänomdeklaration av funktionsmall"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardmallargument får inte användas i vändeklarerade mallar"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standarmallargument får inte användas i funktionsmallar utan %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "standardmallargument får inte användas i partiella specialiseringar"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardargumentet för mallparameter för klass om omsluter %qD"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "mallen %qD deklarerad"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "mallklass utan ett namn"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
@@ -53299,493 +53385,493 @@ msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ogiltig malldeklaration av %qD"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malldefinition av icke-mall %q#D"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d nivåer av mallparametrar förväntades till %q#D, %d fanns"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "fick %d mallparametrar till %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "fick %d mallparametrar till %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d behövs"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "mallargument till %qD stämmer inte med originalmallen %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "använd %<template<>%> för en explicit specialisering"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT är inte en malltyp"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "mallspecificerare inte angivna i deklarationen av %qD"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "omdeklarerad med %d mallparameter"
 msgstr[1] "omdeklarerad med %d mallparametrar"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "tidigare deklaration av %qD använde %d mallparameter"
 msgstr[1] "tidigare deklaration av %qD använde %d mallparametrar"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "mallparameter %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "omdeklarerad här som %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "deklaration av mallparametern %q+#D med andra begränsningar"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprunglig deklaration fanns här"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinition av standardargument till %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprunglig definition fanns här"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "omdeklaration av %q#D med andra begränsningar"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "det måste vara adressen till en funktion med extern lagringsklass"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "det måste vara namnet på en funktion med extern lagringsklass"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "det måste vara en pekare-till-medlem på formen %<&X::Y%>"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "för att den är en medlem av %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  kunde inte härleda mallparametrar %qD"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  typerna %qT och %qT har inkompatibla cv-kvalificerare"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  typerna %qT och %qT stämmer inte överens"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  mallparameter %qD är inte ett parameterpaket, men argument %qD är det"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  mallargument %qE stämmer inte med pekare till medlem-konstanten %qE"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE är inte ekvivalent med %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  inkonsistent härledning av parameterpaket med %qT och %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  härledda typer i konflikt för parametern %qT (T%qT och %qT)"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  härledda värden i konflikt för icke-typ-parametern %qE (%qE och %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  medlemsfunktionstypen %qT är inte ett giltigt mallargument"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  kan inte konvertera %qE (typen %qT) till typ %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT är en tvetydig basklass till %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT är inte härledd från %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  mallparametrarna till ett mallmallargument är inkonsistenta med andra härledda mallargument"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  det går inte att härleda en mall för %qT från typen %qT som inte är en mall"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  mallargument %qE stämmer inte med %qE"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qE inte är en variabel"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT i C++98 eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "adressen till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "adressen till underobjektet %qT till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "adressen till %qD är inte ett giltigt mallargument eftersom den inte har statisk lagringsvaraktighet"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD är inte ett giltigt mallargument för att %qD är en variabel, inte adressen till en variabel"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE är inte ett giltigt mallargument till %qT för det är inte adressen till en variabel"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom strängkonstanter aldrig kan användas i detta sammanhang"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "i mallargument för typen %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "mallargumentet %qE för typen %qT är inte ett konstant heltal"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ignorerar attribut i mallargumentet %qE"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  tvetydigt mallargument till en mallparameter som inte är en typ hanteras som en funktionstyp"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "begränsningar stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD förväntades men fick %qD"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunde inte konvertera mallargument %qE från %qT till %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "angivna till %qD"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till konceptet %qD"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "mallbegränsningsfel för %qD"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "användning av felaktig variabelmall %qE"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibel vektormedlem %qD i union"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "fold över tom expansion över %O"
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE är inte hela mönstret av paketexpansionen"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qT"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qE"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  vid instansiering av standardargument för anrop av %qD"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
@@ -53803,291 +53889,291 @@ msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD instansieras för ett tomt paket"
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "initierare för %q#D expanderar till en tom uttryckslista"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%>  för att expandera argumentpaket"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "fel antal argument till %<__builtin_convertvector%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansiering av icke-mall %q#D"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "explicit instansiering av variabelkonceptet %q#D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "explicit instansiering av funktionskonceptet %q#D"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "explicit specifikation av %qD beror på sig själv"
@@ -54099,132 +54185,132 @@ msgstr "explicit specifikation av %qD beror på sig själv"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mallparameter av härledd klasstyp som inte är en typ är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mallparameter av klasstyp som inte är en typ är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT är inte en giltig typ för en mallparameter som inte är en typ eftersom det inte är en struktur"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "nyckelordet %<template%> är inte tillåtet i deklarerar-id"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ett koncept kan inte begränsas"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "konceptet %qE är inte i namnrymdsräckvidd"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "härledning från klammeromgiven initierarlista kräver %<#include <initializer_list>%>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "icke härledbar mall %qT använd utan mallargument"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "aliasmallhärledning är endast tillgängligt med %<-std=c++2a%> eller %<-std=gnu++2a%>"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "kan inte härleda mallargument till %qT, eftersom den inte några användbara härledningsguider"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "felaktig användning av %qT i mallargument"
@@ -54429,7 +54515,7 @@ msgstr "ogiltigt användning av %<this%> på toppnivå"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ogiltigt kvalificerande räckvidd i pseudodestruerarnamn"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "kvalificerad typ %qT matchar inte destruerarnamnet ~%qT"
@@ -54479,7 +54565,7 @@ msgstr "ogiltig basklasspecifikation"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
@@ -54578,7 +54664,7 @@ msgstr "%<offsetof%> inom icke-standardlayouttypen %qT är villkorligt stött"
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> tillåtet i OpenMP endast i %<declare simd%>-klausuler"
@@ -54618,7 +54704,7 @@ msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
@@ -54743,117 +54829,117 @@ msgstr "%qD förekommer mer än en gång i %<nontemporal%>-klausuler"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD är inte ett l-värdeuttryck eller vektorsektion i en %<depend%>-klausul"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "mallen %qE i-klausulen %qs"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "överlagrad funktion med namnet %qE i klausulen %qs"
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<hint%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%<hint%>-uttryck måste vara ett konstant heltalsuttryck"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "variabeln %qs är varken en pekare eller en referens till en pekare"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs-variabeln är varken en pekare, eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%>-argumentet behöver en heltalstyp"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-kvalificerad %qE utan en %<mutable%>-medlem kan endast förekomma i klausuler %<shared%> eller %<firstprivate%>"
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använd med klassiterationsvariabeln %qE"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statisk försäkran misslyckades: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "argument till %<decltype%> måste vara ett uttryck"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> kan inte lösa upp adressen till en överlagrad funktion"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
@@ -55093,797 +55179,797 @@ msgstr "konvertering mellan olika pekare-på-medlem-typer %qT och %qT saknar en
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "villkorsuttryck mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "kanoniska typer skiljer för identiska typer %qT och %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "samma kanoniska typnod för olika typer %qT och %qT"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ogiltig användning av %qs på en medlemsfunktion"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ogiltig användning av %<sizeof%> på ett bitfält"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<sizeof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ogiltig användning av %<__alignof%> på ett bitfält"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<__alignof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "argumentet till %<alignas%> har typen %qT som inte är en heltalstyp"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion av typen %qT"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "tar adress till temporär vektor"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ förbjuder konvertering av en strängkonstant till %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konvertering från strängkonstant till %qT bör undvikas"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "begäran av medlem %qD i %qE, som är av pekartypen %qT (kanske du hade tänkt använda %<->%> ?)"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "begäran av medlem %qD i %qE, som är av icke-klasstyp %qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ogiltig användning av icke-statisk datamedlem %qE"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ogiltig åtkomst av icke-statisk datamedlem %qD i virtuell bas till NULL-objekt"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objekttyp %qT stämmer inte med destruerarnamnet ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "typen som destrueras är %qT, men destrueraren refererar till %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "fältet %q#D kan kommas åt via %q#D"
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T har ingen medlem med namnet %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %q#D? (åtkomligt via %q#D)"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %q#D? (inte åtkomlig från detta sammanhang)"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %qE?"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> är inte en medlem av %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT är inte en basklass till %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD är inte en medlemsmallfunktion"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT är inte en pekare-på-objekt-typ"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ogiltig användning av vektorindexering på pekare till medlem"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ogiltig användning av unärt %<*%> på pekare till medlem"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ogiltig användning av implicit konvertering av pekare till medlem"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "vänstra operanden till %<->*%> måste vara en pekare på en klass, men är en pekare på en medlem av typen %qT"
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "index saknas i vektorreferens"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "indexering av vektor deklarerad %<register%>"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objekt saknas i användning av %qE"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ förbjuder anrop av %<::main%> inifrån program"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "man måste använda %<.*%> eller %<->*%> för att anropa en pekare-till-medlems-funktion i %<%E (...)%>, t.ex. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kan inte användas som en funktion"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kan inte användas som en funktion"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "uttryck kan inte användas som en funktion"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "för många argument till konstrueraren %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "för få argument till konstrueraren %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "för många argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "för få argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "för många argument till funktionen %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "för få argument till funktionen %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "för många argument till metoden %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "för få argument till metoden %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "för många argument till funktion"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "för få argument till funktion"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P till %qD har ofullständig typ %qT"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametern %P har ofullständig typ %qT"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen till %qD kommer aldrig vara NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kompilatorn kan anta att adressen till %qD aldrig kommer att vara NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antar typkonvertering till %qT från överlagrad funktion"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL använd i aritmetik"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ förbjuder jämförelse mellan pekare och heltal"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operandtyper är %qT och %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "trevägsjämförelse av vektorer"
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "oordnad jämförelse av argument som inte är flyttal"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implicit konvertering från %qH till %qI för att matcha den andra operanden i binärt uttryck"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ogiltiga operander av typ %qT och %qT till binär %qO"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare av typ %<void *%> i subtraktion"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en funktion i subtraktion"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en metod i subtraktion"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ogiltig användning av en pekare till en ofullständig typ i pekararitmetik"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "tar adressen till konstrueraren %qD"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "tar adressen till destrueraren %qD"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ogiltig användning av %qE för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  ett kvalificerat id krävs"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parenteser runt %qE kan inte användas för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en okvalificerad eller parentetiserad icke-statisk medlemsfunktion för att skapa en pekare till en medlemsfunktion.  Säg %<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en bunden medlemsfunktion för att skapa en pekare till medlemsfunktion.  Säg %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "tar adress till ett r-värde"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ förbjuder att ta adressen till funktionen %<::main%>"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan inte skapa pekare till referensmedlem %qD"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "försök att ta adressen till bitfält"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "tar adressen till en omedelbar funktion %qD"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> på ett uttryck av typen %<bool%>"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "tänkte du använda logiskt icke (%<!%>)?"
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ förbjuder ökning av enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ förbjuder minskning av enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "det går inte att öka en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "det går inte att minska en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder ökning av pekare på typ %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder minskning av pekare på typ %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "%qs-uttryck av en %<volatile%>-kvalificerad typ bör undvikas"
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "användning av en operand av typen %qT i %<operator--%> är förbjudet"
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "användning av en operand av typen %qT i %<operator++%> är förbjudet i C++17"
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "användning av en operand av typen %qT i %<operator++%> bör undvikas"
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan inte ta adressen till %<this%>, som är ett rvalue-uttryck"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adress till explicit registervariabel %qD begärd"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adress begärd till %qD, som är deklarerad %<register%>"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "listinitierare för en typ som inte är en klass får inte vara inom parenteser"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i initierare"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i medlemsinitierare"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "uttryckslista behandlas som sammansatt uttryck i funktionstypkonvertering"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "uttryckslistan %s behandlas som sammansatt uttryck"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "ingen kontext för att lösa upp typen på %qE"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "konvertering från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "oanvändbar konvertering till typen %q#T"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "typkvalificerare ignoreras för typkonverterings resultattyp"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ogiltig %<static_cast%> från typ %qT till typ %qT"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "returtypen %qT är ofullständig"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 msgid "converting from %qH to %qI"
 msgstr "konvertering från %qH till %qI"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ogiltig typkonvertering av ett rvärdeuttryck av typ %qT till typ %qT"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr "konvertering från %qH till %qI förlorar precision"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "konvertering mellan inkompatibla funktionstyper från %qH till %qI"
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "typkonvertering mellan inkompatibla pekare till medlemstyper från %qH till %qI"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typkonvertering från %qH till %qI ökar kravet på justering för måltypen"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "typkonvertering mellan pekare-till-funktion och pekare-till-objekt stödjs villkorligt"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ogiltig konvertering från typ %qT till typ %qT"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ogiltig användning av %<const_cast%> med typ %qT, som inte är en pekare, referens, eller pekare-till-datamedlem-typ"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ogiltig användning av %<const_cast%> med typ %qT, som är en pekare eller referens till en funktionstyp"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ogiltig %<const_cast%> av ett rvärde av typ %qT till typ %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ogiltig %<const_cast%> från typ %qT till typ %qT"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ förbjuder typkonvertering till en vektortyp %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ogiltig konvertering till funktionstyp %qT"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr "sammansatt tilldelning med %<volatile%>-kvalificerad vänsteroperand bör undvikas"
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i beräkningen av %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "tilldelning till en vektor från en initierarlista"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "inkompatibla typer i tilldelning av %qT till %qT"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "vektor använd som initierare"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ogiltig vektortilldelning"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i konvertering av pekare till medlemsfunktion"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "konvertering av pekare till medlem via virtuell bas %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i konvertering av pekare till medlem"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ogiltig konvertering till typ %qT från typ %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "det går inte att konvertera %qH till %qI i standardargument"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "det går inte att konvertera %qH till %qI när argument skickas"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "det går inte att konvertera %qH till %qI i initiering"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr "det går inte att konvertera %qH till %qI i retur"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "det går inte att konvertera %qH till %qI i tilldelning"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "parameter %qP till %qD kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "parameter kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "målet för konvertering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "målet för initialisering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "när argument %P till %qD skickades"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerar referens till en temporär"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "att returnera en temporär %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "referens till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "att returnera en lokal %<initializer_list%>-variabel %qD utökar inte livslängden på den underliggande vektorn"
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adressen till etiketten %qD returnerad"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adress till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "att flytta ett lokalt objekt i en retursats förhindrar att kopiering undviks."
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "ta bort anrop av %<std::move%>"
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "redundant förflyttning i retursats"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerar ett värde från en destruerare"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "det går inte att returnerar från en hanterare i ett funktions-try-block eller en konstruerare"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerar ett värde från en konstruerare"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-sats utan värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "returnerar en initierarlista"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "inkonsistenta typer %qT och %qT härledda för lambda-returtypen"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "inkonsistent härledning för auto-returtyp: %qT och sedan %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-sats med ett värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> får inte returnera NULL om den inte är deklarerad %<throw()%> (eller %<-fcheck-new%> är aktivt)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "använder r-värde som l-värde"
@@ -56142,107 +56228,107 @@ msgstr "ta bort %<{ }%> runt initierare"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt litteral"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "ordningen på designeraren för fält %qD stämmer inte med deklarationsordningen i %qT"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde före C++2a"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "kan inte härleda mallargument för %qT från %<()%>"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -56466,10 +56552,10 @@ msgstr "Vektorreferens vid %C har mer än 7 dimensioner"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "Vektorreferens vid %C kan inte ha mer än %d dimensioner"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -56636,7 +56722,7 @@ msgstr "[...]-stils vektorkonstruerare vid %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Vektorkonstruerare med typspecifikation vid %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Typspecifikation vid %L kan inte innehålla ha en fördröjd typparameter"
@@ -56753,7 +56839,7 @@ msgstr "BOZ-litteralkonstanten vid %L kan inte vara ett aktuellt argument till %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argument till %qs vid %L och %L kan inte båda vara litterala BOZ-konstanter"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Felaktig användning av en BOZ-litteralkonstant vid %L"
@@ -56793,7 +56879,7 @@ msgstr "Fortran 2003: Tecken som argument %qs till inbyggd %qs vid %L"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "Argument %qs till inbyggd %qs vid %L måste vara INTEGER eller REAL eller CHARACTER"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha en inbyggd typ"
@@ -56808,7 +56894,7 @@ msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara REAL eller COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER eller PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en konstant"
@@ -56928,167 +57014,168 @@ msgstr "Olika teckenlängder (%ld/%ld) i %s vid %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "%qs- och %qs-argumenten till inbyggd %qs vid %L måste ha samma typ"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "Olika typsorter vid %L"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "NULL-pekare vid %L är inte tillåtet som aktuellt argument till inbyggd funktion %qs"
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara POINTER"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "argumentet %qs till inbyggd %qs vid %L skall inte vara co-indexerat"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en pekare eller mål-VARIABLE eller -FUNCTION"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en POINTER eller en TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "Vektorsektion med ett vektorindex vid %L skall inte vara målet för en pekare"
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "NULL-pekare vid %L är inte tillåtet som aktuellt argument till inbyggd funktion %qs"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "argumentet ATOM vid %L till inbyggd funktion %s skall vara ett heltal av sorten ATOMIC_INT_KIND eller en logisk av sorten ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "ATOM-argumentet vid %L till den inbyggda funktionen %s måste vara en co-vektor eller co-indexerat"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha samma typ som %qs vid %L"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "STAT=-argument till %s vid %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "ATOM-argumentet till den inbyggda funktionen %s vid %L måste vara definierbart"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "argumentet ATOM vid %L till inbyggd funktion %s skall vara ett heltal av sorten ATOMIC_INT_KIND"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "VALUE-argumentet till den inbyggda funktionen %s vid %L måste vara definierbart"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "%qs-argumentet till inbyggd %qs vid %L stödjs inte ännu"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "%qs-argumentet till inbyggd %qs vid %L skall ange en giltig heltalssort"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "OLD-argumentet till den inbyggda funktionen %s vid %L måste vara definierbart"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "EVENT-argumentet vid %L till den inbyggda EVENT_QUERY skall ha typen EVENT_TYPE"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "COUNT-argumentet till den inbyggda funktionen EVENT_QUERY vid %L måste vara definierbart"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "COUNT-argumentet till den inbyggda funktionen EVENT_QUERY vid %L måste ha åtminstone intervallet för standardheltal"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Negativt argument N vid %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste får inte finnas om %<x%> är COMPLEX"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha typen REAL eller INTEGER"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr "Konvertering från %s till standardsorten COMPLEX(%d) vid %L kan tappa precision, överväg att använda argumentet KIND"
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr "Argumentet %<A%> med INTENT(INOUT) vid %L till den inbyggda subrutinen %s skall inte ha ett vektorindex"
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "Argumentet A vid %L till den inbyggda %s skall inte vara co-indexerat"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "stat=-argumentet vid %L måste vara en heltalsvariabel av kind=4"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "errmsg=-argumentet vid %L måste vara en teckenvariabel av standardsort"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "Co-vektorer avaktiverade vid %L, använd %<-fcoarray=%> för att aktivera"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr "Stöd för argumentet A vid %L som är ett polymorft argument A eller har allokerbara komponenter är inte implementerat ännu"
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "A-argumentet vid %L till CO_REDUCE får inte vara polymorft"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr "Stöd för argumentet A vid %L med allokerbara komponenter är inte implementerat ännu"
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "OPERATOR-argumentet till vid %L måste vara en PURE-funktion"
@@ -57096,697 +57183,697 @@ msgstr "OPERATOR-argumentet till vid %L måste vara en PURE-funktion"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Inbyggd funktion %s vid %L är inte tillåten för CO_REDUCE"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr "Funktionen som skickas som OPERATOR vid %L skall ha två argument"
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr "Argument A vid %L har typen %s men funktionen som skickas som OPERATOR vid %L returnerar %s"
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr "Funktionen som skickas som OPERATOR vid %L har argument av typerna %s och %s men skall ha typen %s"
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr "Funktionen som skickas som OPERATOR vid %L skall ha skalära argument som ej är allokerbara och ej är pekare och returnera en skalär som ej är allokerbar och ej är en pekare"
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr "Funktionen som skickas som OPERATOR vid %L skall ha attributet VALUE antingen för inget eller båda argumenten"
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr "Funktionen som skickas som OPERATOR vid %L skall ha attributet TARGET antingen för inget eller båda argumenten"
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr "Funktionen som skickas som OPERATOR vid %L skall ha attributet ASYNCHRONOUS antingen för inget eller båda argumenten"
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr "Funktionen som skickas som OPERATOR vid %L skall ha attributet OPTIONAL antingen för inget eller båda argumenten"
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr "Teckenlängden för argumentet A vid %L och argumenten till OPERATOR vid %L skall vara samma"
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr "Teckenlängden för argumentet A vid %L och funktionsresultatet av OPERATOR vid %L skall vara samma"
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "Argument %qs till inbyggd %qs vid %L skall ha typen heltal, reell eller tecken"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "inbyggd %qs med KIND-argument vid %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har ogiltig form i dimensions %d (%ld/%ld)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha ordning %d eller vara en skalär"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara numeriskt eller LOGICAL"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "Olika former för argument %qs och %qs vid %L för inbyggd %<dot_product%>"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara standard reell"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "argument %qs måste ha samma typ och sort som %qs vid %L i %qs"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "Argumentet %qs saknas till inbyggd %qs vid %L för %qs av typen %qs"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "INTEGER-sorts argument som inte är standardargument till inbyggd %s vid %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "COMPLEX-argumentet %qs till inbyggd %qs vid %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "Argument till %qs har olika sorts typeparametrar vid %L"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Argument till ”%s” vid %L måste ha längden ett"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha samma sort som %qs"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr "det inbyggda underprogrammet %qs vid %L bör undvikas.  Använd det inbyggda underprogrammet INT."
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "SIZE vid %L måste vara positivt"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "Absolutvärdet av SHIFT vid %L måste vara mindre än eller lika med SIZE vid %L"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "STATUS vid %L måste vara en INTENT(OUT)-variabel"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "%qs vid %L måste vara en INTENT(OUT)-variabel"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en dataentitet"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "Inbyggd %qs vid %L måste ha åtminstone två argument"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "Saknat argument %qs till inbyggd %s vid %L"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "Dubblerat argument %qs vid %L till inbyggd %s"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "Okänt argument %qs vid %L till inbyggd %s"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "%<a%d%>-argumentet till inbyggd %qs vid %L måste vara %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "inbyggd %qs med CHARACTER-argument vid %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "%<a1%>-argumentet till inbyggd %qs vid %L måste vara INTEGER, REAL eller CHARACTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "Argumenttyper till inbyggd %qs vid %L måste stämma överens (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "Olika form på dimension 1 för argumenten %qs och %qs vid %L för inbyggd matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "Olika form på dimension 2 för argument %qs och dimension 1 för argument %qs vid %L för inbyggd matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha ordning 1 eller 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "Argumentet %qs till inbyggd %qs vid %L måste vara typkonformt med argument %qs vid %L"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Argumentet FROM till MOVE_ALLOC %L skall inte vara co-indexerat"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "Argumentet TO till MOVE_ALLOC %L skall inte vara co-indexerat"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "Argumentet TO i MOVE_ALLOC vid %L måste vara polymorft om FROM är polymorft"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "Argumenten FROM och TO till den inbyggda MOVE_ALLOC vid %L måste ha samma ordning %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "Argumenten FROM och TO till den inbyggda MOVE_ALLOC vid %L måste ha samma co-ordning %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr "Argumenten FROM och TO vid %L bryter aliasrestriktioner (F2003 12.4.1.7)"
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "Argument %<S%> till NEAREST vid %L får inte vara noll"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "Argument %qs till inbyggd %qs vid %L måste vara en POINTER, ALLOCATABLE eller procedurpekare"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Inbyggd NULL med allokerbar MOLD vid %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ge åtminstone lika många element som det finns .TRUE.-värden i %qs (%ld/%d)"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en attrappvariabel"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en OPTIONAL attrappvariabel"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "%qs-argumentet till inbyggd %qs vid %L får inte vara ett underobjekt till %qs"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Argumentet till inbyggd RANK vid %L måste vara ett dataobjekt"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "%<shape%>-argumentet till inbyggd %<reshape%> vid %L måste vara en vektor av konstant storlek"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "%qs-argumentet till inbyggd %qs vid %L är tomt"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "%<shape%>-argumentet till inbyggd %<reshape%> vid %L har mer än %d element"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har negativa element (%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Elementet %d av aktuellt argument till RESHAPE vid %L får inte vara negativt"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har fel antal element (%d/%d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har dimension utanför giltigt intervall (%d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har en ogiltig permutation av dimensioner (dimension %qd dubblerad)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Utan utfyllnad finns det inte tillräckligt med element i inbyggda RESHAPE-källan vid %L för att stämma med formen"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "Argumentet %qs till inbyggd %qs vid %L kan inte ha typen %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en utvidgningsbar typ"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND med varken %<P%>- eller %<R%>-argument vid %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "inbyggd %qs med RADIX-argument vid %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%<source%>-argumentet till inbyggd %<shape%> vid %L får inte vara en vektor med antagen storlek"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Argument %qs till inbyggd %qs vid %L får inte vara en procedur"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Argumentet %qs till inbyggd %qs vid %L skall inte vara TYPE(*)"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "Argumentet %qs till inbyggd %qs vid %L får inte vara en vektor med antagen storlek"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr misslyckades"
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "Argumentet %qs till inbyggd %qs vid %L måste vara en interoperabel dataenhet: %s"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "Argumentet C_PTR_1 vid %L till C_ASSOCIATED skall ha typen TYPE(C_PTR) eller TYPE(C_FUNPTR)"
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "Argumentet C_PTR_2 vid %L till C_ASSOCIATED skall ha samma typ som C_PTR_1: %s istället för %s"
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "Argumentet CPTR vid %L till C_F_POINTER skall ha typen TYPE(C_PTR)"
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Argumentet FPTR vid %L till C_F_POINTER måste vara en pekare"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "Argumentet FPTR vid %L till C_F_POINTER får inte vara polymorft"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "Argumentet FPTR vid %L till C_F_POINTER skall inte vara co-indexerat"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Oväntat SHAPE-argumentet vid %L till C_F_POINTER med skalär FPTR"
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "SHAPE-argument förväntades till C_F_POINTER med vektor FPTR vid %L"
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "SHAPE-argumentet vid %L till C_F_POINTER måste ha samma storlek som FPTR:s RANK"
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "Polymorf FPTR vid %L till C_F_POINTER"
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Ej interoperabel vektor-FPTR vid %L till C_F_POINTER: %s"
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "Argumentet CPTR vid %L till C_F_PROCPOINTER skall ha typen TYPE(C_FUNPTR)"
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "Argumentet FPTR vid %L till C_F_PROCPOINTER skall vara en procedurpekare"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "Argumentet FPTR vid %L till C_F_PROCPOINTER får inte vara co-indexerat"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Ej interoperabel procedurpekare vid %L till C_F_PROCPOINTER"
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "Argumentet X vid %L till C_FUNLOC får inte vara co-indexerat"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Funktionsresultatet %qs vid %L är ogiltigt som X-argument till C_FUNLOC"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "Argumentet X vid %L till C_FUNLOC skall vara en procedur eller en procedurpekare"
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Ej interoperabel procedur vid %L till C_FUNLOC"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "Argumentet X vid %L till C_LOC får inte vara co-indexerat"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "X-argumentet vid %L till C_LOC får inte vara polymorft"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Argumentet X vid %L till C_LOC skall antingen ha attributet POINTER eller TARGET"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "Argumentet X vid %L till C_LOC får inte vara en sträng med längden noll"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Argumentet vid %L till C_LOC får inte vara polymorft"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Ej interoperabel vektor vid %L som argument till C_LOC: %s"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Vektor med interoperabla typer vid %L till C_LOC som inte är allokerbar och varken antagen storlek eller explicit storlek"
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Vektorsektion vid %L till C_LOC"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "REAL-argument utan dubbel precision till inbyggd %s vid %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara av lägre ordning än %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "%qs-argumentet till inbyggd %qs vid %L är inte ett giltigt dimensionsindex"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "%s-argument till IMAGE_INDEX skall vara en vektor av ordning ett vid %L"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Antalet vektorelement i argumentet SUB till IMAGE_INDEX vid %L skall vara %d (co-ordning) inte %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "DISTANCE= argument till NUM_IMAGES vid %L"
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "FAILED=-argument till NUM_IMAGES vid %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "Argumentet TEAM vid %L till den inbyggda TEAM_NUMBER skall ha typen TEAM_TYPE"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM-argument utan COARRAY-argument är inte tillåtet för inbyggd THIS_IMAGE vid %L"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "Argumentet DISTANCE får inte anges tillsammans med argumentet COARRAY eller DIM i den inbyggda vid %L"
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Oväntat DIM-argument med icke-co-vektor-argument vid %L"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "DISTANCE= argument till THIS_IMAGE vid %L"
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr "argumentet %<MOLD%> till den inbyggda %<TRANSFER%> vid %L är en vektor och skall inte ha lagringsstorlek 0 när argumentet %<SOURCE%> har en storlek större än 0"
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "%<MOLD%>-argumentet till inbyggd %<TRANSFER%> vid %L får inte vara %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "%<MOLD%>-argumentet till inbyggd %<TRANSFER%> vid %L måste vara en %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "%<MOLD%>-argumentet till inbyggd %<TRANSFER%> vid %L får inte vara %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Inbyggd TRANSFER vid %L har delvis odefinierat resultat: källstorlek %ld < resultatstorlek %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha samma ordning som %qs eller vara en skalär"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "%qs- och %qs-argumenten till inbyggd %qs vid %L måste ha identiska former."
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Storlek på %qs-argumentet till inbyggd %qs vid %L är för liten (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "För många argument till %s vid %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "fe_runtime_error-sträng måste vara null-terminerad"
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Fel antal argument (%d istället för %d)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentet COUNT till SYSTEM_CLOCK vid %L har icke-standardsort"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Reellt COUNT_RATE-argument till SYSTEM_CLOCK vid %L"
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentet COUNT_RATE till SYSTEM_CLOCK vid %L har en icke-standardsort"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentet COUNT_MAX till SYSTEM_CLOCK vid %L har en icke-standardsort"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha en sort som inte är bredare än standardsorten (%d)"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "Det aktuella argumentet vid %L till den inbyggda funktionen %qs måste vara en associerad pekare"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER, LOGICAL eller en BOZ-litteralkonstant"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "Den inbyggda funktionen NULL vid %L kan inte vara ett aktuellt argument till STORATE_SIZE, eftersom den returnerar en disassocierad pekare"
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "Polymorfa objekt eller komponenter med antagen storlek, såsom den vid %C, har inte implementerats ännu"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Maximal utökningsnivå nådd med typen %qs vid %L"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "%qs av %qs är PRIVATE vid %L"
@@ -57981,1755 +58068,1755 @@ msgstr "Felaktig INTENT-specifikation vid %C"
 msgid "deferred type parameter at %C"
 msgstr "fördröjd typparameter vid %C"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalärt INTEGER-uttryck förväntades vid %L"
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Gammaldags teckenlängd vid %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Syntaxfel i specifikation av teckenlängd vid %C"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Proceduren %qs vid %C är redan definierad vid %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Den inneslutna proceduren %qs vid %C krockar med proceduren definierad vid %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Namnet %qs vid %C är redan definierat som ett generiskt gränssnitt vid %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Proceduren %qs vid %C har ett explicit gränssnitt från en tidigare deklaration"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "Proceduren %qs som är definierad i gränssnittskroppen vid %L kolliderar med den interna proceduren definierad vid %C"
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Proceduren %qs vid %L måste ha attributet BIND(C) för att vara C-interoperativ"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Typen %qs vid %L är ett attrappargument till BIND(C)-proceduren %qs men är inte interoperativ med C för att den härledda typen %qs inte är interoperativ med C"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Variabeln %qs vid %L är ett attrappargument till BIND(C)-proceduren %qs men är inte interoperativ med C eftersom den är polymorf"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Variabeln %qs vid %L är en attrapparameter till BIND(C)-proceduren %qs men är kanske inte interoperativ med C"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Teckenargument %qs vid %L måste ha längden 1 eftersom proceduren %qs är BIND(C)"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variabeln %qs vid %L med attributet ALLOCATABLE i proceduren %qs med BIND(C)"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variabeln %qs vid %L med attributet POINTER i proceduren %qs med BIND(C)"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Variabeln %qs vid %L kan inte både ha attributet OPTIONAL och VALUE eftersom proceduren %qs är BIND(C)"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variabeln %qs vid %L med attributet OPTIONAL i proceduren %qs som är BIND(C)"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Vektorn %qs med antagen form vid %L som attrappargument till BIND(C)-proceduren %qs vid %L"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Symbolen %qs vid %C är också deklarerad som en typ vid %L"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Variabeln %qs i common-blocket %qs vid %C måste deklareras med en sort som är C-interoperativ eftersom common-blocket %qs är BIND(C)"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "CHARACTER-längden måste vara en konstant vid %L"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER-uttryck vid %L huggs av (%ld/%ld)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "CHARACTER-elementen i vektorkonstrueraren vid %L måste ha samma längd (%ld/%ld)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Initierare är inte tillåten för PARAMETER %qs vid %C"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER vid %L saknar en initierare"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variabeln %qs vid %C med en initierare finns redan i en DATA-sats"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Det går inte att initiera en parametervektor vid %L med element med variabel längd"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "Det går inte att initiera en vektor med antagen form vid %L med en skalär"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr "gfc_array_size misslyckades"
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Lägre gräns som inte är konstant i förmodat formad deklaration vid %L"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponent vid %C måste ha attributet POINTER"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Komponenten %qs med CLASS vid %C måste vara allokerbar eller en pekare"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Vektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponenten %qs vid %C är redan deklarerad vid %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Pekarvektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allokerbar komponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Vektorkomponent i post vid %C måste ha uttrycklig form"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Typparametern %qs vid %C har ingen motsvarande post i typparameternamnlistan vid %L"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-initiering vid %C är tvetydig"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-initiering vid %C kan inte ha MOLD"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Initiering av pekare vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Fel i pekarinitiering vid %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "annan pekarinitiering än NULL vid %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr "RESULT-variabeln %qs vid %L förhindrar FUNCTION-namnet %qs vid %C från att förekomma i en specifikationssats"
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "%qs är inte tillåtet utanför STRUCTURE vid %C"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs vid %C är en DEC-utökning, aktivera den med %<-fdec-structure%>"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "Enheten %qs kan inte ha attribut vid %C"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Felaktigt tecken %qc i ett variabelnamn vid %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Icke-PARAMETER-symbolen %qs vid %L kan inte ha antagen form"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Vektor med antagen form vid %L"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Explicit formad vektor med ickekonstanta gränser vid %C"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs vid %C är en omdefinition av deklarationen i motsvarande gränssnitt för MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Enheten %qs kan inte ha en initierare vid %C"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Dubblerad vektorspecifikation för Cray-utpekad vid %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "Kan inte sätta utpekads vektorspecifikation."
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Gammaldags initiering vid %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Felaktig gammaldags initiering av härledd typkomponent vid %C"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Syntaxfel i gammaldags initiering av %s vid %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initieringen vid %C är inte för en pekarvariabel"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Pekarinitiering vid %C kräver %<=>%>, inte %<=%>"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ett initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initiering av variabel vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initiering av allokerbar komponent vid %C är inte tillåtet"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "Initiering av en strukturkomponent med en HOLLERITH-konstant vid %L är inte tillåtet"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Komponenten med attributet KIND eller LEN vid %C förekommer inte i typparameterlistan vid %L"
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Komponenten vid %C som förekommer i typparameterlistan vid %L har varken attributet KIND eller LEN"
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Pekarkomponenten vid %C som är en typparameter måste vara en skalär"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "BOZ-litteralkonstanten vid %L kan inte förekomma som en initierare"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr "Inkomatibel initiering mellan en härledd typenhet och en enhet med typen %qs vid %C"
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Gammaldags typdeklaration %s*%d stödjs inte vid %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Typdeklaration ej enligt standard %s*%d vid %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Saknad högerparentes vid %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ett skalärt initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Sorten %d stödjs inte för typen %s vid %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Parameter med sort C är för typ %s men typen vid %L är %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Högerparentes eller komma saknas vid %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Sorten %d stödjs inte för typen CHARACTER vid %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfel i CHARACTER-deklaration vid %C"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr "RECORD vid %C är en utökning, aktivera den med %<-fdec-structure%>"
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Postnamn förväntades efter RECORD vid %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "Typparameterspecifikationslistan vid %C får inte innehålla både ASSUMED- och DEFERRED-parametrar"
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Typparameterspecifikationslistan vid %C innehåller inte tillräckligt med parameteruttryck"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Den härledda parametern %qs vid %C har inte ett standardvärde"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Parameteruttrycket vid %C måste vara av typen INTEGER och inte av typen %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "KIND-parametern %qs vid %C kan varken vara ASSUMED eller DEFERRED"
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Värdet på KIND-parametern %qs vid %C reduceras inte till ett konstant uttryck"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "Typparameterspecifikationslistan vid %C innehåller för många parameteruttryck"
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Parametriserad härledd typ vid %C är tvetydig"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-typ vid %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE-typ använd vid %C är inte tillgänglig på målmaskinen"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Förmodad typ vid %C är inte tillåtet för komponenter"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Antagen typ vid %C"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE med inbyggd typspecifikation vid %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "Felformad typspecifikation vid %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX vid %C"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typnamnet %qs vid %C är tvetydigt"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-sats vid %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typnamnet %qs vid %C står i konflikt med tidigare deklarerad enhet vid %L, som har samma namn"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Dubblerad IMPLICIT NONE-sats vid %C"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE med specifikationslista vid %C"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Teckenintervall saknas i IMPLICIT vid %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Bokstäver måste vara i alfabetisk ordning i IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-sats vid %C följer en IMPLICIT NONE (type)-sats"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tom IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-sats vid %C endast tillåten inuti en INTERFACE-kropp"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT-sats vid %C är inte tillåten i en moduls procedurgränssnittskropp"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-sats vid %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Lista med namngivna entiteter förväntades vid %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Det går inte att IMPORT:era %qs från värdräckviddsenhet vid %C — finns inte."
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs är redan IMPORT:erad från värdräckviddsenhet vid %C."
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfel i IMPORT-sats vid %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Co-dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Dubblerat %s-attribut vid %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s vid %L är en DEC-utökning, aktivera den med %<-fdec-static%>"
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attributet ALLOCATABLE vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Attributet ALLOCATABLE vid %C i en STRUCTURE-definition"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attributet KIND vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Attributet KIND vid %C i en STRUCTURE-definition"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Komponent med attributet KIND vid %C måste vara INTEGER"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Komponenten med attributet KIND vid %C måste vara av standardheltalssort (%d)"
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Attributet LEN vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Attributet LEN vid %C i en STRUCTURE-definition"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponenten med attributet LEN vid %C måste vara INTEGER"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Komponenten med attributet LEN vid %C måste vara av standardheltalssort (%d)"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet i en TYPE-definition"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "Attribut vid %L är inte tillåtet i en STRUCTURE-definition"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attributet %s vid %L i en TYPE-definition"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribut vid %L är inte tillåtet utanför specifikationsdelen av en modul"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet utanför en TYPE-definition"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attributet ASYNCHRONOUS vid %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attributet CONTIGUOUS vid %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED vid %C är endast tillåtet i specifikation av en del av en modul"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attributet PROTECTED vid %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attributet VALUE vid %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attributet VOLATILE vid %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Felaktigt attribut"
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Flera identifierare angivna med en ensam NAME=-specificerare vid %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implicit deklarerad BIND(C)-funktion %qs vid %L kan inte vara C-interoperativ"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte vara en sort interoperativ med C men common-blocket %qs är BIND(C)"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs vid %L är inte C-interoperativ men den är BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabeln %qs vid %L får inte ha en C-interoperativ sort men den är BIND(C)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte deklareras med BIND(C) eftersom den inte är en global"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet POINTER och BIND(C)"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet ALLOCATABLE och BIND(C)"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en vektor"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "Returtyp till BIND(C)-funktion %qs med teckentyp vid %L måste ha längden 1"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbolen %qs vid %L är markerad PRIVATE men har getts bindningsetiketten %qs"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Det behövs antingen entitet- eller common-blocknamn för attributspecifikationssatsen vid %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entitets- eller common-blocknamn saknas till attributspecifikationssats vid %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbol saknas"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-sats vid %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Härledd typ vid %C har inte definierats tidigare och kan därför inte förekomma i en härledd typdefinition"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaxfel i anonym postdeklaration vid %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfel i datadeklaration vid %C"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE-prefix vid %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "MODULE-prefix vid %C hittat utanför en modul, undermodul eller gränssnitt"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-procedur vid %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE och IMPURE får inte båda finnas vid %C"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "En typparameterlista krävs vid %C"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Alternativt returargument vid %C"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Ett parameternamn krävs vid %C"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Namnet %qs vid %C är namnet på proceduren"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "En parameterlista förväntades i typdeklarationen vid %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Oväntat skräp i formell argumentlista vid %C"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Dubblerat namn %qs i parameterlistan vid %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Dubblerad symbol %qs i formell argumentlista vid %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Formella argumentnamnen till MODULE PROCEDURE stämmer inte (%s/%s) vid %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Antalet formella MODULE PROCEDURE-argument vid %C stämmer inte"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-variabel vid %C måste vara skilt från funktionsnamnet"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Oväntat skräp efter funktionsdeklaration vid %C"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Attributet BIND(C) vid %L kan inte anges för en intern procedur"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "Attribut BIND(C) vid %C kräver ett gränssnitt med BIND(C)"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-procedur med NAME får inte ha attributet POINTER vid %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Attrapprocedur vid %C kan inte ha attributet BIND(C) tillsammans med NAME"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proceduren %qs vid %L har redan en grundtyp %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfel i PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> förväntades efter bindningsattribut vid %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS eller explicit gränssnitt krävs vid %C"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfel i procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE vid %C måste vara i ett generiskt gränssnitt"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "dubbelkolon i MODULE PROCEDURE-sats vid %L"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formell argumentlista förväntades i funktionsdefinitionen vid %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "Attribut BIND(C) vid %L kan endast användas för variabler och common-block"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr "BIND(C)-namnen stämmer inte (%qs/%qs) vid %C"
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-sats vid %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett PROGRAM"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en MODULE"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en SUBMODULE"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett BLOCK DATA"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett STRUCTURE-block"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en ett DERIVED TYPE-block"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett IF-THEN-block"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett DO-block"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett SELECT-block"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett FORALL-block"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett WHERE-block"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett inneslutet underprogram"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Oväntad ENTRY-sats vid %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-sats vid %C kan inte förekomma i en innesluten procedur"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Nödvändig parentes saknas före BIND(C) vid %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "ENTRY-sats vid %L med BIND(C) är otillåten i en elementär procedur"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "Alternativt returarattrappgument får inte förekomma i en SUBROUTINE med attributet BIND(C) vid %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ogiltig C-identifierare i NAME=-specificerare vid %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfel i NAME=-specifikation för att binda etikett vid %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "NAME=-specificerare vid %C skall vara ett konstant uttryck"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-specificerare vid %C skall vara en skalär av standardteckensort"
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Slutparentes saknas för att binda etikett vid %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Inget bindningsnamn är tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "För attrapprocedur %s är inget bindningsnamn tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME är inte tillåtet på BIND(C) för ABSTRACT INTERFACE vid %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Oväntad END-sats vid %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-sats istället för %s-sats vid %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamn på %qs i %s-sats förväntades vid %L"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Avslutande namn förväntades vid %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Etikett %qs för %s-sats förväntades vid %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i DIMENSION-sats"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensioner angivna för %s vid %L efter dess initiering"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i CODIMENSION-sats"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Vektorspecifikation måste vara fördröjd vid %L"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Dubblerat DIMENSION-attribut vid %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Oväntat tecken i variabellista vid %C"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> förväntades vid %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variabelnamn förväntades vid %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-pekare vid %C måste vara ett heltal"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-pekare vid %C har %d bytes precision, minnesadresser kräver %d byte"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "”,” förväntades vid %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr "Kan inte sätta Cray-utpekad vektorspecifikation."
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "”)” förväntades vid %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> eller slut på sats förväntades vid %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "Cray-pekardeklaration vid %C kräver flaggan %<-fcray-pointer%>"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-sats vid %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Åtkomstspecifikation av operatorn %s vid %C har redan angivits"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Åtkomstspecifikation för operatorn .%s. vid %C har redan angivits"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-sats vid %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfel i PROTECTED-sats vid %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variabelnamn förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "=-tecken i PARAMETER-sats förväntades vid %C"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Uttryck förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initierar redan initierad variabel vid %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER utan ”()” vid %C"
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Oväntade tecken i PARAMETER-sats vid %C"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s vid %C är en DEC-utökning, aktivera den med %<-fdec-static%>"
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Entitetslista förväntades i AUTOMATIC-sats vid %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaxfel i AUTOMATIC-sats vid %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Entitetslista förväntades i STATIC-sats vid %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaxfel i STATIC-sats vid %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Allmän SAVE-sats vid %C följer tidigare SAVE-sats"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-sats vid %C följer allmän SAVE-sats"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfel i SAVE-sats vid %C"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-sats vid %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfel i VALUE-sats vid %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-sats vid %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE anges för co-vektorvariabel %qs vid %C, vilket är use-/host-associerat"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfel i VOLATILE-sats vid %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfel i ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE PROCEDURE-deklaration vid %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE vid %C måste vara i ett generiskt modulgränssnitt"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Den inbyggda proceduren vid %L kan inte vara en MODULE PROCEDURE"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Tvetydig symbol i TYPE-definition vid %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbolen %qs vid %C har inte definierats tidigare"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs i EXTENDS-uttryck vid %C är inte en härledd typ"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kan inte utökas vid %C för att den är BIND(C)"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kan inte utökas vid %C eftersom det är en SEQUENCE-typ"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PRIVATE i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PUBLIC i specifikationsdelen av en modul"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT typ vid %C"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Misslyckades att skapa en post av typen ”%s” vid %C"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Typdefinitionen av %qs vid %C definierades redan vid %L"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Skräp efter MAP-sats vid %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Skräp efter UNION-sats vid %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s vid %C är en DEC-utökning, aktivera den med %<-fdec-structure%>"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Postnamn förväntades i icke nästad postdeklaration vid %C"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Skräp efter icke nästad STRUCTURE-sats vid %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Postnamnet %qs vid %C får inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: förväntades i TYPE-definition vid %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "Manglad härledd typdefinition vid %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typnamnet %qs vid %C kan inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Härlett typnamn %qs vid %C har redan en grundtyp %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Härlett typnamn %qs vid %C har redan en grundtyp"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "Attrappargumentet %qs vid %L får inte vara en härledd typ vid %C"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Härledd typdefinition %qs vid %C har redan definierats"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Skräp efter PARAMETERIZED TYPE-deklaration vid %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-utpekad vid %C kan inte vara förmodat formad vektor"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM och ENUMERATOR vid %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Uppräkningstypen överskrider C:s heltalstyp vid %C"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L är inte initierad med ett heltalsuttryck"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-definitionssats förväntades före %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfel i ENUMERATOR-definition vid %C"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Dubblerad åtkomstspecifikation vid %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten NOPASS vid %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten PASS vid %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Dubblerat POINTER-attribut vid %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Dubblerad NON_OVERRIDABLE vid %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Dubblerad DEFERRED vid %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Åtkomstspecificerare förväntades vid %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindningsattribut förväntades vid %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE och DEFERRED kan inte båda finnas vid %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-attribut krävs för procedurpekarkomponenten vid %C"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Gränssnittsnamn förväntades efter %<(%> vid %C"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> förväntades vid %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Gränssnitt måste anges för DEFERRED bindning vid %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) vid %C skulle vara deklarerat DEFERRED"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-lista vid %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> mål%> är ogiltigt för DEFERRED-bindning vid %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> behövs i PROCEDURE-bindning med explicit mål vid %C"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindningsmål förväntades efter %<=>%> vid %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typen %qs som innehåller en DEFERRED-bindning vid %C är inte ABSTRACT"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC vid %C måste vara inuti en härledd typs CONTAINS"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> förväntades vid %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generiskt namn eller operatorbeskrivare förväntades vid %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Felformad GENERIC-sats vid %C"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> förväntades vid %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en icke-generisk procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindning vid %C måste ha samma åtkomst som den redan definierade bindningen %qs"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Specifikt bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs är redan definierat som en specifik bindning för den generiska %qs vid %C"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Skräp efter GENERIC-bindning vid %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-deklaration vid %C måste vara inuti en härledd typs CONTAINS-sektion"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Härledd typdeklaration med FINAL vid %C måste vara med i specifikationsdelen av en MODULE"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tom FINAL vid %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Modulprocedurnamn förväntades vid %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> förväntades vid %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Okänt procedurnamn %qs vid %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs vid %C är redan definierad som FINAL procedur"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Okänt attribut i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfel i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Direktivet %<GCC unroll%> kräver en icke-negativ heltalskonstant mindre än eller lika med %u vid %C"
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaxfel i direktivet !GCC$ UNROLL vid %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Syntaxfel i direktivet !GCC$ IVDEP vid %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Syntaxfel i direktivet !GCC$ VECTOR vid %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr "Syntaxfel i direktivet !GCC$ NOVECTOR vid %C"
@@ -59854,12 +59941,12 @@ msgstr "index i dimension %d är utanför gränsen vid %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "Antalet element i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "LEN-part_ref vid %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "KIND-part_ref vid %C"
@@ -59934,7 +60021,7 @@ msgstr "transformerande inbyggd %qs vid %L är inte tillåten i ett initieringsu
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Beräkning av ett initieringuttryck utanför standarden vid %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "Funktionen %qs i initieringsuttrycket vid %L måste vara en inbyggd funktion"
@@ -60200,7 +60287,7 @@ msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L:
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för komponenten %qs vid %L: %s"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för %qs vid %L: %s"
@@ -60258,167 +60345,167 @@ msgstr "Målet för översättning av ordning är inte av ordning 1 vid %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datamålet vid %L får inte ha co-index"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Måluttryck i pekartilldelning vid %L måste leverera ett pekarresultat"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Målet för pekartilldelingen i initieraruttrycket har inte attributet TARGET vid %L"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Pekartilldelningsmål är vare sig TARGET eller POINTER vid %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Felaktigt mål i pekartilldelning i PURE-procedur vid %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Pekartilldelning med vektorindexering på högersidan vid %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Pekartilldelningsmålet har attributet PROTECTED vid %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Tilldelning till sammanhängande pekare från icke sammanhängande mål vid %L"
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Pekare vid %L i pekartilldelning kan överleva pekarmålet"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Pekarinitieringsmål vid %L får inte vara ALLOCATABLE"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Målet för pekarinitieringen vid %L måste ha attributet TARGET"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Pekarinitieringsmål vid %L måste ha attributet SAVE"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Procedurpekarinitieringsmål vid %L får inte vara en procedurpekare"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Intern procedur %qs är ogiltigt i procedurpekarinitiering vid %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Attrapproceduren %qs är ogiltig i procedurpekarinitiering vid %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "generate_isocbinding_initializer(): felaktig iso_c_binding-typ, %<c_ptr%> eller %<c_funptr%> förväntades"
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Pekarfunktioner i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Icke variabelt uttryck i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Namngiven konstant %qs i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs i variabeldefinitionssammanhang (%s) vid %L är inte en variabel"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Icke-POINTER i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typen är oåtkomlig i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med vektorindexerat mål kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med uttryck kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associationsnamn %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L eftersom dess mål vid %L inte heller kan"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Element med samma värde vid %L och %L i vektorindex i ett variabeldefinitionssammanhang (%s)"
@@ -60444,7 +60531,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Otillåtet id i copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -60635,12 +60722,12 @@ msgstr "Första argumentet till definierad tilldelning vid %L måste vara INTENT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -60710,582 +60797,582 @@ msgstr "Tvetydiga gränssnitt i %s för %qs vid %L och %qs vid %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "Fast orefererad har %qs tvetydiga gränssnitt vid %L"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs vid %L är inte en modulprocedur"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Vektor med antagen ordning vid %L kräver att attrappargumentet %qs har antagen ordning"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Ordning stämmer inte i argument %qs vid %L (skalär och ordning %d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Ordning stämmer inte i argument %qs vid %L (ordning %d och skalär)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Ordning stämmer inte i argument %qs vid %L (ordning %d och ordning %d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt afgument vid %L (skalär och ordning %d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (ordning %d och skalär)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (ordning %d och ordning %d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Ogiltigt procedurargument vid %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Gränssnitt stämmer inte överens i attrapprocedur %qs vid %L: %s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "Aktuellt argument till sammanhängande pekarattrapp %qs vid %L måste vara enkelt sammanhängande"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Typen stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (%s/%s)."
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Typ stämmer inte i argument %qs vid %L; skickade %s till %s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "Aktuellt argument med antagen typ vid %L kräver att attrappargumentet %qs har antagen typ"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "Aktuellt argument till %qs vid %L måste vara polymorft"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "Aktuellt argument till %qs vid %L måste ha samma deklarerade typ"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr "Aktuella argument till %qs vid %L måste vara obegränsat polymorfa eftersom det formella argumentet är en pekare eller allokerbar obegränsat polymorf enhet [F2008: 12.5.2.5]"
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "Aktuellt argument till %qs vid %L måste vara en co-vektor"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Co-ordning stämmer inte i argument %qs vid %L (%d och %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "Aktuellt argument till %qs vid %L måste vara enkelt sammanhängande eller ett element i en sådan vektor"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är LOCK_TYPE eller har en LOCK_TYPE-komponent"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "Aktuellt argument till icke-INTENT(INOUT)-attrappen %qs vid %L, som är EVENT_TYPE eller har en EVENT_TYPE-komponent"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "Attrappargument %qs måste vara en pekare, vektor med antagen form eller ordning utan attributet CONTIGUOUS - eftersom det aktuella argumentet vid %L inte är enkelt sammanhängande och båda är ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor, INTENT(OUT) attrappargument %qs"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "Skickar co-vektor vid %L till allokerbart, icke co-vektor attrappargument %qs, som är ogiltigt om allokeringsstatusen ändras"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorf skalär skickad till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat som aktuellt argument vid %L kan inte motsvara aktuellt argument vid %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "Element av vektor med antagen form eller pekare skickat till vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Utökning: Skalärt CHARACTER-argument som inte är av standardsort och inte C_CHAR-sort med vektorattrappargument %qs vid %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003: Aktuellt skalärt CHARACTER-argument med attrappargument som är vektor %qs vid %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Nyckelordsargument %qs vid %L är felaktigt i en satsfunktion"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren; menade du %qs?"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Nyckelordsargument %qs vid %L finns inte i proceduren"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Nyckelordsargumentet %qs vid %L är redan associerat med ett annat aktuellt argument"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "Fler aktuella än formella argument i proceduranrop vid %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "Alternativ returspecifierare saknas i subrutinanrop vid %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Oväntad alternativ returspecifierare i subrutinanrop vid %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Oväntad inbyggd NULL() vid %L till attrapp %qs"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008: Nollpekare vid %L till icke-pekarattrapp %qs"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr "Aktuellt argument vid %L till attrapp med antagen typ är av en härledd typ med typgräns eller FINAL-procedurer"
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och pekare eller allokerbart attrappargument %qs vid %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "Teckenlängd stämmer inte (%ld/%ld) mellan aktuellt argument och attrappargument med antagen form %qs vid %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "Aktuellt argument vid %L till allokerbart eller pekarattrappargument %qs måste ha en fördröjd längdtypparameter om och endast om attrappen har en"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Teckenlängden på aktuellt argument är kortare än attrappargumentet %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Aktuellt argument innehåller för få element för attrappargument %qs (%lu/%lu) vid %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "En procedurpekare förväntade som argument %qs vid %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Förväntade en procedur som argument %qs vid %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "Aktuellt argument till %qs kan inte vara en vektor med antagen storlek vid %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "Aktuellt argument till %qs skall vara en pekare vid %L"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008: Aktuellt argument som inte är en pekare vid %L till pekarattrapp %qs"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Co-indexerat faktiskt argument vid %L till pekarattrapp %qs"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Co-indexerat aktuellt argument vid %L till allokerbar attrapp %qs kräver INTENT(IN)"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Co-indexerat ASYNCHRONOUS eller VOLATILE aktuellt argument vid %L kräver att attrappen %qs varken har ASYNCHRONOUS eller VOLATILE"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Co-indexerat faktiskt argument vid %L med allokerbar slutlig komponent till attrappen %qs kräver antingen VALUE eller INTENT(IN)"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "Aktuellt CLASS-vektorargument till %qs måste vara en fullständig vektor vid %L"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "Aktuellt argument till %qs skall vara en ALLOCATABLE vid %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Vektorsektion som aktuellt argument med vektorindex vid %L är inte kompatibelt med attributet INTENT(OUT), INTENT(INOUT), VOLATILE eller ASYNCHRONOUS på attrappargumentet %qs"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Aktuellt argument med antagen form vid %L är inte kompatibel med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Vektorsektion som aktuellt argument vid %L är inkompatibelt med attrappargumentet %qs utan antagen form på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pekarvektor som aktuellt argument vid %L kräver ett attrappargument %qs med antagen form eller pekarvektor på grund av attributet VOLATILE"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "Alternativ returspecifikation saknas i subrutinanrop vid %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Aktuellt argument saknas för argument %qs vid %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Felaktig komponentkod"
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Listor stämmer inte"
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr "check_some_aliasing(): trasig data"
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "Samma aktuella argument associerat med INTENT(%s)-argument %qs och INTENT(%s)-argument %qs vid %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Listor stämmer inte"
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "Procedurargument vid %L är lokalt i en PURE-procedur och har attributet POINTER"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Co-indexerat aktuellt argument vid %L i en PURE-procedur skickas till ett INTENT(%s)-argument"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Co-indexerat aktuell argument vid %L i en PURE-procedur skickas till ett POINTER-attrappargument"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Co-indexerat polymorft aktuellt argument vid %L skickas ett polymorft attrappargument %qs"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad; menade du %qs?"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Proceduren %qs anropad vid %L är inte explicit deklarerad"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Procedur %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Pekarobjektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "Det allokerbara objektet %qs vid %L måste ha ett explicit funktionsgränssnitt eller deklareras som vektor"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allokerbar funktion %qs vid %L måste ha ett explicit funktionsgränssnitt"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Explicit gränssnitt krävs för polymorft argument vid %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för proceduren %qs vid %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "Argumentet ”%s” med antagen typ vid %L kräver ett explicit gränssnitt"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till LOCK_TYPE eller med LOCK_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Aktuellt argument till EVENT_TYPE eller med EVENT_TYPE-komponent vid %L kräver ett explicit gränssnitt för proceduren %qs"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "MOLD-argumentet till NULL krävs vid %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Argumentet med antagen ordning kräver ett explicit gränssnitt vid %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Procedurpekarkomponent %qs anropad med ett implicit gränssnitt vid %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "Nyckelordsargument kräver explicit gränssnitt för procedurpekarkomponent %qs vid %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "MOLD= krävs i NULL()-argument vid %L: Tvetydighet mellan de specifika funktionerna %s och %s"
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "Kan inte hitta symbolen %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "Entiteten %qs vid %L finns redan i gränssnittet"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Felaktig gränssnittstyp"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "Det går inte att skriva över GENERIC %qs vid %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%qs vid %L åsidosätter en procedurbindning deklarerad NON_OVERRIDABLE"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%qs vid %L får inte vara DEFERRED eftersom det åsidosätter en ej DEFERRED bindning"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%qs vid %L åsidosätter en PURE-procedur och måste också vara PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%qs vid %L åsidosätter en ELEMENTAL-procedur och måste också vara ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%qs vid %L åsidosätter en icke-ELEMENTAL-procedur och får inte heller vara ELEMENTAL"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%qs vid %L åsidosätter en SUBROUTINE och måste också vara en SUBROUTINE"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%qs vid %L åsidosätter en FUNCTION och måste också vara en FUNCTION"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Resultaten stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%qs vid %L åsidosätter en PURE-procedur och får inte vara PRIVATE"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "Attrappargument %qs till %qs vid %L skulle ha namnet %qs för att stämma med motsvarande argument i den åsidosatta proceduren"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "Argument stämmer inte överens för den åsidosättande proceduren %qs vid %L: %s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%qs vid %L måste ha samma antal formella argument som den åsidosatta proceduren"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%qs vid %L åsidosätter en NOPASS-bindning och måste också vara NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%qs vid %L åsidosätter en bindning med PASS och måste också vara PASS"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Attrappargument för pass-objekt till %qs vid %L måste vara på samma position som attrappargumentet för pass-objektet i den åsidosatta proceduren"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "DTIO-attrappargument vid %L måste ha typen %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "DTIO-attrappargument vid %L måste ha KIND = %d"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "DTIO-attrappargument vid %L måste vara skalärt"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "DTIO-attrappargument vid %L måste vara en ASSUMED SHAPE ARRAY"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "DTIO-teckenargumentet vid %L måste ha antagen längd"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "DTIO-attrappargument vid %L måste ha INTENT %s"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "Alternativ retur vid %L är inte tillåtet i en DTIO-procedur"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "DTIO-proceduren %qs vid %L måste vara en subrutin"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "För få attrappargument i DTIO-proceduren %qs vid %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "För många attrappargument i DTIO-proceduren %qs vid %L"
@@ -61390,73 +61477,73 @@ msgstr "ALTERNATE RETURN är inte tillåtet vid %L"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "I anrop av %qs vid %L stämmer inte typen i argument %qs; skicka %qs till %qs"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr "resolve_intrinsic(): För många argument för inbyggd"
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "do_simplify(): För många argument för inbyggd"
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "init_arglist(): för många argument"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "Ogiltig standardkod för inbyggd %qs (%d)"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "Inbyggd %qs (är %s) används vid %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "Funktionen %qs som initieringsuttryck vid %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "Transformerande funktion %qs vid %L är ogiltig i ett initieringsuttryck"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Elementär funktion som initieraruttryck med argument som inte är heltal/tecken vid %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Subrutinanrop till inbyggda %qs i DO CONCURRENT-block vid %L är inte PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "Subrutinanrop till inbyggd %qs vid %L är inte PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Utökning: Konvertering från %s till %s vid %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Ickestandardkonvertering från %s till %s vid %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Möjlig ändring av värde vid konvertering från %s till %s vid %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Konvertering från %s till %s vid %L"
@@ -61464,22 +61551,22 @@ msgstr "Konvertering från %s till %s vid %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Kan inte konvertera %s till %s vid %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Kan inte konvertera %qs till %qs vid %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "%qs deklarerad vid %L kan skugga den inbyggda med samma namn.  För att anropa den inbyggda kan en explicit INTRINSIC-deklaration krävas."
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "%qs deklarerad vid %L är också namnet på en inbyggd.  Den kan bara anropas via ett explicit gränssnitt eller om den deklareras EXTERNAL."
@@ -61825,12 +61912,12 @@ msgstr "Typen ACTION står i konflikt med READONLY-specificeraren vid %L"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= vid %L är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "BLANK= vid %L är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr "DECIMAL= vid %L är inte tillåtet i Fortran 95"
@@ -61840,7 +61927,7 @@ msgstr "DECIMAL= vid %L är inte tillåtet i Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "ENCODING= vid %L är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr "ROUND= vid %L är inte tillåtet i Fortran 95"
@@ -61885,7 +61972,7 @@ msgstr "CLOSE-sats vid %L kräver ett UNIT-tal"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-tal i CLOSE-sats vid %L måste vara ickenegativt"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-sats är inte tillåtet i PURE-procedur vid %C"
@@ -61980,7 +62067,7 @@ msgstr "NAMELIST %qs i READ-sats vid %L innehåller symbolen %qs som inte får s
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -62046,7 +62133,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "Förväntade uttryck i %s-sats vid %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfel i %s-sats vid %C"
@@ -62061,83 +62148,83 @@ msgstr "Intern fil vid %L med namnlista"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "IO UNIT i %s-satsen vid %L måste en intern fil i en PURE-procedur"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "PAD= vid %L är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "DELIM= vid %L är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT-namnlista vid %C är en utökning"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "Komma efter * vid %C är inte tillåtet utan I/O-lista"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Komma förväntades i I/O-lista vid %C"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-sats vid %C är inte tillåten inuti PURE-procedur"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "NULL() nära %L kan inte förekomma i en INQUIRE-sats"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE-sats är inte tillåten i PURE-procedur vid %C"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH-tagg ogiltig i INQUIRE-sats vid %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE-sats vid %L får inte innehålla både FILE- och UNIT-specificerare"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE-sats vid %L kräver antingen FILE- eller UNIT-specificerare"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "UNIT-tal i INQUIRE-sats vid %L får inte vara %d"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE-sats vid %L kräver en PENDING=-specificerare med ID=-specificeraren"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT-sats är inte tillåtet i PURE-procedur vid %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "identifierarspill: %d"
@@ -62382,505 +62469,505 @@ msgstr "Skräp efter ASSOCIATE-sats vid %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "Härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "Ogiltig typspecifikation vid %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "Syntaxfel i FORALL-iterator vid %C"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "DO CONCURRENT-konstruktion vid %C"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "Namnet %qs i %s-sats vid %C är okänt"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "Namnet %qs i %s-sats vid %C är inte ett konstruktionsnamn"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s-sats vid %C lämnar CRITICAL-konstruktion"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s-sats vid %C lämnar DO CONCURRENT-konstruktion"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%s-sats vid %C är inte inne i en konstruktion"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s-sats vid %C är inte inne i konstruktionen %qs"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "CYCLE-sats vid %C är inte tillämpbar på icke-slingkonstruktionen %qs"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "EXIT-sats utan något do-konstruktionsnamn vid %C"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s-sats vid %C är inte i tillämpbar på konstruktionen %qs"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s-sats vid %C lämnar ett OpenACC-strukturerat block"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "%s-sats vid %C lämnar ett OpenMP-strukturerat block"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "EXIT-sats vid %C avslutar !$ACC LOOP-slinga"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "CYCLE vid %C till uppdelad !ACC LOOP-slinga som inte är innerst"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "CYCLE vid %C till kollapsad !ACC LOOP-slinga som inte är innerst"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "EXIT-sats vid %C avslutar !$OMP DO-slinga"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "CYCLE vid %C till kollapsad !$OMP DO-slinga som inte är innerst"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "Blank krävs i %s-sats nära %C"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "STOP-kod vid %C får inte vara negativ"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr "STOP-kod vid %C innehåller för många siffror"
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "%s-sats vid %C i PURE-procedur"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "Bildstyrsatsen STOP vid %C i CRITICAL-block"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "Bildstyrsatsen STOP vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr "STOP-kod vid %L måste vara en skalär CHARACTER-konstant eller siffra[siffra[siffra[siffra[siffra]]]]"
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "STOP-kod vid %L måste vara ett skalärt standard-CHARACTER- eller -INTEGER-konstantuttryck"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "STOP-kod vid %L måste antingen vara av INTEGER- eller CHARACTER-typ"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "STOP-kod vid %L måste vara skalär"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "STOP-koden vid %L måste vara standard tecken-KIND=%d"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-kod vid %L måste vara standard heltal KIND=%d"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "PAUSE-sats vid %C"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "ERROR STOP-sats vid %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "Bildstyrsats EVENT %s vid %C i PURE-procedur"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "Bildstyrsatsen EVENT %s vid %C i CRITICAL-block"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "Bildstyrsatsen EVENT %s vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr "Överflödig STAT-tagg funnen vid %L"
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "Överflödig ERRMSG-tagg funnen vid %L"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "Överflödig UNTIL_COUNT-tagg funnen vid %L"
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "ENTRY POST-sats vid %C"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "ENTRY WAIT-sats vid %C"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "FAIL IMAGE-sats vid %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "FORM TEAM-sats vid %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "CHANGE TEAM-sats vid %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "END TEAM-sats vid %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "SYNC TEAM-sats vid %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "Bildstyrsats %s vid %C i PURE-procedur"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "Bildstyrsatsen %s vid %C i CRITICAL-block"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "Bildstyrsatsen %s vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "Överflödig ACQUIRED_LOCK-tagg funnen vid %L"
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "LOCK-sats vid %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "UNLOCK-sats vid %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "Bildstyrsats SYNC vid %C i PURE-procedur"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "SYNC-sats vid %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "Bildstyrsatsen SYNC vid %C i CRITICAL-block"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "Bildstyrsatsen SYNC vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "ASSIGN-sats vid %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "Tilldelad GOTO-sats vid %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "Satsetikettlistan i GOTO vid %C får inte vara tom"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Beräknat GOTO vid %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Fel i typspecifikation vid %L"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "typspecifikation i ALLOCATE vid %L"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr "Typparameterspecifikationslistan i typspecifikationen vid %L får inte innehålla DEFERRED-parametrar"
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "Oväntad konstant vid %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "Felaktigt allokeringsobjekt vid %C för en PURE-procedur"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "Inkompatibelt allokeringsobjekt vid %C för en CHARACTER-typspecifikation vid %L"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "ALLOCATE av co-vektor vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "ALLOCATE av co-vektor vid %C i CRITICAL-block"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "Allokeringsobjekt vid %L är varken en datapekare eller en allokerbar variabel"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "Entitetens typ vid %L är typinkompatibel med typspecifikationen"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Sorttypparameter för enheten vid %L skiljer sig från sorttypparametern i typspecifikationen"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "Formspecifikation för allokerbar skalär vid %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "STAT-taggen vid %L får inte vara en konstant"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG-tagg vid %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE-tagg vid %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr "Överflödig SOURCE-tagg funnen vid %L"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "SOURCE-taggen vid %L står i konflikt med typspecifikationen vid %L"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "SOURCE-tagg vid %L med mer än ett ensamt allokeringsobjekt"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD-tagg vid %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "Överflödig MOLD-tagg funnen vid %L"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "MOLD-taggen vid %L står i konflikt med typspecifikationen vid %L"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "MOLD-taggen vid %L står i konflikt med SOURCE-taggen vid %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allokeringsobjekt vid %L med en fördröjd typparameter behöver antingen en typspecifikation eller en SOURCE-tagg eller en MOLD-tagg"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Obegränsat polymorft allokeringsobjekt vid %L behöver en typspecifikation eller en SOURCE-tagg eller en MOLD-tagg"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "Pekarobjektet vid %C kan inte vara co-indexerat"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr "NULLIFY tillåter inte ommappning av gränser för pekarobjekt vid %C"
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "Otillåtet allokeringsobjekt vid %C för en PURE-procedur"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "DEALLOCATE av co-vektor vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "DEALLOCATE av co-vektor vid %C i CRITICAL-block"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allokeringsobjekt vid %C är varken en pekare på annat än procedur eller en allokerbar variabel"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG vid %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "Bildstyrsatsen RETURN vid %C i CRITICAL-block"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "Bildstyrsatsen RETURN vid %C i DO CONCURRENT-block"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "Alternativ RETURN-sats vid %C är bara tillåten inuti en SUBROUTINE"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "RETURN-sats i huvudprogram vid %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Komponentreferens förväntades vid %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "Skräp efter CALL vid %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "Typbunden procedurreferens eller procedurpekarkomponent förväntades vid %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr "En literal BOZ-konstant vid %L kan inte förekomma som ett faktiskt argument i en subrutinreferens"
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "Syntaxfel i common-blocknamn vid %C"
@@ -62888,217 +62975,217 @@ msgstr "Syntaxfel i common-blocknamn vid %C"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "Variabel %qs vid %L i common-block %qs vid %C måste deklareras med en C-interoperativ sort eftersom common-block %qs är bind(c)"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "Variabel %qs i common-block %qs vid %C får inte vara bind(c) eftersom det inte är globalt"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Symbolen %qs vid %C är redan i ett COMMON-block"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "Initierad symbol %qs vid %C kan endast vara COMMON i BLOCK DATA"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "Vektorspecifikation för symbolen %qs i COMMON vid %C måste vara explicit"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "Symbolen %qs i COMMON vid %C får inte vara en POINTER-vektor"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "Symbolen %qs, i COMMON-block %qs vid %C är indirekt gjort ekvivalent med ett annat COMMON-block %qs"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr "BLOCK DATA-konstruktion vid %L"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "Namnlistegruppnamnet %qs vid %C har redan grundtypen %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "Namnlistegruppnamn %qs vid %C är redan USE-associerat och får inte specificeras om."
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %C är inte tillåtet"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "Härledd typkomponent %C är inte en tillåten EQUIVALENCE-medlem"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "Vektorreferens i EQUIVALENCE vid %C får inte vara en vektorsektion"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "EQUIVALENCE vid %C kräver två eller flera objekt"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "Försök att indirekt överlappa COMMON-block %s och %s med EQUIVALENCE vid %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "Komma förväntades i EQUIVALENCE vid %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "EQUIVALENCE-sats vid %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "Satsfunktion vid %L är rekursiv"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Satsfunktionen %qs vid %L står i konflikt med ett funktionsnamn"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "Satsfunktion vid %L kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "Satsfunktion vid %C"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "Uttryck i CASE-väljare vid %L får inte vara %s"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "Initieringsuttryck förväntades i CASE vid %C"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Blocknamnet %qs förväntades av SELECT-konstruktionen vid %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "SELECT SCOP vid %C får inte förekomma i denna räckvidd"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "parsningsfel i SELECT TYPE-sats vid %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Väljare i SELECT TYPE vid %C är inte en namngiven variabel, använd associationsnamn =>"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "SELECT RANK-sats vid %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Selektorn SELECT RANK vid %C måste vara en variabel med antagen ordning"
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "parsningsfel i SELECT RANK-sats vid %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Oväntad CASE-sats vid %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfel i CASE-specifikation vid %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Oväntad TYPE IS-sats vid %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspecifikationen skall inte specificera en sekvens härledd typ eller en typ med attributet BIND i SELECT TYPE vid %C [F2003:C815]"
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Alla LEN-typparametrar i satsen TYPE IS vid %C måste vara ASSUMED"
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfel i TYPE IS-specifikation vid %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfel i CLASS IS-specifikation vid %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Oväntad RANK-sats vid %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "SELECT RANK CASE-uttrycket vid %C måste vara en skalär heltalskonstant"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "Värdet på SELECT RANK CASE-uttrycket vid %C får inte vara mindre än noll eller större än %d"
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Syntaxfel i RANK-specifikation vid %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-sats vid %C inte innesluten i WHERE-block"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Etiketten %qs vid %C stämmer inte med WHERE-etikett %qs"
@@ -63139,12 +63226,12 @@ msgstr "match_level_4(): Felaktig operator"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr "gfc_basic_typename(): Odefinierad typ"
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "gfc_typename(): Odefinierad typ"
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "gfc_code2string(): Felaktig kod"
@@ -63825,8 +63912,8 @@ msgstr "Den implicit deklarerade subrutinen %s används i !$OMP DECLARE REDUCTIO
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-klausulparameter är mindre än COLLAPSE vid %L"
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
@@ -65233,172 +65320,172 @@ msgstr "Oväntat %<%c%> för variabel med icke härledd typ %qs vid %C"
 msgid "Expected structure component name at %C"
 msgstr "Postkomponentnamn förväntades vid %C"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr "RE eller IM part_ref vid %C"
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr "part_ref:en RE eller IM vid %C måste tillämpas på ett COMPLEX-uttryck"
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "LEN part_ref:en vid %C måste tillämpas på ett CHARACTER-uttryck"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Argumentlista förväntades vid %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr "RE eller IM part_ref vid %C"
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "KIND-part_ref:en vid %C måste tillämpas på ett uttryck av inbyggd typ"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "Procedurpekarkomponent %qs kräver en argumentlista vid %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "Ickepolymorf referens till en abstrakt typ vid %C"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Co-indexerad procedurpekarkomponent vid %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): Uttrycket är inte en variabel"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_caf_attr(): Uttrycket är inte en variabel"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_caf_attr(): Felaktig vektorreferens"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Postkonstruerare med saknade valfria argument vid %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "Ingen initierare för den allokerbara komponenten %qs angiven i postkonstrueraren vid %C"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "Ingen initierare för komponent %qs angiven i postkonstrueraren vid %C"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "Det går inte att konstruera ABSTRACT typ %qs vid %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "Postkonstruerare med namngivna argument vid %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr "Komponentinitierare utan namn efter komponent med namn %s vid %L"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "För många komponenter i postkonstruerare vid %L"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i konstruerare (%ld/%ld) vid %L"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Komponenten %qs initieras två gånger i postkonstrueraren vid %L"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Co-indexerat uttryck till pekar komponent %qs i postkonstruerare vid %L"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "komponent %qs vid %L har redan satts av en härledd föräldratyps konstruerare"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr "%%LOC() är ett r-värde vid %C"
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "%qs vid %C är namnet på en rekursiv funktion och refererar därmed till resultatvariabeln.  Använd en explicit RESULT-variabel för direkt rekursion (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Symbol vid %C passar inte som uttryck"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Oväntad användning av subrutinnamnet %qs vid %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Satsfunktion %qs kräver en argumentlista vid %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "Funktion %qs kräver en argumentlista vid %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Argument saknas till %qs vid %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr "Den vänstraste part-ref i en data-ref kan inte vara en funktionsreferens vid %C"
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Argumentlista saknas i funktionen %qs vid %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Den härledda typen %qs får inte användas som en variabel vid %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Namngiven konstant vid %C är en EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%qs vid %C är inte en variabel"
@@ -65725,493 +65812,493 @@ msgstr "%qs vid %L är tvetydig"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "Typ angiven för inbyggd funktion %qs vid %L ignoreras"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Inbyggd subrutin %qs vid %L får inte ha en typspecificerare"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%qs deklarerad INTRINSIC vid %L finns inte"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "Den inbyggda %qs deklarerad INTRINSIC vid %L är inte tillgänglig i den aktuella standardinställningen utan i %s.  Använd en lämplig flagga %<-std=*%> eller aktivera %<-fall-intrinsics%> för att använda den."
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>."
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Den härledda typen %qs används som aktuellt argument vid %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "Satsfunktionen %qs vid %L får inte vara ett aktuellt argument"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Inbyggd %qs vid %L får inte vara ett aktuellt argument"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Den interna proceduren %qs används som aktuellt argument vid %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL icke INTRINSIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "Det går inte att hitta en angiven INTRINSIC-procedur för referensen %qs vid %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Symbolen  %qs vid %L är tvetydig"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "Värdesargument vid %L har inte en numerisk typ"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "Värdeargument vid %L får inte vara en vektor eller vektorsektion"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "Värdesargument vid %L är inte tillåtet i denna kontext"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "Att skicka intern procedur som plats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL icke INTRINSIC procedur %qs är inte tillåten som aktuellt argument vid %L"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Co-indexerat aktuellt argument vid %L med slutlig pekarkomponent"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%qs vid %L är en vektor och OPTIONAL.  OM DEN SAKNAS kan den inte vara det aktuella argumentet i en ELEMENTAL-procedur om det inte finns ett ej valfritt argument med samma ordning (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "Aktuellt argument vid %L för INTENT(%s)-attrapp %qs av ELEMENTAL-subrutin %qs är en skalär, men ett annat aktuellt argument är en vektor"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "Returtypen stämmer inte för funktionen %qs vid %L (%s/%s)"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Gränssnitt stämmer inte överens i den globala proceduren %qs vid %L: %s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "Det finns ingen specifik funktionen för den generiska %qs vid %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Generisk funktion %qs vid %L är inte konsistent med ett specifikt inbyggt gränssnitt"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Funktionen %qs vid %L är INTRINSIC men är inte kompatibel med en inbyggd"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Kan inte slå upp den specifika funktionen %qs vid %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "Referens till den orena funktionen %qs vid %L är inuti ett FORALL-%s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "Referens till den orena funktionen %qs vid %L är inuti ett DO CONCURRENT-%s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "Referens till den orena funktionen %qs vid %L inuti en PURE-procedur"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "Oväntat skräp efter %qs vid %L"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "%qs vid %L är inte en funktion"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs får inte refereras vid %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr "ABSTRACT INTERFACE %qs vid %L får inte ha ett antagen teckenlängdsresultat (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "Funktionen %qs är deklarerad CHARACTER(*) och får inte användas vid %L eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): felaktig funktionstyp"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr "En literal BOZ-konstant vid %L får inte förekomma som ett faktiskt argument i en funktionsreferens"
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "Användardefinierad ej ELEMENTAL funktion %qs vid %L är inte tillåten i WORKSHARE-konstruktion"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "ENTRY %qs vid %L får inte anropas rekursivt, eftersom funktionen %qs inte är RECURSIVE"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "Funktion %qs vid %L får inte anropas rekursivt, eftersom den inte är RECURSIVE"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "Subrutinanrop till %qs i FORALL-block vid %L är inte PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "Subrutinanrop till %qs i DO CONCURRENT-block vid %L är inte PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "Subrutinanrop till %qs vid %L är inte PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Det finns ingen specifik subrutinen för den generiska %qs vid %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Generisk subrutin %qs vid %L är inte konsistent med ett inbyggt subrutingränssnitt"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Subrutin %qs vid %L är INTRINSIC men är inte kompatibel med en inbyggd"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Kan inte slå upp den specifika subrutinen %qs vid %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%qs vid %L har en typ som inte är konsistent med CALL vid %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "ENTRY %qs vid %L är får inte anropas rekursivt, eftersom subrutinen %qs inte är RECURSIVE"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "SUBROUTINE %qs vid %L får inte anropas rekursivt, eftersom den inte är RECURSIVE"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): felaktig funktionstyp"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "Formerna för operanderna vid %L och %L är inte konforma"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Felaktig inbyggd"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Den orena funktionen %qs vid %L beräknas eventuellt inte"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "Den orena funktionen vid %L beräknas eventuellt inte"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "BOZ-litteralkonstanten vid %L får inte vara en operand till den unära operatorn %qs"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr "Operander vid %L och %L kan inte förekomma som operander av den binära operatorn %qs"
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Felaktig inbyggd"
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Felaktigt uttryck"
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Otillåtet steg på noll vid %L"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Högraste övre gränsen av en sektion av vektor med antagen storlek inte angiven vid %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Ordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Co-indexordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Co-index i co-dimension %d måste vara en skalär vid %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Vektorindex vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Vektorindex vid %L måste ha INTEGER-typ, fann %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-vektorindex vid %L"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Dim-argumentet vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Dim-argumentet vid %L måste ha INTEGER-typ"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Specifikation saknas"
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): oanvänd as(1)"
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): oanvänd as(2)"
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Vektorindex vid %L är en vektor med ordning %d"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Startindex för delsträng vid %L måste typen INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Startindex för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Delsträngs startindex vid %L är mindre än ett"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Slutindex för delsträng vid %L måste ha typen INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Slutsträng för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Slutindex för delsträng vid %L överstiger strängens längd"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Slutindex för delsträng vid %L är för stort"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet POINTER vid %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet ALLOCATABLE vid %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Två eller flera delreferenser med ordning skild från noll får inte anges vid %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr "gfc_expression_rank(): Två vektorspecifikationer"
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får bara användas som ett aktuellt argument"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt argument"
@@ -66220,12 +66307,12 @@ msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen typ %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktuellt argument"
@@ -66234,283 +66321,283 @@ msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktue
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen ordning %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen typ vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen ordning vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs, använd i ett specifikationsuttryck, refereras vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs används vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorft subobjekt till co-indexerat objekt vid %L"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fel i typbundet anrop vid %L"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller över"
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller under"
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på enheten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen EVENT_TYPE eller ha en EVENT_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation eller vektorvärt SOURCE=-uttryck krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Övre cobound är mindre än den lägre cobound vid %L"
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Övre cobound är mindre än lägre cobound av 1 vid %L"
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "”*” förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG-variabeln vid %L måste vara en skalär standard-CHARACTER-variabel"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -66519,284 +66606,284 @@ msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Den associerande enheten %qs vid %L är en procedurpekare"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Den härledda typen %qs får inte användas som en variabel vid %L"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Den associerande neheten %qs vid %L är ett procedurnamn"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Det associerande selector-uttrycket vid %L ger en procedur"
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektorn vid %L får inte vara NULL()"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektorn vid %L har ingen typ"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS vid %L överlappar med TYPE IS vid %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT vid %L upprepas vid %L"
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) vid %L upprepas vid %L"
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) vid %L upprepas %L"
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) vid %L får inte användas med en pekare eller allokerbar selector vid %L"
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s-procedur vid %L måste vara rekursiv"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha PRIVATE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Händelsevariabeln vid %L måste vara en skalär av typen EVENT_TYPE"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor eller co-indexerat"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor men inte co-indexerat"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller ordning-1-uttryck"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -66804,187 +66891,188 @@ msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-konstruktion vid %L"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär variabel av heltalstyp"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%ld/%ld) vid %L"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "I ett rent underprogram skall inte ett INTENT(IN) attrappargument användas som uttrycket vid %L av en inbyggd tilldelningssats i vilken variabeln är av an härledd typ om den härledda typen har en pekarkomponent på någon nivå av komponentvalet."
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn ”=”"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Procedurpekartilldelning vid %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en INTEGER-variabel"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ogiltig NULL vid %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett skalärt REAL- eller INTEGER-uttryck"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en enhet vid %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använder samma globala identifierare som entiteten vid %L från modulen %qs"
@@ -66992,954 +67080,954 @@ msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använde
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som entiteten vid %L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen %qs kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet POINTER eller ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn %qs vid %L måste ha konstant form"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s vid %L"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionens resultatvariabel %qs vid %L för den elementära funktionen %qs skall inte ha ett attribut ALLOCATABLE eller POINTER"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "ELEMENTAL-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "PURE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "RECURSIVE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s mellan MODULE PROCEDURE-deklarationen i MODULE %qs och deklarationen vid %L i (SUB)MODULE %qs"
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typbindningsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponenten %qs med typen BIND(C) vid %L måste ha längden ett"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initierare som står i konflikt i unionen vid %L och %L"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Den parametriserade typen %qs har inte någon komponent som motsvarar parametern %qs vid %L"
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Härledd typ %qs vid %L har inte deklarerats"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Objektet %qs vid %L har en fördröjd LEN-parameter %qs och är varken allokerbar eller en pekare"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "AUTOMATIC-objektet %qs vid %L får inte ha attributet SAVE eller vara en variabel deklarerad i huvudprogrammet, en modul eller en submodul(F08/C513)"
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Objektet %qs vid %L med ASSUMED typparametrar måste vara en attrapp eller en SELECT TYPE-selektor(F08/4.2)"
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Felaktig specifikation för vektor med antagen storlek vid %L"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-variabeln %qs vid %L måste ha längden ett"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen EVENT_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbar entitet förväntades nära %L"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "DATA-objektet nära %L har pekarattributet och det motsvarande DATA-värde är inte en giltig initialt-data-mål"
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats."
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Självreferens i uttrycket för teckenlängd för %qs vid %L"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -68627,154 +68715,154 @@ msgstr "%qs vid %L har attribut angivna utanför dess INTERFACE-kropp"
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Symbolen %qs vid %L står i konflikt med symbolen från modulen %qs, användningsassocierad vid %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbolen %qs vid %L har redan grundtypen %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Procedur %qs vid %L får inte ha grundtypen %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbolen %qs vid %L kan inte ha en typ"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponenten %qs vid %C finns redan i föräldratypen vid %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbolen %qs vid %C är tvetydig"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Härledd typ %qs vid %C används före den är definierad"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponent %qs vid %C är en PRIVATE-komponent i %qs"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs vid %C är inte en medlem av posten %qs; menade du %qs?"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs vid %C är inte en medlem av posten %qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Dubblerad satsetikett %d vid %L och %L"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Etikett %d vid %C är redan refererad som ett grenmål"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Etiketten %d vid %C är redan refererad som en formatetikett"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO avslutningssats som inte är END DO eller CONTINUE med etikett %d vid %C"
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Etikett %d vid %C användes tidigare som en FORMAT-etikett"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Etikett %d vid %C användes tidigare som ett grenmål"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Delad DO-avslutningsetikett %d vid %C"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Etiketterad DO-sats vid %L"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från modulen %qs"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från den aktuella programenheten"
 
 # Vad är "host associated"?
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbolen %qs vid %C har redan blivit host-associerad"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Den angivna symbolen är oväntat NULL"
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Härledd typ %qs deklarerad vid %L måste ha attributet BIND för att vara ett C-interoperativ"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Härledd typ %qs med attributet BIND(C) vid %L är tom, och kan vara otillgängliga av C-följeslagarprocessorn"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponent %qs vid %L får inte ha attributet POINTER eftersom det är en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Procedurpekarkomponenten %qs vid %L kan inte vara en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponent %qs vid %L får inte ha attributet ALLOCATABLE eftersom det är en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ, trots att den härledda typen %qs är BIND(C)"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Härledd typ %qs vid %L kan inte ha attributet SEQUENCE för att den är BIND(C)"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbolen %qs används före den har fått sin typ vid %L"
@@ -68811,83 +68899,83 @@ msgstr "Överlappande olika initierare i EQUIVALENCE vid %C"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Antalet element i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Skapar vektortemporär vid %L för argument %qs"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "felaktig uttryckstyp under genomlöpning (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "Namngivet COMMON-block %qs vid %L skall ha samma storlek som på andra håll (%lu mot %lu byte)"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "get_mpz(): Inte en heltalskonstant"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr "element_number(): Felaktig dimensionstyp"
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "Felaktig vektorreferens vid %L"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "Ogiltig referenstyp vid %L som EQUIVALENCE-objekt"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Inkonsistenta ekvivalensregler rörande %qs vid %L och %qs vid %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "Ekvivalensmängden för variabeln %qs deklarerad vid %L bryter mot justeringskraven"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "Ekvivalens för %qs stämmer inte med ordningen av COMMON %qs vid %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "Ekvivalensmängden för %qs orsakar en ogiltig utvidgning av COMMON %qs vid %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Utfyllnad med %d byte krävs före %qs i COMMON %qs vid %L, byt ordning på element eller använd %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "Utfyllnad med %d byte krävs före %qs i COMMON vid %L, byt ordning på element eller använd %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr "COMMON %qs vid %L finns inte"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON %qs vid %L kräver %d byte utfyllnad, byt ordning på element eller använd %<-fno-align-commons%>"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON vid %L kräver %d byte utfyllnad, byt ordning på element eller använd %<-fno-align-commons%>"
@@ -68907,72 +68995,72 @@ msgstr "ej konstant initieringsuttryck vid %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr "Vektorn %qs vid %L är större än gränsen satt med %<-fmax-stack-var-size=%>, flyttad från stacken till statisk lagring.  Detta gör proceduren osäker när den anropas rekursivt, eller samtidigt från flera trådar.  Överväg att använda %<-frecursive%>, eller öka gränsen %<-fmax-stack-var-size=%>, eller ändra koden till att använda en ALLOCATABLE vektor."
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "inbyggd variabel som inte är en procedur"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Returvärdet för funktionen %qs vid %L är inte satt"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "Fördröjd typparameter stödjs inte ännu"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "bakändedeklaration för modulvariabel %qs finns redan"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "Oanvänd PRIVATE modulvariabel %qs deklarerad vid %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Attrappargument %qs vid %L deklarerades INTENT(OUT) men sattes inte"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "Attrappargument med härledd typ %qs vid %L deklarerades INTENT(OUT) men sattes inte och har inte en standardinitierare"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Oanvänt attrappargument %qs vid %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "Oanvänd modulvariabel %qs som uttryckligen har importerats vid %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Oanvänd variabel %qs deklarerad vid %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Oanvänd parameter %qs deklarerad vid %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Oanvänd parameter %qs som uttryckligen har importerats vid %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Returvärdet %qs för funktionen %qs deklarerad vid %L är inte satt"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Ledsen, !$ACC DECLARE vid %L är inte tillåtet i BLOCK-konstruktion"
@@ -68987,27 +69075,27 @@ msgstr "Kan inte beräkna längden på teckenvektorn vid %L."
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Kod för omallokering av den allokerbara variabeln vid %L kommer läggas till"
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till ett obegränsat polymorft objekt vid %L stödjs inte ännu"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till en obegränsat polymorf komponent vid %L stödjs inte"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Okänd inbyggd op"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Okänd argumentlistefunktion vid %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Om ommappning av gränser anges vid %L skall pekarmålet inte vara NULL"
@@ -69043,22 +69131,22 @@ msgstr "build_dt: format med namnlista"
 msgid "Bad IO basetype (%d)"
 msgstr "Felaktig IO-bastyp (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr "implicit avbildning av vektorn %qD med antagen storlek"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, gcc-internal-format
 msgid "optional class parameter"
 msgstr "valfri klassparameter"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr "ohanterad härledd typ-argument"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare(): Felaktig satskod"
@@ -69168,82 +69256,82 @@ msgstr "parenteserna stämmer inte överens"
 msgid "unable to open file"
 msgstr "kan inte att öppna filen"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "bytekodström: skräp i slutet av symbolsektionen"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "kunde inte tolka hexadecimalt tal"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "oväntat filnamn %s i länkupplösningsfilen.  %s förväntades"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "det gick inte tolka filavstånd"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "oväntat avstånd"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ogiltig rad i upplösningsfilen"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ogiltig upplösning i upplösningsfilen"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "upplösnings-under-id %wx är inte en objektfil"
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "bytekodströmmen i filen %qs är genererad med en GCC-kompilator äldre än 10.0"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "det går inte att läsa %<LTO_section_decls%> från %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Kan inte öppna %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Kan inte avbilda %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Kan inte läsa %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "det gick inte att öppna symbolupplösningsfilen: %m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "upplösningsdata saknas för %s"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "fel vid sammanslagning av översättningsenheter"
@@ -70369,7 +70457,7 @@ msgstr "makronamn saknas efter %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "filnamn saknas efter %qs"
@@ -70569,17 +70657,29 @@ msgstr "okänd algoritm for omordning av grundblock %qs"
 msgid "unknown TLS model %qs"
 msgstr "okänd TLS-modell %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "okänd kostnadsmodell för vektorisering %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "okänt synlighetsvärde %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
+
+#~ msgid "Warn about code paths in which an uninitialized value is used."
+#~ msgstr "Varna för kodvägar i vilka ett oinitierat värde används."
+
+#~ msgid "Use instructions for a future architecture."
+#~ msgstr "Använd instruktioner för en framtida arkitektur."
+
+#~ msgid "three-way comparison operator can only be defaulted in a class definition"
+#~ msgstr "trevägsjämförelseoperatorn kan endast standarddefinieras i en klassdefinition"
+
+#~ msgid "equality comparison operator can only be defaulted in a class definition"
+#~ msgstr "likhetsjämförelseoperatorn kan endast standarddefinieras i en klassdefinition"
diff --git a/gcc/po/tr.po b/gcc/po/tr.po
index 2464542f9fc..c0a1fd53cbf 100644
--- a/gcc/po/tr.po
+++ b/gcc/po/tr.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -2099,18 +2099,18 @@ msgstr "strfmon biçiminde uzunluk değiştirici"
 msgid "<command-line>"
 msgstr "<komut-satırı>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
@@ -2118,78 +2118,78 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "invalid operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid vector constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "terim eksik"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "geçersiz %%d terimi"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "adres geçersiz"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands to binary %s"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "iki terimli %s için terimler geçersiz"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2205,18 +2205,18 @@ msgid "invalid %%r value"
 msgstr "%%r değeri geçersiz"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "%%R değeri geçersiz"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
@@ -2246,7 +2246,7 @@ msgstr "%%M değeri geçersiz"
 msgid "invalid %%U value"
 msgstr "%%U değeri geçersiz"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
@@ -2256,7 +2256,7 @@ msgstr "%%s değeri geçersiz"
 msgid "invalid %%C value"
 msgstr "%%C değeri geçersiz"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
@@ -2266,10 +2266,10 @@ msgstr "%%E değeri geçersiz"
 msgid "unknown relocation unspec"
 msgstr "bilinmeyen yerdeğişim unspec"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "%%xn kodu geçersiz"
@@ -2358,37 +2358,37 @@ msgstr "terim olarak UNSPEC geçersiz"
 msgid "unrecognized supposed constant"
 msgstr "tanınmayan tahmini sabit"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "isnatlı Thumb komutu"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "koşullu dizilimde isnatlı komut"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2396,14 +2396,14 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "komut hiç çalıştırılmadı"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2546,7 +2546,7 @@ msgstr "beklenmeyen terim"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2765,27 +2765,27 @@ msgstr "output_move_double terimi hatalı"
 msgid "bad output_condmove_single operand"
 msgstr "output_condmove_single terimi hatalı"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand %%xn code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand %%xn code invalid for QImode"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid fp constant"
@@ -2949,7 +2949,7 @@ msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 msgid "invalid %%P operand"
 msgstr "%%P terimi geçersiz"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -3007,7 +3007,7 @@ msgid "post-increment address is not a register"
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -3064,8 +3064,8 @@ msgstr "'%s' geçerli bir sınıf ismi değil"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -3209,189 +3209,243 @@ msgstr "Yığıt taştı.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Sınırını belirlemek için kabukta `%s' çalıştırmayı deneyin.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "İndisli adresleme kapatılır"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-f%s ile -msdata=%s uyumsuz."
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%H value"
+msgid "invalid %%A value"
+msgstr "%%H değeri geçersiz"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "%%D değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "%2$qT mutlak sınıf türündeki %1$qE ifadesi throw ifadesi içinde kullanılamaz"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3402,104 +3456,104 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "adres çözümlenemez"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "geçersiz terim çıktı kodu"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "terim olarak ifade geçersiz"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "dönüş değerinde gösterici hedefleri farklı signed'lıkta"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 #, fuzzy
 #| msgid "target format does not support infinity"
 msgid "binary operator does not support vector bool operand"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3784,8 +3838,8 @@ msgstr "<anonim>"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
@@ -3805,7 +3859,7 @@ msgstr "%<;%> umuluyordu"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -3814,7 +3868,7 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -3835,14 +3889,14 @@ msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -3850,8 +3904,8 @@ msgstr "%<{%> umuluyordu"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -3862,13 +3916,13 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -3878,7 +3932,7 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -3890,20 +3944,20 @@ msgstr "%<{%> umuluyordu"
 msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -3912,20 +3966,20 @@ msgstr "%<,%> veya %<;%> umuluyordu"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
@@ -3937,7 +3991,7 @@ msgstr "%<,%> veya %<}%> umuluyordu"
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -3950,19 +4004,19 @@ msgstr "%<{%> umuluyordu"
 msgid "expected label"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "1. aday:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable use of DB instruction"
 msgid "  after user-defined conversion:"
 msgstr "DB komutunun kullanımı etkin olur"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -3970,19 +4024,19 @@ msgid_plural "candidates are:"
 msgstr[0] "1. aday:"
 msgstr[1] "1. aday:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "1. aday:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "2. aday:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "%qD yaftasına jump"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "case yaftasına jump"
 
@@ -4093,7 +4147,7 @@ msgstr "şablon parametresi %q+#D"
 msgid "<statement>"
 msgstr "deyim umuluyordu"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown src"
 msgid "<unknown>"
@@ -4291,50 +4345,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tek terimli eksiye yanlış türde argüman"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs'a yanlış türde argüman"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "mantıksal çarpım için yanlış türde argüman"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -4378,19 +4432,19 @@ msgstr "%C'de BOZ sabitinde kuraldışı karakter"
 msgid "elemental binary operation"
 msgstr "Öğesel ikilik işlem"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "'%s' ve '%s' argümanları 'dot_product' yerleşiği için (%L'de) farklı biçimde"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "'%s' ve '%s' argümanları 'dot_product' yerleşiği için (%L'de) farklı biçimde"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
@@ -4466,7 +4520,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Sürülüm:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 #, fuzzy
 #| msgid "Actual argument at %L must be definable to match dummy INTENT = OUT/INOUT"
 msgid "actual argument to INTENT = OUT/INOUT"
@@ -4483,7 +4537,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4589,11 +4643,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
@@ -4601,252 +4655,252 @@ msgstr "gösterici ataması"
 msgid "simple IF"
 msgstr "basit IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 #, fuzzy
 #| msgid "elemental subroutine"
 msgid "elemental procedure"
 msgstr "öğesel altyordam"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "allocatable argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 #| msgid "no arguments"
 msgid "asynchronous argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 #| msgid "no arguments"
 msgid "optional argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "gösterici ataması"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 #| msgid "no arguments"
 msgid "target argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "value argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-shape argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 #| msgid "no arguments"
 msgid "assumed-rank argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 #| msgid "no arguments"
 msgid "coarray argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "parametrized derived type argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "argüman yok"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 #| msgid "invalid type argument"
 msgid "assumed-type argument"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 #, fuzzy
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "result with non-constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, fuzzy, c-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki tek terimli sayısal '%s' işlecinin terimi %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki iki terimli sayısal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "%%L'deki dizge ekleme işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki mantıksal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L'deki .NOT. işlecinin terimi %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L'de COMPLEX nicelikler karşılaştırılamıyor"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L'deki mantıksallar %s ile karşılaştırılmalı %s ile değil"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' karşılaştırma işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimi %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4859,27 +4913,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4961,7 +5015,7 @@ msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 msgid "Assigned label is not a target label"
 msgstr "Atanmış yafta bir hedef yaftası değil"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -5449,7 +5503,7 @@ msgstr "İşlev gösterici aritmetiği hakkında uyarır"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -6094,8 +6148,8 @@ msgstr "Dışsal olarak görünür isimlere altçizgiler ekler"
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -8843,108 +8897,102 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr ""
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Kendileriyle ilklendirilmiş değişkenlerde uyarır"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "Dump various compiler internals to a file"
 msgid "Dump various analyzer internals to stderr."
 msgstr "Çeşitli derleyici iç oluşumları bir dosyaya dökümlenir"
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13933,10 +13981,9 @@ msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:572
-#, fuzzy, no-c-format
-#| msgid "Use Branch Likely instructions, overriding the architecture default"
-msgid "Use instructions for a future architecture."
-msgstr "Öntanımlı mimariye rağmen Branch Likely komutları kullanılır"
+#, no-c-format
+msgid "Use instructions added in ISA 3.1."
+msgstr ""
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13949,6 +13996,12 @@ msgstr "Yükleme/saklama çoklu komutları üretilir"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate isel instructions"
+msgid "Generate (do not generate) MMA instructions."
+msgstr "isel komutları üretilir"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -19571,7 +19624,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -20308,413 +20361,413 @@ msgstr "Yineleme sayısı bilindiğinde döngü tersine uygulanır"
 msgid "Perform loop unrolling for all loops."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "IEEE veya ISO standartlarını bozabilen matematiksel eniyilemelere izin verilir"
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Döngü anahtarlamaması uygulanır"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Döngü soyması uygulanır"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Olağandışılıkların yakalanması için birbirlerini etkilemeyenlerin tablosu oluşturulur"
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, fuzzy, no-c-format
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Saklama ve yüklemelerde kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Çevirici çıktısına fazladan açıklama ekler"
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Eniyilemelerde ifade değeri ayrımlaması kullanılır"
 
-#: common.opt:3048
+#: common.opt:3052
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Izgara oluşturur ve tek bir değişkenin ilgisiz kullanımlarını ayırır"
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Bütün yazılım eniyilemeleri uygulanır"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "bss bölümüne sıfır ilklendirmeli veri yerleştirilir"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Öntanımlı gelişmiş biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Her işlev için tek çıkış noktası üretilir"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Gelişmiş STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Gelişmiş XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "isel komutları üretilir"
 
-#: common.opt:3209
+#: common.opt:3213
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 #| msgid "Set <dir> to be the system root directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Çıktı <dosya>ya yazılır"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "İşlev ayrımlama etkinleştirilir"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic gibidir ancak uyarılar hata olarak ele alınır"
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Derlenen işlevler ve geçen zaman gösterilmez"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Ayrıntılı çıktı verilir"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Derleyici sürümünü gösterir."
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Uyarılar engellenir"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library."
 msgstr "ID tabanlı paylaşımlı kütüphane etkin olur"
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a static position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -22004,8 +22057,8 @@ msgstr "tek boyutlu dizi yapan döngü tanımı tarafından yerleştirilen çal
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "tek boyutlu dizi yapan döngü tanımı tarafından yerleştirilen çalışma anı sınama sayısı sınırı"
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "hesaplanan değer kullanılmadı"
@@ -22041,7 +22094,7 @@ msgid "expected boolean type"
 msgstr "İfade türü umuluyordu"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -22128,7 +22181,7 @@ msgstr "argüman yok"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -22580,7 +22633,7 @@ msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -22672,12 +22725,12 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -22695,8 +22748,8 @@ msgstr "%qE özniteliği yoksayıldı"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -22825,7 +22878,7 @@ msgstr "deyim umuluyordu"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "göreli konum sabit dizgenin sınırlarının dışında"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -23127,7 +23180,7 @@ msgstr "\"%s\" için argüman eksik"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -23446,13 +23499,13 @@ msgstr "asm taşırıcı çıkış terimi ile çelişiyor"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "asm taşırıcı giriş terimi ile çelişiyor"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "not protecting local variables: variable length buffer"
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "korunmayan yerel değişkenler: değişken uzunlukta tampon"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not protecting function: no buffer at least %d bytes long"
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
@@ -23998,317 +24051,317 @@ msgstr "temel bloklar ardışık numaralı değil"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "komut zinciri (%d) içindeki bb notlarının sayısı != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "çağrıcı ayrıt sayısı negatif"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "missing direct call for speculation %i"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Create console application"
 msgid "missing ref for speculation %i"
 msgstr "Konsol uygulaması oluşturulur"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "tp_first_run must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Tüm simgelerin geçersiz olabileceği varsayılır"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "'void' dönüşlu işlevde değer içeren `return' deyimi"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "edge count is not compatible with function count"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to göstericisi yanlış"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "çok sayıda satıriçi çağrısı"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Inlined_to göstericisi satıriçi olmayan çağrıcılar için belirtilmiş"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, fuzzy, gcc-internal-format
 #| msgid "inlined_to pointer is set but no predecesors found"
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to göstericisi var ama bir öncül yok"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Inlined_to göstericisi kendini gösteriyor"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "paylaşımlı call_stmt:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "yanlış bildirimin köşeleri:"
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "çağrı deyimi için çağrı çizgesi ayrıtı eksik"
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "deyim umuluyordu"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "origin points to a different parent"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node başarısız"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s.%d is missing"
@@ -24406,12 +24459,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F işlevi tanımlanmadan kullanılmış"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
@@ -24585,7 +24638,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
@@ -24940,22 +24993,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "komutta geçersiz rtl paylaşımı bulundu"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "paylaşımlı rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "dahili tutarlılık hatası"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE: emit_jump_insn gereken yerde emit_insn kullanılmış:\n"
@@ -25021,7 +25074,7 @@ msgstr "dizi bölge ağacıyla eşleşmiyor"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "can't open input file: %s"
 msgid "%qs failed"
@@ -25053,13 +25106,13 @@ msgstr "Kod Boehm GC için üretilir"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%q+D işlevinin yeniden bildirimi inline öznitelikli değil"
 
-#: expr.c:11123
+#: expr.c:11128
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute warning: %s"
@@ -25077,7 +25130,7 @@ msgstr "IACC argümanı geçersiz"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "%q+D boyutu %wd bayttan fazla"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
@@ -25100,37 +25153,37 @@ msgstr "büyük tamsayı örtük olarak unsigned türe indirgendi"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "karşılaştırma sonucu daima %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "eşleşmeyenlerin farklılık sınamalarının %<or%> sonucu daima 1 dir"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold sınaması: özgün ağac fold tarafından değiştirildi"
@@ -25826,13 +25879,13 @@ msgstr "işlev yerel değişkenin adresi ile dönüyor"
 msgid "function returns address of local variable"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -26430,10 +26483,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -26617,7 +26670,7 @@ msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 msgid "enclosing %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
@@ -26674,13 +26727,13 @@ msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -26690,151 +26743,151 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "%s variable %qE is private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimpleme başarısız"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT %<...%> üzerinden aktarılırken %qT'ye yükseltgenir"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(bu durumda %<va_arg%>'a %qT değil %qT akarılmalı)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Bu kodun bitiminde uygulama çıkacak"
@@ -26913,7 +26966,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -27204,54 +27257,54 @@ msgstr "alan ilklendirici türü uyumsuzluğu"
 msgid "the extra base is defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -27285,38 +27338,38 @@ msgstr "%Jislev %<noreturn%> özniteliği için olası aday olabilir"
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification failed: %s"
 msgid "IPA-SRA access verification failed"
 msgstr "doğrulama başarısız: %s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -27372,59 +27425,59 @@ msgstr "bir %<asm%> içindeki terim terim kısıtı tutarsız"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "sınıf %qs bulunamıyor"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "%qs için protokol bildirimi bulunamıyor"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -27698,53 +27751,53 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "... to the previous %qs clause here"
 msgstr "%Jönce burada kullanılmış"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr ""
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -27970,53 +28023,53 @@ msgstr "%qs özniteliğinin argümanı geçersiz"
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "routine %qD declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -29461,143 +29514,143 @@ msgstr "bu hedefte -fstack-protector desteklenmiyor"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "bu hedef makina için komut zamanlaması desteklenmiyor"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "bu hedef makina gecikmeli dallanmalara sahip değil"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "bu hedef makinada -f%sleading-underscore desteklenmiyor"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "döküm dosyası %qs açılamadı: %s"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the \"%s\" debug format"
 msgid "target system does not support the %qs debug format"
 msgstr "hedef sistem \"%s\" hata ayıklama biçimini desteklemiyor"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "değişken izleme istendi, ama hata ayıklama bilgisi üretilmeksizin faydasız"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "değişken izleme istendi, ama bu hata ayıklama biçimi tarafından desteklenmiyor"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "bu hedefte -ffunction-sections desteklenmiyor"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays bu hedef için desteklenmiyor (-march seçeneğini deneyin)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays, -Os ile desteklenmiyor"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "bu hedefte -fstack-protector desteklenmiyor"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attributes are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "%Jbölüm öznitelikleri bu hedef için desteklenmiyor"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "%s yazılırken hata: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "%s kapatılırken hata: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -29701,195 +29754,195 @@ msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 msgid "ignoring loop annotation"
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR değişirken sabit yeniden hesaplanmadı"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR değişirken yan etkiler yeniden hesaplanmadı"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "adres alındı, ama ADDRESSABLE biti etkin değil"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression for min lvalue"
 msgstr "terim olarak ifade geçersiz"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in indirect reference"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "In function %qs:"
 msgid "non-scalar %qs"
 msgstr "%qs işlevinde:"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid position or size operand to %qs"
 msgstr "kısıtlar terim için geçersiz"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "%qs of non-mode-precision operand"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "type mismatch in %qs reference"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "%%R için terim geçersiz"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "type mismatch in %qs"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%f operand"
 msgid "invalid %qs offset operator"
 msgstr "geçersiz %%f terimi"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "conversion of register to a different size in %qs"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid address operand in %qs"
 msgstr "%%R için terim geçersiz"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid offset operand in %qs"
 msgstr "%%R için terim geçersiz"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "%qD kullanımı geçersiz"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "basit IF"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid function in gimple call"
 msgstr "işlev bildirimi geçersiz"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "function not inlinable"
 msgid "non-function in gimple call"
 msgstr "işlev satıriçine alınabilir değil"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid pure const state for function"
 msgstr "%qs işlevi için geçersiz saklama sınıfı"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PC in line number table"
 msgid "invalid LHS in gimple call"
 msgstr "satır numarası tablosunda geçersiz program sayacı (PC)"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion in gimple call"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PC in line number table"
 msgid "invalid static chain in gimple call"
 msgstr "satır numarası tablosunda geçersiz program sayacı (PC)"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -29900,577 +29953,577 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument to gimple call"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operands in gimple comparison"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "bir işlev döndüren işlev"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "invalid vector comparison resulting type"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in unary operation"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "invalid vector types in nop conversion"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "invalid types in nop conversion"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid types in address space conversion"
 msgstr "terim olarak ifade geçersiz"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid types in fixed-point conversion"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid types in conversion to floating-point"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid types in conversion to integer"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in %qs expression"
 msgstr "koşullu ifadede tür uyumsuzluğu"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid types for %qs"
 msgstr "%q+D için soyut tür geçersiz"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, fuzzy, gcc-internal-format
 #| msgid "Elemental binary operation"
 msgid "non-register as LHS of binary operation"
 msgstr "Öğesel ikilik işlem"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "invalid operands in binary operation"
 msgstr "iki terimli %s için terimler geçersiz"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid non-vector operands to %qs"
 msgstr "%%R için terim geçersiz"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "vector type expected in %qs"
 msgstr "ifade umuluyordu"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in binary expression"
 msgstr "koşullu ifadede tür uyumsuzluğu"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operands in ternary operation"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "vector types expected in %qs"
 msgstr "ifade umuluyordu"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "vectors with different element number found in %qs"
 msgstr "?: için terimler farklı türde"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "geçersiz döngü komutu"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid position or size in %qs"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "%qs into non-mode-precision operand"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qs not at element boundary"
 msgstr "%q+D bir işlev değil,"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "%qs LHS in clobber statement"
 msgstr "deyim umuluyordu"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R için terim geçersiz"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid indirect memory address"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "geçersiz dolaylı bellek adresi"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of vector %qs elements"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "PHI def is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI tanımı bir GIMPLE değeri değil"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "non-vector %qs with elements"
 msgstr "?: için terimler farklı türde"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "always-false koşuluyla ASSERT_EXPR"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in the instruction"
 msgid "invalid operand in return statement"
 msgstr "komuttaki terim geçersiz"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid conversion in return statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "goto destination is neither a label nor a pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to switch statement"
 msgstr "%%s kodu için terim geçersiz"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code for huge switch statements"
 msgid "non-integral type switch statement"
 msgstr "huge switch deyimleri için kod üretilir"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 #| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr ""
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid case range in switch statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 #| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "format string has invalid operand number"
 msgid "incorrect setting of landing pad number"
 msgstr "biçim dizgesi geçersiz sayıda terim içeriyor"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%p code"
 msgid "invalid comparison code in gimple cond"
 msgstr "%%p kodu için terim geçersiz"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in increment"
 msgid "invalid labels in gimple cond"
 msgstr "arttırmada geçersiz sol taraf"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid address"
 msgid "invalid %<PHI%> result"
 msgstr "adres geçersiz"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "missing %<PHI%> def"
 msgstr "tanım eksik"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid %<PHI%> argument"
 msgstr "IACC argümanı geçersiz"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "atamada uyumsuz türler"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_stmts başarısız"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (phi) is set to a wrong basic block"
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "bb_for_stmt (phi) yanlış temel bloka atanmış"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "PHI node with location"
 msgstr "buradan"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, fuzzy, gcc-internal-format
 #| msgid "bb_for_stmt (stmt) is set to a wrong basic block"
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "bb_for_stmt (stmt) yanlış temel bloka atanmış"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "deyim yakalama için imli, ama olmuyor."
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "Deyim blokun ortasında yakalama için imlenmiş"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "verify_gimple failed"
 msgstr "verify_stmts başarısız"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY_BLOCK has a statement list associated with it"
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK onunla ilişkili bir deyim listesi içeriyor"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, fuzzy, gcc-internal-format
 #| msgid "EXIT_BLOCK has a statement list associated with it"
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK onunla ilişkili bir deyim listesi içeriyor"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "bb %d deki çıkışa düşüş"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr ""
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "%d. temel blokun ortasında denetim akışı"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "bb %d içinde bir denetim deyimi sonrası düşen kenar"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fallthru edge after a control statement in bb %d"
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "bb %d içinde bir denetim deyimi sonrası düşen kenar"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "bb %d sonunda çıkan ayrıt bayrağı sayısı yanlış"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "bb %d sonunda açıkça goto"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "dönüş ayrıtı bb %d içindeki çıkışı göstermiyor"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, fuzzy, gcc-internal-format
 #| msgid "found default case not at end of case vector"
 msgid "found default case not at the start of case vector"
 msgstr "default case, case vektörünün sonunda değil"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 #| msgid "case labels not sorted:"
 msgid "case labels not sorted: "
 msgstr "sırasız case etiketleri:"
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "fazladan çıkan ayrıt %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "ayrıt %i->%i eksik"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> işlev değer döndürüyor"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcontrol reaches end of non-void function"
 msgid "control reaches end of non-void function"
 msgstr "%Hdenetim void olmayan işlevin sonunu aşıyor"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -30487,53 +30540,53 @@ msgstr "%q+D için yeniden tanımlama"
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i yakalanamıyor ama EH ayrıtları var"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "BB %i yakalanamıyor ama EH ayrıtları var"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i son deyiminin bölgesi yanlış belirlenmiş"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unnecessary EH edge %i->%i"
 msgid "Incorrect EH edge %i->%i"
 msgstr "gereksiz EH ayrıtı %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "düşen ayrıtta yanlış komut"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i has incorrect edge"
 msgstr "BB %i son deyiminin bölgesi yanlış belirlenmiş"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -31065,12 +31118,12 @@ msgstr "eniyileme aşamasından sonra değişmiş olarak imlenmiş deyim (%p):"
 msgid "verify_ssa failed"
 msgstr "verify_ssa başarısız"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -31139,7 +31192,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -31150,31 +31203,31 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -31250,37 +31303,37 @@ msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:13103
+#: tree.c:13105
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:13106
+#: tree.c:13108
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:13112
+#: tree.c:13114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tür önerilmiyor"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tür önerilmiyor"
@@ -31305,237 +31358,237 @@ msgstr "tür önerilmiyor"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with graph file\n"
 msgid "first mismatch is field"
 msgstr "%s: zaman damgası çizge dosyası ile çelişiyor\n"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "type is not compatible with its variant"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "main variant is not defined"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -31669,93 +31722,93 @@ msgstr "%q+D için istenen hizalama gerçeklenmiş hizalama %wu'den daha büyük
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for integer value is too complicated"
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "tamsayı değer için ilklendirici fazla karmaşık"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "gerçel sayı için ilklendirici bir gerçel sayı sabit değil"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initial value for member %qE"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D çağrıdan sonra satıriçi bildirilmiş"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D zayıf bildirimi 'public' olmalı"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "%q+D zayıf bildirimi desteklenmiyor"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "bu yapılandırmada sadece zayıf takma adlar destekleniyor"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref is not supported in this configuration"
 msgid "weakref is not supported in this configuration"
 msgstr "%Jweakref bu yapılandırmada desteklenmiyor"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "weakref %q+D eninde sonunda kendini hedefliyor"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %qD to have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "alias definitions not supported in this configuration"
 msgstr "%Jtakma ad tanımlamaları bu yapılandırmada desteklenmiyor"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s bu yapılandırma ile desteklenmiyor"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "görünürlük özniteliği bu yapılandırmada desteklenmiyor; yoksayıldı"
@@ -32409,7 +32462,7 @@ msgstr "%qE özniteliği %qE için yoksayıldı"
 msgid "type was previously declared %qE"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -32433,7 +32486,7 @@ msgstr "assert: %s %s ile uyumlu atanıyor"
 msgid "%qE argument is not a function"
 msgstr "cleanup argümanı bir işlev değil"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
@@ -32838,12 +32891,12 @@ msgstr "gerçeklenim bağlamında %<@end%> eksik"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "atamayı sarmalayan parantezler muhtemelen doğruluk değeri olarak kullanılmış"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> kullanımı geçersiz"
@@ -33009,12 +33062,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -33128,7 +33181,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
@@ -33138,81 +33191,81 @@ msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın tamsayıdan gösterici yapılıyor"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "both arguments must be compatible"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 #| msgid "Substring end index at %L is out of bounds"
 msgid "index value is out of bound"
 msgstr "%L'deki altdizge son indisi sınırların dışında"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -33220,58 +33273,58 @@ msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qE must be directly called"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "dizi boyutu negatif"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -33330,540 +33383,540 @@ msgstr "%qE biçim işlevi türü bilinmiyor"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "biçim dizgesi argümanı biçimlendirilecek argümanları izliyor"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "işlev, %qs biçim özniteliği için olası aday olabilir"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "biçim dizgesi içinde $ teriminde numara eksik"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s  %%n$ terim numaralama biçimlerini desteklemez"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "biçim dizgesi içindeki terim numarası aralık dışında"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "%d. biçim argümanı %s biçiminde birden fazla kullanılmış"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$ terim numarası terim numarası olmaksızın biçimden sonra kullanılmış"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "%d. biçim argümanı $ tarzi biçimde %d. argümandan önce kullanılmamış"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "biçim bir dizge sabiti değil, biçim dizgesi denetlenmedi"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "biçim bir dizge sabiti değil ve biçim argümanları yok"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "biçim bir dizge sabiti değil, argüman türleri denetlenmedi"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "sıfır uzunluklu %s biçim dizgesi"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "biçim bir geniş karakter dizgesi"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "format string argument not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "biçim dizgesinin argümanı bir dizge türü değil"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "sonlandırılmamış biçim dizgesi"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s %<%%%c%> %s biçimi ile kullanılmış"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s %s desteği vermiyor"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s %s'i %<%%%c%> %s biçimiyle desteklemiyor"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "biçim içinde %s yinelenmiş"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "strfmon biçiminin sonunda dolgu karakteri eksik"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "%s biçiminde sıfır uzunluk"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "%s biçiminde sol taraf hassasiyeti boş"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "%s biçiminde boş hassasiyet"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s %qs %s uzunluk değiştiricisini desteklemiyor"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s, `%<%%%c%> %s biçimini desteklemiyor"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s, %s ile %<%%%c%> %s biçimiyle yoksayıldı"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s, %s ile %s biçiminde yoksayıldı"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "%s ve %s birlikte %<%%%c%> %s biçiminle kullanımı"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "%s ve %s birlikte %s biçiminde kullanımı"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> bazı yerellerde yılın son iki hanesini alır"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> yılın sadece son iki hanesini alır"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "%<%%[%> biçimi için kapatan %<]%> yok"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "%qs uzunluk değiştiricinin %qc tür karakteri ile kullanımı"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s, %<%%%s%c%> %s biçimini desteklemiyor"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "terim numarası engellenmiş atama ile belirtilmiş"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "terim numarası argüman almayan biçim için belirtilmiş"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "biçim içinde %s yinelenmiş"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "biçim içinde %s yinelenmiş"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "biçim içinde gömülü %<\\0%>"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "multiple function type attributes specified"
 msgid "unquoted attribute in format"
 msgstr "çok sayıda işlev türü öznitelik belirtilmiş"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "biçimde şüpheli %<%%%> kuyruğu"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "inconsistent capitalization in format"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "biçimde şüpheli %<%%%> kuyruğu"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "biçim içinde %s yinelenmiş"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "biçim içinde %s yinelenmiş"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "biçim içinde %s yinelenmiş"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "biçimde şüpheli %<%%%> kuyruğu"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "biçimde şüpheli %<%%%> kuyruğu"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "unquoted non-graph characters in format"
 msgstr "Ek: %L'deki FORMAT etiketindeki değer karakter değil"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Do not generate #line directives"
 msgid "unterminated quoting directive"
 msgstr "#'li satır yönergeleri üretilmez"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "biçimdeki dönüşüm türü karakteri %qc bilinmiyor"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "biçimde şüpheli %<%%%> kuyruğu"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "dönüşüm, biçim sonunda türden yoksun"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "#ident yönergeleri işlenir"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "biçim içinde gömülü %<\\0%>"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "sonlandırılmamış çevirici aksan alternatifi"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "boş gösterici vasıtasıyla yazma (%d. argüman)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "boş gösterici vasıtasıyla okuma (%d. argüman)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "sabit nesneye yazma (%d. argüman)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "biçim argümanında (%d. argüman) fazladan tür niteleyiciler"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%s%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%q.*s biçiminin %<%s%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs için bir sabit argüman beklenir"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs için bir sabit argüman beklenir"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%>, %<long%> veya %<long long%> olarak tanımlı değil"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "biçimlenecek argümanlar %<...%> değil"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime biçimleri argümanları biçimleyemez"
@@ -34034,7 +34087,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -34052,18 +34105,18 @@ msgstr "%qE özniteliği için vektör türü geçersiz"
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
@@ -34074,7 +34127,7 @@ msgstr "atama engelleme"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -34741,7 +34794,7 @@ msgid "wrong type argument to %s"
 msgstr "abs'a yanlış türde argüman"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "sabit ifadesinde taşma"
@@ -35497,7 +35550,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
@@ -35585,7 +35638,7 @@ msgid_plural "passing argument %i to %qs-qualified parameter aliases with argume
 msgstr[0] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 msgstr[1] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -35605,7 +35658,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "defined here"
@@ -35627,7 +35680,7 @@ msgstr "\"%s\" önişlemci için geçerli bir seçenek değil"
 msgid "too many input files"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -35661,15 +35714,15 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s"
@@ -36239,432 +36292,439 @@ msgstr "takma ad tanımlamaları Mach-O'da desteklenmiyor; yoksayıldı"
 msgid "profiler support for VxWorks"
 msgstr "VxWorks için profilci desteği"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "multilib desteklenmiyor"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use hardware floating point"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "Donanım kayan nokta aritmetiği kullanılmaz"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the bit-field instructions"
 msgid "this operation requires the SVE ISA extension"
 msgstr "Bit alanı komutları kullanılmaz"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cray Pointer extension"
 msgid "%qE requires the SVE ISA extension"
 msgstr "Cray Göstericisi eklentisi kullanılır"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "%%h değeri geçersiz"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid floating point option: -mfpu=%s"
 msgid "tuning string missing in option (%s)"
 msgstr "geçersiz gerçel değer seçeneği: -mfpu=%s"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "bilinmeyen '%s' spec işlevi"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s;"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 #| msgid "missing filename after %qs"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs den sonra dosyaismi yok"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib desteklenmiyor"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> bozuk"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -36866,17 +36926,17 @@ msgstr "%qs özniteliğinin argümanı \"ilink1\" ya da \"ilink2\" değildir"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qs özniteliğinin argümanı \"ilink1\" ya da \"ilink2\" değildir"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -37046,13 +37106,13 @@ msgstr "%qs makine kipi bilinmiyor"
 msgid "invalid type for %<asm%> flag output"
 msgstr "tür argümanı geçersiz"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "options enabled: "
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "etkin seçenekler: "
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -37060,198 +37120,198 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "this builtin is not supported for this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "seçici bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -37261,311 +37321,311 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fpic ve -mapcs-reent uyumsuz"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support ARM mode"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "geri izleme desteğinin etkinleştirilmesi sadece Thumb komut seti için derleme yapılırken anlamlidir"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "çağrılan ile birlikte çalışma desteğinin etkinleştirilmesi sadece Thumb için derleme esnasında anlamlıdır"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g ile -mno-apcs-frame anlamlı hata ayıklama bilgisi vermeyebilir"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with -mthumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "-mtp=cp15, -mthumb ile kullanılamaz"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-G is incompatible with PIC code which is the default"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-G öntanımlı olan PIC kodu ile uyumsuz"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check ile -mno-apcs-frame uyumsuz"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic ve -mapcs-reent uyumsuz"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS yeniden girişli kod desteklenmiyor. Yoksayıldi"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register=, -fpic olmaksızın kullanışsız"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "PIC yazmacı için '%s' kullanılamıyor"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition bu mimaride çalışmaz"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable ile -msdata=%s uyumsuz"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt, düzgün işlem için ABI uyumlu bir AAPCS gerektiriyor"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi bir iwmmxt yetenekli işlemci gerektiriyor"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard ve VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "yığıttaki parametrenin gerçek konumu hesaplanamıyor"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Beklenmeyen modül sonu"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "yüksek yazmaçları çekmeye elverişli düşük yazmaç yok"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -37574,24 +37634,24 @@ msgstr "%qs özniteliğinin argümanı geçersiz"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
@@ -37682,19 +37742,19 @@ msgstr "-pipe desteklenmiyor"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G ve -static birlikte kullanılamaz"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
@@ -37990,7 +38050,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument to built-in function"
@@ -38349,57 +38409,57 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "FP argümanları FP yazmaçlarında aktarılır"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to abs"
 msgid "wrong type of argument %s"
 msgstr "abs'a yanlış türde argüman"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "bu hedefte -ffunction-sections desteklenmiyor"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "TLS is not implemented for GCN."
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "sorry, unimplemented: "
 msgid "Builtin not implemented"
 msgstr "özür, daha gerçeklenmedi: "
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "terim numarası aralık dışında"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -38552,153 +38612,153 @@ msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 msgid "parameter to builtin not valid: %s"
 msgstr "-ffpe-trap seçeneğinin argümanı geçersiz: %s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "shift bir anlık değer olmalı"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "yanlış komut:"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "yanlış komut:"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -39124,161 +39184,161 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "'-%c' option must have argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "'-%c' seçeneğinde argüman eksik"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -39773,7 +39833,7 @@ msgstr "Sayısal sabit, %C özniteliklerine sahip olamaz"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string argument"
@@ -40946,55 +41006,55 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -41117,368 +41177,369 @@ msgstr "sayı 0 ya da 1 olmalı"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "'#pragma longcall' sonunda karışıklik"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "builtin %qs requires builtin %qs"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s bu yapılandırma ile desteklenmiyor"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "AltiVec yerleşiği için parametre birleşimi geçersiz"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından döndürüldü: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından aktarıldı: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs bu alt hedef tarafından desteklenmiyor"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%H%D için son argüman 0 .. 3 arasında bir tamsayı sabit değil"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-#| msgid "this builtin function is only available on the fr450"
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "%L'deki ATANH argümanı -1 .. 1 aralığının içinde kalmalı"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "Altivec yerleşiği %qF için çözümlenmemiş aşırı yükleme"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "%qs is only valid for the cell processor"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "%qs requires the %qs option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 #| msgid "Use the bit-field instructions"
 msgid "%qs requires the %qs and %qs options"
 msgstr "Bit alanı komutları kullanılır"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point"
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "%qs is not supported with the current options"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "iç hata: yan etkili komut main etkisi oluşturuyor"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
@@ -41500,243 +41561,248 @@ msgstr "%<__thread%> %<register%> ile kullanılmış"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "%qs requires %qs or %qs"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 seçeneği PowerPC64 mimarisini gerektirir, etkinleştiriliyor"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 64 bitlik Darwin için desteklenmiyor; kurulu C ve C++ kütüphaneleri ile uyumsuz"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring kıymetsiz baytın başta olduğu sistemlerde desteklenmez"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "TI araçları ile uyumlu kod üretilir"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s %s desteği vermiyor"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs geçerli bir sınıf ismi değil"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Çağrı taşırmalı hedef yazmacı gerekir"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for %<%s=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
@@ -42087,148 +42153,148 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Yerel değişkenlerin toplam boyutu mimarinin izin verdigi sınırı aşıyor"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs çerçevi boyutu "
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs özdevimli yığıt tahsisi kullanıyor"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware vector support not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float bir arada desteklenmiyor"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "yığıt boyutunun yığıt koruma değerinden büyük olması gerekir"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard, -mstack-size uyguluyor"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -42692,8 +42758,8 @@ msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 msgid "could not read the BRIG file"
 msgstr "belirtim dosyası %s bulunamadı\n"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void değer yoksayılması gerekirken yoksayılmadı"
@@ -42987,7 +43053,7 @@ msgstr "%qD bildirimi bir önceki değişken olmayan bildirimi gölgeliyor"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
@@ -43065,7 +43131,7 @@ msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Bildirilmemiş her betimleyici görüldüğü her işlev"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qE yaftası işlev dışına başvuruyor"
@@ -43097,7 +43163,7 @@ msgstr "deyim ifadesine jump"
 msgid "duplicate label declaration %qE"
 msgstr "%qE yaftası bildirimi yinelenmiş"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "yinelenmiş %qD yaftası"
@@ -43320,7 +43386,7 @@ msgstr "oynak alanlı nesne yazmaça konulamaz"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -43704,7 +43770,7 @@ msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
@@ -44044,7 +44110,7 @@ msgstr "%<struct %E%> iç içe yeniden tanımlanmış"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
@@ -44096,7 +44162,7 @@ msgstr "yapı hiç isimli üye içermiyor"
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -44136,7 +44202,7 @@ msgstr "%<enum %E%> iç içe yeniden tanımlanmış"
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> yeniden bildirilmiş"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -44168,7 +44234,7 @@ msgstr "sembolik sabit listesi değerlerinde taşma"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -44202,7 +44268,7 @@ msgstr "%q+D için önceki prototip yok"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -44333,12 +44399,12 @@ msgstr "%qD argümanı yerleşik prototiple eslesmiyor"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -44347,282 +44413,282 @@ msgstr "%qD parametresi ilklendirilmiş"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> döngüsünün ilk bildirimi C99 kipinin dışında kullanılmış"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde statik değişken %q+D bildirimi"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde değişken olmayan %q+D bildirimi"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE yinelenmiş"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE bir typedef veya yerleşik veri türü olarak başarısız"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s %s desteği vermiyor"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<static%>  öncesinde %<__thread%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "bildirim belirteçlerinde çok sayıda saklama sınıfı"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@catch%> veya %<@finally%> olmaksızın %<@try%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "sağa kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -44644,7 +44710,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "%J  diğer tür burada"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -44694,7 +44760,7 @@ msgid "unknown type name %qE"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -44716,7 +44782,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -44734,8 +44800,8 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 msgid "unexpected attribute"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -44777,7 +44843,7 @@ msgstr "dosya etki alanı boş bildiriminde %<auto%>"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
@@ -44807,7 +44873,7 @@ msgstr "ISO C90 %<long long%>'u desteklemez"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "dizge sabiti umuluyordu"
@@ -44842,7 +44908,7 @@ msgstr "bütünleyen ifade %qE bir sabit değil"
 msgid "static assertion failed: %E"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
@@ -44892,14 +44958,14 @@ msgstr "%d. şablon argümanı geçersiz"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "sembolik sabitler listesinin sonunda virgul"
@@ -44986,7 +45052,7 @@ msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not take any arguments"
@@ -44998,7 +45064,7 @@ msgstr "%qs özniteliği veri türlerine uygulanmaz"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -45060,7 +45126,7 @@ msgstr "%HISO C90 kod ve bildirimlerin karışmasına izin vermez"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -45075,7 +45141,7 @@ msgstr "bileşik ifadenin sonunda yafta kullanımı"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "deyim umuluyordu"
@@ -45101,19 +45167,19 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr "betimleyici veya %<*%> umuluyordu"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hif deyiminin gövdesi boş"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%Helse gövdesi boş"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -45135,12 +45201,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -45157,8 +45223,8 @@ msgstr "işlev çağrısında gözcü eksik"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -45189,12 +45255,12 @@ msgstr "ISO C ?: üç terimlisinin orta teriminin atlanmasına izin vermez"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -45625,67 +45691,67 @@ msgstr "bildirim belirteçleri umuluyordu"
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jadres alanı özelliği işlevler için belirtilemez"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -45695,20 +45761,20 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -45732,61 +45798,61 @@ msgstr "%<,%> veya %<;%> umuluyordu"
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -45810,13 +45876,13 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<grainsize%> value must be positive"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<priority%> value must be non-negative"
@@ -45828,23 +45894,23 @@ msgstr "%s' (%L'de) bir değişmez olmalıdır"
 msgid "expected constant integer expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -45861,58 +45927,58 @@ msgstr "%L'deki ifade değişmez olmalı"
 msgid "%qs value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many %<static%> arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "unexpected argument"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -45923,7 +45989,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -45959,25 +46025,25 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -45995,84 +46061,84 @@ msgstr "geçersiz döngü komutu"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "invalid OpenACC clause at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -46089,7 +46155,7 @@ msgstr "%qD bildirilmemişti"
 msgid "expected function name"
 msgstr "umulmadık düğüm"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -46101,74 +46167,74 @@ msgstr "%qD bir üye şablon işlevi değil"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many memory order clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -46179,64 +46245,64 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<:%>, %<,%>, %<;%>, %<}%> veya %<__attribute__%> umuluyordu"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
@@ -46247,76 +46313,76 @@ msgstr "bildirim veya deyim umuluyordu"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -46333,64 +46399,64 @@ msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected trait selector name"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "score argument must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "score argument must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "property must be constant integer expression or string literal"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "property must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
@@ -46402,13 +46468,13 @@ msgstr "%<{%> umuluyordu"
 msgid "variant %qD is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -46419,35 +46485,35 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -46504,45 +46570,45 @@ msgstr "betimleyici veya %<(%> umuluyordu"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "%<large%> kod modeli henüz desteklenmiyor"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -46558,30 +46624,30 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -46591,7 +46657,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -46607,7 +46673,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void ifade kullanımı geçersiz"
@@ -46735,7 +46801,7 @@ msgstr "%<void *%> gösterici ilişkilendirmesi"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "dizi indisi bir tamsayı değil"
@@ -46760,7 +46826,7 @@ msgstr "ISO C90 sol tarafsız dizi indislemesine izin vermez"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -46881,19 +46947,19 @@ msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%q+D zayıf bildirimi ilk kullanımdan sonra belirsiz davranışla sonuçlanıyor"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "gösterici ile tamsayı arasında karşılaştırma"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -46920,7 +46986,7 @@ msgstr "çıkartmada işlev göstericisi kullanılmış"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -47187,7 +47253,7 @@ msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "farklı boyuttaki tamsayı türden göstericiye dönüşüm"
@@ -47376,7 +47442,7 @@ msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
@@ -47551,7 +47617,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "dizge sabitten ilgisiz türde ilklendirilmiş dizi"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
@@ -47583,7 +47649,7 @@ msgstr "ilkledirici öğe yükleme sırasında hesaplanabilir değil"
 msgid "invalid initializer"
 msgstr "geçersiz ilklendirici"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
@@ -47732,7 +47798,7 @@ msgstr "skalar ilklendiricide gereğinden fazla öğe"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
@@ -47775,7 +47841,7 @@ msgstr "ISO C'de %<long%> switch ifadesi %<int%> türüne dönüştürülmez"
 msgid "case label is not an integer constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
@@ -47785,17 +47851,17 @@ msgstr "case etiketi bir switch deyimi içinde değil"
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
@@ -47813,7 +47879,7 @@ msgstr "break deyimi switch ya da döngü içinde değil"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "deyim etkisiz"
@@ -47823,23 +47889,23 @@ msgstr "deyim etkisiz"
 msgid "expression statement has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -47893,7 +47959,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
@@ -47925,57 +47991,57 @@ msgstr "doğrudan değer gereken yerde union türünde değer kullanılmış"
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -47987,8 +48053,8 @@ msgstr "'%s' geçerli bir sınıf ismi değil"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
@@ -48175,12 +48241,12 @@ msgstr "%qD ile ilişkilendirme belirsiz"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -48206,8 +48272,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
@@ -48223,19 +48289,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -48312,123 +48378,123 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of %<->%> is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%>'ın ilk argümanının türü %<va_list%> değil"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -48640,870 +48706,870 @@ msgid "expected case label"
 msgstr "sınıf ismi umuluyordu"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T, %T) <yerleşik>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s %D(%T, %T) <yerleşik>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s %D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s %D(%T) <yerleşik>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s %T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s %T <dönüşüm>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D <near match>"
 msgid "%s%#qD (near match)"
 msgstr "%s %+#D <yakın eşleşme>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr ""
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr ""
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  inherited here"
 msgstr "%J  burada ilklendirildiğinde"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument deduction/substitution failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE %qT türüne dönüştürülemedi"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%D(%A)%> çağrısı belirsiz"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "üye göstericisi işlevi %E nesnesiz çağrılamaz; .* or ->* kullanımı önerilir"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> çağrısı için eşleşme yok"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> çağrısı belirsiz"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "dizi indisi için dönüşüm belirsiz"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types %qT and %qT to binary %qO"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Kullanıcı işleçleri:\n"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%2$E ? %3$E : %4$E%> içindeki %<?: üç terimlisi%> için %1$s"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<%3$E%4$s%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%2$E[%3$E]%> içindeki %<[] işleci%> için %1$s"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%<%3$s %4$E%> içindeki %2$qs için %1$s"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator %s%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<%3$s%4$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%3$E %4$s %5$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<%3$s%4$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ bir ?: üç terimlisinde ikinci terimin eksikliğine izin vermez"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ile %q#T arasında karşılaştırma"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%2$qT için uygun bir %<%1$s işleci%> yok"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D erişilebilir değil"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "%2$qD işlevinin gösterici olmayan %1$P argümanına NULL aktarılması"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL'dan gösterici olmayan %qT türüne dönüşüm"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  %2$qD işlevinin %1$P argümanının ilklendirilmesi"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 #| msgid "converting to %qT from %qT"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "%qT türüne %qT türünden dönüşüm"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "%qE bitalanı %qT türüne bağlanamaz"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "%qE paketli alanı %qT türüne bağlanamaz"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "sağ taraf değeri %qE, %qT türüne bağlanamaz"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden aktarılamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD işlevinin %1$d. parametresi için öntanımlı argüman henüz çözümlenmedi"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  %qD çağrısında"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "; use value-initialization instead"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Ek:`%s' için (%L'de) yeniden ilklendirme"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%s(%A)%> çağrısı belirsiz"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from constructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from destructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "üye işlev %qD nesne olmaksızın çağrılamaz"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qT aktarımı %qT türünü %qT türü üzerinden seçiyor"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD %qD üzerinden,"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  çünkü argüman için dönüşüm süreci daha iyi"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -49539,574 +49605,574 @@ msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with function declaration %q#D"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "işlev bildirimi %q#D ile çelişiyor"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with function declaration %q#D"
 msgid "version inherited from %qT declared here"
 msgstr "işlev bildirimi %q#D ile çelişiyor"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D,"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "%q+D yöntemi için erişim özellikleri çelişkili, yoksayıldı"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "%qE alanı için erişim özellikleri çelişkili, yoksayıldı"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  çünkü yerel yöntem %q+#D ile ismi aynı"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "local method %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  çünkü yerel üye %q+#D ile aynı isimde"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "local member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "sınıf %qT içindeki tüm üye işlevler 'private'"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T sadece private bir yıkıcı tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T sadece private kurucular tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD için %qT içinde eşsiz bir son değiştirici yok"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D,"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  %q+D tarafından gizlendi"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "bit-alanı %q+#D tümleyen türde değil"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit alanı %q+D için genişlik bir tamsayı sabit değil"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bit alanı %q+D için genişlik negatif"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bit alanı %q+D için sıfır genişlik"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D kendi türünden geniş"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D alanı %#T türünün tüm değerlerini tutmak için çok küçük"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "union içinde kuruculu üye %q+#D olamaz"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "union içinde yıkıcılı üye %q+#D olamaz"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "union içinde kopya atama isleçli üye %q+#D olamaz"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D bir union üyesi olduğundan static olmayabilir"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "%q+D alanı ile geçersiz olarak işlev türü bildirildi"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute on unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "paketsiz POD olmayan %q+#D alanı üzerinde paketli öznitelik yoksayılıyor"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "union %qT içinde çok sayıda alan ilklendirildi"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "initialized member %q+D declared here"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "%q+#D alanı sınıf ile aynı isimde"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T gösterici veri üyeleri içeriyor"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  ama %<%T(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ya da %<operator=(const %T&)%> içeriyor"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  ama %<operator=(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "sanal olmayan yöntem %q+D için ilklendirici belirtilmiş"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "%q+T is not literal because:"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has volatile type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan başvuru %q+#D"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan sabit üye %q+#D"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "doğrudan taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "sanal taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D alanının göreli konumu ABI-uyumlu değil ve bu GCC'nin gelecek sürümünde değişebilir"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "array member %q#D declared here"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T sanal olmayan kuruculu sanal işlevler içeriyor"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "yapı tamamlanmaya çalışılırken önceki ayrıştırma hatalarından dolayı kesildi"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "dil dizgesi %<\"%E\"%> tanınmıyor"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "%2$qT türüne dönüşüme dayalı aşırı yüklü %1$qD işlevi çözümlenemiyor"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "%qD işlevinin %q#T türüne dönüşümü için eşleşme yok"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "aşırı yüklü %qD işlevinin %q#T türüne dönüşümü belirsiz"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD üyesine gösterici varsayılıyor"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE ifadesi %qT türünden %qT türüne dönüştürülemez"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -50197,7 +50263,7 @@ msgstr "dosya etki alanı boş bildiriminde %<register%>"
 msgid "%q+E is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
@@ -50260,7 +50326,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%qD bildirimi önceki yereli gölgeliyor"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
@@ -50325,424 +50391,423 @@ msgstr "bütünleyen ifade %qE bir sabit değil"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "allocated here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "no field %qD found in union being initialized"
 msgid "%qD used in its own initializer"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%q#D is not const"
 msgstr "%q+D bir işlev değil,"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D private'dir"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline assembly is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "unexpected template-id %qE"
 msgstr "deyim umuluyordu"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "function not inlinable"
 msgid "function concept must be called"
 msgstr "işlev satıriçine alınabilir değil"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
 msgstr "'%s' de umulmadık dosya sonu"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a type"
 msgstr "%qD bir şablon değil"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -50796,7 +50861,7 @@ msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklend
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "%qT türünden %qT türüne dönüşüm gösterici başvurusunu kaldırmaz"
@@ -50840,321 +50905,321 @@ msgstr "bir gerçel sayı değer umulan yerde %q#T kullanılmış"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "%qT türünden skalar olmayan %qT türüne dönüşüm istendi"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "in call to %qD, declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "sözde yıkıcılar çağrılmaz"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "%2$qT tamamlanmamış türüne %1$qs uygulanması geçersiz"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "deyim etkisiz"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT tünüden öntanımlı türe dönüşüm belirsiz"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  aday dönüşümler %qD ve %qD içeriyor"
@@ -51227,7 +51292,7 @@ msgstr "önceki %q+F bildirimindeki farklı olağandışılıkları yakalıyor"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -51439,12 +51504,12 @@ msgstr "%qD'nin önceki bildirimi buradaydı"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD"
@@ -51458,50 +51523,50 @@ msgstr "%q+D için yeniden tanımlama"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: görünürlük özniteliği yoksayıldı çünkü"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%q#D not declared in class"
 msgstr "%qD bildirilmemiş"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -51509,725 +51574,725 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q+D'nin yerel-evreli bildirimi yerel-olmayan-evreli bildirimi izliyor"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q+D'nin yerel-olmayan-evreli bildirimi yerel-evreli bildirimi izliyor"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous label"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  buradan"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  %q+#D ilklendirmesini kesiyor"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  catch blokuna giriyor"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a template"
 msgid "%q#T is not a class"
 msgstr "%q#T bir şablon değil"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde sınıf şablonu yok"
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "trampolines desteklenmiyor"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kuruculu üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde yıkıcılı üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kopya atama isleçli üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T için öznitelik %qs anahtar sözcüğünü izlemeli"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "bir bildirimde birden fazla tür"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++ yerleşik türü %qT için yeniden bildirim"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef bildiriminde tür ismi eksik"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ anonim yapıları (struct) yasaklar"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sadece kurucular için belirtilebilir"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ %<%T::%D%>nin %<%T::%D%> olarak tanımlanmasına izin vermez"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "%qD ilklendirmesi yinelenmiş"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "%q#D değişkeni ilklendirilmiş ama içi boş türde"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "küme %q#D içi boş türde olup tanımlı olamaz"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "alelade olmayan ilklendiriciler desteklenmiyor"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  ilklendiriciyi kaldırarak bunun olurunu bulabilirsiniz"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "%qs türü bir kullanıcı tanımlı yapıcıya sahip"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "%2$qT türündeki bir vektör için ilklendirici olarak %1$qT türü geçersiz"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "geçersiz ilklendirici"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 bileşik sabitlere izin vermez"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD bir kurucu ile ilklendirilmeli, %<{...}%> ile değil"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "parantezli dizge sabiti %2$qE ile ilklendirilmiş %1$qD dizgesi"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "kuruculu statik üye için ilklendirici geçersiz"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(bir sınıf dışı ilklendirme gerekli)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "could not find variant declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "enumerator %q+D yeniden bildirilmiş"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "önceki %q#D tür bildirimini gölgeliyor"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "içi boş ture gösterici ilişkilendirme"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%u name provided for structured binding"
@@ -52235,211 +52300,211 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs yapı alan için saklama sınıfı belirtilmiş"
 msgstr[1] "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "in initialization of structured binding variable %qD"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot decompose union type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "adres çözümlenemez"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -52735,7 +52800,7 @@ msgstr "dizi boyutunda taşma"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
@@ -52922,7 +52987,7 @@ msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
@@ -53142,886 +53207,886 @@ msgstr "%qE özniteliği yoksayıldı"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "requires-clause on return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a member function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametre %q+D soyut %qT türünde bildirilemez"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "%s açılamıyor"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -54033,98 +54098,98 @@ msgstr "%qT türüne enum olarak başvuruluyor"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in the class %qT"
 msgid "%qT defined with multiple direct bases"
 msgstr "%qD zaten sınıf %qT içinde tanımlı"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
@@ -54133,79 +54198,79 @@ msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarı
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -54246,7 +54311,7 @@ msgstr "bir işlev silinemez. Sadece nesnelerin göstericileri %<delete%>'e konu
 msgid "deleting %qT is undefined"
 msgstr "%qT silinmesi tanımsız"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D şablon bildirimi"
@@ -54257,7 +54322,7 @@ msgstr "%q#D şablon bildirimi"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "yıkıcı %qD üye şablon olarak bildirilmiş"
@@ -54609,154 +54674,154 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "argüman yok"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "%<%T::%D%> ile ilişkilendirme belirsiz"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD, %qD nin bir üyesi değil"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD, %qD nin bir üyesi değil"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> bildirilmemişti"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> bildirilmemişti"
@@ -54951,365 +55016,365 @@ msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "initializer for flexible array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD üye ilklendirme listesinde ilklendirilmiş olmalı"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "sınıf %T kendisiyle dolaylı kardeş"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "taban %qT sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  taban %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  burada ilklendirildiğinde"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J%qD için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jtaban %qT için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J%qT'nin çok sayıda üyesi için ilklendirmeler"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D bir static veri üyesidir; sadece tanımında ilklendirilebilir"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "taban sınıfı olmayan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "çoklu miras kullanan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD  hem doğrudan hem de dolaylı sanal taban"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qT is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "içi boş tür %qT üye %qD'yi içermiyor"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "%qD bit alanına gösterici geçersiz"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "ifadede tamsayı taşması"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "new için %<void%> türü geçersiz"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "%2$qT sınıfında uygun bir %1$qD yok"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "üye %qD için istek belirsiz"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new bir referans türe uygulanamaz"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "ilklendirici erken sonlanıyor"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete içindeki dizi boyutu bilinmiyor"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
@@ -55482,13 +55547,13 @@ msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişe
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can't use default assignment operator"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "statik olmayan sabit üye %q#D, öntanımlı atama işleci kullanamaz"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can't use default assignment operator"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
@@ -55517,172 +55582,177 @@ msgstr "%q+D için çelişen türler"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "%qE özniteliği sadece Java sınıf tanımlarına uygulanabilir"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "%qE özniteliği sadece Java sınıf tanımlarına uygulanabilir"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD %<void%> almalı"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+#| msgid "%smember function %qD cannot have cv-qualifier"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "%süye işlev %qD cv niteleyicisini içeremez"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD zaten %qT'nin kardeşi"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot default compare union %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "referans üye %qD için gösterici oluşturulamaz"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsynthesized method %qD first required here "
 msgid "synthesized method %qD first required here"
 msgstr "%Hbireştirilmiş %qD yöntemi önce burada gerekli"
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "%1$J%<const%> %3$qT türü ile ilklendirilmemiş üye %2$qD"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "initializer for %q#D is invalid"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "expected signature: %qD"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "%q+#D bildirilemez"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "file ends in default argument"
 msgid "defaulted function %q+D with default argument"
@@ -55729,232 +55799,232 @@ msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "%q+#D genel bildirimi"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
 msgstr "önceki %q+#D bildirimiyle çelişiyor"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%q+D bildirimi kullanımı önceki bildirimlerden biri ile çelişiyor"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "enumerator %q+D yeniden bildirilmiş"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> yıkıcı isimlendiriyor"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared in %qE"
 msgstr "%qD bildirilmemişti"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD bildirimi %qD'yi kuşatan isim alanında değil"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD bildiriminde doğrudan niteleme"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD %qD içinde bildirilmeliydi"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%qD öznitelik yönergesi yoksayıldı"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%q+#D bildirilemez"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "it was later defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' simgesi (%L'de) belirsiz"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "burada isim alanı rumuzu %qD kullanılamaz, %qD varsayılıyor"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX, pop_everything () işlevine giriyor\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -55981,7 +56051,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -56009,7 +56079,7 @@ msgstr "%<::%D%> bildirilmemişti"
 msgid "request for member %qE in non-class type %qT"
 msgstr "sınıf olmayan %2$qT türündeki %1$qD üyesi için istek"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -56101,7 +56171,7 @@ msgstr "geçersiz şablon kimliği"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -56238,7 +56308,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -56369,7 +56439,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -56482,13 +56552,13 @@ msgstr "%2$qT üyesi olarak %<~%1$T%> bildirimi"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef ismi %qD yıkıcı bildiricisi olarak kullanılmış"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "belirteç niteleyici listesi umuluyordu"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bir şablon değil"
@@ -56528,7 +56598,7 @@ msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 msgid "expected nested-name-specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
@@ -56546,7 +56616,7 @@ msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -56562,7 +56632,7 @@ msgstr "ISO C++ birleşik sabitlere izin vermez"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD kullanımı geçersiz"
@@ -56590,1007 +56660,1012 @@ msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "parantezli tür kimliğinden sonra dizi sınırı yasak"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "eski tarz tür dönüşümü"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| içindeki && çevresinde parantezler önerilir"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Beklenmeyen modül sonu"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "%<this%> cannot be captured by reference"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case etiketi %qE bir switch deyimi içinde değil"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "condition declares a function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "fazladan %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "karışık bildirimler ve işlev tanımları yasaktır"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "boş bildirim"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for structured binding declaration"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D %q#T içinde geçersiz"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "type-specifier invalid in lambda"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in explicit-specifier"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "temel ilklendiricileri sadece kurucular alır"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "artık tarih olmuş eski tarz temel sınıf ilklendiricisi"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (bir nitelikli üye ilklendirici örtük olarak bir tür olduğundan)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "koşullu terim geçersiz"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
 msgstr "beklenmeyen terim"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> bir şablon argüman listesi başlatamaz"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ile %<[%> aynı şeyi gösterir. %<<%> ile %<::%> arasında boşluk bırakın"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid template-argument-list"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<(%> after template-argument-list"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
 msgstr "deyim umuluyordu"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "bir şablon olduğunu belirtmek için %<%T::template %D%> kullanın"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "C ilintileme ile şablon özelleştirmesi"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Umulmadık isim"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE bir türü isimlendirmiyor"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "concept defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "fazladan niteleme yoksayıldı"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "nested namespace name required"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD işlev etki alanı dışında tanımlı değil"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT bir isim alanı değil"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD işlev etki alanı dışında tanımlı değil"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function %qs"
 msgid "initializer provided for function"
 msgstr "kardeş işlev %qs ilklendirilemiyor"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -57600,479 +57675,479 @@ msgstr "%<%T::%D%> bir tür değil"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD bir isim alanıdır"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "missing template arguments after %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "öntanımlı argümanlara sadece işlev parametresi olarak izin verilir"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD bildirimindeki sınıf ismi geçersiz"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "bir doğrudan özelleştirme %<template <>%> ile öncelenmeli"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T türünde önceden tanım"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "bir kardeş bildirilirken bir sınıf anahtarı kullanılmalıdır"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD has non-integral type %qT"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "expected %<;%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (taban sınıfı örtük olarak bir türdür)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "expression must be enclosed in parentheses"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "istenen konum bir tamsayı sabit değil"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "istenen hizalama bir sabit değil"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -58081,608 +58156,608 @@ msgstr "şablon parametresi listesi çok az"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "replace the class-key with %qs"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qT defined as %qs here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT first declared as %qs here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression list"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bir üye şablon işlevi değil"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma pack%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma pack%> sonunda döküntü"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -58976,7 +59051,7 @@ msgstr "veri üyesi %qD bir üye şablon olamaz"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -59005,92 +59080,92 @@ msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 msgid "template parameter %qD declared here"
 msgstr "şablon parametre türü %qT %<friend%> bildirimli"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of variable concept %q#D"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 msgstr[1] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD için öntanımlı argüman yok"
@@ -59098,54 +59173,54 @@ msgstr "%qD için öntanımlı argüman yok"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "bir isim olmaksızın şablon sınıfı"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -59156,59 +59231,59 @@ msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "şablon olmayan %q#D için şablon tanımı"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d seviye umulurken %q#D için şablon parametresi seviyesi olarak %d seviye alındı"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d şablon parametresi %q#T için alındı"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  ama %d gerekiyordu"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD bildiriminde şablon belirteçleri belirtilmemiş"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -59216,7 +59291,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "%qD şablon parametreleri olmaksızın kullanılmış"
 msgstr[1] "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -59224,478 +59299,478 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 msgstr[1] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "şablon parametresi %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "typedef %q+D için yeniden tanımlama"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration %q#D with different constraints"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü bu bağlamda dizge sabitler kullanılamaz"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "in template argument for type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes in template argument %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  %qD türünde bir şablon umulurken %qD alındı"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "template constraint failure for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
@@ -59713,314 +59788,314 @@ msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<__builtin_choose_expr%> not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "%<__builtin_choose_expr%> için ilk argüman bir sabit değil"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -60033,148 +60108,148 @@ msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bir isim alanı değil"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %qT in template argument"
@@ -60404,7 +60479,7 @@ msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "sözde yıkıcı isminde niteleyen etki alanı geçersiz"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
@@ -60456,7 +60531,7 @@ msgstr "taban sınıf belirtimi geçersiz"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
@@ -60564,7 +60639,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -60607,7 +60682,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
@@ -60747,130 +60822,130 @@ msgstr "%qD bir işlev şablonu değil"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<grainsize%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<priority%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<hint%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -61149,893 +61224,893 @@ msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türl
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "bir üye işleve %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "dizge sabitten %qT'ye dönüşüm artik önerilmiyor"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "static olmayan veri üyesi %qE kullanımı geçersiz"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "iptal edilen tür %qT iken yıkıcı %qT ile ilişkili"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bir nesne göstericisi türü değil"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE kullanimında nesne eksik"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ program içinden %<::main%> çağrısına izin vermez"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<%E (...)%> içinde üye gösterici işlevi çağrısı için %<.*%> veya %<->*%> kullanılmalı"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "işlev için çok fazla argüman belirtildi"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "işlev için çok az argüman belirtildi"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%P parametresi %qD içinde tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametre %P tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "aşırı yüklü işlevden %qT türüne dönüşüm yapildigi varsayılıyor"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "aritmetik içinde NULL kullanımı"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ da gösterici ile tamsayı arasında karşılaştırmaya izin verilmez"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ bir çıkarma içinde %<void *%> türde gösterici kullanımına izin vermez"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içindeki bir işlev göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içinde bir yöntem göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "gösterici aritmetiginde tamamlanmamış ture gösterici kullanımı geçersiz"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "%qE kullanımı üye işleve gösterici biçiminde geçersiz"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  bir nitelemeli kimlik gerekli"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around %qE cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parantez icene alınmis %qE üye işleve gösterici biçiminde kullanilamaz"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir niteliksiz ya da parantezli statik olmayan üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir."
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir sınır üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ %<::main%> işlevinin adresinin alınmasına izin vermez"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "referans üye %qD için gösterici oluşturulamaz"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "%qD bit-alanının adresi alınamaz"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of an immediate function %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "%qD doğrudan yazmaç değişkeninin adresi istendi"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr " %qD için adres istegi (%<register%> olarak bildirilmiş olan)"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT yerel tür %qT kullanıyor"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "%qT'den %qT'ye dönüşüm"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "%qT'den %qT'ye tür dönüşümü hassasiyet kaybi oluşturuyor"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "%qT türünden %qT türüne dönüşüm hedef türün hizalama gereksinimini arttiriyor"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ işlev ve nesne göstericileri arasında dönüşüme izin vermez"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ne bir gösterici türü ne de bir veri üyesine gösterici türü olan %qT ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "bir gösterici ya da bir işlev türüne referans olan %qT türü ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  %<%Q(%#T, %#T)%> nin gelisiminde"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "dizi ilklendirici hatalı"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   üye işleve gösterici dönüşümünde"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "sanal taban %qT üzerinden üye göstericisine dönüşüm"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   üyeye gösterici dönüşümünde"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "%2$q+D işlevinin %1$P. argümanına aktarımda"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "yerel değişken %q+D'ye referans donduruldu"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "redundant move in return statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "bir yıkıcıdan değer donuyor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "bir kurucunun bir işlev deneme blokunun bir tutamagından dondurulemez"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "kurucudan bir değer dondurulemez"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "ilklendirici yok"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%>', %<throw()%> olarak bildirilmedikce (ya da -fcheck-new etkinken) NULL donmemeli"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -62331,116 +62406,116 @@ msgstr "skalar ilklendiriciyi kuşatan parantezler"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -62679,10 +62754,10 @@ msgstr "%C'deki dizi başvurusu %d boyuttan fazlasını içeremez"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "%C'deki dizi başvurusu %d boyuttan fazlasını içeremez"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -62865,7 +62940,7 @@ msgstr "Fortran 2003'te yeni: %C'de [...] tarzı dizi kurucular"
 msgid "Array constructor including type specification at %C"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
@@ -62990,7 +63065,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir sabit olmalı"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -63038,7 +63113,7 @@ msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "`a1' argümanı `%s' yerleşiği için  (%L'de) INTEGER ya da REAL olmalı"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
@@ -63056,7 +63131,7 @@ msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) REAL veya COMPLEX olmal
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTEGER veya PROCEDURE olmalı"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -63197,188 +63272,188 @@ msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Different type kinds at %L"
 msgid "Different type kinds at %L"
 msgstr "Ek: %L'de farklı tür çeşitleri"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "%L'deki NULL gösterici '%s' yerleşik işlevinin fiili argümanı olamaz"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of type REAL or COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) REAL ya da COMPLEX türünde olmalı"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER or a TARGET"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER veya bir TARGET olmalı"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "%L'deki vektör indisli dizi parçası bir göstericinin hedefi olmamalı"
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "%L'deki NULL gösterici '%s' yerleşik işlevinin fiili argümanı olamaz"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) `%s' çeşidinde ve aynı türde olmalı"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "STAT= argument to %s at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Negative argument N at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be present if 'x' is COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) eğer 'x' COMPLEX ise mevcut olmamalı"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of type REAL or COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) REAL ya da COMPLEX türünde olmalı"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "OPERATOR argument at %L must be a PURE function"
@@ -63387,773 +63462,773 @@ msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic function %s(%d) not recognized"
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "Yerleşik işlev %s(%d) tanınmiyor"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) 1. veya 2. sırada olmalı"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be numeric or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) sayısal ya da LOGICAL olmalı"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "'%s' ve '%s' argümanları 'dot_product' yerleşiği için (%L'de) farklı biçimde"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) `%s' çeşidinde ve aynı türde olmalı"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "?: için terimler farklı türde"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s ile aynı çeşit olmalı"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "SIZE at %L must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of LOG at %L cannot be less than or equal to zero"
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "%L'de LOG'un argümanı sıfır veya sıfırdan küçük olamaz"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol at %L is not a DUMMY variable"
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir sabit olmalı"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "yerleşik `%s' için  (%L'de) en az iki argüman olmalı"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "`a%d' argümanı `%s' yerleşiği için  (%L'de) %s(%d) olmalı"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 #| msgid "'a1' argument of '%s' intrinsic at %L must be INTEGER or REAL"
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "`a1' argümanı `%s' yerleşiği için  (%L'de) INTEGER ya da REAL olmalı"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "`a%d' argümanı `%s' yerleşiği için  (%L'de) %s(%d) olmalı"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 #| msgid "different shape on dimension 1 for arguments '%s' and '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "'matmul' yerleşiği için 1. boyuttaki '%s' ve '%s' argümanları (%L'de) farklı biçimde"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 #| msgid "different shape on dimension 2 for argument '%s' and dimension 1 for argument '%s' at %L for intrinsic matmul"
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "'matmul' yerleşiği için 2. boyutta '%s' ve 1. boyutta '%s' argümanları (%L'de) farklı biçimde"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) 1. veya 2. sırada olmalı"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "%L'de LOG'un karmaşık argümanı sıfır olamaz"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument of NEAREST at %L may not be zero"
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "%L'de NEAREST'ın ikinci argümanı sıfır olmayabilir"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) `%s' çeşidinde ve aynı türde olmalı"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir sözde değişken olmalı"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an OPTIONAL dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir OPTIONAL sözde değişken olmalı"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "%L'de 'reshape' yerleşiğinin 'shape' argümanı sabit boyutlu bir dizi olmalı"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "%L'de 'reshape' yerleşiğinin 'shape' argümanı d elemandan fazlasını içeriyor"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "`a%d' argümanı `%s' yerleşiği için  (%L'de) %s(%d) olmalı"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "%L'de LOG'un karmaşık argümanı sıfır olamaz"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. sırada olmalı"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) sayısal bir tür olmalı"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%L'de 'shape' yerleşiğinin 'source' argümanı tahmini boyutlu bir dizi olmalı"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTENT(IN) olamaz"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "%L'de 'shape' yerleşiğinin 'source' argümanı tahmini boyutlu bir dizi olmalı"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Yerleşik işleç arayüzü '%s' %L'de bir FUNCTION olmalı"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. sıradan önce olmalı"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s ile aynı çeşit olmalı"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTEGER veya LOGICAL olmalı"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -64370,821 +64445,821 @@ msgstr "%C'deki INTENT belirtimi hatalı"
 msgid "deferred type parameter at %C"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal character in BOZ constant at %C"
 msgid "Old-style character length at %C"
 msgstr "%C'de BOZ sabitinde kuraldışı karakter"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "işlev '%s' (%C'deki) bir dolaysız arayüze sahip ve %L'de bildirilmiş özniteliklere sahip olmamalı"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element in %s array constructor at %L is %s"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "%s dizi kurucudaki öğe (%L'deki) %s"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "PARAMETER `%s' için %C'de ilklendirme yapılamaz"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "%L'deki PARAMETER bir ilklendirici kaybediyor"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Değişken '%s' %C'de bir ilklendirici ile zaten bir DATA deyiminde görünüyor"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "çok boyutlu diziler ilklendiricilerle ilklendirilemez"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "çok boyutlu diziler ilklendiricilerle ilklendirilemez"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız ya da ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer array component of structure at %C must have a deferred shape"
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız durumda olmalı"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Üç nokta imli bir parametre listesi bir boş parametre isim listesi bildirimi ile eşleşemez"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL() ilklendirme %C'de belirsiz"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL() ilklendirme %C'de belirsiz"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C'deki gösterici ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Bad character '%c' in OPERATOR name at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "OPERATOR isminde '%c' karakteri geçersiz (%C'de)"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Cray göstericileri için dizi belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "bir gösterici türüne dönüştürülemez"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Eski tarz tür bildirimi %s*%d %C'de desteklenmiyor"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%s*%d %C'de standartdısı tür bildirimi"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C'de ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C'deki ilklendirme ifadesinin değişmez olması umuluyordu"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Structure name expected after RECORD at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "%L'deki ifade INTEGER türünde olmalı"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter '%s' at %L has not been declared or is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Bir sabit ifadesine indirgenmeyen '%s' parametresi %L'de ya bildirilmemiş ya da değişken değil"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Genişletme: %C'de BYTE türü"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C'de hedef makinede desteklenmeyen BYTE türü kullanılmış"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Malformed type-spec at %C"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tür ismi '%s' %C'de belirsiz"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C'de IMPLICIT NONE deyimi yinelenmiş"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C'deki IMPLICIT içinde karakter aralığı eksik"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyiminde harfler alfabetik sırada olmalı"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s özniteliği ('%L'de) bir MODULE dışında kullanılamaz"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "%C'deki satır kırpıldı"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
@@ -65192,1116 +65267,1116 @@ msgstr "Belirtim işlevi '%s' (%L'de) bir deyim işlevi olamaz"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C'deki USE deyiminde soysal belirtim eksik"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "sayı eksik"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C'deki türetilmiş tür evvelce tanımlanmış olmamalıydı, bu durumda bir türetilmiş tür tanımı içinde görünemez"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "MODULE prefix at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template argument required for %<%s %T%>"
 msgid "A type parameter list is required at %C"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C'de diğer return yaftası umuluyordu"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template argument required for %<%s %T%>"
 msgid "A parameter name is required at %C"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C'deki dizi bildiriminde farklı bir boyut umuluyordu"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Sembol '%s' %C'deki biçimsel argüman listesinde yinelenmiş"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C'deki RESULT değişkeninin ismi işlev isminden farklı olmalı"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C'deki yapı kurucuda söz dizimi hatası"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "%C'deki işlev tanımında biçimsel argüman listesi umuluyordu"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C'deki ENTRY deyimi bir PROGRAM içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C'deki ENTRY deyimi bir BLOCK DATA içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C'deki ENTRY deyimi bir DERIVED TYPE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C'deki ENTRY deyimi bir IF-THEN bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C'deki ENTRY deyimi bir DO bloku içinde görünemez"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C'deki ENTRY deyimi bir FORALL bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C'deki ENTRY deyimi bir WHERE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş altyordamın içinde görünemez"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş işlevde görünemez"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş işlevde görünemez"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C'de biçim yaftası eksik"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "'%s' işlev ismi olarak %C'de kullanılamaz"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "'%s' etiketi umuluyordu (%s deyiminde, %C'de)"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Dizi belirtimi %L'de ertelenmiş olmalı"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C'deki değişken listesinde umulmadık karakter"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C'deki Cray göstericisi %d baytlık hassasiyete sahip ancak bellek adresi %d bayt gerektiriyor"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "bir gösterici türüne dönüştürülemez"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "%C'de \")\" umuluyordu"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C'de \",\" veya deyim sonu umuluyordu"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "%C'deki Cray göstericisi bildirimi -fcray-pointer seçeneğini gerektiriyor"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%s işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ".%s. işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C'de PARAMETER deyiminde değişken ismi umuluyordu"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde = işareti umuluyordu"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C'deki PARAMETER deyiminde ifade umuluyordu"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
 msgstr "COMMON değişkeni `%s' için %C'de ilklendirme yapılamaz"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde umulmayan karakterler"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C'deki kapsamlı SAVE deyiminden önce bir SAVE deyimi var"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "'%s' simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD evreye yerel olamaz çünkü POD olmayan %qT türünde"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PRIVATE olabilir"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PUBLIC olabilir"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Mangled derived type definition at %C"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "Sözde argüman '%s' (%L'de) OPTIONAL olamaz"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C'deki Cray göstericileri tahmini biçimli dizi olamaz"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM AND ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003'te yeni: %C'de ENUM AND ENUMERATOR"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Sayısal sabitler %C'de C tamsayı türünü aşıyor"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "bir tamsayı ifadesi ile ilklendirilmemiş ENUMERATOR %L"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C öncesinde ENUM tanım deyimi umuluyordu"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C'deki ENUMERATOR tanımında sözdizimi hatası"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "%C'de isimsiz bir arayüz umuluyordu"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C'de dizi indisi umuluyordu"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected module procedure name at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RESULT attribute required in ENTRY statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki ENTRY deyimi bir RESULT özniteliği gerektirir"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "%C'deki FORALL yineleyicisinde sözdizimi hatası"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in ENUMERATOR definition at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -66437,13 +66512,13 @@ msgstr "%L'deki altdizge son indisi sınırların dışında"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "LEN part_ref at %C"
 msgstr "%C'deki satır kırpıldı"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "KIND part_ref at %C"
@@ -66525,7 +66600,7 @@ msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "Ek: %L'de standartdışı ilklendirme ifadesinin değerlenimi"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
@@ -66830,7 +66905,7 @@ msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
@@ -66893,179 +66968,179 @@ msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi ne TARGET ne de POINTER"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L'deki PURE yordamdaki gösterici atamasında hedef berbat"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L'de sağ tarafta vektör indisli gösterici ataması"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Nesne '%s' (%L'de), %s SAVE özniteliğine sahip olmalı"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -67094,7 +67169,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
@@ -67308,12 +67383,12 @@ msgstr "%L'de tanımlanmış atamanın ilk argümanı INTENT(IN) veya INTENT(INO
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -67390,641 +67465,641 @@ msgstr "'%s' ve '%s' arayüzleri (%s içinde, %L'de) belirsiz"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "referans %qs belirsiz: %qs ve %qs arayüzlerinde görünüyor"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "%qs at %L is not a module procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
 msgid "Invalid procedure argument at %L"
 msgstr "%L'de IBITS'in üçüncü argümanı geçersiz"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "Anahtar sözcük argümanı '%s' (%L'de) başka bir fiili argümanla zaten ilişkili"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L'deki yordam çağrısında biçimselden daha gerçekçi argümanlar"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında umulmadık diğer return belirtimi"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "'%s' için fiili argüman (%L'de) bir tahmini boyutlu dizi olamaz"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L'deki altyordam çağrısında diğer return belirtimi eksik"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Argüman '%s' için fiili argüman eksik (%L'de)"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "INTENT(%s) ile '%s' argümanı ve INTENT(%s) ile '%s' argümanı aynı fiili argüman ile ilişkilendirilmiş"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup POINTER özniteliğine sahiptir"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure argument at %L is local to a PURE procedure and is passed to an INTENT(%s) argument"
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L'deki yordam argümanı bir PURE yordamına yerel olup bir INTENT(%s) argümanına aktarılmıştır"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "'%s' simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, fuzzy, gcc-internal-format
 #| msgid "Keyword argument '%s' at %L is not in the procedure"
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "Anahtar kelime argümanı '%s' (%L'de) yordam içinde değil"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "MOLD argument to NULL required at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D aliased to undefined symbol %qs"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D tanımsız %qs simgesine rumuzlu"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %C is already present in the interface"
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "'%s' öğesi (%C'de) zaten arayüzde mevcut"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "Bir PURE yordamında içerilmiş '%s' yordamının kendisi de PURE olmalı"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "`%s' argümanı (%L'de) tek uzunluk olmalı"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Character-valued internal function '%s' at %L must not be assumed length"
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Karakter değerli iç işlev '%s' tahmini uzunlukta olmamalı (%L'de)"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "'%s' yordamı (%s içinde, %L'de) be işlev ne de altyordam"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "`%s' çağrısındaki argümanlar çok fazla (%L'de)"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -68143,80 +68218,80 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used with too many arguments"
 msgid "init_arglist(): too many arguments"
 msgstr "%<va_start%> çok fazla argümanla kullanılmış"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Function %qs as initialization expression at %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "'%s' yerleşiğine altyordam çağrısı %L'de PURE değil"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "'%s' yerleşiğine altyordam çağrısı %L'de PURE değil"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "Ek: %s den %s e dönüşüm (%L'de)"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Conversion from %s to %s at %L"
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "Ek: %s den %s e dönüşüm (%L'de)"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "%s den %s e dönüşüm (%L'de)"
@@ -68224,24 +68299,24 @@ msgstr "%s den %s e dönüşüm (%L'de)"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -68645,13 +68720,13 @@ msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -68663,7 +68738,7 @@ msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -68714,7 +68789,7 @@ msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
@@ -68818,7 +68893,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -68888,7 +68963,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "%s deyiminde ifade umuluyordu (%C'de)"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
@@ -68905,90 +68980,90 @@ msgstr "%L'deki yerleşik mevcut değil"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C'de PRINT isim listesi bir ifadedir"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "%C'deki INQUIRE deyimi PURE yordamı içinde olamaz"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "%C'deki IOLENGTH etiketi INQUIRE deyimi içinde geçersiz"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "%L'deki INQUIRE deyimi hem FILE hem de UNIT belirtecini içeremez"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -69266,554 +69341,554 @@ msgstr "%C'de PRIVATE deyimi yinelenmiş"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Invalid type-spec at %C"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "%C'deki FORALL yineleyicisinde sözdizimi hatası"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "İsim '%s' %s deyimi içindeki bir döngü ismi değil (%C'de)"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "İsim '%s' %s deyimi içindeki bir döngü ismi değil (%C'de)"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "%s statement at %C is not within a construct"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s deyimi '%s' döngüsü içinde değil (%C'de)"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "%s deyimi '%s' döngüsü içinde değil (%C'de)"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement at %C is not within loop '%s'"
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s deyimi '%s' döngüsü içinde değil (%C'de)"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %C cannot be negative"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement at %C in PURE procedure"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "STOP code at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PAUSE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ERROR STOP statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT POST statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "EVENT WAIT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "FAIL IMAGE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "FORM TEAM statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CHANGE TEAM statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "END TEAM statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC TEAM statement at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "LOCK statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "UNLOCK statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "SYNC statement at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: ASSIGN statement at %C"
 msgid "ASSIGN statement at %C"
 msgstr "Atıl: %C'deki ASSIGN deyimi"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: Assigned GOTO statement at %C"
 msgid "Assigned GOTO statement at %C"
 msgstr "Atıl: %C'deki atanmış GOTO deyimi"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "%C'de GOTOdaki deyim yaftası listesi boş olamaz"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad allocate-object in ALLOCATE statement at %C for a PURE procedure"
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "PURE yordam için ALLOCATE deyiminde hatalı yer ayırma nesnesi (%C'de)"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "%C'deki DEALLOCATEde PURE yordamı için kuraldışı yer açma ifadesi"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer to member type %qT incompatible with object type %qT"
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "STAT tag at %L cannot be a constant"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "%C'deki boş BLOCK DATA %L'deki önceki BLOCK DATA ile çelişiyor"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal deallocate-expression in DEALLOCATE at %C for a PURE procedure"
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "%C'deki DEALLOCATEde PURE yordamı için kuraldışı yer açma ifadesi"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "%C'deki diğer RETURN deyimine sadece bir SUBROUTINE içinde izin verilir"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: RETURN statement in main program at %C"
 msgid "RETURN statement in main program at %C"
 msgstr "Ek: %C'deki main programı içinde RETURN deyimi"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected component reference at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "%C'deki ortak blok isminde sözdizimi hatası"
@@ -69821,243 +69896,243 @@ msgstr "%C'deki ortak blok isminde sözdizimi hatası"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "'%s' simgesi (%C'deki) zaten bir COMMON blokundadır"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "COMMON içindeki '%s' simgesi için dizi belirtimi örtük olmamalıdır (%C'de)"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "COMMON içindeki '%s' simgesi bir POINTER dizisi olamaz (%C'de)"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "'%s' simgesi, '%s' COMMON blokunda dolaylı olarak başka bir '%s' COMMON blokuna eşdeğer oluyor (%C'de)"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "BLOCK DATA construct at %L"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already has a basic type of %s"
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "'%s' isim listesi grup ismi (%C'de) zaten bir temel %s türüne sahip"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "'%s' isim listesi grup ismi (%C'de) zaten USE ile ilişkili olup yeniden ilişkilendirilemez"
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "%C'deki türetilmiş tür bileşeni izin verilmiş bir EQUIVALENCE üyesi değildir"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "EQUIVALENCE içindeki dizi başvurusu bir dizi bölümü olamaz (%C'de)"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "%C'deki EQUIVALENCE iki veya daha fazla nesne gerektirir"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "COMMON blokları %s ve %s, EQUIVALENCE tarafından %C'de dolaylı olarak üstüste bindirilmeye çalışılıyor"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected comma in I/O list at %C"
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "EQUIVALENCE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "Statement function at %C"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be scalar"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "%C'deki CASE'de ilklendime ifadesi umuluyordu"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a DO block"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "%C'deki ENTRY deyimi bir DO bloku içinde görünemez"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C'deki ELSEWHERE deyimi WHERE bloku içinde değil"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -70101,12 +70176,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -70861,8 +70936,8 @@ msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
@@ -72362,193 +72437,193 @@ msgstr "%C'deki değişken listesinde umulmadık karakter"
 msgid "Expected structure component name at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Expected argument list at %C"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "%C'deki yapı kurucuda çok az bileşen"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "%C'deki yapı kurucuda çok az bileşen"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "Structure constructor with named arguments at %C"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many components in structure constructor at %C"
 msgid "Too many components in structure constructor at %L"
 msgstr "%C'deki yapı kurucuda çok fazla bileşen"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "%C'deki yapı kurucuda çok az bileşen"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "Too few components in structure constructor at %C"
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "%C'deki yapı kurucuda çok az bileşen"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "%C'deki simge bir ifade için uygun değil"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected use of subroutine name '%s' at %C"
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "'%s' altyordam isminin beklenmedik kullanımı (%C'de)"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs requires argument list at %C"
 msgstr "'%s' deyim işlevi %C'de argüman listesi gerektiriyor"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Function %qs requires an argument list at %C"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "Missing argument to %qs at %C"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Missing argument list in function %qs at %C"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "'%s' ismi (%C'de) tanımlı bir işleç olarak kullanılamaz"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "'%s' isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol at %L is not a DUMMY variable"
 msgid "%qs at %C is not a variable"
@@ -72925,544 +73000,544 @@ msgstr "'%s' simgesi (%L'de) belirsiz"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "'%s' işlevinde diğer return belirtecine %L'de izin verilmiyor"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%L'deki yerleşik mevcut değil"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL INTRINSIC olmayan '%s' yordamına %L'de bir fiili argüman olarak izin verilmez"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "'%s' simgesi (%L'de) belirsiz"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of INT at %L is not a valid type"
 msgid "By-value argument at %L is not of numeric type"
 msgstr "%L'de INT'in argümanı geçerli bir tür değil"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL INTRINSIC olmayan '%s' yordamına %L'de bir fiili argüman olarak izin verilmez"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "%2$qs sayacı okunurken %1$qs işlevi için kapsanma çelişkisi"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 #| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "Soysal işlev '%s' (%L'de) belirli bir yerleşik arayüz ile uyumlu değil"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "İşlev '%s' (%L'de) bir INTRINSIC ama bir yerleşik ile uyumlu değil"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific function '%s' at %L"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "Function reference to '%s' at %L is inside a FORALL block"
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "'%s' için işlev başvurusu %L'de bir FORALL blokunun içindedir"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot write to internal file unit '%s' at %C inside a PURE procedure"
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "PURE yordamının içinde dahili dosya birimi '%s' yazılamıyor (%C'de)"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after %qs at %L"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qs at %L is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "'%s' işlevi CHARACTER(*) bildirimli olup, bir sözde argüman olmadığından %L'de kullanılamaz"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "'%s' (%L'de bir FORALL blokunun içindeki) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "'%s' (%L'de bir FORALL blokunun içindeki) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine call to '%s' at %L is not PURE"
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "'%s' (%L'de) için altyordam başvurusu PURE değil"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "Özel altyordam '%s' %L'de çözümlenemiyor"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 #| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "Soysal işlev '%s' (%L'de) bir yerleşik altyordam arayüzü ile uyumlu değil"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 #| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "Altyordam '%s' (%L'de) bir INTRINSIC ama bir yerleşik ile uyumlu değil"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Unable to resolve the specific subroutine '%s' at %L"
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "Özel altyordam '%s' %L'de çözümlenemiyor"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "'%s' (%L'deki) %L'deki CALL ile uyumlu olmayan bir türe sahip"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L ve %L'de terimlerin biçimleri benzer değil"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "Impure function at %L might not be evaluated"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L'de sıfır adım uzunluğu kuraldışı"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Tahmini boyutlu dizi bölümünün en sağ üst sınırı %L'de belirtilmemiş"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ek: %L'de REAL dizi indisi"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L'deki dizi indisi %d. mertebeden bir dizidir"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge başlangıç indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L'deki altdizge başlangıç indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L'deki altdizge başlangıç indisi birden küçük olmalıdır"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge son indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L'de sıfırdan farklı bir mertebeden iki veya daha fazla parça başvurusu belirtilmemelidir"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -73472,12 +73547,12 @@ msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -73487,298 +73562,298 @@ msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in typebound call at %L"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -73787,301 +73862,301 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "'%s' ismi (%C'de) tanımlı bir işleç olarak kullanılamaz"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -74089,12 +74164,12 @@ msgstr "%L'deki dallanma bir sonsuz döngüye sebep oluyor"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -74102,194 +74177,195 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "FORALL construct at %L"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -74297,7 +74373,7 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -74306,63 +74382,63 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -74370,984 +74446,984 @@ msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olm
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s işlevinde (%s dosyasının %d. satırı)"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -76086,168 +76162,168 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%qs simgesi (%L'de) bir türe sahip olamaz"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%qs simgesi %C'de belirsiz"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "'%s' bileşeni (%C'deki) '%s'nin bir PRIVATE bileşenidir"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr " %d yaftası %L ve %L'de yinelenmiş"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%d yaftası (%C'deki) zaten dallanma hedefi olarak başvurulu"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%d yaftası (%C'deki) zaten bir biçim yaftası olarak başvurulu"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%d yaftası (%C'deki) evvelce bir biçim yaftası olarak kullanılmış"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%d yaftası (%C'deki) evvelce dallanma hedefi olarak kullanılmış"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "'%s' ismi (%C'deki) '%s'e '%s' modülünden belirsiz bir başvurudur"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "%qs ismi (%C'deki) şu an ki program biriminden %qs'e belirsiz bir başvurudur"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%qs simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -76286,66 +76362,66 @@ msgstr "%C'deki G/C listesinde virgül umuluyordu"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "yürüyüş sırasında ifade türü hatalı (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "istenen konum bir tamsayı sabit değil"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "EQUIVALENCE nesne olarak %L'deki başvuru türü kuraldışı"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "Uyumsuz eşdeğerlik kuralları '%s' (%L'deki) ve '%s' (%L'deki) ilişkilendiriliyor"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "%qs değişkeni için bildirilen eşdeğerlik kümesi hizalama gereksinimleriyle çelişiyor (%L'de)"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "%qs'nin eşdeğerliği ile COMMON %qs'nin mertebesi uyuşmuyor (%L'de)"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "%qs'nin eşdeğerliği COMMON %qs'ye geçersiz eklemeye sebep oluyor (%L'de)"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L"
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
@@ -76355,7 +76431,7 @@ msgstr ""
 "COMMON '%s' içinde\n"
 "%L'de (tam şiir gibi olsun bari)"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L"
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
@@ -76365,19 +76441,19 @@ msgstr ""
 "COMMON '%s' içinde\n"
 "%L'de (tam şiir gibi olsun bari)"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "COMMON %qs at %L does not exist"
 msgstr "%L'deki yerleşik mevcut değil"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L requires %d bytes of padding at start"
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "COMMON '%s' (%L'de) başlangıçta %d baytlık adımlama gerektiriyor"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L requires %d bytes of padding at start"
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
@@ -76399,81 +76475,81 @@ msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "bir yordam olmayan yerleşik değişken"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value of function %qs at %L not set"
 msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Deferred type parameter not yet supported"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "modül değişkeni %qs için artyüz bildirimi zaten mevcut"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "gerçekleme değişkeni %qs %s olarak bildirilmiş"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "INTENT(OUT) sözde argüman '%s' %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "Unused dummy argument %qs at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Unused variable %qs declared at %L"
 msgstr "gerçekleme değişkeni %qs %s olarak bildirilmiş"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "Unused parameter %qs declared at %L"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 #| msgid "Return values of functions in FPU registers"
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -76488,28 +76564,28 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Bilinmeyen yerleşik terim"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Unknown argument list function at %L"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -76547,25 +76623,25 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr "Hatalı GÇ tabantürü (%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "implicit mapping of assumed size array %qD"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "optional class parameter"
 msgstr "argüman yok"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "unhandled derived-type component"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_omp_workshare(): Bad statement code"
@@ -76691,92 +76767,92 @@ msgstr "aç-parantez eksik"
 msgid "unable to open file"
 msgstr "%qs öykünümü mümkün değil"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 #| msgid "could not find specs file %s\n"
 msgid "could not parse file offset"
 msgstr "belirtim dosyası %s bulunamadı\n"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected node"
 msgid "unexpected offset"
 msgstr "umulmadık düğüm"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid line in the resolution file"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid resolution in the resolution file"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "sınıf %qs bulunamıyor"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "%s: çıktı dosyası '%s' açılamadı\n"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -77990,7 +78066,7 @@ msgstr "%qs den sonra makro ismi eksik"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs den sonra dosyaismi yok"
@@ -78220,19 +78296,19 @@ msgstr "%qs makine kipi bilinmiyor"
 msgid "unknown TLS model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "visibility değeri \"%s\" tanınmıyor"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
@@ -80318,6 +80394,9 @@ msgstr "(%qs için near ilklendirme)"
 #~ msgid "overriding final function %q+D"
 #~ msgstr "%s %q#D işlevini gölgeliyor"
 
+#~ msgid "%qE attribute can only be applied to Java class definitions"
+#~ msgstr "%qE özniteliği sadece Java sınıf tanımlarına uygulanabilir"
+
 #~ msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 #~ msgstr "%qE artik kullanilmiyor; g++ vtables simdi öntanımlı olarak COM-uyumludur"
 
diff --git a/gcc/po/uk.po b/gcc/po/uk.po
index 9506c5d5335..ef8adb82e0a 100644
--- a/gcc/po/uk.po
+++ b/gcc/po/uk.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2020-05-08 13:32+0300\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <trans-uk@lists.fedoraproject.org>\n"
@@ -1893,83 +1893,83 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "некоректний операнд для «%%%c»"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, c-format
 msgid "invalid vector constant"
 msgstr "некоректна векторна константа"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "несумісний операнд регістру для «%%%c»"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "пропущено операнд"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "некоректна константа"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "некоректний операнд"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "некоректний префікс операнда «%%%c»"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr "некоректний режим адресування"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некоректне перетворення з типу %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некоректне перетворення до типу %<bfloat16_t%>"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' використано без будь-яких локальних динамічних посилань TLS"
@@ -1985,18 +1985,18 @@ msgid "invalid %%r value"
 msgstr "некоректне значення %%r"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "некоректне значення %%R"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "некоректне значення %%N"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "некоректне значення %%P"
@@ -2026,7 +2026,7 @@ msgstr "некоректне значення %%M"
 msgid "invalid %%U value"
 msgstr "некоректне значення %%U"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "некоректне значення %%s"
@@ -2036,7 +2036,7 @@ msgstr "некоректне значення %%s"
 msgid "invalid %%C value"
 msgstr "некоректне значення %%C"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "некоректне значення %%E"
@@ -2046,10 +2046,10 @@ msgstr "некоректне значення %%E"
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -2131,35 +2131,35 @@ msgstr ""
 msgid "unrecognized supposed constant"
 msgstr ""
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2167,13 +2167,13 @@ msgstr ""
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
@@ -2293,7 +2293,7 @@ msgstr "непідтримуваний операнд"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2510,25 +2510,25 @@ msgstr "помилковий операнд output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "помилковий операнд output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr "помилкова адреса ADDR_SPACE_GLOBAL"
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, c-format
 msgid "invalid operand %%xn code"
 msgstr "некоректний код операнда %%xn"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, c-format
 msgid "operand %%xn code invalid for QImode"
 msgstr ""
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, c-format
 msgid "invalid fp constant"
 msgstr "некоректна константа з рухомою крапкою"
@@ -2672,7 +2672,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "некоректне значення %%p"
@@ -2726,7 +2726,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "помилкова адреса"
 
@@ -2778,8 +2778,8 @@ msgstr ""
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -2910,165 +2910,219 @@ msgstr ""
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "%<-mvsx%> потребує індексованого адресування."
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 msgid "%<-mno-altivec%> disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "Помилкове 128-бітове пересування"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "некоректне значення %%J"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "некоректне значення %%D"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "некоректне значення %%e"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "некоректне значення %%f"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "некоректне значення %%F"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "некоректне значення %%G"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, c-format
 msgid "invalid %%t value"
 msgstr "некоректне значення %%t"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "некоректне значення %%T"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "некоректне значення %%u"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "некоректне значення %%v"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "некоректне значення %%V"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "некоректне значення %%z"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to type %<bfloat16_t%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "некоректне перетворення до типу %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "некоректне перетворення до %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to type %<bfloat16_t%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "некоректне перетворення до типу %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from type %<bfloat16_t%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "некоректне перетворення з типу %<bfloat16_t%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "некоректне перетворення до %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3079,88 +3133,88 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некоректний вираз для модифікатора виведення «%c»"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3423,8 +3477,8 @@ msgstr "({анонімний})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "мало бути %<;%>"
@@ -3444,7 +3498,7 @@ msgstr "мало бути %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "мало бути %<)%>"
@@ -3452,7 +3506,7 @@ msgstr "мало бути %<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "мало бути %<]%>"
@@ -3470,21 +3524,21 @@ msgstr "мало бути %<;%>, %<,%> або %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "мало бути %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "мало бути %<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "мало бути %<{%>"
@@ -3495,12 +3549,12 @@ msgstr "мало бути %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "мало бути %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "мало бути %<while%>"
@@ -3509,7 +3563,7 @@ msgstr "мало бути %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "мало бути %<,%>"
@@ -3518,18 +3572,18 @@ msgstr "мало бути %<,%>"
 msgid "expected %<.%>"
 msgstr "мало бути %<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "мало бути %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "мало бути %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "мало бути %<,%> або %<)%>"
@@ -3537,19 +3591,19 @@ msgstr "мало бути %<,%> або %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "мало бути %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "мало бути %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "мало бути %<#pragma omp section%> або %<}%>"
@@ -3558,7 +3612,7 @@ msgstr "мало бути %<#pragma omp section%> або %<}%>"
 msgid "(anonymous)"
 msgstr "(анонімний)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "мало бути %<<%>"
@@ -3569,34 +3623,34 @@ msgstr "мало бути %<<%>"
 msgid "expected label"
 msgstr "мало бути вказано мітку"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 msgid "candidate:"
 msgstr "кандидат:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr ""
 
@@ -3685,7 +3739,7 @@ msgstr ""
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -3851,48 +3905,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -3932,17 +3986,17 @@ msgstr ""
 msgid "elemental binary operation"
 msgstr ""
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr ""
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr ""
@@ -4015,7 +4069,7 @@ msgstr ""
 msgid "Driving:"
 msgstr ""
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
@@ -4030,7 +4084,7 @@ msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4136,11 +4190,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "присвоювання"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr ""
 
@@ -4148,199 +4202,199 @@ msgstr ""
 msgid "simple IF"
 msgstr ""
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr ""
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr ""
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr ""
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr ""
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr ""
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr ""
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr ""
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr ""
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr ""
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr ""
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr ""
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr ""
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr ""
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr ""
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr ""
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Невідомий оператор %%<%s%%> у %%L; хотіли написати «%s»?"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Невідомий оператор %%<%s%%> у %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -4353,27 +4407,27 @@ msgstr ""
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4448,7 +4502,7 @@ msgstr ""
 msgid "Assigned label is not a target label"
 msgstr ""
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
@@ -4871,7 +4925,7 @@ msgstr "Попереджати щодо створення тимчасових
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
@@ -5453,8 +5507,8 @@ msgstr ""
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
@@ -7895,105 +7949,100 @@ msgstr ""
 
 #: analyzer/analyzer.opt:103
 #, no-c-format
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr ""
-
-#: analyzer/analyzer.opt:107
-#, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12424,7 +12473,7 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, no-c-format
-msgid "Use instructions for a future architecture."
+msgid "Use instructions added in ISA 3.1."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:576
@@ -12437,6 +12486,12 @@ msgstr ""
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate divide instructions."
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Створити інструкції divide."
+
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
 msgid "-mcall-ABI\tSelect ABI calling convention."
@@ -17378,7 +17433,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18021,367 +18076,367 @@ msgstr ""
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr "Розташувати ініціалізовані нулями дані у розділі bss."
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr "Створити діагностичні дані у типовому форматі."
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3116
+#: common.opt:3120
 #, no-c-format
 msgid "Generate extended entry point information for inlined functions."
 msgstr ""
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr ""
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Увімкнути докладне виведення."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Придушити попередження."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Створити бібліотеку спільного використання."
 
-#: common.opt:3394
+#: common.opt:3398
 #, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Не створювати динамічно скомпонований виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3398
+#: common.opt:3402
 #, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "Створити динамічно скомпонований виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3402
+#: common.opt:3406
 #, no-c-format
 msgid "Create a static position independent executable."
 msgstr "Створити статичний виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19531,8 +19586,8 @@ msgstr ""
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -19558,7 +19613,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "мало бути ціле число"
@@ -19622,7 +19677,7 @@ msgstr "недостатньо аргументів"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "забагато аргументів"
@@ -19976,7 +20031,7 @@ msgstr ""
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20060,12 +20115,12 @@ msgstr ""
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20083,8 +20138,8 @@ msgstr ""
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -20205,7 +20260,7 @@ msgstr "."
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE оголошено тут"
@@ -20496,7 +20551,7 @@ msgstr "некоректний аргумент 0 %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -20786,12 +20841,12 @@ msgstr ""
 msgid "%<asm%> clobber conflict with input operand"
 msgstr ""
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21301,302 +21356,302 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr ""
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, gcc-internal-format, gfc-internal-format
 msgid "missing ref for speculation %i"
 msgstr ""
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr ""
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr ""
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr ""
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr ""
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "встановлено вказівник inlined_to, але не виявлено попередників"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr ""
@@ -21682,12 +21737,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F використано, але ніколи не визначено"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -21839,7 +21894,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr ""
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "не вдалося відкрити %s: %m"
@@ -22166,22 +22221,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr ""
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr ""
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr ""
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22241,7 +22296,7 @@ msgstr "%<region_array%> є несумісним з %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> є несумісним з %<region_tree%>"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -22271,12 +22326,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -22291,7 +22346,7 @@ msgstr "некоректний аргумент %qs %qs"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr ""
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
@@ -22311,37 +22366,37 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -22959,13 +23014,13 @@ msgstr "функція може повертати адресу локально
 msgid "function returns address of local variable"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "оголошено тут"
@@ -23555,10 +23610,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -23723,7 +23778,7 @@ msgstr ""
 msgid "enclosing %<target%>"
 msgstr ""
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
@@ -23773,13 +23828,13 @@ msgstr ""
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr ""
@@ -23789,147 +23844,147 @@ msgstr ""
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "некоректне приватне спрощення %qE"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -24004,7 +24059,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr ""
@@ -24276,7 +24331,7 @@ msgstr ""
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -24284,7 +24339,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24292,7 +24347,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -24300,7 +24355,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -24308,7 +24363,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24316,7 +24371,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24324,12 +24379,12 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24359,37 +24414,37 @@ msgstr ""
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
 msgstr ""
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24439,57 +24494,57 @@ msgstr ""
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr ""
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -24741,52 +24796,52 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr ""
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr ""
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25007,52 +25062,52 @@ msgstr ""
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr ""
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -26377,132 +26432,132 @@ msgstr "підтримки %<-fcf-protection=return%> для цього приз
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr ""
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr ""
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr ""
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, gcc-internal-format
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "підтримки %<-f%sleading-underscore%> для цього призначення не передбачено"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr ""
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr ""
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr ""
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, gcc-internal-format
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "підтримки %<-ffunction-sections%> для цього призначення не передбачено"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, gcc-internal-format
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "підтримки %<-fdata-sections%> для цього призначення не передбачено"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "підтримки %<-fprefetch-loop-arrays%> для цього призначення не передбачено"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr ""
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, gcc-internal-format
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr ""
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr ""
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, gcc-internal-format
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "підтримки %<-fstack-protector%> для цього призначення не передбачено"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr ""
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr ""
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr ""
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr ""
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -26597,172 +26652,172 @@ msgstr ""
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr ""
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr ""
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr ""
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr ""
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr ""
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, gcc-internal-format
 msgid "invalid operands to %qs"
 msgstr "некоректні операнди %qs"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "невідповідність типів у %qs"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr ""
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr ""
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "некоректний операнд адреси у %qs"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "некоректний операнд зсуву у %qs"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, gcc-internal-format
 msgid "invalid clique in %qs"
 msgstr ""
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, gcc-internal-format
 msgid "%qs in gimple IL"
 msgstr ""
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr ""
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -26773,507 +26828,507 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr ""
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr ""
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr ""
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr ""
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr ""
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr ""
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "некоректні типи у перетворенні простору адрес"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "некоректні типи у перетворенні із фіксованою крапкою"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "некоректні типи у перетворенні до значення із рухомою крапкою"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "некоректні типи у перетворенні до цілого значення"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr ""
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "некоректні типи для %qs"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr ""
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "некоректні невекторні операнди %qs"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, gcc-internal-format
 msgid "invalid (pointer) operands %qs"
 msgstr ""
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "у %qs мало бути використано векторний тип"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr ""
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "у %qs мало бути використано векторні типи"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "некоректний тип маскування у %qs"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, gcc-internal-format
 msgid "not allowed type combination in %qs"
 msgstr ""
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "некоректна позиція або розмір у %qs"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr ""
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, gcc-internal-format
 msgid "insertion out of range in %qs"
 msgstr ""
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr ""
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr ""
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr ""
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, gcc-internal-format
 msgid "invalid operand in %qs"
 msgstr "некоректний операнд у %qs"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr ""
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr ""
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr ""
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr ""
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "некоректний %<CASE_CHAIN%>"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr ""
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "некоректний результат %<PHI%>"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr ""
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "некоректний аргумент %<PHI%>"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr ""
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "помилка %<verify_gimple%>"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "локальне оголошення з іншої функції"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr ""
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr ""
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr ""
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr ""
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "мітка "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr ""
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr ""
@@ -27288,47 +27343,47 @@ msgstr "у визначенні макросу %qs"
 msgid "in expansion of macro %qs"
 msgstr "у розгортанні макросу %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i має декілька країв EH"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -27842,12 +27897,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr ""
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -27912,7 +27967,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -27922,27 +27977,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "визначено тут %qD"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -28017,32 +28072,32 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD вважається застарілим: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD вважається застарілим"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE вважається застарілим: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE вважається застарілим"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "тип вважається застарілим: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип вважається застарілим"
@@ -28067,232 +28122,232 @@ msgstr "тип вважається застарілим"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:14387
+#: tree.c:14398
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr ""
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "%<TYPE_NEXT_PTR_TO%> не належить до типу %<POINTER_TYPE%>"
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "%<TYPE_NEXT_REF_TO%> не належить до типу %<REFERENCE_TYPE%>"
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "%<TYPE_BINFO%> не належить до типу %<TREE_BINFO%>"
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "%<TYPE_ARRAY_MAX_SIZE%> не %<INTEGER_CST%>"
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr ""
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "%<TYPE_CACHED_VALUES%> не належить до %<TREE_VEC%>"
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -28417,82 +28472,82 @@ msgstr ""
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr ""
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr ""
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, gcc-internal-format
 msgid "symver is only supported on ELF platforms"
 msgstr ""
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, gcc-internal-format
 msgid "%qs is not supported in this configuration"
 msgstr "підтримки %qs на цій конфігурації не передбачено"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -29072,7 +29127,7 @@ msgstr ""
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -29092,7 +29147,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -29462,12 +29517,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "некоректне використання %<restrict%>"
@@ -29623,12 +29678,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -29729,7 +29784,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr ""
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
@@ -29739,124 +29794,124 @@ msgstr ""
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "аргументи мають бути сумісними"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr ""
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "розмір масиву %qE не є сталим виразом"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "розмір масиву не є сталим виразом"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr ""
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr ""
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -29911,502 +29966,502 @@ msgstr ""
 msgid "format string argument follows the arguments to be formatted"
 msgstr ""
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr ""
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr ""
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr ""
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr ""
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr ""
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr ""
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr ""
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr ""
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr ""
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr ""
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr ""
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr ""
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr ""
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr ""
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr ""
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr ""
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr ""
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr ""
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr ""
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr ""
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr ""
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr ""
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr ""
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr ""
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr ""
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr ""
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, gcc-internal-format
 msgid "unquoted type name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, gcc-internal-format
 msgid "unquoted operator %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, gcc-internal-format
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, gcc-internal-format
 msgid "use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr ""
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, gcc-internal-format
 msgid "spurious trailing space in format"
 msgstr ""
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr ""
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, gcc-internal-format
 msgid "bare apostrophe %<'%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, gcc-internal-format
 msgid "grave accent %<`%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, gcc-internal-format
 msgid "quoted %qs directive in format"
 msgstr ""
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr ""
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr ""
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, gcc-internal-format
 msgid "unterminated color directive"
 msgstr ""
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> не визначено як тип"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> не визначено як тип"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, gcc-internal-format
 msgid "%qs is not defined as a type"
 msgstr "%qs не визначено як тип"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> не визначено як тип"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> не визначено як тип"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr ""
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, gcc-internal-format
 msgid "argument to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -30567,7 +30622,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -30582,17 +30637,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
@@ -30602,7 +30657,7 @@ msgstr ""
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -31198,7 +31253,7 @@ msgid "wrong type argument to %s"
 msgstr ""
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -31874,7 +31929,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -31951,7 +32006,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -31971,7 +32026,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
 msgid "defined here"
 msgstr "визначено тут"
@@ -31991,7 +32046,7 @@ msgstr ""
 msgid "too many input files"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr ""
@@ -32022,14 +32077,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "коректними аргументами є такі: %s; ви мали на увазі %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "коректні аргументи: %s"
@@ -32546,391 +32601,398 @@ msgstr ""
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, gcc-internal-format
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, gcc-internal-format
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "неочікуване %<%s%> після %<%s%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, gcc-internal-format
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "некоректний формат sve_width"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid sve_width value: %d"
 msgstr "некоректне значення sve_width: %d"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невідомий параметр регулювання (%s)"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs не є коректним зсувом у %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "коректні аргументи: %s;"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "некоректний модифікатор можливості %qs у %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "некоректний модифікатор можливості %qs у %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, gcc-internal-format
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "підтримки моделі коду %qs у режимі ilp32 не передбачено"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, gcc-internal-format
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr ""
@@ -33111,17 +33173,17 @@ msgstr ""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -33271,12 +33333,12 @@ msgstr ""
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -33284,194 +33346,194 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "%Kаргумент %d %qE має бути сталим значенням у діапазоні [0-%d]"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33481,283 +33543,283 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr ""
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr ""
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, gcc-internal-format
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr ""
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, gcc-internal-format
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, gcc-internal-format
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr ""
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, gcc-internal-format
 msgid "unable to use %qs for PIC register"
 msgstr "не можна використовувати %qs для регістру PIC"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr ""
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr ""
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr ""
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr ""
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -33765,22 +33827,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr ""
@@ -33859,17 +33921,17 @@ msgstr "підтримки %<-fpie%> не передбачено"
 msgid "%<-fPIE%> is not supported"
 msgstr "підтримки %<-fPIE%> не передбачено"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
@@ -34131,7 +34193,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr ""
@@ -34462,52 +34524,52 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr ""
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "помилковий тип аргументу %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, gcc-internal-format
 msgid "TLS is not implemented for GCN."
 msgstr ""
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr ""
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr ""
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -34641,132 +34703,132 @@ msgstr ""
 msgid "parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr ""
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr ""
@@ -35146,144 +35208,144 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -35728,7 +35790,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -36800,52 +36862,52 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr ""
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
@@ -36961,323 +37023,324 @@ msgstr ""
 msgid "junk at end of %<#pragma longcall%>"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "вбудований код %qs потребує вбудованого коду %qs"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr "Аргумент має бути сталою від 0 до 31."
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 3."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "підтримки %<__builtin_set_fpscr_drn%> у 32-бітовому режимі не передбачено"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, gcc-internal-format
 msgid "Argument must be a value between 0 and 7."
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, gcc-internal-format
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, gcc-internal-format
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, gcc-internal-format
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент 1 %qs має бути сталою"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 %qs лежить поза припустимим діапазоном"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -37297,219 +37360,224 @@ msgstr "%qs використовує регістр r29"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs потребує %qs або %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs потребує %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "невідомий параметр для %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "некоректний процесор %qs для %s%qs%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> вимикає %<-m%s%>"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
@@ -37830,139 +37898,139 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
@@ -38380,8 +38448,8 @@ msgstr ""
 msgid "could not read the BRIG file"
 msgstr ""
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -38658,7 +38726,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -38728,7 +38796,7 @@ msgstr ""
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -38758,7 +38826,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
@@ -38966,7 +39034,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39305,7 +39373,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -39612,7 +39680,7 @@ msgstr ""
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -39662,7 +39730,7 @@ msgstr ""
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -39698,7 +39766,7 @@ msgstr ""
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -39728,7 +39796,7 @@ msgstr ""
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
@@ -39758,7 +39826,7 @@ msgstr ""
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -39873,12 +39941,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "встановлено значення параметра %qD, але сам параметр ніде не використано"
@@ -39886,257 +39954,257 @@ msgstr "встановлено значення параметра %qD, але 
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr ""
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "У ISO C90 не передбачено підтримки %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "підтримки %<__int%d%> для цього призначення не передбачено"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "У ISO C не передбачено підтримки типу %<_Float%d%s%>"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "підтримки %<_Float%d%s%> для цього призначення не передбачено"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr ""
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> до %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> до %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -40156,7 +40224,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "для відповідності цьому %qs"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -40202,7 +40270,7 @@ msgid "unknown type name %qE"
 msgstr ""
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -40222,7 +40290,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -40237,8 +40305,8 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -40276,7 +40344,7 @@ msgstr ""
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "мало бути %<,%> або %<;%>"
@@ -40304,7 +40372,7 @@ msgstr "У ISO C99 не передбачено підтримки %<_Static_asse
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "У ISO C90 не передбачено підтримки %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -40334,7 +40402,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -40379,14 +40447,14 @@ msgstr ""
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -40471,7 +40539,7 @@ msgstr ""
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr ""
@@ -40481,7 +40549,7 @@ msgstr ""
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr ""
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -40541,7 +40609,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -40556,7 +40624,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
@@ -40581,17 +40649,17 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr ""
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -40611,12 +40679,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -40631,8 +40699,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr ""
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -40659,12 +40727,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "перший операнд %<sizeof%> було оголошено тут:"
@@ -41055,61 +41123,61 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> має перебувати у області видимості файла"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -41119,18 +41187,18 @@ msgstr ""
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp requires%> можна використовувати лише на рівні файла"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
@@ -41150,53 +41218,53 @@ msgstr "мало бути %<)%> або %<,%>"
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "мало бути %<none%> або %<present%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "мало бути %<none%> або %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "мало бути %<data%>, %<update%>, %<enter%> або %<exit%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "мало бути %<data%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41218,12 +41286,12 @@ msgstr "значення %<num_threads%> має бути додатним"
 msgid "%<num_tasks%> value must be positive"
 msgstr "значення %<num_tasks%> має бути додатним"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значення %<grainsize%> має бути додатним"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значення %<priority%> має бути невід’ємним"
@@ -41233,22 +41301,22 @@ msgstr "значення %<priority%> має бути невід’ємним"
 msgid "expected constant integer expression"
 msgstr "мало бути використано сталий цілочисельний вираз"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "мало бути %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> або %<default%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "мало бути %<scalar%>, %<aggregate%> або %<pointer%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -41263,52 +41331,52 @@ msgstr ""
 msgid "%qs value must be positive"
 msgstr "значення %qs має бути додатним"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "забагато аргументів %<static%>"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "несподіваний аргумент"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "мало бути %<concurrent%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "мало бути %<teams%>, %<parallel%> або %<thread%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -41318,7 +41386,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr "значення розміру фрагмента має бути додатним"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -41353,22 +41421,22 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr ""
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -41383,77 +41451,77 @@ msgstr ""
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "мало бути %<host%>, %<nohost%> або %<any%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "мало бути %<data%> після %<#pragma acc %s%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41468,7 +41536,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "мало бути вказано назву функції"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -41478,67 +41546,67 @@ msgstr ""
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> має бути застосовано до використання"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> має бути застосовано до визначення"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "мала бути команда %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> або %<hint%>"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "забагато атомарних команд"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41548,57 +41616,57 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "мало бути %<in%>, %<out%>, %<inout%> або %<mutexinoutset%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "мала бути команда %<depend%>, %<destroy%> або %<update%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "мало бути %<acq_rel%>, %<release%> або %<acquire%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "мала бути команда %<inclusive%> або %<exclusive%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "мало бути %<#pragma omp scan%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -41608,72 +41676,72 @@ msgstr ""
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "мало бути %<for%> після %qs"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "мало бути %<point%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41688,57 +41756,57 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "мало бути %<construct%>, %<device%>, %<implementation%> або %<user%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "мало бути %<match%>"
@@ -41748,12 +41816,12 @@ msgstr "мало бути %<match%>"
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -41763,32 +41831,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "мало бути %<target%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "мало бути %<declare%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -41843,42 +41911,42 @@ msgstr "мало бути вказано назву функції %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "мало бути %<simd%>, %<reduction%>, %<target%> або %<variant%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "мало бути %<seq_cst%>, %<relaxed%> або %<acq_rel%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr ""
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -41893,27 +41961,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
@@ -41923,7 +41991,7 @@ msgstr ""
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -41938,7 +42006,7 @@ msgstr ""
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -42059,7 +42127,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -42084,7 +42152,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42197,17 +42265,17 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "замало аргументів для вбудованої функції %qE; мало бути %u"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -42232,7 +42300,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -42480,7 +42548,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -42647,7 +42715,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -42807,7 +42875,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -42838,7 +42906,7 @@ msgstr ""
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозорі типи векторів не може бути ініціалізовано"
@@ -42983,7 +43051,7 @@ msgstr ""
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -43023,7 +43091,7 @@ msgstr ""
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -43033,17 +43101,17 @@ msgstr ""
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -43058,7 +43126,7 @@ msgstr ""
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
@@ -43068,22 +43136,22 @@ msgstr ""
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -43134,7 +43202,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -43164,51 +43232,51 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -43218,8 +43286,8 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
@@ -43387,12 +43455,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
@@ -43417,8 +43485,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -43433,19 +43501,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -43515,116 +43583,116 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr ""
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -43806,30 +43874,30 @@ msgid "expected case label"
 msgstr "мало бути вказано мітку випадку"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr ""
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 msgid "  no known conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43837,748 +43905,748 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T, %T)%> (вбудований)"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%<%D(%T, %T)%> (вбудований)"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%<%D(%T)%> (вбудований)"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr "%s%qT (перетворення)"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr "%s%#qD (близький відповідник)"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr "%s%#qD (вилучено)"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr ""
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s%#qD"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr ""
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr ""
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr "немає відповідників "
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs у %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "%<operator %s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator %s%> у %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr ""
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, gcc-internal-format
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, gcc-internal-format
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr ""
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  оголошено тут"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "некоректне перетворення з %qH на %qI"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT оголошено тут:"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 msgid "cannot convert %qH to %qI"
 msgstr "не вдалося перетворити %qH на %qI"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -44607,519 +44675,519 @@ msgstr ""
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D конфліктує зі версією, успадкованою від %qT"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "версію, успадковану від %qT, оголошено тут:"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "локальний метод %q#D оголошено тут:"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr ""
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "локальний член %q#D оголошено тут"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT оголошено тут:"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr ""
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, gcc-internal-format
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  але не оголошує %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  або %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, gcc-internal-format
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  але не оголошує %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr ""
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, gcc-internal-format
 msgid "destructor for %qT is ambiguous"
 msgstr ""
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr ""
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "член масиву %q#D оголошено тут"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "у оголошенні %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, gcc-internal-format
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "оголошення %q#D змінює сенс %qD"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, gcc-internal-format
 msgid "%qD declared here as %q#D"
 msgstr "%qD оголошено тут як %q#D"
@@ -45199,7 +45267,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "виклик внутрішньої функції %qE"
@@ -45255,7 +45323,7 @@ msgstr ""
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
@@ -45310,369 +45378,368 @@ msgstr ""
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "розіменування нульового вказівника"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, gcc-internal-format
 msgid "allocated here"
 msgstr ""
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "зміна %qE не є сталим виразом"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "інструкція не є сталим виразом"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значення %qE типу %qT не є сталим виразом"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%<reinterpret_cast%> не є сталим виразом"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "перетворення нульового вказівника %qT на %qT не є сталим виразом"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є сталим виразом"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "вираз %qE не є сталим виразом"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr ""
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ділення на нуль не є сталим виразом"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не є сталим виразом"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не є сталим виразом"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD не є типом класів"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr ""
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "обчислюємо %qs"
@@ -45713,7 +45780,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -45751,292 +45818,292 @@ msgstr ""
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr ""
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr ""
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "у виклику %qD, оголошено тут"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr ""
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -46101,7 +46168,7 @@ msgstr "з попереднього оголошення %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "попереднє оголошення %qD"
@@ -46282,12 +46349,12 @@ msgstr "попереднє оголошення %qD було тут"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "вилучене визначення %qD"
@@ -46300,44 +46367,44 @@ msgstr "вилучене визначення %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -46345,650 +46412,650 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "previous label"
 msgstr "попередня мітка"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  звідси"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  входить до блоку %<catch%>"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD використано без аргументів шаблона"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr ""
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не ініціалізовано %<const %D%>"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "у C++98 %qD має бути ініціалізовано конструктором, а не за допомогою %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "неможливо розкласти недоступний член %qD %qT"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -46996,7 +47063,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -47004,7 +47071,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -47012,177 +47079,177 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не є інтегральним сталим виразом"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "не вдалося розкласти тип об'єднання %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
@@ -47452,7 +47519,7 @@ msgstr ""
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
@@ -47617,7 +47684,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
@@ -47818,810 +47885,810 @@ msgstr ""
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "некоректне використання %<decltype(auto)%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "некоректне використання %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD не може бути %qs"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD не приймає аргументів"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT має попереднє оголошення тут"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -48633,95 +48700,95 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -48730,72 +48797,72 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -48835,7 +48902,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -48845,7 +48912,7 @@ msgstr ""
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -49170,147 +49237,147 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(немає аргументів)"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, gcc-internal-format
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, gcc-internal-format
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr ""
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -49491,338 +49558,338 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD має бути ініціалізовано у списку ініціалізації членів"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D має бути ініціалізовано"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD буде ініціалізовано після"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "базове %qT буде ініціалізовано після"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  коли ініціалізовано тут"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "масив має бути ініціалізовано за допомогою взятого у фігурні дужки ініціалізатора"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, gcc-internal-format
 msgid "invalid type %<void%> for %<new%>"
 msgstr "некоректний тип %<void%> для %<new%>"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -49982,12 +50049,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr ""
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr ""
@@ -50012,157 +50079,162 @@ msgstr ""
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/method.c:1108
+#: cp/method.c:1115
 #, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1111
+#: cp/method.c:1123
 #, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
+msgid "defaulted %qD must be %<const%>"
 msgstr ""
 
-#: cp/method.c:1126
+#: cp/method.c:1128
 #, gcc-internal-format
-msgid "defaulted %qD must return %<bool%>"
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1155
 #, gcc-internal-format
-msgid "defaulted %qD must be %<const%>"
+msgid "defaulted %qD is not a friend of %qT"
 msgstr ""
 
-#: cp/method.c:1158
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr ""
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, gcc-internal-format
 msgid "cannot default compare reference member %qD"
 msgstr ""
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr ""
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr ""
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr ""
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "очікуваний підпис: %qD"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -50202,132 +50274,132 @@ msgstr ""
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "локальне зовнішнє оголошення %q#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "не відповідає попередньому оголошенню %q#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -50335,78 +50407,78 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr ""
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD визначено тут"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -50431,7 +50503,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50456,7 +50528,7 @@ msgstr ""
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -50536,7 +50608,7 @@ msgstr ""
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -50657,7 +50729,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr ""
@@ -50777,7 +50849,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -50877,12 +50949,12 @@ msgstr ""
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -50917,7 +50989,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
@@ -50932,7 +51004,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "помилкова кількість аргументів %<__builtin_launder%>"
@@ -50947,7 +51019,7 @@ msgstr ""
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
@@ -50972,912 +51044,918 @@ msgstr ""
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "у виразах %qs не можна визначати типи"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+#| msgid "%<__builtin_thread_pointer%> is not supported on this target"
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "підтримки %<__builtin_thread_pointer%> для цього призначення не передбачено"
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr ""
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "вже захоплене %qD у лямбда-виразі"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr ""
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr "забагато %<...%> у лямбда-захопленні"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "визначено типовий аргумент для лямбда-параметра"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "дублювання %<mutable%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, gcc-internal-format
 msgid "condition declares an array"
 msgstr ""
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, gcc-internal-format
 msgid "condition declares a function"
 msgstr "умова оголошує функцію"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> у функції %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "зайве %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD є некоректним у лямбді"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "специфікатор типу є некоректним у лямбді"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr ""
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "некоректний префікс кодування у буквальному операторі"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "мало бути вказано оператор"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некоректний параметр обмеженого типу"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr ""
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr ""
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "помилка обробки у списку аргументів шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "спеціалізація шаблона із C-компонуванням"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "мало бути вказано специфікатор типу"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "мало бути вказано тип-назву"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, gcc-internal-format
 msgid "%qE does not constrain a type"
 msgstr "%qE не обмежує тип"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, gcc-internal-format
 msgid "concept defined here"
 msgstr ""
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "мало бути %<;%> або %<{%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "У ISO C++ заборонено порожні enum без назви"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, gcc-internal-format
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr ""
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, gcc-internal-format
 msgid "%qT is not an %<asm%> qualifier"
 msgstr ""
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не є типом"
@@ -51886,430 +51964,430 @@ msgstr "%<%T::%E%> не є типом"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE потребує %<-fgnu-tm%>"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "мало бути вказано специфікатор типу"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "мало бути %<,%> або %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "мало бути %<{%> або %<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "не вдалося визначити тип typename"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "попереднє визначення %q#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "мало бути %<class%> або %<typename%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "У ISO C++17 не можна визначати динамічні специфікації виключень"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "мав бути атрибут перед %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -52318,543 +52396,543 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "У ISO C++ 1998 не передбачено підтримки %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "вказано одразу %<__thread%> і %<thread_local%>"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублювання %qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублювання %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "мало бути %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "мало бути %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "мало бути %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "мало бути %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "мало бути %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "мало бути %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "мало бути %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "мало бути %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "мало бути %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "мало бути %<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "мало бути %<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "мало бути %<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "мало бути %<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "мало бути %<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "мало бути %<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "мало бути %<auto%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "мало бути %<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "мало бути %<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "мало бути %<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "мало бути %<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "мало бути %<__transaction_atomic%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "мало бути %<__transaction_relaxed%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "мало бути %<co_yield%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "мало бути %<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "мало бути %<...%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "мало бути %<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "мало бути %<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "мало бути %<:%> або %<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "мало бути %<class%>, %<typename%> або %<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "теґ %qs використано у назві %q#T"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "мало бути використано список цілих значень"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "типи не можна визначати у типі ітератора"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> можна використовувати лише на рівні файлів або просторів назв"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> має перебувати всередині функції"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> має перебувати всередині функції"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53125,7 +53203,7 @@ msgstr ""
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -53150,67 +53228,67 @@ msgstr ""
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr ""
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -53218,17 +53296,17 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -53236,47 +53314,47 @@ msgstr ""
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "оголошено шаблон %qD"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -53286,57 +53364,57 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -53344,7 +53422,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -53352,132 +53430,132 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53485,297 +53563,297 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "в аргументі шаблона для типу %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  мало бути %qD, втім, маємо %qD"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -53793,291 +53871,291 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "порожній ініціалізатор у захопленні під час ініціалізації лямбди"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "скористайтеся краще %<this->%D%>"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "скористайтеся краще %<%T::%D%>"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "помилкова кількість аргументів %<__builtin_convertvector%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не є класом або простором назв"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не є класом або простором назв"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT є змінним за змінними типом"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "інтегральний вираз %qE не є сталою"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "специфікація виключення %qD залежить від самої себе"
@@ -54089,132 +54167,132 @@ msgstr "специфікація виключення %qD залежить ві
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некоректний шаблон нетипізованого параметра"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr ""
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr ""
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "не вдалося вивести %qT з %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "некоректне використання %qT в аргументі шаблона"
@@ -54419,7 +54497,7 @@ msgstr ""
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -54469,7 +54547,7 @@ msgstr ""
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -54568,7 +54646,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -54608,7 +54686,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
@@ -54733,117 +54811,117 @@ msgstr ""
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "Вираз %<hint%> має бути сталим цілочисельним виразом"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, у %<__builtin_launder%>"
@@ -55083,797 +55161,797 @@ msgstr ""
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некоректне перетворення з типу %qT до типу %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr ""
@@ -56132,107 +56210,107 @@ msgstr ""
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr ""
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -56456,10 +56534,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -56626,7 +56704,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -56743,7 +56821,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -56783,7 +56861,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr ""
@@ -56798,7 +56876,7 @@ msgstr ""
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr ""
@@ -56918,167 +56996,167 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr ""
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr ""
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr ""
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr ""
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr ""
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr ""
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr ""
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr ""
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr ""
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr ""
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr ""
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -57086,697 +57164,697 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr ""
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr ""
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr ""
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr ""
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr ""
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr ""
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr ""
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr ""
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr ""
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr ""
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr ""
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr ""
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr ""
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr ""
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr ""
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr ""
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr ""
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr ""
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr ""
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr ""
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "аргумент %<SOURCE%> %<TRANSFER%> всередині у %L не може бути %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "аргумент %<MOLD%> %<TRANSFER%> всередині у %L не може бути %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr ""
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr ""
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr ""
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr ""
@@ -57971,1755 +58049,1755 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr ""
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Процедура %qs у %C є явним інтерфейсом з попереднього оголошення"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr ""
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Синтаксична помилка у ініціалізації у старому стилі %s, адреса — %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Значення параметра KIND %qs у %C не спрощується до сталого виразу"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr ""
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксична помилка у оголошенні анонімної структури у %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Потрібна назва параметра у %C"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "У оголошенні типу у %C мав бути список параметрів"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr ""
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксична помилка у інструкції AUTOMATIC у %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксична помилка у інструкції STATIC у %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Зайві команди після інструкції MAP у %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Зайві команди після інструкції UNION у %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Зайві команди після невкладеної інструкції STRUCTURE у %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Похідна назва типу %qs у %C вже має базовий тип"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr ""
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr ""
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
 msgstr ""
@@ -59844,12 +59922,12 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr ""
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr ""
@@ -59924,7 +60002,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -60190,7 +60268,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -60248,167 +60326,167 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -60434,7 +60512,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -60625,12 +60703,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -60700,582 +60778,582 @@ msgstr ""
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%qs у %L не є процедурою модуля"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Некоректний аргумент процедури у %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr ""
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "Неочікуваний специфікатор повернення з альтернативи у виклику підпрограми у %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "Неочікуване NULL() всередині у %L до фіктивного %qs"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr ""
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr ""
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr ""
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr ""
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr ""
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr ""
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr ""
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr ""
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr ""
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr ""
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr ""
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr ""
@@ -61380,73 +61458,73 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr ""
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr ""
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr ""
@@ -61454,22 +61532,22 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -61815,12 +61893,12 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr ""
@@ -61830,7 +61908,7 @@ msgstr ""
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr ""
@@ -61875,7 +61953,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -61970,7 +62048,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -62036,7 +62114,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -62051,83 +62129,83 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr ""
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, gcc-internal-format, gfc-internal-format
 msgid "identifier overflow: %d"
 msgstr "переповнення ідентифікатора: %d"
@@ -62372,505 +62450,505 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr ""
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr ""
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "Потрібен пробіл у інструкції %s поряд із %C"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr ""
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr ""
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr ""
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "Інструкція FAIL IMAGE у %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr ""
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr ""
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr ""
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr ""
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected constant at %C"
 msgstr "Неочікувана стала у %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr ""
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr ""
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr ""
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr ""
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr ""
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr ""
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -62878,217 +62956,217 @@ msgstr ""
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr ""
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr ""
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr ""
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr ""
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr ""
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr ""
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr ""
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr ""
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -63129,12 +63207,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -63815,8 +63893,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -65222,172 +65300,172 @@ msgstr ""
 msgid "Expected structure component name at %C"
 msgstr "У %C мало бути вказано назву компонента структури"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "У %C мало бути вказано список аргументів"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): вираз не є змінною"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_caf_attr(): вираз не є змінною"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_caf_attr(): помилкове посилання на масив"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr ""
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "Забагато компонентів у конструкторі структури, %L"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "Символ у %C є відповідним для виразу"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "Неочікуване використання назви підпрограми %qs, %C"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "Функція %qs потребує списку аргументів, %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "Пропущено аргумент %qs, %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "Пропущено список аргументів у функції %qs, %C"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Похідний тип %qs не можна використовувати як змінну у %C"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "Іменована стала у %C в EQUIVALENCE"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%qs у %C не є змінною"
@@ -65714,493 +65792,493 @@ msgstr ""
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr ""
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr ""
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr ""
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -66209,12 +66287,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -66223,283 +66301,283 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -66508,284 +66586,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Похідний тип %qs не можна використовувати як змінну у %L"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -66793,187 +66871,187 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -66981,954 +67059,954 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -68614,153 +68692,153 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): наданий символ неочікувано виявився рівним NULL"
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -68797,83 +68875,83 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "get_mpz(): не є сталим цілим значенням"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr "element_number(): помилковий тип розмірності"
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr ""
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr ""
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -68893,72 +68971,72 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Невикористану змінну %qs оголошено у рядку %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Невикористаний параметр %qs, оголошено у %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "Невикористаний параметр %qs, який було явно імпортовано у %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr ""
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -68973,27 +69051,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -69029,22 +69107,22 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, gcc-internal-format
 msgid "optional class parameter"
 msgstr "необов'язковий параметр класу"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -69154,82 +69232,82 @@ msgstr ""
 msgid "unable to open file"
 msgstr "не вдалося відкрити файл"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr ""
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr ""
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr ""
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr ""
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Не вдалося відкрити %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr ""
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Не вдалося прочитати %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -70355,7 +70433,7 @@ msgstr ""
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr ""
@@ -70555,17 +70633,17 @@ msgstr "невідомий алгоритм переупорядковуванн
 msgid "unknown TLS model %qs"
 msgstr "невідома модель TLS %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "невідоме значення видимості %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/vi.po b/gcc/po/vi.po
index 619ed5c8826..e54294da447 100644
--- a/gcc/po/vi.po
+++ b/gcc/po/vi.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -1946,93 +1946,93 @@ msgstr "đồ sửa đổi chiều dài theo định dạng strfmon"
 msgid "<command-line>"
 msgstr "<dòng lệnh>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "toán hạng không hợp lệ đối với “%%%c”"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 #| msgid "incompatible floating point / vector register operand for '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "toán hạng còn thiếu"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "toán hạng không hợp lệ"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "tiền tố toán hạng không hợp lệ “%%%c”"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "sai đặt chế độ đặt địa chỉ"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "toán hạng không hợp lệ trong phép toán nhị phân"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
@@ -2048,18 +2048,18 @@ msgid "invalid %%r value"
 msgstr "giá trị %%r sai"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "giá trị %%R sai"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
@@ -2089,7 +2089,7 @@ msgstr "giá trị %%M sai"
 msgid "invalid %%U value"
 msgstr "giá trị %%U sai"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
@@ -2099,7 +2099,7 @@ msgstr "giá trị %%s sai"
 msgid "invalid %%C value"
 msgstr "giá trị %%C sai"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
@@ -2109,10 +2109,10 @@ msgstr "giá trị %%E sai"
 msgid "unknown relocation unspec"
 msgstr "không rõ bỏ ghi rõ bố trí lại"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "mã %%xn sai"
@@ -2195,35 +2195,35 @@ msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 msgid "unrecognized supposed constant"
 msgstr "không nhận ra điều nên là hằng số"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "sai đặt toán hạng dời"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "lệnh Thumb căn cứ vào"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "gặp lệnh căn cứ vào trong dãy có điều kiện"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2231,13 +2231,13 @@ msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "lệnh chưa bao giờ thực hiện"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "định dạng mã Maverick đã cũ “%c”"
@@ -2371,7 +2371,7 @@ msgstr "gặp toán hạng bất thường"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2588,27 +2588,27 @@ msgstr "đặt sai toán hạng output_move_double"
 msgid "bad output_condmove_single operand"
 msgstr "đặt sai toán hạng output_condmove_single"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operand %%xn code"
 msgstr "toán hạng không hợp lệ cho mã %%Z"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand %%xn code invalid for QImode"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid fp constant"
@@ -2761,7 +2761,7 @@ msgstr "thao tác sai %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "gặp toán hạng %%P sai"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -2815,7 +2815,7 @@ msgid "post-increment address is not a register"
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -2867,8 +2867,8 @@ msgstr "“%%%c” không phải là một tiền tố toán hạng đúng"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "sai sử dụng “%%%c”"
@@ -3009,182 +3009,236 @@ msgstr "Không đủ sức chứa trong ngăn xếp.\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Hãy thử chạy “%s” trong trình bao để tăng giới hạn.\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx yêu cầu dấu chấm động loại phần cứng"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx yêu cầu đặt địa chỉ một cách phụ lục"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx và -mno-altivec không tương thích với nhau"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec thì tắt vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "-mquad-memory yêu cầu chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 #, fuzzy
 #| msgid "-mquad-memory-atomic requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "-mquad-memory-atomic cần chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 #| msgid "-mquad-memory is not available in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "giá trị %%J sai"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "giá trị %%D sai"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 và __ibm128 không thể được dùng trong cùng một biểu thức"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "sai chuyển đổi từ %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "sai chuyển đổi sang %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "sai chuyển đổi từ %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "sai chuyển đổi sang %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "sai chuyển đổi từ %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "sai chuyển đổi sang %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "sai chuyển đổi từ %<__fpreg%>"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "sai chuyển đổi sang %<__fpreg%>"
+
 #: config/s390/s390.c:7787
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3195,90 +3249,90 @@ msgstr ""
 msgid "cannot decompose address"
 msgstr "không thể giải mã địa chỉ"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "hằng không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "véc-tơ hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "biểu thức không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "biểu thức không hợp lệ cho bộ sửa đầu ra “%c”"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "Vector argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3541,8 +3595,8 @@ msgstr "({nặc danh})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
@@ -3562,7 +3616,7 @@ msgstr "cần %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -3570,7 +3624,7 @@ msgstr "cần %<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -3588,21 +3642,21 @@ msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -3613,12 +3667,12 @@ msgstr "cần %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
@@ -3627,7 +3681,7 @@ msgstr "cần %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -3636,18 +3690,18 @@ msgstr "cần %<,%>"
 msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
@@ -3655,19 +3709,19 @@ msgstr "cần %<,%> hoặc %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
@@ -3676,7 +3730,7 @@ msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -3687,36 +3741,36 @@ msgstr "cần %<<%>"
 msgid "expected label"
 msgstr "cần kênh"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Bật câu lệnh được người dùng xác định."
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "ứng cử 2:"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "nhảy tới nhãn %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "nhảy tới nhãn lệnh case"
 
@@ -3806,7 +3860,7 @@ msgstr "<lỗi tham số mẫu>"
 msgid "<statement>"
 msgstr "<lời khai báo>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<không rõ>"
@@ -3977,48 +4031,48 @@ msgstr "việc chuyển đổi cũng bỏ trình trạng bất biến"
 msgid "source type is not polymorphic"
 msgstr "nguồn không có loại nhiều dạng"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "đối số có loại sai đối với dấu trừ nguyên phân"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "đối số có loại sai đối với dấu cộng nguyên phân"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "đối số có loại sai đối với phần bù bit"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "đối số có loại sai đối với phần chia"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "trong đối số tới bộ nguyên phân !"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "không có toán tử tiền gia cho loại"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "không có toán tử hậu gia cho loại"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "không có toán tử giảm gia cho loại"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "không có toán tử hậu giảm cho loại"
 
@@ -4060,17 +4114,17 @@ msgstr "Tên có chứa ký tự không hợp lệ tại %C"
 msgid "elemental binary operation"
 msgstr "thao tác nhị phân loại yếu tố"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "đối số “a%d” và “a%d” cho “%s” thực chất"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "đối số “%s” và “%s” cho %s thực chất"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "đối số “%s” và “%s” cho “%s” thực chất"
@@ -4147,7 +4201,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "Đang điều khiển:"
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "tham số thực tế cho INTENT = OUT/INOUT"
 
@@ -4162,7 +4216,7 @@ msgstr "đơn vị bên trong trong GHI"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "thẻ %s với INQUIRE"
@@ -4268,11 +4322,11 @@ msgstr "IF (nếu) loại khối"
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
@@ -4280,201 +4334,201 @@ msgstr "sự gán hàm trỏ"
 msgid "simple IF"
 msgstr "IF (nếu) đơn giản"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "thủ tục loại yếu tố"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 msgid "allocatable argument"
 msgstr "đối số phân bổ được"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 msgid "asynchronous argument"
 msgstr "đối số không đồng bộ"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "đối số tùy chọn"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 msgid "pointer argument"
 msgstr "đối số con trỏ"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 msgid "target argument"
 msgstr "đối số đích"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 msgid "value argument"
 msgstr "đối số giá trị"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 msgid "volatile argument"
 msgstr "đối số hay thay đổi"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 msgid "assumed-shape argument"
 msgstr "đối số assumed-shape"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 msgid "assumed-rank argument"
 msgstr "đối số assumed-rank"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 msgid "coarray argument"
 msgstr "đối số coarray"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr "đối số kiểu được dẫn suất tham số hóa"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 msgid "polymorphic argument"
 msgstr "đối số polymorphic"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "thuộc tính NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 msgid "assumed-type argument"
 msgstr "đối số assumed-type"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "kết quả mảng"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 msgid "pointer or allocatable result"
 msgstr "con trỏ hoặc kết quả cấp phát được"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 msgid "result with non-constant character length"
 msgstr ""
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 msgid "bind(c) procedure"
 msgstr "thủ tục bind(c)"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "Gặp ngữ cảnh sai cho hàm trỏ NULL() tại %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Tại %%L có một toán tử thuộc số nguyên phân “%s” với toán hạng %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử ghép nối chuỗi với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử hợp lý “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Tại %%L có một toán tử .not. với toán hạng %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Không thể so sánh các số lượng PHỨC TẠP tại %L"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Tại %%L thì các bộ hợp lý phải được so sánh với %s thay cho %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử so sánh “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Các toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tại %%L và %%L có một toán tử với các phân hàng mâu thuẫn nhau"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
@@ -4487,27 +4541,27 @@ msgstr "Bộ dựng mảng chứa các chiều dài KÝ_TỰ khác nhau (%ld/%ld
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật không tương ứng với điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr "Gán vô hướng cho mảng chưa cấp phát"
 
@@ -4584,7 +4638,7 @@ msgstr "Câu lệnh V/R chứa con số đơn vị quá lớn"
 msgid "Assigned label is not a target label"
 msgstr "Nhãn đã gán không phải là một nhãn đích"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Số ảnh không hợp lệ %d trong SYNC IMAGES"
@@ -5024,7 +5078,7 @@ msgstr "Cảnh báo về sự tạo mục mảng tạm thời."
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Không làm gì. Giữ lại vì mục đích tương thích ngược."
@@ -5613,8 +5667,8 @@ msgstr "Có tên hiển thị bên ngoài thì phụ thêm dấu gạch dưới.
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Không làm gì. Dành cho mục đích tương thích ngược."
@@ -8118,107 +8172,101 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "Cảnh báo về các vĩ lệnh đã định nghĩa trong tập tin chính mà không được sử dụng."
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves."
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "Cảnh báo về biến bị tự khởi tạo."
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr ""
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -12733,9 +12781,8 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "Use Branch Likely instructions, overriding the architecture default."
-msgid "Use instructions for a future architecture."
-msgstr "Sử dụng câu lệnh rất có thể thích hợp với nhanh (Branch Likely), thì ghi đè lên giá trị mặc định của kiến trúc đó."
+msgid "Use instructions added in ISA 3.1."
+msgstr "Đừng sử dụng chỉ lệnh callt (mặc định)."
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -12749,6 +12796,12 @@ msgstr "Tạo chỉ lệnh di chuyển điều kiện"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Tạo ra mã tương đối với PC (pc-relative)."
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+#| msgid "Generate norm instruction."
+msgid "Generate (do not generate) MMA instructions."
+msgstr "Tạo ra câu lệnh norm."
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention."
@@ -17778,7 +17831,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -18422,371 +18475,371 @@ msgstr ""
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2863
+#: common.opt:2867
 #, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2876
+#: common.opt:2880
 #, no-c-format
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2880
+#: common.opt:2884
 #, no-c-format
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2884
+#: common.opt:2888
 #, no-c-format
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, no-c-format
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2896
+#: common.opt:2900
 #, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2900
+#: common.opt:2904
 #, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2904
+#: common.opt:2908
 #, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2916
+#: common.opt:2920
 #, no-c-format
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2924
+#: common.opt:2928
 #, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2930
+#: common.opt:2934
 #, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2938
+#: common.opt:2942
 #, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2943
+#: common.opt:2947
 #, no-c-format
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2951
+#: common.opt:2955
 #, no-c-format
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2955
+#: common.opt:2959
 #, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2997
+#: common.opt:3001
 #, no-c-format
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:3001
+#: common.opt:3005
 #, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, no-c-format
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:3048
+#: common.opt:3052
 #, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:3052
+#: common.opt:3056
 #, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:3056
+#: common.opt:3060
 #, no-c-format
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:3060
+#: common.opt:3064
 #, no-c-format
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:3064
+#: common.opt:3068
 #, no-c-format
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:3068
+#: common.opt:3072
 #, no-c-format
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:3072
+#: common.opt:3076
 #, no-c-format
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:3076
+#: common.opt:3080
 #, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3080
+#: common.opt:3084
 #, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr ""
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:3108
+#: common.opt:3112
 #, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:3112
+#: common.opt:3116
 #, no-c-format
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function."
 msgid "Generate extended entry point information for inlined functions."
 msgstr "Tạo ra một điểm ra khỏi riêng lẻ cho mỗi hàm."
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:3144
+#: common.opt:3148
 #, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:3148
+#: common.opt:3152
 #, no-c-format
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:3152
+#: common.opt:3156
 #, no-c-format
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, no-c-format
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, no-c-format
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:3183
+#: common.opt:3187
 #, no-c-format
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:3187
+#: common.opt:3191
 #, no-c-format
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3205
+#: common.opt:3209
 #, no-c-format
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<định dạng>\tTạo phần gỡ lỗi nén theo định dạng <định dạng>."
 
-#: common.opt:3216
+#: common.opt:3220
 #, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tĐặt <dir> cho thư mục phần bổ sung mặc định."
 
-#: common.opt:3220
+#: common.opt:3224
 #, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <dir>\tĐặt <dir> để cho thư mục con bao gồm đa kiến trúc."
 
-#: common.opt:3245
+#: common.opt:3249
 #, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <tập tin>\tĐặt kết xuất vào <tập tin>"
 
-#: common.opt:3249
+#: common.opt:3253
 #, no-c-format
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3259
+#: common.opt:3263
 #, no-c-format
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3299
+#: common.opt:3303
 #, no-c-format
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3331
+#: common.opt:3335
 #, no-c-format
 msgid "Enable verbose output."
 msgstr "Bật kết xuất chi tiết."
 
-#: common.opt:3335
+#: common.opt:3339
 #, no-c-format
 msgid "Display the compiler's version."
 msgstr "Hiển thị thông tin về phiên bản của bộ biên dịch."
 
-#: common.opt:3339
+#: common.opt:3343
 #, no-c-format
 msgid "Suppress warnings."
 msgstr "Thu hồi cảnh báo."
 
-#: common.opt:3349
+#: common.opt:3353
 #, no-c-format
 msgid "Create a shared library."
 msgstr "Tạo thư viện dùng chung."
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 #| msgid "Don't create a position independent executable."
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Đừng tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable."
 msgid "Create a dynamically linked position independent executable."
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable."
 msgid "Create a static position independent executable."
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -19966,8 +20019,8 @@ msgstr "Đóng kết với số các sự kiểm tra lúc chạy được chèn
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "Đóng kết với số các sự kiểm tra lúc chạy được chèn bởi việc kiểm tra phiên bản vòng lặp để xếp hàng của bộ véc-tơ hóa."
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "giá trị được tính không được sử dụng"
@@ -19993,7 +20046,7 @@ msgid "expected boolean type"
 msgstr "cần kiểu boolean"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Mong đợi một số nguyên"
@@ -20059,7 +20112,7 @@ msgstr "không đủ đối số"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "quá nhiều đối số"
@@ -20418,7 +20471,7 @@ msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -20503,12 +20556,12 @@ msgstr ""
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -20526,8 +20579,8 @@ msgstr "thuộc tính %qE bị lờ đi"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "khai báo trước đây của %qD"
@@ -20651,7 +20704,7 @@ msgstr "  đã được khai báo ở đây"
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -20942,7 +20995,7 @@ msgstr "thiếu đối số đối cho %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -21238,12 +21291,12 @@ msgstr ""
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "%<%%%> hằng được dùng với toán hạng cuối"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr ""
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr ""
@@ -21758,307 +21811,307 @@ msgstr ""
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing counts for called function %s/%i"
 msgid "missing direct call for speculation %i"
 msgstr "Thiếu số lượng cho cú gọi hàm %s/%i"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "thiếu chắn sau khối %i"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "tp_first_run must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "ký hiệu cục bộ phải được định nghĩa"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to con trỏ là sai"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "nhiều bộ gọi chung dòng"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "con trỏ inlined_to chỉ đến chính nó"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node có clone_of sai"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node có danh sách nhân bản sai"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Bí danh có cạnh gọi"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Bí danh có tham chiếu non-alias"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt được chia sẻ:"
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr ""
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gặp lỗi"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: section %s is missing"
 msgid "%s: section %s.%d is missing"
@@ -22154,12 +22207,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -22319,7 +22372,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "Phần hỗ trợ LTO không được bật trong cấu hình này"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "không thể mở %s: %m"
@@ -22664,22 +22717,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr ""
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "rtx dùng chung"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "tính nhất quán nội tại gặp lỗi nghiêm trọng"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr ""
@@ -22740,7 +22793,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -22771,12 +22824,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -22793,7 +22846,7 @@ msgstr "đối số không hợp lệ cho %qD"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "kích thước của %q+D lớn hơn %wd byte"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
@@ -22813,37 +22866,37 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "so sánh luôn là %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -23494,13 +23547,13 @@ msgstr "hàm có thể trả về địa chỉ của biến cục bộ"
 msgid "function returns address of local variable"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "được khai báo ở đây"
@@ -24064,10 +24117,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -24241,7 +24294,7 @@ msgstr "SPE không được hỗ trợ ở đích này"
 msgid "enclosing %<target%>"
 msgstr "bao quanh %s"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
@@ -24292,13 +24345,13 @@ msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "%qD in %<reduction%> clause is a zero size array"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
@@ -24309,147 +24362,147 @@ msgstr "%qD trong mệnh đề %<reduction%> là một mạng cỡ không"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gặp lỗi"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -24527,7 +24580,7 @@ msgstr "thẻ bài %u có x-location == %u"
 msgid "token %u has %<y-location == %u%>"
 msgstr "thẻ bài %u có y-location == %u"
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "dùng %<auto%> không hợp lệ"
@@ -24801,48 +24854,48 @@ msgstr ""
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
@@ -24875,38 +24928,38 @@ msgstr "hàm nên ứng cử cho thuộc tính %<%s%> nếu nó biết trả v
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr ""
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification failed: %s"
 msgid "IPA-SRA access verification failed"
 msgstr "thẩm tra gặp lỗi: %s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -24959,57 +25012,57 @@ msgstr ""
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "Số tối đa các lần có thể định thời một lệnh nào đó."
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "không thể tìm thấy LTO cgraph trong %s"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "không thể tìm thấy tham chiếu phần LTO trong %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -25277,54 +25330,54 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "previously used here"
 msgid "... to the previous %qs clause here"
 msgstr "cái trước được dùng là ở đây"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "switch starts here"
 msgid "... with %qs clause here"
 msgstr "switch bắt đầu ở đây"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -25550,52 +25603,52 @@ msgstr ""
 msgid "invalid branch to/from %s structured block"
 msgstr ""
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr "chứa vòng lặp"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -27005,142 +27058,142 @@ msgstr "-fstack-protector không hỗ trợ đích này"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%<-fabi-version=1%> không còn tiếp tục được hỗ trợ nữa"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr ""
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr ""
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr ""
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr ""
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr ""
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr ""
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr ""
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-fdata-sections không được hỗ trợ cho đích này"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections không được hỗ trợ cho đích này"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays không được hỗ trợ bởi đích này"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays không được hỗ trợ bởi đích này (thử -march switches)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays không được hỗ trợ bởi -Os"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math bị tắt; các tùy chọn khác nhận quyền ưu tiên"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector không hỗ trợ đích này"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fsanitize=address và -fsanitize=kernel-address không được hỗ trợ cho đích này"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "lỗi ghi vào %s: %m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "lỗi đóng %s: %m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 #| msgid "self-tests incompatible with -E"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "self-tests không tương thích với -E"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "self-tests không được bật trong lần biên dịch này"
@@ -27237,183 +27290,183 @@ msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr ""
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr ""
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr ""
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr ""
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr ""
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "non-scalar type"
 msgid "non-scalar %qs"
 msgstr "kiểu không-scalar"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid position or size operand to %qs"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr ""
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs of non-mode-precision operand"
 msgstr "dịch của toán hạng không nguyên"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr ""
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "kiểu không khớp trong tham chiếu mảng"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "sai đặt toán hạng tới %%R"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in parameter %i"
 msgid "type mismatch in %qs"
 msgstr "không khớp kiểu trong tham số %i"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "invalid shift operand"
 msgid "invalid %qs offset operator"
 msgstr "sai đặt toán hạng dời"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr ""
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr ""
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s operand"
 msgid "invalid address operand in %qs"
 msgstr "toán hạng %%s sai"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%t operand '"
 msgid "invalid offset operand in %qs"
 msgstr "sai toán hạng %%t “"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "dùng %qD không hợp lệ"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "IF (nếu) đơn giản"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr ""
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr ""
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "hàm không hợp lệ trong cú gọi gimple"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr ""
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr ""
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr ""
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr ""
@@ -27424,532 +27477,532 @@ msgstr ""
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "đối số không hợp lệ cho cú gọi hàm gimple"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr ""
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr ""
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr ""
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr ""
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr ""
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr ""
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr ""
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "toán hạng không hợp lệ trong phép toán một ngôi"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "các kiểu không hợp lệ trong chuyển đổi nop"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "các kiểu không hợp lệ trong chuyển đổi nop"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr ""
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr ""
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid types in conversion to floating-point"
 msgstr "các kiểu không hợp lệ trong chuyển đổi nop"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr ""
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in shift expression"
 msgid "type mismatch in %qs expression"
 msgstr "kiểu không khớp trong biểu thức dịch"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid types for %qs"
 msgstr "kiểu trừu tượng cho %q+D không hợp lệ"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr ""
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr ""
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "toán hạng không hợp lệ trong phép toán nhị phân"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid non-vector operands to %qs"
 msgstr "sai đặt toán hạng tới %%R"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "chế độ con trỏ %qs không hợp lệ"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 #| msgid "type is deprecated: %s"
 msgid "vector type expected in %qs"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "kiểu không khớp trong biểu thức nhị phân"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr ""
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "toán hạng không hợp lệ trong phép toán tam nguyên"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 #| msgid "type is deprecated: %s"
 msgid "vector types expected in %qs"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr ""
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type for %q+D"
 msgid "invalid mask type in %qs"
 msgstr "kiểu trừu tượng cho %q+D không hợp lệ"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "Hóa hợp không được hỗ trợ: %s"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid position or size in %qs"
 msgstr "chế độ con trỏ %qs không hợp lệ"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 #| msgid "shift of non-integer operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "dịch của toán hạng không nguyên"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a directory"
 msgid "%qs not at element boundary"
 msgstr "%qs không phải là một thư mục"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number %qs"
 msgid "non-trivial conversion in %qs"
 msgstr "số thứ tự phiên bản không hợp lệ %qs"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "cần biểu thức"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "sai đặt toán hạng tới %%R"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for %q+D"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "tên thanh ghi cho %q+D không hợp lệ"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 msgid "incorrect type of vector %qs elements"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 #| msgid "different number of results"
 msgid "incorrect number of vector %qs elements"
 msgstr "khác số của kết quả"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr ""
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr ""
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr ""
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr ""
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr ""
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr ""
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr ""
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "invalid CASE_CHAIN"
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "sai CASE_CHAIN"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "nhãn case không hợp lệ trong câu lệnh switch"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "kiểu không khớp cho nhãn case trong câu lệnh switch"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr ""
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "các nhãn case không được sắp xếp trong câu lệnh switch"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "array notations cannot be used in declaration"
 msgid "label context is not the current function declaration"
 msgstr "Cảnh báo về lời khai báo kiểu cũ"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr ""
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr ""
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr ""
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "kết quả PHI không hợp lệ"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "thiếu PHI def"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "sai tham số PHI"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in send"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "không tương thích kiểu trong bộ gửi"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple gặp lỗi"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr ""
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 msgid "local declaration from a different function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, gcc-internal-format
 msgid "PHI node with location"
 msgstr ""
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr ""
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr ""
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "lệnh được đánh dấu cho throw, nhưng không phải vậy"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "lệnh được đánh dấu cho throw ở giữa một khối"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple gặp lỗi"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr ""
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr ""
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "nhãn không-cục-bộ"
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr ""
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "nhãn"
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr ""
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr ""
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr ""
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr ""
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "nhãn cho case chưa được sắp xếp: "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr ""
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "thiếu edge %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> hàm trả về"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
@@ -27964,47 +28017,47 @@ msgstr "trong phần định nghĩa macro %qs"
 msgid "in expansion of macro %qs"
 msgstr "trong phần mở rộng macro %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "BB %i thiếu cạnh"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i có cạnh sai"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -28510,12 +28563,12 @@ msgstr ""
 msgid "verify_ssa failed"
 msgstr "verify_ssa gặp lỗi"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr ""
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr ""
@@ -28584,7 +28637,7 @@ msgstr ""
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr ""
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -28595,31 +28648,31 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "union được định nghĩa ở đây"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "chỉ số mảng nằm ngoài phạm vi của mảng"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "chỉ số mảng nằm ngoài phạm vi của mảng"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "chỉ số mảng nằm ngoài phạm vi của mảng"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "chỉ số mảng nhỏ hơn cận dưới"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -28699,32 +28752,32 @@ msgstr ""
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "tree check: cần omp_clause %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD đã lạc hậu: %s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD đã lạc hậu"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE đã lạc hậu: %s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE đã lạc hậu"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "kiểu đã lạc hậu"
@@ -28749,234 +28802,234 @@ msgstr "kiểu đã lạc hậu"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "main variant is not defined"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr ""
 
-#: tree.c:14605
+#: tree.c:14616
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -29104,86 +29157,86 @@ msgstr ""
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr ""
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 #| msgid "%+D declared weak after being used"
 msgid "%+qD declared weak after being used"
 msgstr "%+D đã khai báo weak sau khi được dùng"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref không được hỗ trợ trong cấu hình này"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelax is only supported for RTP PIC"
 msgid "symver is only supported on ELF platforms"
 msgstr "-mrelax chỉ hỗ trợ cho RTP PIC"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, gcc-internal-format
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s không được hỗ trợ bởi cấu hình này"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -29797,7 +29850,7 @@ msgstr "thuộc tính %qE theo %qE"
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -29817,7 +29870,7 @@ msgstr "%qD không tương thích với %qD"
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -30206,12 +30259,12 @@ msgstr ""
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh phép gán được dùng như là giá trị chân lý"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "dùng %<restrict%> không hợp lệ"
@@ -30367,12 +30420,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "quá ít đối số cho hàm %qE"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -30474,7 +30527,7 @@ msgstr ""
 msgid "size of array is too large"
 msgstr "kích cỡ mảng là quá lớn"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
@@ -30484,130 +30537,130 @@ msgstr ""
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be channel"
 msgid "both arguments must be compatible"
 msgstr "đối số phải là kênh"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "đối số %d của %qE phải là bội số của %d"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "giá trị chỉ mục nằm ngoài phạm vi cho phép"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "kích cỡ mảng bị âm"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30663,517 +30716,517 @@ msgstr ""
 msgid "format string argument follows the arguments to be formatted"
 msgstr ""
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "hàm nên ứng cử cho thuộc tính %<%s%>"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr ""
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr ""
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr ""
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr ""
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, gcc-internal-format
 msgid "%<$%>operand number used after format without operand number"
 msgstr ""
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr ""
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr ""
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr ""
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "quá nhiều đối số cho định dạng"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, gcc-internal-format
 msgid "unused arguments in %<$%>-style format"
 msgstr ""
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "chuỗi định dạng %s có độ dài bằng không"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "định dạng là một chuỗi ký tự rộng lớn"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type %qT"
 msgid "format string is not an array of type %qs"
 msgstr "ISO C++ cấm việc áp đổi kiểu của mảng %qT"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "gặp chuỗi định dạng chưa được chấm dứt"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s được dùng với định dạng %<%%%c%> %s"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s không hỗ trợ %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s không hỗ trợ %s với %<%%%c%> định dạng %s"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "lặp %s trong định dạng"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr ""
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "độ rộng bằng không trong định dạng %s"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "độ chính xác trái bị trống rỗng trong định dạng %s"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "độ chính xác bị trống rỗng trong định dạng %s"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr ""
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s không hỗ trợ %<%%%c%> định dạng %s"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s bị bỏ qua với %s và %<%%%c%> %s định dạng"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s bị bỏ qua với %s trong %s định dạng"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "dùng của %s và %s cùng với %<%%%c%> định dạng %s"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "dùng của %s và %s cùng với định dạng %s"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> chỉ sinh ra 2 số cuối của năm trong một số địa phương"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> chỉ sinh ra 2 số cuối của năm"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "chưa đóng %<]%> cho định dạng %<%%[%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr ""
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s không hỗ trợ %<%%%s%c%> định dạng %s"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr ""
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr ""
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "lặp %s trong định dạng"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "lặp %s trong định dạng"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "%<\\0%> được nhúng trong định dạng"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "dùng %qE để thay thế"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "unquoted attribute in format"
 msgstr "thuộc tính hàm không khớp"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "không thể tắt hàm dựng sẵn %qs"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, gcc-internal-format
 msgid "unquoted whitespace character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "precision in printf format"
 msgid "spurious trailing space in format"
 msgstr "độ chính xác theo định dạng printf"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr ""
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, gcc-internal-format, gfc-internal-format
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr ""
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 msgid "unquoted control characters in format"
 msgstr "Có ký tự tab không phù hợp tại %C"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 msgid "unquoted control character %qc in format"
 msgstr "Có ký tự tab không phù hợp tại %C"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, gcc-internal-format
 msgid "unquoted option name %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
 msgstr ""
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "lặp %s trong định dạng"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "lặp %s trong định dạng"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "lặp %s trong định dạng"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, gcc-internal-format
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, gcc-internal-format
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "Có ký tự tab không phù hợp tại %C"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph character %qc in format"
 msgstr "Có ký tự tab không phù hợp tại %C"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, gcc-internal-format
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated format string"
 msgid "unterminated quoting directive"
 msgstr "gặp chuỗi định dạng chưa được chấm dứt"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 msgid "unterminated quote character %<%c%> in format"
 msgstr "Có ký tự tab không phù hợp tại %C"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr ""
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, gcc-internal-format
 msgid "nested quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "%<\\0%> được nhúng trong định dạng"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "sự xen kẽ phương ngôn assembly chưa chấm dứt"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> cần khớp một đối số %<%s%s%>"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> cần khớp một đối số %<%T%s%> argument"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> không được định nghĩa là một kiểu"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> không được định nghĩa như là kiểu %<long%> hay %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> không được định nghĩa là kiểu con trỏ"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "args được định dạng không %<…%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -31337,7 +31390,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -31352,17 +31405,17 @@ msgstr "biến iterator"
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
@@ -31372,7 +31425,7 @@ msgstr "thiếu biểu thức gia số"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -31996,7 +32049,7 @@ msgid "wrong type argument to %s"
 msgstr "sai kiểu đối số cho %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "tràn trong biểu thức hằng"
@@ -32696,7 +32749,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -32773,7 +32826,7 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -32793,7 +32846,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
@@ -32814,7 +32867,7 @@ msgstr "“%qs” không phải là một tùy chọn hợp lệ cho bộ tiền
 msgid "too many input files"
 msgstr "quá nhiều tập tin nhập vào"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -32848,14 +32901,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ là: %s; có phải ý bạn là là: %qs?"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -33415,423 +33468,430 @@ msgstr ""
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "Assembler không hỗ trợ -mabi=ilp32"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "cần %qT nhưng đối số là kiểu %qT"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "cần %qT nhưng đối số là kiểu %qT"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> không phải là một chuỗi hay số"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "cần %<for%> sau %qs"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the SVE ISA extension"
 msgstr "Không dùng lệnh mở rộng SPE ABI."
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "Vector argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%qE requires the SVE ISA extension"
 msgstr "Dùng lệnh mở rộng SPE ABI."
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid format of %s"
 msgid "invalid format for sve_width"
 msgstr "định dạng của %s không hợp lệ"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "giá trị %%h sai"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "không hiểu tùy chọn chỉnh (%s)"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mcpu=%qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "thiếu cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 #| msgid "missing arch name in -march=%qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "thiếu tên kiến trúc trong -march=%qs"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -march"
 msgid "unknown value %qs for %<-march%>"
 msgstr "không hiểu giá trị %qs cho -march"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mtune=%qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "thiếu tên cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s xung đột với -march=%s"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "Assembler không hỗ trợ -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %<-f%s%>"
 msgstr "mô hình mã %qs với -f%s"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<=%> (after %<getter%> attribute)"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> sai dạng"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -34027,17 +34087,17 @@ msgstr ""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -34196,13 +34256,13 @@ msgstr "không hiểu xuất bộ liên kết %qs"
 msgid "invalid type for %<asm%> flag output"
 msgstr "sử dụng kết xuất cờ asm sai"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "coprocessor not enabled"
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "đồng xử lý chưa được bật"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -34210,196 +34270,196 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "đối số %d của %qE phải nằm trong vùng %d…%d"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections không được hỗ trợ cho đích này"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "bộ chọn phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 7"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 3"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 1"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mặt nạ phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "vùng mặt nạ phải nằm từ 0 đến 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_rori_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_ror_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_si64 trong mã."
@@ -34409,296 +34469,296 @@ msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt và NEON là xung khác lẫn nhau"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "CPU đích không hỗ trợ chế độ ARM"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, gcc-internal-format
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt không được hỗ trợ dưới chế độ Thumb"
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "không thể sử dụng -mtp=cp15 với 16-bit Thumb"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC không tương thích với Thumb"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr "-mslow-flash-data chỉ hỗ trợ mã không-pic trên đích armv7-m"
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr "-mslow-flash-data chỉ hỗ trợ mã không-pic trên đích armv7-m"
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "CPU đích không hỗ trợ truy cập chưa cân chỉnh"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check không tương thích với -mno-apcs-frame"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic và -mapcs-reent là xung khắc nhau"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC không tương thích với -msingle-pic-base"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= là vô ích nếu không có -fpic"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "không thể dùng “%s” cho thanh ghi PIC"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition không được hỗ trợ trên kiến trúc này"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable và -msdata=%s là không tương thích"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "CPU đích không hỗ trợ làm việc tương tác"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS không hỗ trợ -mcaller-super-interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS không hỗ trợ -mcallee-super-interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 và không ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, fuzzy, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard và VFP"
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard và VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS dẫn suất biến thể PCS"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "biến thể PCS"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 dấu-chấm-động-bằng-phần-cứng VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific cho Thumb-1"
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fpu for attribute(target(\"%s\"))"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -34707,23 +34767,23 @@ msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown target attribute or pragma %qs"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "asm flags not supported in thumb1 mode"
@@ -34807,18 +34867,18 @@ msgstr "-fpie không được hỗ trợ"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE không được hỗ trợ"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-fwpa và -fltrans loại trừ lẫn nhau"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs hàm không có đối số"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs hàm không trả về giá trị nào"
@@ -35090,7 +35150,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr ""
@@ -35433,56 +35493,56 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "Gửi đối số dấu chấm động trong thanh ghi dành cho dấu chấm động."
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "wrong type of argument %s"
 msgstr "sai kiểu đối số cho %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr ""
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "TLS is not implemented for GCN."
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "sorry, unimplemented"
 msgid "Builtin not implemented"
 msgstr "tiếc là chưa thực hiện"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "số thứ tự toán hạng ở ngoại phạm vi"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -35627,133 +35687,133 @@ msgstr "đối số %d của %qE phải nằm trong vùng %d…%d"
 msgid "parameter to builtin not valid: %s"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr ""
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 2-bít"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "đối số thứ ba phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 3-bít"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "chế độ so sánh không đúng"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "đối số cuối phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "đối số thứ tư phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -36160,146 +36220,146 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and thiscall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -36765,7 +36825,7 @@ msgstr ""
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr ""
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Thuộc tính %qE cần tham số là chuỗi"
@@ -37875,55 +37935,55 @@ msgstr ""
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr ""
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
@@ -38048,350 +38108,351 @@ msgstr "số phải là 0 hay 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "có rác ở cuối %<#pragma align%>"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs requires an argument list at %C"
 msgid "builtin %qs requires builtin %qs"
 msgstr "Hàm %qs cần một danh sách đối số tại %C"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s không được hỗ trợ bởi cấu hình này"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, gcc-internal-format
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "đối số 1 phải là trường 8-bit"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_set_thread_pointer không được hỗ trợ trên đích này"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a field reference"
 msgid "Argument must be a value between 0 and 3."
 msgstr "đối số phải là một tham chiếu trường"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_set_thread_pointer không được hỗ trợ trên đích này"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_set_thread_pointer is not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_set_thread_pointer không được hỗ trợ trên đích này"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a field reference"
 msgid "Argument must be a value between 0 and 7."
 msgstr "đối số phải là một tham chiếu trường"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "đối số 1 phải là kiểu văn có dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "đối số %qd không phải hằng số"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs is too large (max. %d)"
 msgid "argument 1 of %qs is out of range"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/rs6000/rs6000-call.c:9255
-#, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr ""
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s chỉ chấp nhận một tham số"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "đối số không hợp lệ cho %qD"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 4-bit"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 2-bit"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 6-bit"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "đối số 2 phải là 0 hay 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be 0 or 2"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be 0 or 2"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is only valid for the cell processor"
 msgstr "“%qs” không phải là một tùy chọn hợp lệ cho bộ tiền xử lý"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "%qE needs isa option %s"
 msgid "%qs requires the %qs option"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "Bật sử dụng câu lệnh dấu số thực chấm động 128-bit IEEE."
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported with the current options"
 msgstr "%s không được hỗ trợ bởi cấu hình này"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
@@ -38412,238 +38473,243 @@ msgstr "%qE được dùng với %<register%>"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 yêu cầu kiến trúc PowerPC64, đang bật"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec không được hỗ trợ ở đích này"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring không được hỗ trợ trên hệ thống lớn trước"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs không tương thích với %s %s"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT được coi là %qs"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "dùng phần mở rộng số nguyên chính đôi IEEE"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "dùng phần mở rộng số nguyên chính đôi IBM"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128 requires VSX support"
 msgid "%qs requires VSX support"
 msgstr "-mfloat128 cần hỗ trợ VSX"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
 #| msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "Chưa biết thư viện véc-tơ-hóa ABIs (để dùng với tùy chọn -mveclibabi=):"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs needs a valid base register"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated and has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs đã lỗi thời và không có tác động gì"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
@@ -38989,141 +39055,141 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float không được hỗ trợ trong tổ hợp"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -39560,8 +39626,8 @@ msgstr ""
 msgid "could not read the BRIG file"
 msgstr "không thể ghi vào tập tin đáp ứng %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -39843,7 +39909,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -39913,7 +39979,7 @@ msgstr ""
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -39943,7 +40009,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "trùng nhãn %qD"
@@ -40154,7 +40220,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -40494,7 +40560,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -40801,7 +40867,7 @@ msgstr "định nghĩa lại bị lồng của %<struct %E%>"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -40851,7 +40917,7 @@ msgstr "cấu có không thành viên đã đặt tên"
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -40887,7 +40953,7 @@ msgstr ""
 msgid "redeclaration of %<enum %E%>"
 msgstr "khai báo lại của %<enum %E%>"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
@@ -40917,7 +40983,7 @@ msgstr "tràn giá trị liệt kê"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared weak"
 msgid "inline function %qD given attribute %qs"
@@ -40948,7 +41014,7 @@ msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
@@ -41063,12 +41129,12 @@ msgstr ""
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
@@ -41076,259 +41142,259 @@ msgstr "đối số %qD đặt nhưng chưa được dùng"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "cần các định danh khai báo"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 không hỗ trợ kiểu complex"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C không hỗ trợ kiểu saturating"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "lặp lại %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 không hỗ trợ kiểu lô-gíc"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm động hệ thập phân"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "kiểu dấu chấm cố định không được hỗ trợ trên đích này"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm cố định"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE không ở đầu của khai báo"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE được dùng với %<auto%>"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 không hỗ trợ %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 không hỗ trợ %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> trước %<extern%>"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> trước %<static%>"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "trùng %<_Thread_local%> hay %<__thread%>"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs được dùng với %qE"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> được dùng mà không có %<_Fract%> or %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "dịch trái của một giá trị âm"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
@@ -41349,7 +41415,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "không khớp cho"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -41395,7 +41461,7 @@ msgid "unknown type name %qE"
 msgstr "không hiểu tên kiểu %qE"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -41415,7 +41481,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -41430,8 +41496,8 @@ msgstr ""
 msgid "unexpected attribute"
 msgstr "cần thuộc tính"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -41469,7 +41535,7 @@ msgstr "%<__auto_type%> cần một khai báo khởi tạo dữ liệu"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> có lẽ chỉ được dùng với khai báo đơn"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "cần %<,%> hoặc %<;%>"
@@ -41497,7 +41563,7 @@ msgstr "ISO C99 không hỗ trợ %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 không hỗ trợ %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "cần chuỗi văn chương"
@@ -41528,7 +41594,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "thẩm tra tĩnh gặp lỗi"
@@ -41573,14 +41639,14 @@ msgstr ""
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "dấu phẩy ở cuối của danh dánh liệt kê"
@@ -41665,7 +41731,7 @@ msgstr "cần các định danh khai báo hay %<…%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string argument"
 msgid "%qE attribute does not take any arguments"
@@ -41677,7 +41743,7 @@ msgstr "Thuộc tính %qE cần tham số là chuỗi"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -41737,7 +41803,7 @@ msgstr ""
 msgid "expected %<}%> before %<else%>"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> mà không có %<if%> ở trước"
@@ -41752,7 +41818,7 @@ msgstr ""
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "cần biểu thức"
@@ -41777,17 +41843,17 @@ msgstr ""
 msgid "expected identifier or %<*%>"
 msgstr "cần một định danh hoặc %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -41807,12 +41873,12 @@ msgstr ""
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -41828,8 +41894,8 @@ msgstr ""
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "trùng cv-qualifier"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -41858,12 +41924,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -42265,63 +42331,63 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<setter%>)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
@@ -42332,18 +42398,18 @@ msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
@@ -42364,54 +42430,54 @@ msgstr "cần %<,%> hoặc %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến trỏ"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "cần %<data%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -42433,12 +42499,12 @@ msgstr "%<num_threads%> giá trị phải dương"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%> giá trị phải dương"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%> giá trị phải dương"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
@@ -42449,25 +42515,25 @@ msgstr "%<priority%> giá trị phải dương"
 msgid "expected constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> hoặc %<max%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -42482,55 +42548,55 @@ msgstr "biểu thức %qs phải là số nguyên"
 msgid "%qs value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "gặp tham số thừa"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%>"
 msgid "expected %<concurrent%>"
 msgstr "cần %<none%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
@@ -42540,7 +42606,7 @@ msgstr ""
 msgid "chunk size value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -42575,23 +42641,23 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %qs"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs không tương thích với %qs"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -42607,77 +42673,77 @@ msgstr "kiểu proc_bind không hợp lệ"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "cần mệnh đề %<#pragma acc%>"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
@@ -42692,7 +42758,7 @@ msgstr "%qE chưa được khai báo"
 msgid "expected function name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD không phải là hàm thành viên mẫu"
@@ -42702,73 +42768,73 @@ msgstr "%qD không phải là hàm thành viên mẫu"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau cho bộ nhớ"
@@ -42778,62 +42844,62 @@ msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "cần %<:%>, %<,%>, %<;%>, %<}%> hoặc %<__attribute__%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
@@ -42843,73 +42909,73 @@ msgstr "cần khai báo nhắc lại hay sự khởi tạo"
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> với mệnh đề %<depend%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -42925,64 +42991,64 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> phải xuất hiện trước khai báo của %D, đang lờ đi"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "cần selection-statement"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "%s tại %L phải là số nguyên"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "cần chuỗi văn chương"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "property must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -42994,13 +43060,13 @@ msgstr "cần %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43010,32 +43076,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "cần %<declare%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -43090,45 +43156,45 @@ msgstr "cần tên-hàm %<(%>"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "clause not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "mệnh đề vẫn chưa được hỗ trợ"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -43145,27 +43211,27 @@ msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
@@ -43176,7 +43242,7 @@ msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
@@ -43191,7 +43257,7 @@ msgstr "tác vụ bao quanh"
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "sử dụng sai biểu thức void"
@@ -43312,7 +43378,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "chỉ số mảng không phải là số nguyên"
@@ -43337,7 +43403,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -43452,18 +43518,18 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "quá ít đối số cho hàm %qE"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about use of multi-character character constants."
 msgid "comparison between pointer and zero character constant"
 msgstr "Cảnh báo về sử dụng hằng số ký tự đa ký tự."
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "did you mean to use logical not?"
 msgid "did you mean to dereference the pointer?"
@@ -43489,7 +43555,7 @@ msgstr "con trỏ đến hàm được dùng trong phép trừ"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -43739,7 +43805,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -43912,7 +43978,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -44077,7 +44143,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "mảng loại không thích hợp bị khởi tạo từ hằng số chuỗi"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sai sử dụng mảng không phải lvalue"
@@ -44108,7 +44174,7 @@ msgstr "yếu tố khởi tạo không tính được vào lúc nạp"
 msgid "invalid initializer"
 msgstr "bộ khởi tạo sai"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -44254,7 +44320,7 @@ msgstr "gặp yếu tố thừa trong bộ khởi tạo vô hướng"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C cấm %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
@@ -44294,7 +44360,7 @@ msgstr ""
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -44304,17 +44370,17 @@ msgstr ""
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "câu lệnh “continue” nằm ở ngoài một vòng lặp"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -44329,7 +44395,7 @@ msgstr ""
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "câu lệnh không có tác dụng"
@@ -44339,22 +44405,22 @@ msgstr "câu lệnh không có tác dụng"
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -44405,7 +44471,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -44435,53 +44501,53 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma simd%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "cần mệnh đề %<#pragma simd%>"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %qs"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE không phải là thành viên của union"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
@@ -44491,8 +44557,8 @@ msgstr "%qE không phải một biến trong mệnh đề %qs"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD trong mệnh đề %qs"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
@@ -44669,12 +44735,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE phải là %<threadprivate%> với %<copyin%>"
@@ -44699,8 +44765,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
@@ -44715,19 +44781,19 @@ msgstr ""
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
@@ -44800,117 +44866,117 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE không phải một kiểu ánh xạ được trong mệnh đề %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE không phải một biến cũng không phải tên hàm trong mệnh đề %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "nguồn không phải là một hàm trỏ"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -45113,821 +45179,821 @@ msgid "expected case label"
 msgstr "cần kênh"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  chuyển đổi cho đối số %d nên là ill-formed:"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  no known conversion from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 #| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  ứng cử cần %d đối số, %d được cung cấp"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T, %T) <dựng-sắn>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T) <dựng-sẵn>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%D(%T) <dựng-sẵn>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s%T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s%T <chuyển đổi>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <near match>"
 msgid "%s%#qD (near match)"
 msgstr "%s%#D <gần khớp>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <deleted>"
 msgid "%s%#qD (deleted)"
 msgstr "%s%#D <xóa>"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <deleted>"
 msgid "%s%#qD (reversed)"
 msgstr "%s%#D <xóa>"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D"
 msgid "%s%#qD"
 msgstr "%s%#D"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, gcc-internal-format
 msgid "  inherited here"
 msgstr "  được kế thừa ở đây"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr ""
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr ""
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr ""
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr ""
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr ""
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%D(%A)%> chưa rõ ràng"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "cú gọi của %<(%T) (%A)%> chưa rõ ràng"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "quá tải chưa rõ ràng đối với"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, gcc-internal-format
 msgid "no match for "
 msgstr "không khớp cho"
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (các kiểu toán hạng là %qT, %qT, and %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (các kiểu toán hạng là %qT và %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (kiểu toán hạng là %qT)"
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "bộ tam nguyên %<operator?:%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "bộ tam nguyên %<operator?:%> trong %<%E ? %E : %E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> trong %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> trong %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs trong %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> trong %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> trong %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> trong %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "return type of %qD is not %qs"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "so sánh giữa %q#T và %q#T"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is a usual (non-placement) deallocation function"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "đã được khai báo ở đây"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "được khai báo bảo vệ ở đây"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D là không thể truy cập trong ngữ cảnh này"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  đang khởi tạo đối số %P của %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind %qT lvalue to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "không thể buộc %qT lvalue thành %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "re-initialization of %qs at %L"
 msgid "; use copy-initialization instead"
 msgstr "khởi tạo lại của %qs tại %L"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%#qT declared here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%s(%A)%> chưa rõ ràng"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "đóng %qD thông qua %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ứng cử 1: %q#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ứng cử 2: %q#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -45956,536 +46022,536 @@ msgstr ""
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr ""
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D inherited from %qT"
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "%q#D kế thừa từ %qT"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "version inherited from %qT declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D không thể được quá tải"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr ""
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr ""
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr "  bởi vì phương thức nội bộ %q+#D có cùng tên"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr "  bởi vì thành viên nội bộ %q+#D có cùng tên"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "array member %q#D declared here"
 msgid "local member %q#D declared here"
 msgstr "thành viên mảng %q#D đã khai báo ở đây"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q#D không thể được tạo đè"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%q+D bị ẩn"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  bởi %q+D"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, gcc-internal-format
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr ""
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "độ rộng bị âm trong trường bít %q+D"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "trường bít %q+D có độ rộng là không"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 #| msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-qualifiers chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "trường %q#D với cùng tên với lớp"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T có thành viên dữ liệu con trỏ"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  nhưng không đè %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  hoặc %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  nhưng không được ghi đè %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T không là kiểu văn chương vì:"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu hay thay đổi"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "lớp cơ sở %q+T có một hủy tử non-trivial truy cập được"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "thành viên mảng %q#D đã khai báo ở đây"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "trong định nghĩa của %q#T"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "không đủ thông tin kiểu"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -46570,7 +46636,7 @@ msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E không phải biểu thức hằng"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "gọi hàm nội bộ"
@@ -46629,7 +46695,7 @@ msgstr "Đang cố cấp phát một biến đã được cấp phát rồi"
 msgid "deallocation of storage that was not previously allocated"
 msgstr ""
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "gọi hàm nội bộ"
@@ -46685,382 +46751,381 @@ msgstr ""
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "con trỏ rỗng"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer is not an integer constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "được khai báo ở đây"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D không là const"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D là volatile"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD không được khởi tạo với một biểu thức hằng"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "Đổi giá trị trong chuyển đổi từ %qs sang %qs tại %L"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "cần template-id"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<constexpr%> outside its class"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD được khai báo %<constexpr%> ngoài lớp của nó"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<concept%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have integral type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "evaluating %qs"
@@ -47110,7 +47175,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -47153,293 +47218,293 @@ msgstr "%q#T được dùng ở nơi mà %qT cần"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "Chuyển đổi từ %qs sang %qs tại %L"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "câu lệnh không có tác động gì"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -47506,7 +47571,7 @@ msgstr "từ khai báo trước đây %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "khai báo trước đây %q#D"
@@ -47698,12 +47763,12 @@ msgstr "khai báo trước đây của %q+D ở đây"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD"
@@ -47717,44 +47782,44 @@ msgstr "định nghĩa lại của %q+D"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "định nghĩa lại của %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -47762,853 +47827,853 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "khai báo lại của %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "khai báo trước"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  từ đây"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  thoát khỏi khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  sự khởi tạo chéo của %q+#D"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  vào khối try"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  vào khối catch"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "cần biểu thức"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  bỏ qua sự khởi tạo của %q#D"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "%qD used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T không phải là một lớp"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "không có kiểu có tên %q#T trong %q#T"
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d không được hỗ trợ"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> chỉ có thể được chỉ định trong một lớp"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> chỉ có thể được chỉ định cho cấu tử"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> chỉ có thể được chỉ định cho lớp và hàm"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> bị bỏ qua trong khai báo này"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D không phải là thành viên tĩnh của %q#T"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ không cho phép %<%T::%D%> được định nghĩa như là %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared %<virtual%> inside a union"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa được khởi tạo"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "thiếu kích thước mảng trong %qD"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "uninitialized %<const %D%>"
 msgstr "lặp lại %<const%>"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "đối số %q#D có kiểu chưa đầy đủ"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "tham chiếu %qD được khởi tạo bằng chính nó"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "nguồn là một hàm trỏ tới loại không hoàn toàn"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "nguồn có loại lớp không hoàn toàn"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
@@ -48882,7 +48947,7 @@ msgstr "tràn kích thước mảng"
 msgid "%qD declared as array of %qT"
 msgstr "%qD được khai báo là mảng của %qT"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
@@ -49051,7 +49116,7 @@ msgstr ""
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
@@ -49259,835 +49324,835 @@ msgstr "thuộc tính bị bỏ qua"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not have parameters"
 msgid "constructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> ngoài khai báo lớp"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "typedef may not be a function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "typedef may not be a member function definition"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "cấu tử không thể là %<concept%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "không thể mở %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qD in unnamed class"
 msgid "static data member %qE declared %qs"
 msgstr "thành viên dữ liệu tĩnh %qD trong lớp không tên"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared with placeholder %qT"
 msgid "non-static data member %qE declared %qs"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "hậu tố %qD cần trả về %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -50099,95 +50164,95 @@ msgstr "%qT được coi là enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT được định nghĩa với cơ sở đa trực tiếp"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT được định nghĩa cơ sở trực tiếp ảo"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
@@ -50196,73 +50261,73 @@ msgstr "đối số %d của %qE phải là một địa chỉ"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 #| msgid "increment of enumeration value is invalid in C++"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -50302,7 +50367,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "cho khai báo hàm mẫu %q+D"
@@ -50312,7 +50377,7 @@ msgstr "cho khai báo hàm mẫu %q+D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -50648,168 +50713,168 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "converting far pointer to near pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "lệnh không thỏa những ràng buộc của nó:"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "không có đối số nào"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 #| msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11 auto inline chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-qualifiers chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-qualifiers chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++11 auto inline chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ref-qualifiers chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE; did you mean %qE?"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE; did you mean %qE?"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD không phải là thành viên của %qD"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> chưa được khai báo"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> chưa được khai báo"
@@ -50992,339 +51057,339 @@ msgstr ""
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D nên được khởi tạo"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sẽ được khởi tạo sau"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  cơ sở %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  khi khởi tạo ở đây"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "con trỏ cho trường bít %qD không hợp lệ"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "tràn số nguyên trong kích thước mảng"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr ""
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "kiểu không hợp lệ %<void%> cho new"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, gcc-internal-format
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr ""
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "bộ khởi tạo kết thúc bất ngờ"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, gcc-internal-format
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr ""
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -51487,12 +51552,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr ""
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr ""
@@ -51521,163 +51586,169 @@ msgstr "kiểu xung đột cho %q+D"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/method.c:1108
-#, gcc-internal-format
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1111
-#, gcc-internal-format
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr ""
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD phải nhận %<void%>"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr ""
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD đã sẵn là bạn của %qT"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot default compare reference member %qD"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture member %qD of anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr ""
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr ""
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected signature: %qD"
 msgstr "cần con trỏ"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr ""
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "một mẫu không thể là mặc định"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD không thể là mặc định"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -51721,223 +51792,223 @@ msgstr "%q#D trước định nghĩa ở đây"
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "sự khai báo của các bóng %qD như là thành viên của %qT"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q#D"
 msgid "local external declaration %q#D"
 msgstr "khai báo toàn cục %q#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q#D"
 msgid "does not match previous declaration %q#D"
 msgstr "xung đột với khai báo trước %q#D"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, gcc-internal-format
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> tên hủy tử"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> các tên cấu tử trong %qT"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qE"
 msgstr "%qE chưa được khai báo"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of namespace %qD here"
 msgid "using-declaration may not name namespace %qD"
 msgstr "khai báo trước đây của không gian tên %qD ở đây"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD chưa được khai báo trong %qD"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "các khả năng được gợi ý:"
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD đã định nghĩa rồi"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fabi-version=1%> is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<-fabi-version=1%> không còn tiếp tục được hỗ trợ nữa"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%qs tại %L phải là số nguyên"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX vào pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -51963,7 +52034,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -51988,7 +52059,7 @@ msgstr "%<::%E%> chưa được khai báo"
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> chưa được khai báo"
@@ -52068,7 +52139,7 @@ msgstr "template-id không hợp lệ"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -52194,7 +52265,7 @@ msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "%<concept%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 #| msgid "%<requires%> only available with -fconcepts"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
@@ -52316,7 +52387,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "cần khai báo"
@@ -52418,12 +52489,12 @@ msgstr "phần khai báo của %<~%T%> là thành viên của %qT"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD không phải một mẫu"
@@ -52459,7 +52530,7 @@ msgstr ""
 msgid "expected nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
@@ -52474,7 +52545,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
@@ -52489,7 +52560,7 @@ msgstr "ISO C++ cấm compound-literals"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "dùng %qD không hợp lệ"
@@ -52514,950 +52585,955 @@ msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in %qs expressions"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.c:8769
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "dùng áp kiểu theo cách cũ"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gợi ý bao quanh biểu thức %<>>%> bằng dấu ngoặc đơn"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 #| msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "cần kết thúc của capture-list"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "chụp %<*this%> chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "%<@synthesize%> can not be used in categories"
 msgid "%<this%> cannot be captured by reference"
 msgstr "%<@synthesize%> không thể được dùng trong các-ta-lốc"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "chụp %<*this%> chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "capture of non-variable %qE"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D được khai báo ở đây"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "lặp lại %<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "cần labeled-statement"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> tên cấu tử, không phải kiểu"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "trường %qE được khai báo như là một hàm"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "cần bộ khởi tạo"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 #| msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> mở rộng"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> không ở đầu của một khối"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "khai báo trống rỗng"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> được dùng bên ngoài lớp"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> thay đổi ý nghĩa trong C++11; hãy bỏ nó đi"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr ""
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in lambda"
 msgid "type-specifier invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in explicit-specifier"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "đặc tả linkage không hợp lệ"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 #| msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "static_assert không có lời nhắn chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "cần định danh hậu tố"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "cần toán tử"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu mặc định"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "cần template-id"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template-id"
 msgid "invalid template-argument-list"
 msgstr "template-id không hợp lệ"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "cần template-argument"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "cần template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "cần template-argument"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr ""
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "cần bộ chỉ định kiểu"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "cần template-id cho kiểu"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "cần type-name (tên kiểu)"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE không phải tên một kiểu"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%> after %qE"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "cần %<,%> hoặc %<)%> sau %qE"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD là một mẫu liệt kê"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD không phải tên một kiểu enumeration trong %qT"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "cần %<;%> hoặc %<{%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "không cho phép từ hạn định mở rộng"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ cấm kiểu liệt kê nặc danh không tên trống rỗng"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD không là một namespace-name"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> không cho phép định nghĩa ở đây"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr ""
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT không phải là một namespace"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr ""
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, gcc-internal-format
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> không phải một kiểu"
@@ -53466,439 +53542,439 @@ msgstr "%<%T::%E%> không phải một kiểu"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "bộ khai báo không hợp lệ"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "dùng %<%T::%D%> thay cho %<%T::%D%> cho tên của cấu tử trong tên hạn định"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "mã hạn định trong khai báo"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "cần câu khai báo"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD là một namespace"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "cần ptr-operator"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "đa ref-qualifiers"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "cách dùng không hợp lệ %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "cần type-specifier"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "cần %<,%> hoặc %<…%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "cần class-name"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "cần %<;%> sau định nghĩa cấu trúc"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "cần %<{%> hoặc %<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "không thể chỉ định %<override%> cho lớp"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "khai báo trước đây của %q+#T"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "cần %<;%> tại cuối khai báo thành viên"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "dùng %<auto%> không hợp lệ trong đặc tả ngoại lệ"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "cần %<:%> hoặc %<…%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 #| msgid "expression must be integral"
 msgid "expression must be enclosed in parentheses"
 msgstr "chỉ số phải là số nguyên"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "result type is not a plain type-constraint"
 msgstr "đối số %qd không phải hằng số"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -53907,555 +53983,555 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "cần %<data%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "cần %<@end%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "cần class-key"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "cần biểu thức nguyên"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in iterator type"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression (các đối số)"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> trước"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma grainsize%> must be inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma grainsize%> phải ở bên trong một hàm"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -54734,7 +54810,7 @@ msgstr ""
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -54760,84 +54836,84 @@ msgstr ""
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "quá nhiều đối số cho hàm %qE"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -54845,47 +54921,47 @@ msgstr ""
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -54895,500 +54971,500 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "phần khai báo mẫu của %qD không hợp lệ"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "nhận được %d đối số mẫu cho %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  nhưng cần %d"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with different type"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "định nghĩa lại của typedef %q+D với kiểu khác"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "định nghĩa nguyên bản xuất hiện ở đây"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  kiểu không khớp %qT và %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE không tương đương với %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ứng cử cần ít nhất %d đối số, nhưng cung cấp %d"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  không thể chuyển đổi %qE (kiểu %qT) thành kiểu %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT không được dẫn xuất từ %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "in template argument for type %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần mẫu kiểu %qD, nhưng lại nhận được %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  cần %qD nhưng lại nhận %qD"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "được cung cấp cho %qD"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
 msgstr "ràng buộc mẫu gặp lỗi nghiêm trọng"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE không ở đầu của khai báo"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
@@ -55406,298 +55482,298 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "sai số lượng đối số cho %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 #| msgid "%s %#S"
 msgid "%s %#qS"
 msgstr "%s %#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "previous specification in %q#D here"
 msgid "exception specification of %qD depends on itself"
@@ -55710,136 +55786,136 @@ msgstr "sau đặc tả trước đây trong %q#D"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT không phải là một namespace hay enum không hoạt vi"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in template argument"
 msgid "invalid use of %qT in template argument"
@@ -56056,7 +56132,7 @@ msgstr ""
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -56106,7 +56182,7 @@ msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
@@ -56208,7 +56284,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -56248,7 +56324,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
@@ -56379,122 +56455,122 @@ msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "target is not pointer or reference to complete type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "đích không phải là hàm trỏ hoặc tham chiếu đến loại hoàn toàn"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<tile%> value must be integral"
 msgid "%<tile%> argument needs integral type"
 msgstr "giá trị %<tile%> phải là số nguyên"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "thẩm tra tĩnh gặp lỗi: %s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<chưa giải quyết loại hàm quá tải>"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
@@ -56748,831 +56824,831 @@ msgstr ""
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 has invalid type"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "đối số 2 có kiểu không hợp lệ"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "lấy địa chỉ của mảng tạm"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ cấm chuyển đổi hằng chuỗi thành %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "việc chuyển đổi từ chuỗi thành %qT đã lỗi thời"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T không có thành viên nào mang tên %qE"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> không phải là thành viên của %qT"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT không là cơ sở của %qT"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT không phải kiểu con trỏ đến đối tượng"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ cấm gọi %<::main%> từ bên trong chương trình"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD không thể được dùng như một hàm"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "quá nhiều đối số cho cấu tử %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "quá nhiều đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "quá ít đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "quá nhiều đối số cho hàm %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "quá ít đối số cho hàm %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "quá nhiều đối số cho phương thức %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "quá ít đối số cho phương thức %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "quá nhiều đối số cho hàm"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "quá ít đối số cho hàm"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL được dùng trong số học"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "các kiểu toán hạng là %qT và %qT"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "Unrecognized option to floating-point init value: %qs"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "Không nhận ra tùy chọn để khởi tạo giá trị dấu chấm động: %qs"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "lấy địa chỉ của cấu tử %qE"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  cần qualified-id"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "đang lấy địa chỉ của mẫu"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "không thể lấy địa chỉ của %qs"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "%<~%> on a boolean expression"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> trên một biểu thức lôgíc"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 #| msgid "useless cast to type %qT"
 msgid "useless cast to type %q#T"
 msgstr "trừ phi ép thành kiểu %qT"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "%E qualifier ignored on asm"
 msgid "type qualifiers ignored on cast result type"
 msgstr "từ hạn định %E bị bỏ qua trên asm"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "đang chuyển đổi từ %qT thành %qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "áp đổi kiểu tử %qT thành %qT làm mất độ chính xác"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "áp đổi kiểu tử %qT thành %qT yêu cầu tăng cân chỉnh của kiểu đích"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ cấm việc áp đổi kiểu của mảng %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  trong định giá %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "gán giá trị cho mảng từ một danh sách bộ khởi tạo"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "mảng được dùng như là bộ khởi tạo"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "gán mảng không hợp lệ"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "%qD cannot have default arguments"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in return"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "trong đối số chuyển qua %P của %qD"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "tham chiếu đến biến cục bộ %qD được trả về"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "địa chỉ của nhãn %qD được trả về"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "địa chỉ của biến cục bộ %q+D được trả về"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in return statement"
 msgstr "quá nhiều giá trị trong lệnh trả về"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "trả về danh sách bộ khởi tạo"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "biểu thức trả về với một giá trị, trong hàm trả lại “void”"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -57840,107 +57916,107 @@ msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -58164,10 +58240,10 @@ msgstr ""
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr ""
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, gcc-internal-format
@@ -58336,7 +58412,7 @@ msgstr ""
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
@@ -58458,7 +58534,7 @@ msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -58501,7 +58577,7 @@ msgstr "đối số %qs của %qs intrinsict tại %L phải là %s"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là NGUYÊN hay THỰC"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr ""
@@ -58516,7 +58592,7 @@ msgstr "đối số %qs của %qs intrinsict tại %L phải là THỰC hay PH
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là NGUYÊN hay THỦ TỤC"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
@@ -58637,169 +58713,169 @@ msgstr ""
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr ""
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.c:1461
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr ""
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr ""
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr ""
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr ""
 
-#: fortran/check.c:1524
-#, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr ""
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr ""
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr ""
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr ""
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "STAT= đối số cho %s tại %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr ""
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là %s"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a variable"
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là một biến"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr ""
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr ""
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "Đối số âm N tại %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr ""
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr ""
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr ""
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr ""
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr ""
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr ""
@@ -58807,704 +58883,704 @@ msgstr ""
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr ""
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr ""
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr ""
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr ""
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr ""
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr ""
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be %s"
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là %s"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr ""
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr ""
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "SIZE tại %L phải là số dương"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr ""
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr ""
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a variable"
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "%qs tại %C không phải là một biến"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "Đối số %qs của hạn chế %qs tại %L phải là thực thể dữ liệu"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr ""
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr ""
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr ""
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr ""
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr ""
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr ""
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr ""
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "Đối số %qs của hạn chế %qs tại %L phải là khoảng 1 hay 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr ""
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr ""
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr ""
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr ""
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr ""
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr ""
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be %s"
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a scalar"
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là tuyến tính"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr ""
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "%qs của %qs là RIÊNG tại %L"
@@ -59699,757 +59775,757 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr ""
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Tên “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Ký hiệu “%qs” tại %C đã sẵn được khai báo tại %L"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr ""
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn được khai báo tại %L"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Khởi tạo con trỏ khác KHÔNG tại %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qs hàm không có đối số"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "Tên có chứa ký tự không hợp lệ tại %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Sự khởi tạo kiểu cũ tại %C"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "đối số kiểu được dẫn suất tham số hóa"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "kiểu BYTE tại %C"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Giả định kiểu tại %C"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid type-spec at %C"
 msgid "Malformed type-spec at %C"
 msgstr "type-spec không hợp lệ tại %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "câu lệnh CLASS tại %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr ""
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "thuộc tính ASYNCHRONOUS tại%C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "thuộc tính CONTIGUOUS tại %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "thuộc tính BẢO VỆ tại %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "thuộc tính VALUE tại %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "thuộc tính VOLATILE tại %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Thuộc tính sai"
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "Return value %qs of function %qs declared at %L not set"
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
@@ -60457,1023 +60533,1023 @@ msgstr "Trả lại giá trị %sq của hàm %qs khai báo tại %L chưa đặ
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Thiếu ký hiệu"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C) tại %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Tiền tố MODULE tại %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr ""
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "thủ tục IMPURE tại %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A type parameter list is required at %C"
 msgstr "Đẳng sau “%<*%>” thì yêu cầu một dấu ngoặc đơn mở"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A parameter name is required at %C"
 msgstr "Đẳng sau “%<*%>” thì yêu cầu một dấu ngoặc đơn mở"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Cần một giao diện không tên tại %C"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol %qs in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Trùng ký hiệu %qs trong danh sách đối số hình thức tại %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Trùng ký hiệu %qs trong danh sách đối số hình thức tại %C"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Thủ tục “%qs” tại %L đã sẵn có kiểu cơ bản của %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "Hàm khai báo tại %L không phải xuất hiện trong một GIAO DIỆN"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Không cần câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr ""
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "cần lệnh %s tại %L"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Cần tên chấm dứt tại %C"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "Cần %<(%> tại %C"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Cần tên biến tại %C"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Cần \")\" tại %C"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "cần %<,%> hoặc kết thúc câu lệnh tại %C"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr ""
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "câu lệnh CONTIGUOUS tại %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "câu lệnh VALUE tại %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "câu lệnh VOLATILE tại %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "câu lệnh ASYNCHRONOUS tại %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Kiểu TRỪU TƯỢNG tại %C"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "gặp lỗi khi đóng tập tin thống kê %s [%s]"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "derived type declaration"
 msgid "Mangled derived type definition at %C"
 msgstr "lời khai báo loại có hướng"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %L already has basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "Thủ tục “%qs” tại %L đã sẵn có kiểu cơ bản của %s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "thẻ %s tại %L phải là kiểu %s"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM và ENUMERATOR tại %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Trùng DEFERRED tại %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Cần access-specifier tại %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "cần %<)%> tại %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Cần tên ràng buộc tại %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "danh sách PROCEDURE tại %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Cần %<::%> tại %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Cần %<=>%> tại %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL trống rỗng tại %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "Cần %<,%> tại %C"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Không rõ tên thủ tục “%qs” tại %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -61601,13 +61677,13 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE prefix at %C"
 msgid "LEN part_ref at %C"
 msgstr "Tiền tố MODULE tại %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE prefix at %C"
 msgid "KIND part_ref at %C"
@@ -61685,7 +61761,7 @@ msgstr ""
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr ""
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr ""
@@ -61953,7 +62029,7 @@ msgstr ""
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
@@ -62012,172 +62088,172 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is used as actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Thủ tục nội tại %qs được dùng làm đối số thật tại %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 #| msgid "Error in pointer initialization at %C"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -62204,7 +62280,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -62402,12 +62478,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -62478,586 +62554,586 @@ msgstr "Chuyển đổi từ %qs sang %qs tại %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr ""
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr ""
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr ""
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr ""
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr ""
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "Đối số thủ tục không hợp lệ tại %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr ""
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr ""
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr ""
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr ""
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr ""
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr ""
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr ""
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr ""
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr ""
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr ""
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr ""
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr ""
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L may not be a statement function"
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "Giao diện %qs tại %L không thể là hàm khai báo"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr ""
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr ""
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr ""
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr ""
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%qs” (%lu/%lu) tại %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "Đối số thực tế có chứa quá ít phần tử cho đối số giả “%qs” (%lu/%lu) tại %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "Cần một con trỏ thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr ""
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr ""
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr ""
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr ""
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr ""
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr ""
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr ""
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr ""
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "Thiếu đối số đối thực tế cho đối số %qs tại %L"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr "compare_actual_expr(): Mã thành phần sai"
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr "check_some_aliasing(): Danh sách không khớp"
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr "check_intents(): Danh sách không khớp"
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr ""
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr ""
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr ""
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr ""
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs called at %L is not explicitly declared"
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "Thủ tục %qs được gọi tại %L không được khai báo rõ ràng"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "Thủ tục %qs được gọi tại %L không được khai báo rõ ràng"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr ""
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr ""
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument %qs at %L"
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr ""
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr ""
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr ""
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr ""
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr ""
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr ""
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "không thể tìm thấy ký hiệu %qs"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr ""
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr "gfc_add_interface(): Kiểu giao diện sai"
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't overwrite GENERIC %qs at %L"
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "không thể đè GENERIC %qs tại %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr ""
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr ""
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr ""
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr ""
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr ""
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr ""
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr ""
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr ""
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr ""
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr ""
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr ""
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "thẻ %s tại %L phải là kiểu %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là các loại %d"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "Đối số giả chưa dùng %qs tại %L"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr ""
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "Quá nhiều đối số trong cuộc gọi đến %qs tại %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "Quá nhiều đối số trong cuộc gọi đến %qs tại %L"
@@ -63166,75 +63242,75 @@ msgstr ""
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr ""
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr "do_simplify(): Quá nhiều đối số cho intrinsic"
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "init_arglist(): quá nhiều đối số"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "Hàm %qs được khởi tạo giống như là một biểu thức %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs as initialization expression at %L"
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "Hàm %qs được khởi tạo giống như là một biểu thức %L"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr ""
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "Chuyển đổi từ %s sang %s tại %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr ""
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "Chuyển đổi từ %s sang %s tại %L"
@@ -63242,24 +63318,24 @@ msgstr "Chuyển đổi từ %s sang %s tại %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "Không thể chuyển đổi %s thành %s tại %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %qs to %qs at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "Không thể chuyển đổi %qs thành %qs tại %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr ""
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr ""
@@ -63625,13 +63701,13 @@ msgstr ""
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "ROUND= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "BLANK= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -63643,7 +63719,7 @@ msgstr "DECIMAL= tại %C không được phép trong Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "ENCODING= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -63691,7 +63767,7 @@ msgstr ""
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -63786,7 +63862,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -63854,7 +63930,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -63869,85 +63945,85 @@ msgstr ""
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr ""
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "PAD= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "DELIM= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr ""
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr ""
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "Câu lệnh V/R chứa con số đơn vị quá lớn"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -64200,515 +64276,515 @@ msgstr ""
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr ""
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "type-spec không hợp lệ tại %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr ""
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr ""
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr ""
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr ""
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr ""
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr ""
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr ""
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr ""
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr ""
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr ""
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr ""
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr ""
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  enters OpenMP structured block"
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr ""
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr ""
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr ""
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr ""
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr ""
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr ""
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr ""
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ERRMSG tag at %L"
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "ERRMSG tag tại %L"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr ""
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr ""
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "VALUE statement at %C"
 msgid "FAIL IMAGE statement at %C"
 msgstr "câu lệnh VALUE tại %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C"
 msgid "FORM TEAM statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CLASS statement at %C"
 msgid "CHANGE TEAM statement at %C"
 msgstr "câu lệnh CLASS tại %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C"
 msgid "END TEAM statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SYNC statement at %C"
 msgid "SYNC TEAM statement at %C"
 msgstr "câu lệnh SYNC tại %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr ""
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr ""
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr ""
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "câu lệnh SYNC tại %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "câu lệnh ASSIGN tại %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr ""
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr ""
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Được tính toán GOTO tại %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "Sai trong type-spec tại %L"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr ""
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr ""
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr ""
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr ""
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr ""
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "ERRMSG tag tại %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "SOURCE tag tại %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SOURCE tag at %L"
 msgid "Redundant SOURCE tag found at %L"
 msgstr "SOURCE tag tại %L"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr ""
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "MOLD tag tại %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L"
 msgid "Redundant MOLD tag found at %L"
 msgstr "MOLD tag tại %L"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr ""
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr ""
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr ""
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr ""
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr ""
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr ""
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "ERRMSG tại %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr ""
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr ""
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr ""
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr ""
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "Cần tham chiếu thành phần tại %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr ""
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr ""
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr ""
@@ -64716,224 +64792,224 @@ msgstr ""
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr ""
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr ""
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "Ký hiệu %qs tại %C đã có trong khối COMMON"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr ""
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr ""
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr ""
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr ""
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "BLOCK DATA construct at %L"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr ""
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr ""
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr ""
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr ""
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr ""
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "VALUE statement at %C"
 msgid "EQUIVALENCE statement at %C"
 msgstr "câu lệnh VALUE tại %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr ""
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L cannot appear within an INTERFACE"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "Hàm khai báo tại %L không phải xuất hiện trong một GIAO DIỆN"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "Hàm khai báo tại %L không phải xuất hiện trong một GIAO DIỆN"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr ""
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr ""
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr ""
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "%qD chưa được khai báo trong phạm vi này"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -64974,12 +65050,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr ""
@@ -65677,8 +65753,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -67092,175 +67168,175 @@ msgstr "Không cần %<*%> cho đối chiếu %d của %d tại %C"
 msgid "Expected structure component name at %C"
 msgstr ""
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr ""
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "Cần danh sách đối số tại %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, gcc-internal-format, gfc-internal-format
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr ""
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr ""
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr ""
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr ""
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): Biểu thức không phải là một biến"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, fuzzy, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr(): Biểu thức không phải là một biến"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_variable_attr(): Tham chiếu mảng sai"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr ""
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 #| msgid "Can't construct ABSTRACT type %qs at %L"
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "Không thể xây dựng kiểu TRỪU TƯỢNG %qs tại %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr ""
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr ""
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "Too many components in structure constructor at %L"
 msgstr "quá nhiều đối số cho cấu tử %q#D"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "Component %qs at %C already in the parent type at %L"
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn trong kiểu cha mẹ %L"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr ""
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr ""
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr ""
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr ""
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "Câu lệnh hàm %qs cần một danh sách đối số tại %C"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "Hàm %qs cần một danh sách đối số tại %C"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr ""
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr ""
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "%qs tại %C không phải là một biến"
@@ -67591,496 +67667,496 @@ msgstr "%qs tại %L phải là số nguyên"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr ""
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr ""
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr ""
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr ""
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is used as actual argument at %L"
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Thủ tục nội tại %qs được dùng làm đối số thật tại %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr ""
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Thủ tục nội tại %qs được dùng làm đối số thật tại %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "Ký hiệu “%qs” tại %L chưa rõ ràng"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr ""
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr ""
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr ""
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr ""
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr ""
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr ""
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr ""
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr ""
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr ""
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr ""
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr ""
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Không thể phân giải hàm đặc tả %qs tại %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr ""
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr ""
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected intrinsic type %qs at %L"
 msgid "Unexpected junk after %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "ABSTRACT INTERFACE %qs phải không tham chiếu tại %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "resolve_function(): kiểu hàm sai"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr ""
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr ""
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr ""
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr ""
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr ""
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "resolve_subroutine(): kiểu hàm sai"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr ""
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, fuzzy, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function %qs at %L not set"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr ""
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -68089,12 +68165,12 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -68103,284 +68179,284 @@ msgstr ""
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Sai trong type-spec tại %L"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs tại %L phải là THỦ TỤC CON"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs tại %L phải là HÀM"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): sai kiểu biểu thức"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -68389,285 +68465,285 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "tham số %u có kiểu void"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ngữ cảnh sai cho hạn chế NULL() tại %L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -68675,188 +68751,188 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL không hợp lệ %L"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -68864,959 +68940,959 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s tại %L"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của thủ tục FINAL tại %L phải là kiểu %qs"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là dẫn xuất kiểu %qs"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qE chưa được khai báo"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %L"
 msgid "Expecting definable entity near %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -70508,155 +70584,155 @@ msgstr ""
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn trong kiểu cha mẹ %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -70693,83 +70769,83 @@ msgstr ""
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr ""
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr ""
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr ""
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr ""
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr ""
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr ""
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr ""
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr "COMMON “%qs” tại %L không tồn tại"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr ""
@@ -70789,72 +70865,72 @@ msgstr ""
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr ""
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "Trả lại giá trị của hàm %qs tại %L chưa đặt"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr ""
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr ""
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr ""
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr ""
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "Đối số giả chưa dùng %qs tại %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "Biến số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "Đối số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr ""
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "Trả lại giá trị %sq của hàm %qs khai báo tại %L chưa đặt"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -70869,27 +70945,27 @@ msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Không hiểu intrinsic op"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -70926,24 +71002,24 @@ msgstr ""
 msgid "Bad IO basetype (%d)"
 msgstr ""
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr ""
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "optional argument"
 msgid "optional class parameter"
 msgstr "đối số tùy chọn"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "unhandled derived-type component"
 msgstr "đối số kiểu được dẫn suất tham số hóa"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr ""
@@ -71053,84 +71129,84 @@ msgstr "các cha mẹ không khớp"
 msgid "unable to open file"
 msgstr "không thể mở tập tin"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "không thể phân tích số thập lục phân"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "không thể phân tích khoảng bù tập tin"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "không cần offset"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "gặp dòng sai trong tập tin phân giải"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "phân giải không hợp lệ trong tập tin phân giải"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr ""
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "cannot read LTO decls from %s"
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "không thể đọc “LTO decls” từ %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Không thể mở %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Không thể map %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Không thể đọc %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing argument to %qs"
 msgid "missing resolution data for %s"
 msgstr "thiếu đối số đối cho %qs"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -72278,7 +72354,7 @@ msgstr "thiếu tên macro sau %qs"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "thiếu tên tập tin sau %qs"
@@ -72483,17 +72559,17 @@ msgstr "không hiểu thuật toán xếp lại khối cơ bản %qs"
 msgid "unknown TLS model %qs"
 msgstr "không hiểu mô hình TLS %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:3004
+#: common.opt:3008
 #, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:3023
+#: common.opt:3027
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
diff --git a/gcc/po/zh_CN.po b/gcc/po/zh_CN.po
index c93b9568933..31ac5329bc6 100644
--- a/gcc/po/zh_CN.po
+++ b/gcc/po/zh_CN.po
@@ -33,7 +33,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 9.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2019-08-19 15:13-0400\n"
 "Last-Translator: Boyuan Yang <073plan@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -1928,90 +1928,90 @@ msgstr "strfmon 格式的长度修饰符"
 msgid "<command-line>"
 msgstr "<命令行>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "缺少操作数"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "%%R 代码的操作数无效"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "‘%%%c’不是一个有效的操作数前缀"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "无效寻址模式"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 #| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二元操作中中操作数无效"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
@@ -2027,18 +2027,18 @@ msgid "invalid %%r value"
 msgstr "无效 %%r 值"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "无效 %%R 值"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
@@ -2068,7 +2068,7 @@ msgstr "无效 %%M 值"
 msgid "invalid %%U value"
 msgstr "无效 %%U 值"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
@@ -2078,7 +2078,7 @@ msgstr "无效 %%s 值"
 msgid "invalid %%C value"
 msgstr "无效 %%C 值"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
@@ -2088,10 +2088,10 @@ msgstr "无效 %%E 值"
 msgid "unknown relocation unspec"
 msgstr "未指定未知的重定位方式"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "无效的 %%xn 代码"
@@ -2174,35 +2174,35 @@ msgstr "无效的 UNSPEC 用作操作数"
 msgid "unrecognized supposed constant"
 msgstr "预期的常量无法识别"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, c-format
 msgid "invalid shift operand"
 msgstr "无效的移位操作数"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "预测到的 Thumb 指令"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在条件序列中预测到的指令"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2210,13 +2210,13 @@ msgstr "代码‘%c’的操作数无效"
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, c-format
 msgid "instruction never executed"
 msgstr "指令从不被执行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支持的算符用于编码‘%c’"
@@ -2357,7 +2357,7 @@ msgstr "非预期的操作数"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2574,27 +2574,27 @@ msgstr "错误的 output_move_double 操作数"
 msgid "bad output_condmove_single operand"
 msgstr "错误的 output_condmove_single 操作数"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr ""
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operand %%xn code"
 msgstr "%%Z 代码的操作数无效"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand %%xn code invalid for QImode"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 msgid "invalid fp constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
@@ -2746,7 +2746,7 @@ msgstr "对%<__fpreg%>的操作无效"
 msgid "invalid %%P operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -2800,7 +2800,7 @@ msgid "post-increment address is not a register"
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "错误地址"
 
@@ -2852,8 +2852,8 @@ msgstr "‘%%%c’不是一个有效的操作数前缀"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "对‘%%%c’的使用无效"
@@ -2989,181 +2989,235 @@ msgstr "堆栈溢出。\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "尝试在命令解释器中运行‘%s’以提升它的极限。\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 #| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx 需要硬件浮点"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 #| msgid "-mvsx needs indexed addressing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx 需要变址寻址"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 #| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx 与 -mno-altivec 互不兼容"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 #| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec 禁用了 VSX"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 #, fuzzy
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "生成小端在前的代码"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "无效 %%J 值"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "无效的 %%D 值"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, c-format
 msgid "invalid %%t value"
 msgstr "无效 %%t 值"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, c-format
 msgid "invalid %%V value"
 msgstr "无效 %%V 值"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效 %%x 值"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, c-format
 msgid "invalid %%z value"
 msgstr "无效 %%z 值"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "对声明中的过时用法给出警告"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr ""
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "从%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "向%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "从%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "向%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "从%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "向%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "从%<__fpreg%>的转换无效"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "向%<__fpreg%>的转换无效"
+
 #: config/s390/s390.c:7787
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3174,93 +3228,93 @@ msgstr "符号内存参考是只有支持的于 z10 或稍后"
 msgid "cannot decompose address"
 msgstr "无法分解地址"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "‘o’修饰符的操作数无效"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "内存参考预期的用于‘S’输出修饰键"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "%s：无效的输出格式"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘N’输出修饰键"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘公尺’输出修饰键"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "无效的操作数输出代码"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "无效的最小左值表达式"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "返回指针时目标与指针符号不一致"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "目标格式不支持无限大浮点数"
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3529,8 +3583,8 @@ msgstr "({匿名})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
@@ -3550,7 +3604,7 @@ msgstr "需要%<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -3558,7 +3612,7 @@ msgstr "需要%<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -3576,21 +3630,21 @@ msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -3601,12 +3655,12 @@ msgstr "需要%<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
@@ -3615,7 +3669,7 @@ msgstr "需要 %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -3624,18 +3678,18 @@ msgstr "需要 %<,%>"
 msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
@@ -3643,19 +3697,19 @@ msgstr "需要 %<,%> 或 %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
@@ -3664,7 +3718,7 @@ msgstr "需要%<#pragma omp section%>或%<}%>"
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -3676,36 +3730,36 @@ msgstr "需要%<<%>"
 msgid "expected label"
 msgstr "需要通道"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "备选 1："
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 #| msgid "Enable user-defined instructions"
 msgid "  after user-defined conversion:"
 msgstr "启用用户自定义指令"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "备选 1："
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "备选 2："
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "跳转至标号%qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "跳转至 case 标号"
 
@@ -3797,7 +3851,7 @@ msgstr "<模板参数数错误>"
 msgid "<statement>"
 msgstr "<语句>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<未知>"
@@ -3973,48 +4027,48 @@ msgstr "转换丢失了常量属性"
 msgid "source type is not polymorphic"
 msgstr "源类型不是多态的"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "单目减的操作数类型错误"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "单目加的操作数类型错误"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的参数类型错误"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能对该类型的参数求绝对值"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能对该类型的参数求共轭"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 msgid "in argument to unary !"
 msgstr "单目 ! 的参数中"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 msgid "no pre-increment operator for type"
 msgstr "类型没有前自增运算符"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 msgid "no post-increment operator for type"
 msgstr "类型没有后自增运算符"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 msgid "no pre-decrement operator for type"
 msgstr "类型没有前自减运算符"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 msgid "no post-decrement operator for type"
 msgstr "类型没有后自减运算符"
 
@@ -4056,17 +4110,17 @@ msgstr "%C处的 BOZ 常量中有非法字符"
 msgid "elemental binary operation"
 msgstr "基本二元操作"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "‘a%d’和‘a%d’用作内建函数‘%s’的参数"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "‘%s’和‘%s’用作内建函数‘%s’的参数"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "‘%s’和‘%s’用作内建函数‘%s’的参数"
@@ -4143,7 +4197,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "驱动："
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "实际参数到含义=出/INOUT"
@@ -4160,7 +4214,7 @@ msgstr "%L处内部单位带向量下标"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s 标记"
@@ -4266,11 +4320,11 @@ msgstr "块 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "指针赋值"
 
@@ -4278,229 +4332,229 @@ msgstr "指针赋值"
 msgid "simple IF"
 msgstr "简单的 IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 msgid "elemental procedure"
 msgstr "基本过程"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 msgid "allocatable argument"
 msgstr "没有参数"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "参数"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 msgid "optional argument"
 msgstr "可选参数"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 msgid "pointer argument"
 msgstr "对空指针指向内容的写操作(实参 %d)"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 msgid "target argument"
 msgstr "目标"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 msgid "value argument"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 msgid "volatile argument"
 msgstr "重复的%<volatile%>"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "在调度器中启用秩启发"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 msgid "coarray argument"
 msgstr "无效的参数"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 #, fuzzy
 msgid "parametrized derived type argument"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 msgid "polymorphic argument"
 msgstr "源类型不是多态的"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr "NO_ARG_CHECK 属性"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "该类型不支持自增"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr "数组结果"
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "%3$L 处“%1$s”分句对象“%2$s”有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字符串毗连运算符(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "逻辑运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L处的 .not. 运算符的操作数为 %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L处复数不能比较大小"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L处逻辑值必须与 %s 比较，而不是 %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比较运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%%L和%%L处的操作数的秩不一致"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 msgid "iterator variable"
 msgstr "变量"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 #, fuzzy
 msgid "STAT variable"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 #, fuzzy
 msgid "item in READ"
 msgstr "读取概要："
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "无法锁定新归档文件"
@@ -4515,27 +4569,27 @@ msgstr "数组构造函数中 CHARACTER 长度不同(%ld/%ld)"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "试图分配负数大小的内存。可能有整数溢出"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度不匹配其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度短于其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目标的分级重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4612,7 +4666,7 @@ msgstr "I/O 语句中单位数太大"
 msgid "Assigned label is not a target label"
 msgstr "赋值标号不是目标标号"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, fuzzy, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "无效的影像号码 %d 在中同步影像"
@@ -5072,7 +5126,7 @@ msgstr "创建临时数组时给出警告"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
@@ -5720,8 +5774,8 @@ msgstr "为外部可见的名字添加下划线"
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
@@ -8438,109 +8492,103 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "当定义在主文件中的宏未被使用时给出警告"
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "对初始化为自身的变量给出警告。"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "-fdump-<类型>\t将一些编译器内部信息转储到一个文件里"
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "Dump various analyzer internals to stderr."
 msgstr "-fdump-<类型>\t将一些编译器内部信息转储到一个文件里"
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13397,8 +13445,9 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-msgid "Use instructions for a future architecture."
-msgstr "为块移动使用字符串指令"
+#| msgid "Use vector/scalar (VSX) instructions"
+msgid "Use instructions added in ISA 3.1."
+msgstr "使用向量/标量(VSX)指令"
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13411,6 +13460,11 @@ msgstr "生成加载/存储乘法指令"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "不使用未对齐的内存引用"
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "在函数序言中生成 cld 指令"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -18922,7 +18976,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -19654,412 +19708,412 @@ msgstr "展开所有迭代次数已知的循环"
 msgid "Perform loop unrolling for all loops."
 msgstr "展开所有循环"
 
-#: common.opt:2863
+#: common.opt:2867
 #, fuzzy, no-c-format
 #| msgid "Allow optimization for floating-point arithmetic which may change the"
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "允许可能因不同舍入模式而改变结果的浮点算术优化。"
 
-#: common.opt:2868
+#: common.opt:2872
 #, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "与 -fassociative-math 相同，作用于包含除法的表达式。"
 
-#: common.opt:2876
+#: common.opt:2880
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "允许可能违反 IEEE 或 ISO 标准的优化"
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "外提循环内的测试语句"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "进行循环剥离"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "仅为异常处理生成堆栈展开表"
 
-#: common.opt:2896
+#: common.opt:2900
 #, fuzzy, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "进行变量跟踪"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking by annotating assignments"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "评注赋值以进行变量跟踪"
 
-#: common.opt:2930
+#: common.opt:2934
 #, fuzzy, no-c-format
 #| msgid "Toggle -fvar-tracking-assignments"
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "切换 -fvar-tracking-assignments"
 
-#: common.opt:2938
+#: common.opt:2942
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 msgid "Enable vectorization on trees."
 msgstr "在树上进行循环向量化"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "在树上进行循环向量化"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 #| msgid "Enable basic block vectorization (SLP) on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "在树上进行基本块向量化(SLP)"
 
-#: common.opt:2959
+#: common.opt:2963
 #, fuzzy, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "启用向量化开销模型"
 
-#: common.opt:2963
+#: common.opt:2967
 #, fuzzy, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "启用向量化开销模型"
 
-#: common.opt:2979
+#: common.opt:2983
 #, fuzzy, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
-#: common.opt:2987
+#: common.opt:2991
 #, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "为标量演化信息进行复写传递。"
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "为汇编输出添加额外注释"
 
-#: common.opt:3001
+#: common.opt:3005
 #, fuzzy, no-c-format
 #| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\t设置符号的默认可见性"
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "在优化中使用表达式值样本提供的信息"
 
-#: common.opt:3048
+#: common.opt:3052
 #, fuzzy, no-c-format
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "建立关系网并且分离对同一变量的无关应用"
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 #| msgid "Enable conditional dead code elimination for builtin calls"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "为内建函数启用有条件的死代码消除优化"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "进行全程序优化"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "将初始化为零的数据存放在 bss 节中"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3076
+#: common.opt:3080
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
 
-#: common.opt:3080
+#: common.opt:3084
 #, fuzzy, no-c-format
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 msgid "Generate debug information in default version of DWARF format."
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in DWARF v2 (or later) format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "生成默认扩展格式的调试信息"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "为每个函数生成单一的退出点"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, fuzzy, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "生成 STABS 格式的调试信息"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "生成扩展 STABS 格式的调试信息"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, fuzzy, no-c-format
 #| msgid "Don't emit DWARF additions beyond selected version"
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "不生成较所选版本更先进的 DWARF 附加信息"
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 #| msgid "Toggle debug information generation"
 msgid "Toggle debug information generation."
 msgstr "切换调试信息生成"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "生成 XCOFF 格式的调试信息"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "生成 XCOFF 扩展格式的调试信息"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 msgid "Generate compressed debug sections."
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:3209
+#: common.opt:3213
 #, fuzzy, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<目录>\t将目录设定为默认的插件子目录"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <目录>\t将目录设定为 multilib 的包含子目录"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 #| msgid "-o <file>\tPlace output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <文件>\t将输出写入文件"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "启用函数取样"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "与 -pedantic 类似，但将它们视作错误"
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "不显示编译的函数或逝去的时间"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "启用详细输出"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "显示编译器版本"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "不显示警告"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "生成一个共享库"
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -21336,8 +21390,8 @@ msgstr "向量循环版本化插入的运行时别名检查次数的上限"
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "向量循环版本化插入的运行时对齐检查次数的上限"
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "计算出的值未被使用"
@@ -21365,7 +21419,7 @@ msgid "expected boolean type"
 msgstr "需要整数或布尔类型"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -21437,7 +21491,7 @@ msgstr "实参太少"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "实参太多"
@@ -21842,7 +21896,7 @@ msgstr "%qE属性与 %s 属性冲突"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -21927,12 +21981,12 @@ msgstr "类型属性在定义后被忽略"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -21951,8 +22005,8 @@ msgstr "%qE属性被忽略"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD先前没有声明"
@@ -22073,7 +22127,7 @@ msgstr "模板形参类型%qT声明为%<friend%>"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量越过字符串常量界"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -22366,7 +22420,7 @@ msgstr "%qs缺少参数"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K对%<__builtin_va_arg_pack ()%>的使用无效"
@@ -22673,12 +22727,12 @@ msgstr "汇编篡改列表与输出操作数冲突"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "汇编篡改列表与输入操作数冲突"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, fuzzy, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "没有保护局部变量：可变长度的缓冲区"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "没有保护函数：没有至少有 %d 字节长的缓冲区"
@@ -23193,305 +23247,305 @@ msgstr "基本块不连贯"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "指令链中记录的基本块数 (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "调用边计数为负"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "函数‘%s’在%C处缺少参数列表"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "块 %i 后缺少屏障"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "节点是单独在中 comdat 群组"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "需要内联克隆"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "强制公共符号必须定义"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "为外部可见的名字添加下划线"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "已取地址，但是 ADDRESSABLE 位未被设置"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "需要内联克隆"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "在有返回值的的函数中，%<return%>不带返回值"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "edge count is not compatible with function count"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "间接边缘从 %s 未被标记为间接或已关联的 indirectinfo(_I)，相应叙述是："
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 错误"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多个内联调用者"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "为非内联的调用者设定了 inlined_to pointer"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "设定了 inlined_to 指针却找不到前驱"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "节点有错误的 clone_of"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "节点的克隆列表不正确"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "节点的 prev_clone 指针错误"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "基本块 %i 有多个 EH 边"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "别名有 non-alias 参考"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "别名有超过一个别名参考"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "%qE有%qs的引用类型"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "没有边缘超出 thunk 节点"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超过一个边缘超出 thunk 节点"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "边指向错误的声明："
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "间接边缘与未知被调用端相应到 callstmt 与已知声明(_S)："
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "调用语句缺少 callgraph 边："
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "删除死存储"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "将一个指针转换为大小不同的整数"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失败"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "在 %s %s 中有缺失的“%s”\n"
@@ -23581,12 +23635,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F使用过但从未定义"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F声明为%<static%>却从未定义过"
@@ -23746,7 +23800,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO 支持在此配置下未被启用"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
@@ -24085,22 +24139,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "变量位置处发现未被非法化的 UNSPEC %d"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "指令中有无效的 RTL 共享"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "共享的 rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "内部一致性错误"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE：需要 emit_jump_insn 时使用了 emit_insn：\n"
@@ -24165,7 +24219,7 @@ msgstr "region_array 不匹配 region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array 不匹配 region_tree"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -24197,12 +24251,12 @@ msgstr "生成用户模式的代码"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%K调用%qs，声明有错误属性：%s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K调用%qs，声明有警告属性：%s"
@@ -24218,7 +24272,7 @@ msgstr "%<...%>作为实参。)"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "栈帧有 %wd 字节，超过了 %wd 字节"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "无法打开最终指令转储文件%qs：%s"
@@ -24238,37 +24292,37 @@ msgstr "大定点常量隐式截断为定点类型"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比较结果始终为 %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "对两个不匹配的不等比较取%<or%>的结果总为 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "对两个互斥的相等比较取%<and%>的结果永远是 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "在比较中归约常量时假定有符号数从不溢出"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "在比较周围组合变量时假定有符号数从不溢出"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折叠检查: 原始树因折叠而改变 "
@@ -24911,13 +24965,13 @@ msgstr "函数可能返回局部变量的地址"
 msgid "function returns address of local variable"
 msgstr "函数返回局部变量的地址"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, gcc-internal-format
 msgid "declared here"
 msgstr "在此声明"
@@ -25494,10 +25548,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -25673,7 +25727,7 @@ msgstr "%qE未为在括入的并行中指定"
 msgid "enclosing %<target%>"
 msgstr "括入并行"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
@@ -25726,13 +25780,13 @@ msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
 msgstr "尚未支持代码模式 %<large%>"
@@ -25742,150 +25796,150 @@ msgstr "尚未支持代码模式 %<large%>"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD模板声明无效"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, fuzzy, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, fuzzy, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "返回值的数量不匹配值的数量"
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失败"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "通过%<...%>传递时%qT被提升为%qT"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您应该向%<va_arg%>传递%qT而不是%qT)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果执行到这段代码，程序将中止"
@@ -25962,7 +26016,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -26235,49 +26289,49 @@ msgstr "<返回值>"
 msgid "the extra base is defined here"
 msgstr "未定义 C++ 基类"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid fnsummary in LTO stream"
 msgstr "gimple 调用中有非法函数"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, fuzzy, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "ipa 内联概要缺少在中输入文件"
@@ -26309,38 +26363,38 @@ msgstr "函数可能是%<noreturn%>属性的备选"
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "ipa 参考概要缺少在中 ltrans 单位"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification failed: %s"
 msgid "IPA-SRA access verification failed"
 msgstr "验证失败：%s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -26391,57 +26445,57 @@ msgstr "%<asm%>中操作数约束不一致"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "最大值条件保存对数量该可以是 sunk"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "字节码流：找到 cgraph 节点 %d 的多个实例"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "字节码流：读取边时找不到调用者"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "字节码流：读取边时找不到被调用者"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "字节码流：找到空的 cgraph 节点"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "最多 %i 侧写档运行被支持。也许已损坏侧写档？"
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "%s：已损坏\n"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "无法从 “%s” 中读取 LTO decls"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "%s：无法找到区段：%s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "表格类型   ：%s\n"
@@ -26708,54 +26762,54 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 #| msgid "previously used here"
 msgid "... to the previous %qs clause here"
 msgstr "已在这里使用过"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 #| msgid "switch starts here"
 msgid "... with %qs clause here"
 msgstr "开关语句从此开始"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -26989,53 +27043,53 @@ msgstr "OpenMP 结构块出口无效"
 msgid "invalid branch to/from %s structured block"
 msgstr "OpenMP 结构块出口无效"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, fuzzy, gcc-internal-format
 msgid "containing loop here"
 msgstr "循环变量"
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "routine %qD declared here"
 msgstr "%qD在此声明"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -28445,141 +28499,141 @@ msgstr "-fstack-protector 在此目标机上不受支持"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "指令调度在此目标机上不受支持"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "此目标机没有延迟转移指令"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore 在此目标机上不受支持"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "无法打开用零填充的指令转储文件%qs：%s"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, gcc-internal-format
 msgid "target system does not support the %qs debug format"
 msgstr "目标系统不支持 %qs 调试格式"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "要求追踪变量，但若不生成调试信息则无用"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "求追踪变量，但不为这种调试格式所支持"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments 改变了选择性调度"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections 在此目标机上不受支持"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections 在此目标机上不受支持"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays 在此目标机上不受支持"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays 在此目标机上不受支持(尝试 -march 开关)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays 不支持与 -Os 并用"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 #| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math 为其他选项所禁用"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector 在此目标机上不受支持"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fsanitize=address 及 -fsanitize=kernel-address 在此目标机上不受支持"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "写入 %s 时出错：%m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "关闭 %s 时出错：%m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "%qs必须与%qs一起使用"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -28674,185 +28728,185 @@ msgstr "函数定义中不允许有属性"
 msgid "ignoring loop annotation"
 msgstr "循环变量"
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR 变化时常量未被重新计算"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 #| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR 变化时副作用未被重新计算"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, fuzzy, gcc-internal-format
 #| msgid "DECL_GIMPLE_REG_P set on a variable with address taken"
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "为一个已被取地址的变量设定了 DECL_GIMPLE_REG_P"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 #| msgid "address taken, but ADDRESSABLE bit not set"
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "已取地址，但是 ADDRESSABLE 位未被设置"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "无效的最小左值表达式"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "间接引用操作数无效"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 #| msgid "non-scalar type"
 msgid "non-scalar %qs"
 msgstr "非标准类型"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "integral result type precision does not match field size of BIT_FIELD_REF"
 msgid "integral result type precision does not match field size of %qs"
 msgstr "整体结果类型精度不匹配 BIT_FIELD_REF 字段尺寸"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
 #| msgid "mode precision of non-integral result does not match field size of BIT_FIELD_REF"
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "非整体结果的模式精度不匹配 BIT_FIELD_REF 的字段尺寸"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "无效的移位操作数"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "数组引用类型不匹配"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "%%R 的操作数无效"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "非类型参数包中类型不匹配"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "在左操作数边转化 SSA_NAME。"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "将一个指针转换为大小不同的整数"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "错误地使用了%qD"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "简单的 IF"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, fuzzy, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "gimple 调用有两目标"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "gimple 调用无目标"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "gimple 调用中有非法函数"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "gimple 调用了非函数"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "纯常函数状态无效"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "gimple 调用中左操作数无效"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, fuzzy, gcc-internal-format
 #| msgid "LHS in noreturn call"
 msgid "LHS in %<noreturn%> call"
 msgstr "不返回的调用中有左值"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "gimple 调用中转换无效"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "gimple 调用中静态链无效"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, fuzzy, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "静态调用链中有不使用静态调用的函数"
@@ -28863,529 +28917,529 @@ msgstr "静态调用链中有不使用静态调用的函数"
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "gimple 调用中参数无效"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "gimple 比较中操作数无效"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "在类型%qT和%qT间比较"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, fuzzy, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "函数返回了一个函数"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "向量值的加法中有无效的非向量操作数"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, fuzzy, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "非寄存器作为单目操作的左操作数"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "单目操作中操作数无效"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "空转换中类型无效"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "空转换中类型无效"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "地址空间转换中类型无效"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "整点转换中类型无效"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "向浮点转换时类型无效"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "向整数转换时类型无效"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "移位表达式类型不匹配"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "无效的操作数代码‘%c’"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "单目操作时不平凡的转换"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "非寄存器作为二元操作的左操作数"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "二元操作中中操作数无效"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-vector operands to vector valued plus"
 msgid "invalid non-vector operands to %qs"
 msgstr "向量值的加法中有无效的非向量操作数"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "无效的指针模式%qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "需要整数表达式"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "二元表达式中类型不匹配"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "非寄存器作为单目操作的左操作数"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "二元操作中中操作数无效"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "需要整数表达式"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "矢量与不同的组件号码找到在中矢量 permute 运算式"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 msgid "invalid mask type in %qs"
 msgstr "表格类型   ：%s\n"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "不支持的组合：%s"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size in %qs"
 msgstr "BIT_FIELD_REF 位置或大小操作数无效"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "无效的移位操作数"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "常量实参超过%qs的范围"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a directory"
 msgid "%qs not at element boundary"
 msgstr "%qs 不是目录"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "non-trivial conversion at assignment"
 msgid "non-trivial conversion in %qs"
 msgstr "赋值时不平凡的转换"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "%qs LHS in clobber statement"
 msgstr "在语句中"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R 的操作数无效"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rhs for gimple memory store"
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "gimple 内存存储中右操作数无效"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "左移次数大于或等于类型宽度"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "提供给函数%qE的实参太多"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI 参数不是 GIMPLE 变量"
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "向量初始值设定项中有多余元素"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 #| msgid "ASSERT_EXPR with an always-false condition"
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR 具有一个总是假的条件"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "返回语句操作数无效"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "返回语句转换无效"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "goto 的目标既非标号亦非指针"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "开关语句操作数无效"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "位段%qD非整型"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, fuzzy, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "gimple 调用中静态链无效"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case 标号未排序： "
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 msgid "label context is not the current function declaration"
 msgstr "make_local_variable: 当前作用域中没有函数上下文"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "label_to_block_map 中条目不正确"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "着陆场号码设置不正确"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "gimple 条件中比较代码无效"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "gimple 条件中的标号无效"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "无效的 PHI 结果"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 #| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "缺少 PHI 定义"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "无效的 PHI 实参"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "PHI 实参 %u 类型不兼容"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple 失败"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "在 EH 表中死了的 STMT"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "隐式声明函数%qE"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimple_bb (phi) 设置为一个错误的基本块"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, fuzzy, gcc-internal-format
 msgid "PHI node with location"
 msgstr " (位置列表)"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "对树结节的共享不正确"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, fuzzy, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr "PHI 参数不是 SSA_NAME 或不变量"
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimple_bb (stmt) 设置为一个错误的基本块"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "语句被标记为抛出异常，但实际上并未抛出"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "语句在块中被标记为抛出"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verify_gimple 失败"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK 有与之关联的 IL"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK 有与之关联的 IL"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "直通边从基本块 %d 退出"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, gcc-internal-format
 msgid "nonlocal label "
 msgstr "非局部标号"
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH 着陆场标号"
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, gcc-internal-format
 msgid "label "
 msgstr "标号"
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "基本块 %d 中出现流程控制"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "在基本块 %d 中控制语句后的直通边"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "基本块 %d 中非 GIMPLE_COND 后的真假边"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "基本块 %d 结尾处有错误的出边标记"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "基本块 %d 末尾显式的 goto"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "基本块 %d 中，返回边并不指向退出"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "默认 case 不在 case 向量的开头"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "case 标号未排序： "
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "多余的出边 %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "缺少边 %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>函数返回了"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "在有返回值的函数中，控制流程到达函数尾"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
@@ -29401,48 +29455,48 @@ msgstr "%qs后缺少宏名"
 msgid "in expansion of macro %qs"
 msgstr "印出 EXPR 的宏展开"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "基本块 %i 有多个 EH 边"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has an EH edge"
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "基本块 %i 不能抛出异常但却有 EH 边"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "基本块 %i 最后一条语句设置了不正确的 lp"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "基本块 %i 缺少一条 EH 边"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "不正确的 EH 边 %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "基本块 %i 缺少一条边"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "基本块 %i 下落边太多"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "基本块 %i 有不正确的边"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "基本块 %i 有不正确的下落边"
@@ -29949,12 +30003,12 @@ msgstr "stmt (%p) 在优化以后标记为修改的："
 msgid "verify_ssa failed"
 msgstr "verify_ssa 失败"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, fuzzy, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "机器独立内置编码超出范围"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "目标相关的内建函数不可用"
@@ -30023,7 +30077,7 @@ msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -30034,31 +30088,31 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "联合在此定义"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "数组下标越过了数组边界"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "数组下标越过了数组边界"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "数组下标越过了数组边界"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "数组下标小于数组边界"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -30137,32 +30191,32 @@ msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 %2$s 的第 %1$d
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 omp_clause %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.c:13103
+#: tree.c:13105
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.c:13112
+#: tree.c:13114
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "已弃用类型：%s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "已弃用此类型"
@@ -30187,237 +30241,237 @@ msgstr "已弃用此类型"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with notes file\n"
 msgid "first mismatch is field"
 msgstr "%s:时间戳与说明文件不匹配\n"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "main variant is not defined"
 msgstr "环境变量%qs未定义"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -30546,87 +30600,87 @@ msgstr "%q+D需要的对齐边界大于实现的对齐边界 %wu"
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D的存储大小未知"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "整数/定点值的初始值设定太复杂"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "浮点值的初始值设定不是一个浮点常量"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "成员%qE的初始值无效"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%q+D声明为友元"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D的弱声明必须是公共的"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "不支持%q+D的弱声明"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "此配置下只支持弱别名"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "弱引用在此配置下不受支持"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "%qE属性在此平台上不受支持"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "weakref%q+D最终指向其自身"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "弱引用%q+D必须有静态链接"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "别名定义在此配置下不受支持"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s 不为这个配置所支持"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可见性属性在此配置下不受支持；已忽略"
@@ -31246,7 +31300,7 @@ msgstr "%qE属性为%qE所忽略"
 msgid "type was previously declared %qE"
 msgstr "以前在此声明过"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -31267,7 +31321,7 @@ msgstr "选择%qD而不是%qD"
 msgid "%qE argument is not a function"
 msgstr "属性%qE的参数无效"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "过时消息不是一个字符串"
@@ -31661,12 +31715,12 @@ msgstr "枚举常量在此定义"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建议在用作真值的赋值语句前后加上括号"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "错误地使用了%<restrict%>"
@@ -31825,12 +31879,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供给函数%qE的实参太少"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -31932,7 +31986,7 @@ msgstr "索引 %E 指定了一个大于%qT大小的偏移量"
 msgid "size of array is too large"
 msgstr "数组太大"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -31944,131 +31998,131 @@ msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "传递%2$qE的第 %1$d 个参数时将整数赋给指针，未作类型转换"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "左实参必须是一个切片"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "提供给函数%qE的实参太多"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "索引值越界"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "built-in function %qE must be directly called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "数组%qE的大小为负"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "数组大小为负数"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "数组%qE的大小为负"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -32124,534 +32178,534 @@ msgstr "%qE是一个无法识别的格式字符串函数类型"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "格式字符串出现在待格式化的实参之后"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "函数可能是%qsformat 属性的备选"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "格式字符串缺少 $ 操作数号"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s 不支持 %%n$ 操作数号格式字符串"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "格式字符中操作数号越界"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "格式实参 %d 在 %s 格式字符串中使用不止一次"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$ 操作数号在不使用操作数号的格式后被使用"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "格式实参 %d 在被使用的 $ 风格的格式实参 %d 前未被使用"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "格式字符串不是一个字面字符串，格式字符串未被检查"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "格式字符串不是一个字面字符串而且没有待格式化的实参"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "格式字符串不是一个字面字符串，没有进行实参类型检查"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "提供给格式字符串的实参太多"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "$ 风格的格式字符串中有未使用的实参"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "格式字符串 %s 长度为 0"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "格式字符串是一个宽字符串"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "格式字符串出现在待格式化的实参之后"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "未终止的格式字符串"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s 与%<%%%c%>%s 格式并用"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s 不支持 %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s 不支持 %s 出现在%<%%%c%>%s 格式字符串中"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "格式字符串中有重复的 %s"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "strfmon 格式字符串末尾缺少填充字符"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "%s 格式字符串中域宽为 0"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "%s 格式字符串中左精度为空"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "%s 格式字符串中精度为空"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s 不支持%qs%s 长度修饰符"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s 不支持%<%%%c%>%s 格式"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s 与 %s 和%<%%%c%>%s 格式字符串合用时被忽略"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s 和 %s 出现在 %s 格式字符串中时被忽略"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "同时使用 %s 和 %s，在%<%%%c%>%s 格式字符串中"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "同时使用 %s 和 %s，在 %s 格式字符串中"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%>在某些区域设定下只给出 2 位表示的年份"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%>只给出 2 位表示的年份"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "%<%%[%>格式没有相应的%<]%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "将%qs长度修饰符和%qc类型字符一起使用"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s 不支持%<%%%s%c%>%s 格式"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "为格式字符串指定的操作数号取消了赋值"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "为格式字符串指定的操作数号不带参数"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "格式字符串中有重复的 %s"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "格式字符串中有重复的 %s"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "格式字符串嵌有%<\\0%>"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "尝试使用%qE代替"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "unquoted attribute in format"
 msgstr "函数属性不匹配"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "内建函数实参无效"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "格式字符串尾有可疑的%<%%%>"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "inconsistent capitalization in format"
 msgstr "%L处非常量初始化表达式"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "格式字符串尾有可疑的%<%%%>"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "格式字符串中有重复的 %s"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "格式字符串中有重复的 %s"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "格式字符串中有重复的 %s"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "格式字符串尾有可疑的%<%%%>"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "格式字符串尾有可疑的%<%%%>"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 #| msgid "Nonconforming tab character at %C"
 msgid "unquoted non-graph characters in format"
 msgstr "%C处的制表符不相容"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated format string"
 msgid "unterminated quoting directive"
 msgstr "未终止的格式字符串"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "格式字符串中出现无效的类型转换字符%qc"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "格式字符串尾有可疑的%<%%%>"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "格式字符串末尾的转换缺少类型"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "处理 #ident 指令"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "格式字符串嵌有%<\\0%>"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "未结束的汇编风格指示"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "对空指针指向内容的写操作(实参 %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "对空指针指向内容的读操作(实参 %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "对常量对象的写操作(实参 %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "格式字符串实参 %d 有多余的类型限定"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "格式%q.*s需要类型%<%s%s%>，但实参 %d 的类型为%qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s: “%s” 而不需吻合中 “ifdef” 或 “ifndef” "
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "格式%q.*s需要类型%<%s%s%>，但实参 %d 的类型为%qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%>未被定义为一个类型"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%>未被定义为%<long%>或%<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%>未被定义为一个类型"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%>未被定义为一个类型"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%>未被定义为一个类型"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%>未被定义为一个类型"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%>未被定义为一个指针类型"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "待格式化的实参不是%<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime 格式字符串无法格式化实参"
@@ -32817,7 +32871,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -32833,17 +32887,17 @@ msgstr "迭代变量%qE类型无效"
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
@@ -32853,7 +32907,7 @@ msgstr "缺少自增语句"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -33494,7 +33548,7 @@ msgid "wrong type argument to %s"
 msgstr "不能对该类型的参数求绝对值"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常量表达式溢出"
@@ -34198,7 +34252,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
@@ -34281,7 +34335,7 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -34301,7 +34355,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
@@ -34322,7 +34376,7 @@ msgstr "%qs对%qs而言无效"
 msgid "too many input files"
 msgstr "输入文件太多"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mcpu"
 msgid "unknown value %qs for %<-mcpu%>"
@@ -34356,14 +34410,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "%qs对%qs而言无效"
@@ -34913,406 +34967,413 @@ msgstr "重叠定义在 Mach-O 中不受支持；已忽略"
 msgid "profiler support for VxWorks"
 msgstr "对 VxWorks 的取样支持"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "实参必须是常数"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "掩码必须是一个立即数"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "实参必须是常数"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "汇编器不支持 -mabi=ilp32"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "实参必须是常数"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %qT but argument is of type %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%>不是字符串或数字"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "未知的 #pragma GCC coprocessor %E"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new 不能用于函数类型"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "不使用位段指令"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 msgid "invalid format for sve_width"
 msgstr "操作无效的对象"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "无效 %%h 值"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "%s: 不适用的选项 -- %c\n"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "spec 函数名格式错误"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, gcc-internal-format
 msgid "specify a system register with a small string length."
 msgstr ""
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "%qs对%qs而言无效"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "%X%P: 未知特征 %s\n"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "内建函数实参无效"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "内建函数实参无效"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "开关 -mcpu=%s 与 -march=%s 冲突"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "汇编器不支持 -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s 只接受 2 个参数"
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "目标系统不支持调试输出"
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:18004
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "不支持的真理哈希类型 %d。\n"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -35508,17 +35569,17 @@ msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -35677,13 +35738,13 @@ msgstr "未知的 TLS 模型%qs"
 msgid "invalid type for %<asm%> flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "coprocessor not enabled"
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "协处理器未被启用"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr ""
@@ -35691,194 +35752,194 @@ msgstr ""
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "实参必须是常数"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s 需要范围在[%d，%d]内的整型字面常量。"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "掩码必须是一个立即数"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "选择子必须是立即数"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "掩码必须是一个立即数"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE属性的参数应当在 0 和 255 之间"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -35888,302 +35949,302 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt 与 NEON 互不兼容"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "目标 CPU 不支持 ARM 模式"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "函数调用回溯支持只在为 Thumb 编译时有意义"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "被调用者协作只在为 Thumb 编译时有意义"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g 与 -mno-apcs-frame 并用可能不能给出有意义的调试信息"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "-mtp=cp15 和 16 位 Thumb 不能并用"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC 与 Thumb 不兼容"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-fjni 与 -freduced-reflection 不兼容"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "目标 CPU 不支持 THUMB 指令"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "目标 CPU 不支持未对齐的访问"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check 和 -mno-apcs-frame 互不兼容"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic 和 -mapcs-reent 互不兼容"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "不支持 APCS 重入代码。已忽略"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "结构大小边界只能被设定为 %s"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "结构大小边界只能被设定为 %s"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 与 -msingle-pic-base 不兼容"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= 不与 -fpic 并用时不起作用"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "‘%s’不能被用作 PIC 寄存器"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition 不能在此架构下工作"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable 与 -msdata=%s 互不兼容"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt 需要与 AAPCS 兼容的 ABI 方能正确操作"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi 需要相应 CPU 的支持"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "目标 CPU 不支持交互工作"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS 不支持 -mcaller-super-interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS 不支持 -mcallee-super-interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 而无 ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "目标 CPU 不支持 THUMB 指令"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, fuzzy, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "不是从 AAPCS 派生出的 PCS 变种"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "可变参数函数必须使用基础的 AAPCS 变种"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS 变动"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 硬件浮点 VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE属性只能用于函数而非 %s"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE属性只能用于函数而非 %s"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE属性只能用于函数"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, fuzzy, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "无法计算出栈中参数的真实地址"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "非预期的模块结束"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高寄存器弹栈时没有可用的低寄存器"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 #| msgid "invalid element type for attribute %qs"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -36192,24 +36253,24 @@ msgstr "属性%qs的元素类型无效"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "属性%qE的向量类型无效"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes SPE ABI"
 msgid "unknown target attribute or pragma %qs"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
@@ -36290,17 +36351,17 @@ msgstr "不支持"
 msgid "%<-fPIE%> is not supported"
 msgstr "不支持"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-flto and -fwhopr 互斥"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD不能有默认参数"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "不正确的函数返回值"
@@ -36574,7 +36635,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "嵌套函数在此目标机上不受支持"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "内建函数实参无效"
@@ -36921,56 +36982,56 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "在浮点寄存器中传递浮点参数"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "不能对该类型的参数求绝对值"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "nested function trampolines not supported on this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "嵌套函数蹦床在此目标机上不受支持"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "sorry, unimplemented"
 msgid "TLS is not implemented for GCN."
 msgstr "对不起，尚未实现"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 #| msgid "sorry, unimplemented"
 msgid "Builtin not implemented"
 msgstr "对不起，尚未实现"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "操作数号超出范围"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -37111,134 +37172,134 @@ msgstr ""
 "\n"
 "错误：“%s”并非有效新闻群组！\n"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最后一个实参必须是一个 2 位立即数"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最后一个实参必须是一个 3 位立即数"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "倒数第二个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "不正确的格式：%s\n"
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "控制生成的浮点舍入模式"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE需要未知的 ISA 选项"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE需要 ISA 选项 %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最后一个实参必须是一个立即数"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "左实参必须是一个切片"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "(提示略过)"
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 #| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
@@ -37652,149 +37713,149 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "中断函数不能有参数"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -38262,7 +38323,7 @@ msgstr "%qE不能同时有%<mips16%>和%<nomips16%>属性"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE重声明有冲突的属性%qs"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -39364,56 +39425,56 @@ msgstr "%qE属性需要一个整常量作为实参"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD不能有默认参数"
@@ -39536,344 +39597,345 @@ msgstr "数字必须是 0 或 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "#pragma longcall 末尾有垃圾字符"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s 不为这个配置所支持"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "对 AltiVec 内建函数来说无效的参数组合"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 返回向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 传递向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs 在此子目标上不受支持"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%K%D 的最后一个实参不是一个 0 到 3 之间的整常量"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return 在此目标机上不受支持"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return 在此目标机上不受支持"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return 在此目标机上不受支持"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "%srtd%s 在 64 位模式下被忽略"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "%srtd%s 在 64 位模式下被忽略"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s 只接受 1 个参数"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "属性%qs的参数无效"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "属性%qs的参数无效"
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "实参 3 必须是一个 4 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "实参 2 必须是一个 2 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "无法解析的重载 Altivec 内建函数%qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be [0, 12]"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "此内建函数只在 fr450 上可用"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部错误：内建函数 %s 有非预期的返回类型 %s"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
@@ -39895,232 +39957,237 @@ msgstr "ISO C90 不允许可变数组成员"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC target 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架构，正在启用"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位 Darwin 下不受支持；它与已安装的 C 和 C++ 库不兼容"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring 在小端在前的系统上不受支持"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs必须与%qs一起使用"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT作为%qs被引用"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "目标属性或 pragma 改变了 long double 的大小"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "使用 IEEE 扩展精度 long double"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "使用 IBM 扩展精度 long double"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s 不支持 %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "%2$sveclibabi=%3$s %4$s向量库 ABI 类型(%1$s)未知"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目标属性或 pragma 改变了 AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目标属性或 pragma 改变了 darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs没有指定类名"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "调用篡改寄存器用作全局寄存器变量"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
@@ -40465,146 +40532,146 @@ msgstr "%qE属性的实参不是一个字符串常量"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部变量大小总和超过架构极限。"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函数 %qs 是 %wd 字节超出用户提供的堆叠限制的 %d 字节。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函数 %qs 是 %wd 字节该项是超过半堆叠大小。动态检查会无法是 reliable。没有检查发出用于这个函数。"
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "栈帧大小不是 8 字节的倍数：%wd"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs使用动态栈分配"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬件十进制浮点指令在 ESA/390 模式下不可用"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支持"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "栈大小必须大于栈防护值"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "栈大小不能大于 64K"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard 意味着使用 -mstack-size"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE属性只为 SH2A 所支持"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "嵌套函数在此目标机上不受支持"
@@ -41036,8 +41103,8 @@ msgstr "%qs属性只能为数组类型使用"
 msgid "could not read the BRIG file"
 msgstr "无法写入响应文件 %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如预期地被忽略"
@@ -41321,7 +41388,7 @@ msgstr "%q+D的声明隐藏了先前的一个非变量声明"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD的声明隐藏了一个全局声明"
@@ -41394,7 +41461,7 @@ msgstr "%qE未声明(在此函数内第一次使用)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每个未声明的标识符在其出现的函数内只报告一次"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "标号%qE在所有函数外被引用"
@@ -41424,7 +41491,7 @@ msgstr "跳转至语句表达式中"
 msgid "duplicate label declaration %qE"
 msgstr "重复的标号定义%qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重复的标号%qD"
@@ -41636,7 +41703,7 @@ msgstr "不能将带有 volatile 字段的对象放入寄存器"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -41982,7 +42049,7 @@ msgstr "类型名声明为返回一个数组的函数"
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
@@ -42289,7 +42356,7 @@ msgstr "嵌套的%<struct %E%>重定义"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
@@ -42339,7 +42406,7 @@ msgstr "结构不包含任何有名成员"
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
@@ -42376,7 +42443,7 @@ msgstr "嵌套的%<enum %E%>重定义"
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>重声明"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -42407,7 +42474,7 @@ msgstr "枚举值溢出"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
@@ -42438,7 +42505,7 @@ msgstr "%qD先前没有原型"
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
@@ -42553,12 +42620,12 @@ msgstr "实参%qD与内建原型不符"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
@@ -42566,263 +42633,263 @@ msgstr "形参%qD被设定但未被使用"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "只允许在 C99 模式下使用%<for%>循环初始化声明"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "使用 -std=c99 或 -std=gnu99 来编译您的代码"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了静态变量%qD"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了非变量%qD"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定声明"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支持复数类型"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支持饱和类型"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重复的%qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支持布尔类型"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C 不支持十进制浮点数"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定点类型在此目标机上不受支持"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支持定点类型"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "%qD的 C++ 查询会返回一个字段而非类型"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE没有出现在声明的开头"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE不能用作函数"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支持 %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支持 %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%>出现在%<extern%>之前"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%>出现在%<static%>之前"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "声明指定了多个存储类"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>使用时缺少%<_Fract%>或%<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次数为负"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次数大于或等于类型宽度"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -42843,7 +42910,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "没有匹配"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -42890,7 +42957,7 @@ msgid "unknown type name %qE"
 msgstr "未知的类型名%qE"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -42911,7 +42978,7 @@ msgstr "%q+D不能有 section 属性"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "属性在未初始化类型上被忽略"
@@ -42926,8 +42993,8 @@ msgstr "属性在模板实例化上被忽略"
 msgid "unexpected attribute"
 msgstr "非预期的属性"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -42966,7 +43033,7 @@ msgstr "文件作用域中出现%<auto%>空声明"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用于变量或函数声明"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要%<,%>或%<;%>"
@@ -42994,7 +43061,7 @@ msgstr "ISO C90 不支持%<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字符串"
@@ -43025,7 +43092,7 @@ msgstr "静态断言中出现非常量条件"
 msgid "static assertion failed: %E"
 msgstr "静态断言错误：%E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -43072,14 +43139,14 @@ msgstr "模板第 %d 个参数无效"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "枚举表以逗号结尾"
@@ -43164,7 +43231,7 @@ msgstr "需要指定声明或%<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE属性需要带有名实参的原型"
@@ -43175,7 +43242,7 @@ msgstr "%qE属性需要带有名实参的原型"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, fuzzy, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
@@ -43235,7 +43302,7 @@ msgstr "ISO C90 不允许混合使用声明和代码"
 msgid "expected %<}%> before %<else%>"
 msgstr "%<else%>前需要%<}%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%>之前没有%<if%>"
@@ -43250,7 +43317,7 @@ msgstr "标号位于复合语句末尾"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要语句"
@@ -43275,17 +43342,17 @@ msgstr "标号只能是语句的一部分，而声明并非语句"
 msgid "expected identifier or %<*%>"
 msgstr "需要标识符或%<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建议在空的%<if%>语句体周围加上花括号"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建议在空的%<else%>语句体周围加上花括号"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建议显式地使用花括号以避免出现有歧义的%<else%>"
@@ -43305,12 +43372,12 @@ msgstr "不允许多个中断属性"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "此指令中寄存器无效"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -43326,8 +43393,8 @@ msgstr "快速枚举在 Objective-C 1.0 里不可用"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重复的 cv 限定"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, gcc-internal-format
 msgid "first seen here"
 msgstr ""
@@ -43356,12 +43423,12 @@ msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -43767,63 +43834,63 @@ msgstr "%C处数组声明需要另外一维"
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%qs后断言"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<readonly%>属性与%<setter%>属性冲突"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
@@ -43834,18 +43901,18 @@ msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要语句"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
@@ -43866,58 +43933,58 @@ msgstr "需要 %<,%> 或 %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -43939,12 +44006,12 @@ msgstr "%<num_threads%>值必须为正"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%>值必须为正"
@@ -43955,24 +44022,24 @@ msgstr "%<num_threads%>值必须为正"
 msgid "expected constant integer expression"
 msgstr "需要整数表达式"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "启用最小/最大值指令"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with unspecified category"
@@ -43988,56 +44055,56 @@ msgstr "调度块大小表达式必须为整型"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多 %<static%> 参数"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "非预期的参数"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "需要%<new%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
@@ -44047,7 +44114,7 @@ msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -44082,22 +44149,22 @@ msgstr "%H折叠变量需要正整常数表达式"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -44113,79 +44180,79 @@ msgstr "无效的调度类型"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -44201,7 +44268,7 @@ msgstr "%qE未声明"
 msgid "expected function name"
 msgstr "需要函数"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -44212,69 +44279,69 @@ msgstr "%qD不是一个成员模板函数"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
@@ -44284,62 +44351,62 @@ msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "整型表达式%qE不是常量"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
@@ -44349,74 +44416,74 @@ msgstr "需要迭代声明或初始化"
 msgid "not enough perfectly nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -44431,62 +44498,62 @@ msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "需要选择语句"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s 只接受 2 个参数"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "需要字面字符串"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "需要整数表达式"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, fuzzy, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "内容 %qs 已经指定的在中 %<@synthesize%>"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
@@ -44497,13 +44564,13 @@ msgstr "需要%<catch%>"
 msgid "variant %qD is not a function"
 msgstr "在函数%qs中"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不兼容"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -44513,32 +44580,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
@@ -44593,43 +44660,43 @@ msgstr "需要函数"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -44644,27 +44711,27 @@ msgstr "使用了变长数组"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而无需 transactional 内存支持已启用"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
@@ -44674,7 +44741,7 @@ msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> 函数调用无法在之内外异动作业或 %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>无法在之内 %<__transaction_atomic%>"
@@ -44690,7 +44757,7 @@ msgstr "括入并行"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "对 void 表达式的使用无效"
@@ -44818,7 +44885,7 @@ msgstr "提领%<void *%>指针"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "数组下标不是一个整数"
@@ -44843,7 +44910,7 @@ msgstr "ISO C90 不允许非左值的数组作为下标运算的左操作数"
 msgid "enum constant defined here"
 msgstr "枚举常量在此定义"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -44958,18 +45025,18 @@ msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "提供给函数%qE的实参太少"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比较指针和整数"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -44995,7 +45062,7 @@ msgstr "函数指针不能相减"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在指向不完全类型的指针上执行算术运算"
@@ -45252,7 +45319,7 @@ msgstr "将一个指针转换为大小不同的整数"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "从类型为%qT的函数调用转换到不匹配的类型%qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "将一个整数转换为大小不同的指针"
@@ -45433,7 +45500,7 @@ msgstr "赋值的左手边可能是 format 属性的备选时"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
@@ -45606,7 +45673,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字符串常量初始化的数组类型不合适"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "对非左值数组的使用无效"
@@ -45637,7 +45704,7 @@ msgstr "初始值设定中的元素在载入时无法被计算出"
 msgid "invalid initializer"
 msgstr "无效的初始值设定"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
@@ -45783,7 +45850,7 @@ msgstr "标量初始值设定项中有多余元素"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允许%<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
@@ -45823,7 +45890,7 @@ msgstr "在 ISO C 中，%<long%>开关表达式不被转换为%<int%>"
 msgid "case label is not an integer constant expression"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 标号出现在开关语句外"
@@ -45833,17 +45900,17 @@ msgstr "case 标号出现在开关语句外"
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>标号未出现在 switch 语句内"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP for 循环中使用了 break 语句"
@@ -45858,7 +45925,7 @@ msgstr "break 语句不在循环或开关语句内"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "语句不起作用"
@@ -45868,22 +45935,22 @@ msgstr "语句不起作用"
 msgid "expression statement has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "形参数量不同"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -45935,7 +46002,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "指针与整数 0 比较大小"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指针与整数 0 比较大小"
@@ -45965,52 +46032,52 @@ msgstr "需要标量时使用了联合类型"
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD不是一个成员模板函数"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 msgid "cannot dereference %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -46020,8 +46087,8 @@ msgstr "%qE在子句%qs中不是一个变量"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
@@ -46196,12 +46263,12 @@ msgstr "用户定义的%qD总是计算所有两个参数"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
@@ -46226,8 +46293,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -46242,19 +46309,19 @@ msgstr "%qD在数据子句中多次出现"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD在数据子句中多次出现"
@@ -46324,120 +46391,120 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 #| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "源不是一个指针"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "-frepo 必须与 -c 一起使用"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "给%<va_arg%>的第一个参数的类型不是%<va_list%>"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ 在%<va_arg%>中需要提升后的类型而不是枚举"
@@ -46643,838 +46710,838 @@ msgid "expected case label"
 msgstr "需要类名"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "以从%qT转换为%qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 msgid "  no known conversion from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T, %T) <内建>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T) <内建>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 #| msgid "%s%D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%D(%T) <内建>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 #| msgid "%s%T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s%T  <转换>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <near match>"
 msgid "%s%#qD (near match)"
 msgstr "%s%#D <就近匹配>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <deleted>"
 msgid "%s%#qD (deleted)"
 msgstr "%s%#D <删除的>"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D <deleted>"
 msgid "%s%#qD (reversed)"
 msgstr "%s%#D <删除的>"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, fuzzy, gcc-internal-format
 #| msgid "%s%#D"
 msgid "%s%#qD"
 msgstr "%s%#D"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 #| msgid "  when initialized here"
 msgid "  inherited here"
 msgstr "在此处初始化后被初始化"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, fuzzy, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  传回类型 %qT 的明确的转换函数无法转换到 %qT 与合格转换"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, fuzzy, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  转换从传回类型 %qT 的模板转换函数特殊化到 %qT 不是精确的匹配"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, fuzzy, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  替代的 deduced 模板参数结果的在中错误看见以上的"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, fuzzy, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  建构子需单一参数的它的本身类别类型无效"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "调用重载的%<%D(%A)%>有歧义"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "没有对象不能调用成员函数指针 %E，考虑使用 .* 或 ->*"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "对%<(%T) (%A)%>的调用没有匹配"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "对%<(%T) (%A)%>的调用有歧义"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "调用重载的%<%D(%A)%>有歧义"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "没有匹配"
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "需要%<operator%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E::%E%>既不是类也不是命名空间"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "错误的运算符"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E::%E%>不是一个类型"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "重复的%qs"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "在协议中找到%<-%E%>而非%<+%E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, fuzzy, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第二个操作数类型为%<void%>，但第三个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第三个操作数类型为%<void%>，但第二个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "条件表达式中枚举不匹配：%qT对%qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%>没有出现在后缀%qs中，尝试使用前缀运算符"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "没有为后缀%2$qs声明%<%1$D(int)%>"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD没有相应的释放函数"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "没有合适的%<operator %s%>给%qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "在此声明"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "在此声明"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D无法访问"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "在此声明"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "将 NULL 转换到非指针类型%qT"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT的初始值设定周围花括号太多"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "从初始化列表转换为%qT将使用显式构造函数%qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "无法将位段%qE绑定到%qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能将紧实的字段%qE绑定到%qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "无法将右值%qE绑定到%qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "不能通过%<...%>传递有不能平凡复制的类型%q#T"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "递归计算%q#D的默认参数"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD的第 %1$d 个形参的默认实参尚未被解析到"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "在调用%qD时"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT是%qT的一个不可访问的基类"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "(在%qs的初始化附近)"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "在此声明"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "不能将%qT转换为%qT"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "对于函数类型的类型转换，移除冗余的%<::%D%>"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "对重载的%<%s(%A)%>的调用有歧义"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "没有对象无法调用成员函数%qD"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "传递%qT时选择%qT而不是%qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "选择%qD而不是%qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "因为前者的实参类型转换序列更好"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "重载解决时默认参数不匹配"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr "备选 1: %q+#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr "备选 2: %q+#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暂时的约束到 %qD 只有持续直到建构子离开"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -47505,547 +47572,547 @@ msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "与先前此处的声明冲突"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "version inherited from %qT declared here"
 msgstr "%qD在此声明"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D无法被重载"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "先前的声明%q+D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "方法%q+D的权限设定冲突，已忽略"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "字段%qE的权限设定冲突，已忽略"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr " 因为局部方法%q+#D与之重名"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 msgid "local method %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr " 因为局部成员%q+#D与之重名"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 msgid "local member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "在此声明"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "类%qT中所有成员函数都是私有的"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T仅定义了一个私有析构函数且没有友元"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T仅定义了一个私有构造函数且没有友元"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD的最终重载在%qT中不唯一"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "函数%q+D的定义被标记为 dllimport"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+D定义后未使用"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D为"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "%q+D所隐藏"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "当继承来的方法未被实现时给出警告"
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "位段%q+#D有非整数的类型"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位段%q+D的宽度不是一个整数常量"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位段%q+D宽度为负"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位段%q+D宽度为 0"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D的宽度超过了它的类型"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D太小而不能存放%q#T的所有可能值"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有构造函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有析构函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D不能是静态的，因为它是联合的成员"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "字段%q+D无效地声明为函数类型"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "为非紧实的非简单旧数据字段%q+#D忽略 packed 属性"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了联合%qT中的多个字段"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 msgid "initialized member %q+D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "字段%q+#D与类重名"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T有指针数据成员"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "但没有重载%<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "或者%<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "但没有重载%<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 msgid "pointer member %q+D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%qD的对齐"
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%qD的对齐"
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "为非虚方法%q+D指定了初始值设定项"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法强制变更两者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "为不存在的方法%qE创建选择子"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基类%q#T有一个非虚析构函数"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是汇总，没有 trivial 缺省构造函数，而没有任何 constexpr 建构子该并非复制或移动建构子"
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "类中有非静态引用%q+#D，却没有提供构造函数"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "类中有非静态常量成员%q+#D却没有构造函数"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，直接基类%qT在%qT中无法访问"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，虚基类%qT在%qT中无法访问"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D的偏移量与 ABI 不兼容，并且在 GCC 的未来版本中可能会有变化"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "数组%qE太大"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "对非左值数组的使用无效"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "类型%qT大小未知"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "类型透明类别 %qT 有基础类别"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "类型%qE有虚成员函数"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "试图完成结构，但为先前的解析错误所中断"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "语言字符串%<\"%E\"%>不可识别"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "没有可将函数%qD转换到类型%q#T的匹配项"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "将重载函数%qD转换为类型%q#T有歧义"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成员指针%qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "类型信息不充分"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -48129,7 +48196,7 @@ msgstr "调用这些函数时给出警告"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "内部函数"
@@ -48188,7 +48255,7 @@ msgstr "试图分配已经分配的数组‘%s’"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%qD的声明隐藏了先前的一个局部变量"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "调用非函数的%qD"
@@ -48243,384 +48310,383 @@ msgstr "%q+E不是一个常量表达式"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "在此声明"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D不是 const"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D是 volatile"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "需要模板 ID"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "function concept must be called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 对象 %qE 与线程本地或自动贮藏体并非常数运算式"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "虚函数不能是友元"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%L处被零除"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处非常量初始化表达式"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD不是一个类型"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE不是一个类"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 msgid "evaluating %qs"
 msgstr "括入并行"
@@ -48669,7 +48735,7 @@ msgstr "将类型为%2$qT的右值转换为非常量引用类型%1$q#T"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "从%qT转换到%qT并未提领指针"
@@ -48712,298 +48778,298 @@ msgstr "需要浮点数值时使用了%q#T"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "请求从%qT转换到非标量类型%qT"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD在此声明"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "伪析构函数未被调用"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第二个操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第三个操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "提领不会访问作为逗号操作符右操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "提领不会访问作为逗号操作符左操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "提领不会访问语句中具有不完全类型的对象%qT"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "提领不会访问 for 循环增量表达式中具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "向 void 的转换不会访问具有类型%qT的对象"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "隐式提领不会访问作为条件表达式第二个操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "隐式提领不会访问作为条件表达式第三个操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "隐式提领不会访问作为逗号操作符右操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "隐式提领不会访问作为逗号操作符左操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "隐式提领不会访问语句中类型为%qT的对象"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "隐式提领不会访问 for 循环增量表达式中具有类型%qT的对象"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第二个操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第三个操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "提领不会访问作为逗号操作符右操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "提领不会访问作为逗号操作符左操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "提领不会访问语句中具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "提领不会访问 for 循环增量表达式中具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "向 void 的转换不会访问具有不完全类型%2$qT的对象%1$qE"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "条件表达式第二个操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "条件表达式第三个操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "逗号操作符的右操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "逗号操作符的左操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "语句中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "for 循环增量表达式中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "给予函数%qE的参数不是浮点数"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "语句不起作用"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for 循环増量表达式不起作用"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "将 NULL 转换为非指针类型"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT的默认类型转换有歧义"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  备选转换包括%qD和%qD"
@@ -49076,7 +49142,7 @@ msgstr "从先前的声明%q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "先前的声明%q+D"
@@ -49267,12 +49333,12 @@ msgstr "%q+D的上一个声明在此"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD"
@@ -49286,44 +49352,44 @@ msgstr "删除了%qD的定义"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D的数据区域与先前的声明冲突"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q#D 重定义"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD与已用的函数冲突"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D未在类中声明"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D重声明内联并有%<gnu_inline%>属性"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D重声明为内联而没有%<gnu_inline%>属性"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -49331,879 +49397,879 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q#D的线程局部声明出现在其非线程局部声明之后"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q#D的非线程局部声明出现在其线程局部声明之后"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q#D重声明"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "上一个声明"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "从这里"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "退出了 OpenMP 结构块"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "进入了有不平凡析构函数的%q+#D的作用域"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "进入了 try 块"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "进入了 catch 块"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "进入了 OpenMP 结构块"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "需要语句"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "进入了有不平凡析构函数的%q+#D的作用域"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "OpenMP 结构块出口无效"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD使用时未带模板参数"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T不是一个类"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "在%2$qT中查询%1$qT有歧义"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类模板"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类型"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "不支持 -falign-labels=%d"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有构造函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有构构函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T的属性必须跟在%qs关键字后面"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一个声明指定了多个类型"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "对 C++ 内建类型%qT的重声明"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 声明中缺少类型名"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允许匿名结构"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%>只能在类中指定"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能为构造函数指定%<explicit%>"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "此声明中的%<typedef%>被忽略"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略在定义之外为类类型%qT应用的属性"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略在关联定义之外为依赖类类型%qT应用的属性"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef%qD被初始化(改用 decltype)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D声明有%<extern%>并被初始化"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允许将%<%T::%D%>定义为%<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允许成员%qD的初始化"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %qs function"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "变量%q#D有初始值设定，但是类型不完全"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "数组%q#D的元素类型不完全"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名字被用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值设定不受支持"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD的存储大小未知"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD的存储大小不是常量"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr " 变通的作法是删除初始值设定"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T没有用户提供的默认构造函数"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建构子未被 user-provided 因为它是明确的缺席在中类别本体"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建构子不初始化 %q+#D"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT没有名为%qD的非静态数据成员"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示项 %qE 外侧汇总初始设置式"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "数组%q#T的元素类型不完全"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "变长复合字面量"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q+D类型不完全"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "标量对象%qD在初始值设定中需要一个元素"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在 C++98 中%qD必须由构造函数而不是%<{...}%>初始化"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "数组%qD被有括号的字面字符串%qE所初始化"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "构造函数中对静态成员的初始化无效"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一个类外的初始化)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隐藏了早先的类型声明%q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT是%qT不可访问的基类"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "为结构字段指定了%qs"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "无法分解地址"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "源有不完全的类类型"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解构式"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD没有声明为一个参数"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -50483,7 +50549,7 @@ msgstr "数组维数溢出"
 msgid "%qD declared as array of %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
@@ -50658,7 +50724,7 @@ msgstr "缺少声明标识符：使用了保留字%qD"
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
@@ -50866,847 +50932,847 @@ msgstr "忽略%qs属性"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "错误地使用了%<auto%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "构造函数不能被声明为虚函数"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD模板声明无效"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "不能打开 %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -51718,96 +51784,96 @@ msgstr "%qT作为枚举被引用"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下层的输入 enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -51817,73 +51883,73 @@ msgstr "%<%2$T%>的内在类型%<%1$T%>必须是整型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -51923,7 +51989,7 @@ msgstr "不能 delete 一个函数。只有指向对象的指针才是%<delete%>
 msgid "deleting %qT is undefined"
 msgstr "删除%qT未定义"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D声明为模板"
@@ -51933,7 +51999,7 @@ msgstr "%q#D声明为模板"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "提供的模板参数列表与 %qD 的模板不符"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "析构函数%qD被声明为一个成员模板"
@@ -52277,153 +52343,153 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "没有参数"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "对%<%T::%D%>的引用有歧义"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD不是%qD的成员"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%>未被声明"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%>未被声明"
@@ -52607,346 +52673,346 @@ msgstr "生成指向引用类型%qT的引用"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD应该在成员初始化列表中被初始化"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "形参%qD已初始化"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D将在"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D将在"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基类%qT将在"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "%q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "基类%qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "在此处初始化后被初始化"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "为%qD给定了多个初始值设定"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "为基类%qT给定了多个初始值设定"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化%qT的多个成员"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基类%q#T应该在复制构造函数中显式地初始化"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D是一个静态数据成员；它只能在定义时被初始化"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "对没有基类的%qT的无名初始化"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "对使用了多继承的%qT的无名初始化"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD既是一个直接基类又是一个间接虚基类"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全类型%qT没有成员%qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "指向位段%qD指针无效"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "对非静态数据成员%qD的无效使用"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "表达式中整复数溢出"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "文件域中的动态可变字段"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "对 new 而言类型%<void%>无效"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合适的%qD，在类%qT中"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "对成员%qD的请求有歧义"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用于引用类型"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用于函数类型"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值设定在完成之前结束"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 时数组大小未知"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "删除对象的抽象类别类型 %qT 该项有 non-virtual 解构式将造成未定义的行为"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "删除对象的 polymorphic 类别类型 %qT 该项有 non-virtual 解构式也许造成未定义的行为"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的实参类型既非指针也非数组"
@@ -53111,12 +53177,12 @@ msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "非静态的常量成员%q#D，不能使用默认的赋值运算符"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "非静态的引用成员%q#D，不能使用默认的赋值运算符"
@@ -53142,165 +53208,169 @@ msgstr "不能对该类型的参数求绝对值"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "只能为 Java 类定义应用%qE属性"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "只能为 Java 类定义应用%qE属性"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD必须有%<void%>类型"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "非成员函数%qD不能拥有 cv 限定符"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD已经是%qT的友元"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot default compare union %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "不能创建指向引用成员%qD的指针"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare anonymous union member"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "synthesized method %qD first required here "
 msgid "synthesized method %qD first required here"
 msgstr "在这里第一次需要生成的方法%qD"
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "未初始化的成员%qD具有%<const%>类型%qT"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "缺席缺省构造函数不初始化 %q+#D"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "缺席缺省构造函数不初始化任何非静态数据成员"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "lambda 闭合类型有删除的缺省构造函数"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "lambda 闭合类型有删除的复制指派运算符"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D 是隐含地声明的作为删除的因为 %qT 声明移动建构子或移动指派运算符"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D 是隐含地删除的因为缺省定义会被不当形式的："
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "不匹配%qD预期的签名"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 #| msgid "does not match expected signature %qD"
 msgid "expected signature: %qD"
 msgstr "不匹配%qD预期的签名"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, fuzzy, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "明确的缺席函数 %q+D 无法声明的作为 constexpr 因为蕴含声明不是 constexpr："
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "%qD不能被默认化"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD不能被默认化"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "默认化函数%q+D有默认参数"
@@ -53344,225 +53414,225 @@ msgstr "形参%qD被无效地被声明为具有方法类型"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D的声明隐藏了一个形参"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "全局声明%q+#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
 msgstr "与先前的声明%q+#D冲突"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "本地类中的友元声明%qD没有先前声明"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "枚举%q+D重声明"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%>指定了析构函数"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%>在%qT内指定了构造函数"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qE"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "不允许在 using 声明中使用命名空间%qD"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD的声明不在包含%qD的命名空间中"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD的声明中有显式的限定"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D声明为友元"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD应当先在%qD内声明"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD属性需要一个 NTBS 作为实参"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD属性无意义，因为匿名命名空间的成员拥有局部符号"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定%qD属性被忽略"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空间搜索的用于 %qE"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建议的替代："
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "结构在此定义"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "‘%s’(位于 %L)有歧义"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "这里不允许命名空间别名%qD，假定为%qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法属性必须被指定的于结束只有"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "标号%qD在此定义"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX 进入 pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -53588,7 +53658,7 @@ msgstr "标识符%qE与 C++ 关键字冲突"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
@@ -53613,7 +53683,7 @@ msgstr "%<::%E%>尚未声明"
 msgid "request for member %qE in non-class type %qT"
 msgstr "在非类类型%2$qT中请求成员%1$qE"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>尚未声明"
@@ -53694,7 +53764,7 @@ msgstr "无效的模板 ID"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮点字面量不能出现在常量表达式中"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "常量表达式中不能出现目标不是整型或枚举型的类型转换"
@@ -53816,7 +53886,7 @@ msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -53938,7 +54008,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "无法找到字串实字运算符 %qD 与 %qT，%qT 参数"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "需要声明"
@@ -54041,12 +54111,12 @@ msgstr "%<~%T%>声明为%qT的一个成员"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名%qD用于析构函数声明"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD不是一个模板"
@@ -54081,7 +54151,7 @@ msgstr "%C 期待访问指定符"
 msgid "expected nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "类型不能定义在类型转换中"
@@ -54096,7 +54166,7 @@ msgstr "类型不能定义在%<typeid%>表达式中"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -54111,7 +54181,7 @@ msgstr "ISO C++ 不允许复合字面量"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "错误地使用了%qD"
@@ -54136,946 +54206,951 @@ msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "__builtin_saveregs 不为此目标所支持"
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的类型标识符后面不能出现数组边界"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要表达式类型"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "使用旧式的类型转换"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>运算符在 C++0x 中将被认为是两个右尖括号"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建议%<>>%>表达式周围加上括号"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++ 不允许省略 ?: 的中间操作数"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, fuzzy, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "捕获列表应在此结束"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %<this%> 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "已经在 Lambda 表达式中捕获了%<this%>"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 #| msgid "cannot capture %qE by reference"
 msgid "%<this%> cannot be captured by reference"
 msgstr "无法通过引用捕获%qE"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%qD不是一个变量"
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "截取的变量 %qD 与 non-automatic 贮藏体持续时间"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "太多的%qs子句"
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %qD 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明确的 by-reference 截取的 %qD 冗余与 by-reference 截取缺省"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重复的%<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "需要标号语句"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 标号%qE未出现在 switch 语句中"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%qE之前需要%<typename%>，因为%qT是一个有依赖的作用域"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>命名了一个构造函数而非类型"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "标号位于复合语句末尾"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "函数返回了一个数组"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "字段%qE声明为一个函数"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "类型不能定义在条件表达式中"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "需要初始值设定"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "前往目录:"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多余的%<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>未出现在块起始"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合声明和函数定义"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "初始值设定项中索引范围为空"
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration"
 msgid "empty structured binding declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "成员函数%qD的初始值设定无效"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%>用在类外"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%>的语义在 C++0x 中将被改变；请考虑删除它"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D无效，在%q#T中"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "类定义不能被声明为友元"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in an exception-specification"
 msgid "types may not be defined in explicit-specifier"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有构造函数才能有基类初始值设定"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代错误的旧式基类初始值设定"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(限定的初始值设定隐式地是一个类型)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介于 %<“”%>和后缀识别码"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "需要标识符或%<(%>"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "二元操作中中操作数无效"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "需要操作符"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以%<<::%>开始一个模板实参列表"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%>是%<[%>的另一种拼法。请在%<<%>和%<::%>间加上空格"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用%<-fpermissive%>G++ 会接受您的代码)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "需要模板实参"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "模板实参表语法错误"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "需要模板名"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非模板%qD用作模板"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用%<%T::template %D%>来表示这是一个模板"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "需要模板实参"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "显式实例化不应当使用%<inline%>限定符"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "需要类型名"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE不是一个类型名"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "concept defined here"
 msgstr "联合在此定义"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用于范围的 enum 必须不使用 %<%D%>关键字"
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 #| msgid "typedef name may not be a nested-name-specifier"
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "声明%qD没有声明任何东西"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD不是一个枚举模板"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "启用模板自动实例化"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qD声明出现在命名空间%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD声明出现在%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "不允许有多余的限定"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而无需名称"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必须使用简单的识别码"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace name required"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "模板标识符不允许出现在 using 声明中"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "访问声明被不宜用在中 favour 的 using-declarations；建议：加入 %<using%> 关键字"
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT不是一个命名空间"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "%qD在函数作用域外未被定义"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "预期的建构子、解构式，或类型转换"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "为函数提供了初始值设定"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "函数%q+D重声明为内联的"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>不是一个类型"
@@ -55084,442 +55159,442 @@ msgstr "%<%T::%E%>不是一个类型"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "无效的声明"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "将构造函数用作模板无效"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "需要一个限定的标识符"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "需要声明"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD是一个命名空间"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "%q+D的类型限定冲突"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "%C处重复访问限定符"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "对%qT的使用非法"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "不能在模板实参中定义类型"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "需要%<,%>或%<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "默认参数只允许出现在函数参数中"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "需要类名"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "结构定义后需要%<;%>"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "联合定义后需要%<;%>"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "需要%<{%>或%<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "不能为类指定 %<override%>"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T的前一个定义"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "声明友元时必须使用 class 关键字"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "位段%qD非整型"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函数定义上有 pure 指定"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "指定了无效的 AE 类型(%s)\n"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "在基类限定中指定了多于一次的%<virtual%>"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超过一个访问说明符在中 base-specified"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(基类隐式地是一个类型)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "动态异常规格被不宜用在中 C++0x; 使用 %<noexcept%> 作为替代"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要标识符"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, fuzzy, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, fuzzy, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -55528,555 +55603,555 @@ msgstr "模板参数表太少"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "没有声明任何东西"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的标号%qD"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "于 %s 等待异动作业锁定\n"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "需要 %<@end%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "标号%qD在此定义"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "在此声明"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 消息参数被预期"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "%C处数组声明需要另外一维"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介于 Objective-C++ 方法"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "不一致的实例变量指定"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "属性可能无法被指定的之前 %<@%D%>Objective-C++ 关键字"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "不能设置只读属性"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "需要整数表达式"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效还原标识符"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "上一个声明"
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>无法在之内外 %<__transaction_atomic%>"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函数"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%>末尾有垃圾字符"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "此上下文中不允许标准转换"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -56359,7 +56434,7 @@ msgstr "展开样式%<%E%>不包括参数包"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "参数包未能在%<...%>中被展开："
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "       %qD"
@@ -56388,84 +56463,84 @@ msgstr "%q+D的声明隐藏了一个形参"
 msgid "template parameter %qD declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到模板参数："
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "参数包实参%qT必须出现在模板实参表末尾"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "模板实参%2$qE的类型%1$qT取决于模板参数"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD没有默认参数"
@@ -56473,49 +56548,49 @@ msgstr "%qD没有默认参数"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "只有指定了 -std=c++0x 或 -std=gnu++0x 时才能在函数模板中使用默认参数"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "默认参数不能用在部分特例化中"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "形参%qD被声明为 void"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "模板类没有名字"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
@@ -56525,64 +56600,64 @@ msgstr "非成员函数%qD不能拥有 cv 限定符"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD模板声明无效"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "对非模板%q#D的模板定义"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 级的%q#D模板参数，却给出了 %d 级"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%2$q#T得到了 %1$d 个模板参数"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "但实际需要 %d 个"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用 template<> 来显式特例化"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT不是一个模板类型"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD的声明中没有 template 限定"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "重声明为具有 %d 个模板参数"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -56590,444 +56665,444 @@ msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "先前的声明%q+D使用了 %d 个模板参数"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "模板形参%q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必须是格式为‘&X::Y’的成员指针"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  类型 %qT 和 %qT 有不兼容的 cv-qualifiers"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 冲突值用于 non-type 参数 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "派生联合%qT无效"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板参数的模板模板参数是不一致与其他 deduced 模板参数"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE不是类型%qT的有效模板实参，因为字面字符串不能用在此上下文中"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D声明为模板"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "内部一致性错误"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "联合和可变数组成员"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE没有出现在声明的开头"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
@@ -57045,296 +57120,296 @@ msgstr "生成非类类型%qT的成员函数指针"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 msgid "%s %#qS"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -57347,140 +57422,140 @@ msgstr "在初次使用后显式特例化%qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT作为枚举被引用"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "模板第 %d 个参数无效"
@@ -57702,7 +57777,7 @@ msgstr "在文件作用域使用%<this%>无效"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "伪析构函数名的限定作用域无效"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的类型%qT不匹配析构函数名 ~%qT"
@@ -57752,7 +57827,7 @@ msgstr "无效的基类"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
@@ -57854,7 +57929,7 @@ msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -57895,7 +57970,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
@@ -58020,120 +58095,120 @@ msgstr "%qD在数据子句中多次出现"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "太多的%qs子句"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -58387,842 +58462,842 @@ msgstr "在不同的成员指针类型%qT和%qT之间的转换需要一个类型
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "不同的成员指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "相同类型 %T 和 %T 的正规类型不同"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "不同类型 %T 和 %T 有相同的正规类型节点"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs用于成员函数无效"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "对位段使用%<sizeof%>无效"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<sizeof%>应用到函数类型的表达式上"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "对位段使用%<__alignof%>无效"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<__alignof%>应用到函数类型的表达式上"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "对非静态数据成员%qE的使用无效"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "对 NULL 对象非静态数据成员%qD的访问无效"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "对象类型%qT的析构函数名~%qT不匹配"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被析构的类型是%qT，但析构函数却使用了%qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT不是%qT的基类"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD不是一个成员模板函数"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT不是一个指向对象的类型"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "对成员指针数组索引的使用无效"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "对成员指针使用一元%<*%>非法"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "隐式转换成员指针用法无效"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "数组引用缺少下标"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用%qE时缺少对象"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允许在程序里调用%<::main%>"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必须用%<.*%>or%<->*%>调用%<%E (...)%>中的成员函数指针，例如%<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太少"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "形参 %P 的类型%qT不完全"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD的地址永远不会为 NULL"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定从重载函数转换到类型%qT"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算术表达式中使用了 NULL"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允许比较指针和整数的值"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮点实参间的无效比较"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "操作数类型%qT和%qT对双目%qO而言无效"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允许在减法中使用类型为%<void *%>的指针"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允许在减法中使用函数指针"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允许在减法中使用指向方法的指针"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指针算术中使用指向不完全类型的指针无效"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "取构造函数%qE的地址"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用%qE形成成员函数指针的用法无效"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "需要一个限定的标识符"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "%qE两边的括号不能用来构造一个成员函数指针"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过提取一个未限定的或带括号的非静态成员函数的地址来形成一个成员函数指针。请使用%<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过取已绑定的成员函数的地址来构造成员函数指针。请改用%<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允许取函数%<::main%>的地址"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能创建指向引用成员%qD的指针"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "无法取得位段%qD的地址"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "取一个类型为%<void%>的表达式的地址"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ 不允许枚举自增"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自增"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自减"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求显式寄存器变量%qD的地址。"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "请求声明为%<register%>的%qD的地址"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的类型转换丢失了限定符"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 static_cast 丢失了限定符"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 reinterpret_cast 丢失了限定符"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 static_cast 无效"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "源有不完全的类类型"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "从%qT转换到%qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "从%qT到%qT的转换损失精度"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "在不同的成员指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "从%qT到%qT的转换增大了目标类型的对齐需求"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允许在函数指针和对象指针间进行转换"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它既不是指针，也不是引用，也不是数据成员指针"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它是一个指针函数类型的指针或引用"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允许转换为数组类型%qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "在求%<%Q(%#T, %#T)%>值时"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "初始值设定中数组索引不是常数"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "数组被用作初始值设定"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "无效的数组赋值"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "在成员函数指针转换中"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成员指针转换经由虚基类%qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "在成员指针转换中"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "不能在参数默认时将%qT转换为%qT"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "不能在传参时将%qT转换为%qT"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "不能在返回时将%qT转换为%qT"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "不能在赋值时将%qT转换为%qT"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在传递%2$q+D的第 %1$P 个实参时"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "返回了对局部变量的%q+D的引用"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in return statement"
 msgstr "返回语句中值太多"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "析构函数返回值"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能从构造函数的异常处理中返回"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "构造函数返回值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%>不能返回 NULL，除非它被声明为%<throw()%>(或 -fcheck-new 起作用)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "右值的引用用作左值"
@@ -59489,108 +59564,108 @@ msgstr "标量初始化带花括号"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "类型%qD不匹配原先的声明"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -59817,10 +59892,10 @@ msgstr "%C处的任何引用都不能多于 %d 维"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "%C处的任何引用都不能多于 %d 维"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, fuzzy, gcc-internal-format
@@ -59990,7 +60065,7 @@ msgstr "程序使用 C 风格的类型转换时给出警告"
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003：%C处包含类型规格的数组构造"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
@@ -60112,7 +60187,7 @@ msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "‘我’于 %L 和‘J’于 %L 无法两者是 BOZ 实字常数"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%2$C处 DATA 语句初始值设定 %1$s 无效"
@@ -60152,7 +60227,7 @@ msgstr "%2$L处 %1$s 内建函数缺少实参"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "%2$L处‘%1$s’内建函数的‘a1’实参必须是 INTEGER、REAL 或 CHARACTER"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
@@ -60167,7 +60242,7 @@ msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须为实数型或复
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "实参‘%s’(属于内建函数‘%s’，位于 %L)必须为 INTEGER 或 PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
@@ -60287,167 +60362,167 @@ msgstr "%4$L处 %3$s 中字符长度不相等 (%1$ld/%2$ld)"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参类型必须相同"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "%L处指针赋值时秩不同"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "%L 的 NULL 指针不能用作内建函数‘%s’的实参"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有种别 %4$d"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为指针或目标 VARIABLE 或 FUNCTION"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个 POINTER 或 TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "%L处由向量下标选择的数组段不应是指针的目标"
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "%L 的 NULL 指针不能用作内建函数‘%s’的实参"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "原子参数于 %L 到内置函数 %s 应该是整数的 ATOMIC_INT_KIND 或逻辑的的 ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有与‘%4$s’一样的类型和种别"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
 msgstr "无法检验状态：%s：%s\n"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为默认实型"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为默认实型"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参不是一个有效的维数索引"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为默认实型"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有种别 %4$d"
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为默认实型"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为默认实型"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "当‘x’是 COMPLEX 时%3$L处内建函数‘%2$s’的实参‘%1$s’不能存在"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为 REAL 或 INTEGER"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有种别 %4$d"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, fuzzy, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "集合数组在%C处被禁用，使用 -fcoarray= 来启用"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
@@ -60455,699 +60530,699 @@ msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "%2$L处内建函数‘%1$s’不允许出现在在初始化表达式中"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "%3$L处‘%2$s’内建函数的实参‘%1$s’在维数 %4$d (%5$ld/%6$ld)上外形无效"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须有 %4$d 的秩或者是一个标量"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须为数字或 LOGICAL 型"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "%3$L处点乘内建函数的参数‘%1$s’和‘%2$s’外形不相同"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "%3$L处内建函数‘%2$s’的‘%1$s’实参类型必须为默认实型"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, fuzzy, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有与‘%4$s’一样的类型和种别"
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是 %4$s"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "%2$L处 %1$s 内建函数缺少实参"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "形参类型不同"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "%s 的参数(位于 %L)长度必须为 1"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有与‘%4$s’一样的种别"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "间断值必须是正数。"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "%L处 LOG 的实参不可以小于或等于零"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "为 auto 变量%2$qE指定了%1$qs"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个常量"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "%2$L处的内建函数‘%1$s’必须至少有两个实参"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "%3$L处内建‘%2$s’内建函数的‘%1$s’实参为空"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "‘%s’和‘%s’用作内建函数‘%s’的参数"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "‘%s’和‘%s’用作内建函数‘%s’的参数"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘a%1$d’必须是 %4$s(%5$d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "%2$L处‘%1$s’内建函数的‘a1’实参必须是 INTEGER、REAL 或 CHARACTER"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "%2$L处内建‘%1$s’的参数必须匹配(%3$s/%4$s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "%3$L处矩阵乘法的两个参数‘%1$s’和‘%2$s’第一维的外形不相同"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "用作%3$L处矩阵乘法参数的‘%1$s’的第二维和‘%2$s’的第一维的外形不相同"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’的秩必须为 1 或 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个数组"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "到参数在中 MOVE_ALLOC 于 %L 必须是 polymorphic 如果从是 polymorphic"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参必须有相同的秩 %5$d/%6$d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参必须有相同的秩 %5$d/%6$d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须为 ALLOCATABLE"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Fortran 2003:空值 intrinsic 与 allocatable 铸型于 %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须至少具有与‘%4$s’(%5$ld/%6$d)中 .TRUE. 值一样多的元素"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个哑元"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个 OPTIONAL 哑元"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个变量"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "‘reshape’内建函数的‘shape’实参在%L处必须是大小为常量的数组"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "‘reshape’内建函数的‘shape’实参在%L处有多于 %d 个的元素"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "%3$L处内建‘%2$s’内建函数的‘%1$s’实参有负的元素(%4$d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "%L处 LOG 的复数实参不可为零"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参的元素数错误(%4$d/%5$d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "%3$L处内建‘%2$s’内建函数的‘%1$s’实参维数越界(%4$d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参维数置换无效(维数%4$d重复)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "若没有填充，%L处内建 ESHAPE 源中没有足够的元素去与外形匹配"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是 %4$s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有可扩展类型"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, fuzzy, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "Fortran 2008:SELECTED_REAL_KIND 与 neither‘P’nor‘R’参数于 %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "‘shape’内建函数的‘source’实参在%L处不能是假定大小的数组"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’不能是 INTENT(IN)"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "‘shape’内建函数的‘source’实参在%L处不能是假定大小的数组"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个数组"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "实际参数到‘%s’于 %L 必须是 polymorphic"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "实际参数到‘%s’于 %L 必须是 polymorphic"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "%2$L处的函数返回值‘%1$s’处没有隐式类型"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%C处的组件必须有 POINTER 属性"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "参数‘S’的最近的于 %L 不应该是零"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "缺少参数“%s”，在调用“%s”时，位于 %L"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "%C处 EQUIVALENCE 中的数组引用不能是个数组段"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "%2$L处 %1$s 内建函数缺少实参"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’秩必须小于 %4$d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参不是一个有效的维数索引"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "数组元素数量的子参数到 IMAGE_INDEX 于 %L 应该是 %d (corank) 无法 %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "铸型参数到空值必要项于 %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有种别 %4$d"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM 参数而无需数组参数不允许用于 THIS_IMAGE intrinsic 于 %L"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "%L处按值传递的实参不具有数字类型"
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "%L处‘TRANSER’内建函数的‘MOLD’参数不能是 %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "%L处‘TRANSER’内建函数的‘MOLD’参数不能是 %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "%L处‘TRANSER’内建函数的‘MOLD’参数不能是 %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "%L处内建 TRANSFER 有部分未定义的结果：源尺寸 %ld < 结果尺寸 %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是标量或者具有与‘%4$s’一样的秩"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参必须有相同的外形。"
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’的大小太小(%4$i/%5$i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’的种别必须不能比默认种别(%4$d)宽"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "实参‘%s’(属于内建函数‘%s’，位于 %L)必须为 INTEGER 或 LOGICAL"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "假设的大小 polymorphic 对象或成分，像是该于 %C, 尚未被实现"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "%2$L处类型‘%1$s’达到了最大的扩展级别"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, fuzzy, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "%qs必须与%qs一起使用"
@@ -61353,1794 +61428,1794 @@ msgstr "%C处错误的 INTENT 规格"
 msgid "deferred type parameter at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "%2$C处的名字‘%1$s’已经在%3$L处被定义为泛型接口"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "%2$L处的过程‘%1$s’必须有属性才能与 C 互操作"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "%2$L 处类型“%1$s”是去到 BIND(C) 过程“%3$s”的参数，但不能与 C 互操作，因为派生类型“%4$s”不是与 C 可互操作的"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "%2$L处变量‘%1$s’是 BIND(C) 过程‘%3$s’的参数，但它不能与 C 互操作"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "%2$L处变量‘%1$s’是 BIND(C) 过程‘%3$s’的参数，但它不能与 C 互操作"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "%2$L处字符参数‘%1$s’长度必须为 1，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 ALLOCATABLE 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 POINTER 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 OPTIONAL 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 OPTIONAL 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "%2$L处假定外形数组‘%1$s’不能是%4$L处过程‘%3$s’的参数，因为该过程是 BIND(C)"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "%3$C处公共块‘%2$s’中的变量‘%1$s’必须被声明为与 C 可互操作的种别，因为公共块‘%4$s’是 BIND(C)"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "%3$L处数组构造函数中不同 CHARACTER 长度(%1$d/%2$d)"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER 表达式在%L处被截断(%d/%d)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "%L处的数组构造函数的 CHARACTER 元素必须有相同的长度(%d/%d)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "PARAMETER‘%s’在%C处不允许有初始值设定"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "%L处 PARAMETER 缺少初始值设定"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "%2$C处有初始值设定的变量‘%1$s’已经出现在一个 DATA 语句中"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "不能用初始值设定项来初始化多维数组"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "不能用初始值设定项来初始化多维数组"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C处的组件必须有 POINTER 属性"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "%C处结构的数组组件必须有显式或延迟的外形"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "%2$C处的组件‘%1$s’已于 %3$L处被声明"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "%C处结构的指针数组组件必须有延迟的外形"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "%C处结构的数组组件必须有显式的外形"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "带有省略号的形参列表无法与空形参名列表声明匹配"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, fuzzy, gcc-internal-format
 #| msgid "VALUE is not allowed inside of BLOCK at %C"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "VALUE 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qD不能有默认参数"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Invalid character %qc in variable name at %C"
 msgstr "%C处的名字中有非法字符"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008：%L处格式中的‘G0’"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 msgid "Cannot set pointee array spec."
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "创建旧风格表格"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "引用类型的非法值初始化"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C处需要一个初始化表达式"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C处对变量的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "不允许在%C处初始化可分配的组件"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of allocatable component at %C is not allowed"
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "不允许在%C处初始化可分配的组件"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "%3$L处‘%2$s’的指针组件‘%1$s’类型尚未声明"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%3$C处旧式的类型声明 %1$s*%2$d 不受支持"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%3$C处的 %1$s*%2$d 类型声明不符合标准"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "%C处缺少右括号"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C处需要初始化表达式"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C处需要标量初始化表达式"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "种别 %1$d 不为类型%3$C处 %2$s 所支持"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C 种别类型参数对应类型 %s 但%L处的类型却是 %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C处缺少右括号或逗号"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "种别 %d 在%C处不为 CHARACTER 所支持"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "%C 需要一个无名接口"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "%L实体的种别类型参数与类型限定中的种别类型参数不同"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%>的第一个形参不能有默认参数"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%2$L处数组‘%1$s’是个变量，不能被归约为常量表达式"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "扩展：%C处的 BYTE 类型"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C处使用到的 BYTE 类型在目标机上不可用"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C处 TYPE 中的组件必须先于 CONTAINS"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "%C处类型指定无效"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid type-spec at %C"
 msgid "Malformed type-spec at %C"
 msgstr "%C处类型指定无效"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "扩展：‘%s’重初始化于 %L"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "未定义 C++ 基类"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "类型名称‘%s’于 %C 冲突与在之前声明的实体于 %L, 该项有同名"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C处 IMPLICIT NONE 语句重复"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C处 IMPLICIT 缺少字符范围"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句中的字母必须按序排列"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "不能从%2$C处主机作用域单元 IMPORT‘%1$s’- 不存在。"
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "‘%s’已经从%C处主机作用域单元导入。"
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%C处的 IMPORT 语句语法错误"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重复的 %s 属性，位于 %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%2$L处的 %1$s 属性不允许出现在模块规格说明以外"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "%C处的 PROTECTED 仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "%L处指定了重复的 VALUE 属性"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "%C处为单个 NAME= 指定了多个标识符"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "%2$L处隐式声明的 BIND(C) 函数‘%1$s’不能与 C 互操作"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’可能不是 C 互操作种别，即使公共块‘%4$s’是 BIND(C)"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "%2$L处的类型声明‘%1$s’不是与 C 可互操作的，但它是个 BIND(C)"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "%2$L处的变量‘%1$s’无法与 C 互操作但被声明为 BIND(C)"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’不能被声明为 BIND(C)，因为它不是全局的"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个数组"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个字符串"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "%2$L处符号‘%1$s’被标记为 PRIVATE 但是已经给定绑定标号‘%3$s’"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句需要实体或公共块名"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句缺少实体或公共块名"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "%s:%d: 缺少新的符号名称"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C处的派生类型以前尚未被定义，因此不能出现在派生类型定义中"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "%C处的 MODULE PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必须不出现两者于 %C"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "缺少前导左括号"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%L 不带 * 虚参的替代返回"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "缺少前导左括号"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C处数组声明需要另外一维"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C处形参列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "重复的汇编操作数名%qs"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符号‘%s’在%C处的形参列表中重复出现"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C处 RESULT 变量不能与函数重名"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008：%L处的 BIND(C)属性对于内部过程不可以指定"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "%C处的 BIND(C) 属性要求一个具有 BIND(C)的接口"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "%C处的哑过程不能有带有 NAME 的 BIND(C) 属性"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "%C处需要一个类型限定的过程或过程指针组件"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C处过程指针组件语法错误"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C处的 PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "函数定义在%C处需要形参列表"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%L处的 BIND(C) 属性只能用于变量或公共块"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C处的 ENTRY 语句不能出现在 PROGRAM 中"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C处的 ENTRY 语句不能出现在 DERIVED TYPE 块中"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C处的 ENTRY 语句不能出现在 IF-THEN 块中"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C处的 ENTRY 语句不能出现在 DO 块中"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C处的 ENTRY 语句不能出现在 FORALL 块中"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C处的 ENTRY 语句不能出现在 WHERE 块中"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C处的 ENTRY 语句不能出现在嵌套的子程序中"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "%C 处 BIND(C) 前缺少要求的括号"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate return cannot appear in operator interface at %L"
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "替代返回不能出现在%L处的运算符接口中"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%C处的名字中有非法字符"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C绑定标号的 NAME= 限定符语法错误"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C处绑定标号缺少右括号"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "对于哑过程 %s，%C 处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "%C 处的 ABSTRACT INTERFACE 的 BIND(C)上不允许有 NAME"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "%s 语句在%C处不能跟随 %s 语句在%L处"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要块名‘%s’在‘%s’表达式中，于 %C"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "%2$C处需要 %1$s 语句"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "%2$L处在初始化后为 %1$s 指定了维数"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L处数组规格必须延迟"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate POINTER attribute at %C"
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "%C处 POINTER 属性重复"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C处变量列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在%C处需要变量名"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C处的 Cray 指针精度为 %d；内存地址需要 %d 字节"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 msgid "Cannot set Cray pointee array spec."
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在%C处需要“)”"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "%C处的 Cray 指针声明需要 -fcray-pointer 标记"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%2$C处的 %1$s 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "%2$C处的 .%1$s. 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PRIVATE 语句仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PUBLIC 语句只不允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C处的 PARAMETER 语句需要变量名"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 语句中需要 = 符号"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 语句中需要表达式"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "%C处初始化已经初始化的变量"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C处 PARAMETER 语句中有非预期的字符"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C处覆盖 SAVE 语句跟随以前的 SAVE 语句"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易变的用于 coarray 变量‘%s’于 %C, 该项是 use-/ host-associated"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C处的 MODULE PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "%L处内建过程不能是 MODULE PROCEDURE"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 BIND(C)"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 SEQUENCE 类型"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PRIVATE"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PUBLIC"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "%q+D的抽象类型无效"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, fuzzy, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定义中需要 ::"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "%C处的 GENERIC 必须是在派生类型 CONTAINS 内"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "%2$C处的派生类型名“%1$s”已经有一个基本类型 %3$s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "%2$C处的派生类型名“%1$s”已经有一个基本类型 %3$s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C处 Cray 指针不能指向假定外形数组"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C处：枚举量超过 C 整数类型"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L没有用整数表达式初始化"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C 前需要 ENUM 定义语句"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C处 ENUMERATOR 定义中语法错误"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "%C处重复访问限定符"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "捆绑属性已经指定传递，%C处 NOPASS 非法"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "捆绑属性已经指定传递， %C处 PASS 非法"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%C处 POINTER 属性重复"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C处 NON_OVERRIDABLE 重复"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "%C需要访问限定符"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE 和 DEFERRED 不能同时出现在%C处"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "%C处的过程指针组件需要 POINTER 属性"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%C 需要一个无名接口"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "%C处的 PROCEDURE(接口) 需要声明为 DEFERRED"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%C处与显式目标捆绑的 PROCEDURE 中需要‘::’"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "%2$C处包含 DEFERRED 绑定的类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "在 %3$C 处对于派生类型“%2$s”已经有一个非普通的过程用限定名“%1$s”"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "%C处的 GENERIC 必须是在派生类型 CONTAINS 内"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C处需要泛型名或运算符描述子"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C处的 USE 语句缺少泛型规格"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "%3$C处派生类型‘%2$s’已经有一个绑定名为‘%1$s’的非泛型过程"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "%C处的绑定必须有与已经定义的绑定‘%s’相同的访问权限"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "%C处需要特定的绑定名"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%3$C处‘%1$s’已经定义为泛型的‘%2$s’特定的限定"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "%C处的 FINAL 声明必须在一个派生类型的 CONTAINS 节内"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "%C处带有 FINAL 的派生类型声明必须在 MODULE 的规格说明部分内"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "%C处的 FINAL 为空"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "未知的 C++ 编码名称"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中有未知的属性"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中的语法错误"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "%C处 FORALL 游标语法错误"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "%C处 FORALL 游标语法错误"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "%C处 FORALL 游标语法错误"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -63267,12 +63342,12 @@ msgstr "%2$L处第 %1$d 维下标越界"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND part_ref at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
@@ -63347,7 +63422,7 @@ msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
@@ -63615,7 +63690,7 @@ msgstr "%L处过程指针赋值中接口不匹配：%s"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
@@ -63674,167 +63749,167 @@ msgstr "Fortran 2008：%L处格式中的‘G0’"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L处指针赋值的右手边带有向量下标"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003：%L处初始化表达式中非整数指数"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 运算式在中变量定义语境 (%s) 于 %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指标关联语境 (%s) 于 %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associate-name‘%s’无法出现在中变量定义语境 (%s) 于 %L 因为它的目标于 %L 无法，还是"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "‘%s’于 %L 关联的到运算式无法已用于变量定义语境 (%s)"
@@ -63863,7 +63938,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -64056,12 +64131,12 @@ msgstr "%L处定义赋值的第一个参数必须是 INTENT(OUT) 或 INTENT(INOU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -64131,589 +64206,589 @@ msgstr "有歧义的接口‘%s’和‘%s’在 %s 中，位于 %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "尽管没有被引用，%2$L处的‘%1$s’的接口有歧义"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "%L处内建过程不能是 MODULE PROCEDURE"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "INTENT(%s) %L处的实参可能干涉%L处的实参。"
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "%2$L处实参‘%1$s’类型不匹配；将 %3$s 传递给 %4$s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参类型必须相同"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "%2$L处实参‘%1$s’秩不匹配(%3$d 和 %4$d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "实际参数到 non-INTENT (INOUT) 虚设‘%s’于 %L, 该项是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虚参数‘%s’必须是指标或 assumed-shape 数组而无需 CONTIGUOUS 属性 - 作为实际参数于 %L 不是仅需 contiguous 和两者是异步或易变的"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "传递 coarray 于 %L 到 allocatable、noncoarray，含义 (出) 虚参数‘%s’"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "传递 coarray 于 %L 到 allocatable，noncoarray 虚参数‘%s’，该项无效如果配额状态被已修改"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "%2$L 处假定外形的数组的元素传递给哑参数“%1$s”"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "%2$L处假定外形的数组的元素传递给虚参‘%1$s’"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003：%2$L处标量 CHARACTER 实参带有数组虚参‘%1$s’"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "%2$L处关键字参数‘%1$s’已经与另一个实参相关联"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "%L处调用过程时实参比形参多"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing alternate return spec in subroutine call at %L"
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected alternate return spec in subroutine call at %L"
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "%L处子进程调用中的替代返回限定与预期不符"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指标于 %L 到 non-pointer 虚设‘%s’"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "%4$L处实参和指针或可分配虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "%4$L处实参和假定外形虚参‘%3$s’之间字符长度失配(%1$ld/%2$ld)"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "实际参数于 %L 到 allocatable 或指标虚参数‘%s’必须有已推迟长度类型参数如果和只有如果虚设有一个"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参的字符长度短于虚参‘%1$s’(%2$lu/%3$lu)"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "%4$L处实参包含的元素对于虚参‘%1$s’(%2$lu/%3$lu)而言太少"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "‘%s’的实参在%L处必须不是一个假定大小的数组"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 实际参数于 %L 到指标虚设‘%s’"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 异步或易变的实际参数于 %L 需求该虚设‘%s’有 neither 异步 nor 易变的"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "%L处的实参必须是可定义的，因为虚参‘%s’是 INTENT = OUT/INOUT"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "%L处带有向量下标的数组节实际参数与虚参‘%s’的 INTENT(OUT)、INTENT(INOUT) 或 VOLATILE 属性不兼容"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处假定外形的实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处数组节实参由于 VOLATILE 属性而与非假定外形虚参‘%s’不兼容"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "%L处指针数组的实参由于 VOLATILE 属性要求一个假定外形或指针数组虚参‘%s’"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "%C处的实参数列中缺少关键字名"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "%5$L处同样的实际参数与 INTENT(%1$s) 实参‘%2$s’和 INTENT(%3$s)实参‘%4$s’相关联"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "%L处的过程参数对于 PURE 过程是局部的，但是有 POINTER 属性"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "%L处的过程参数对于 PURE 过程是局部的而被传递给一个 INTENT(%s) 参数"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "%2$L处调用的过程‘%1$s’不是显式声明的"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "调用过程‘%s’带隐式接口，位于 %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "%2$L处的自动字符长度函数‘%1$s’必须有一个显式的接口"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "铸型参数到空值必要项于 %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "%2$L处过程‘%1$s’的关键字参数要求显式的接口"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "%2$L调用过程指针组件‘%1$s’时有隐式接口"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "%2$L处过程指针组件‘%1$s’的关键字实参需要显式接口"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "铸型=必要项在中空值() 参数于 %L:模棱两可介于特定的函数 %s 和 %s"
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "在类%qs中找不到可溢出的寄存器"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "%2$C处实体‘%1$s’已经出现在接口中"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "不能覆盖%2$L处的 GENERIC‘%1$s’"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "%2$L处的‘%1$s’覆盖了一个绑定声明为 NON_OVERRIDABLE 的过程"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "%2$L处的‘%1$s’不能被 DEFERRED，因为它覆盖了一个非 DEFERRED 绑定"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PURE 过程因此必须也是 PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "%2$L处的‘%1$s’覆盖了一个 ELEMENTAL 过程因此也必须是 ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "%2$L处的‘%1$s’覆盖了一个非 ELEMENTAL 过程因此必须也不是 ELEMENTAL"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 SUBROUTINE 因此也必须是 SUBROUTINE"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "%2$L处的‘%1$s’覆盖了一个 PUBLIC 过程因此必须不是 PRIVATE"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "%3$L处‘%2$s’的虚参‘%1$s’应该命名为‘%4$s’以匹配被覆盖过程的相应参数"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "哑过程‘%s’接口在%L处不匹配：%s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "%2$L处的‘%1$s’必须有与被覆盖的过程相同数量的形式参数"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个 NOPASS 绑定因此必须也是 NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "%2$L处的‘%1$s’覆盖了一个具有 PASS 的绑定因此也必须是 PASS"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "%2$L处的‘%1$s’的传递对象虚参必须与被覆盖的过程传递对象的虚参位置相同"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s 标记在%L处必须具有类型 %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "%3$L处有字符值的 %1$s‘%2$s’不能是假定长度的"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "过程‘%s’(在 %s 中，位于 %L) 既不是函数也不是子进程"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
@@ -64818,74 +64893,74 @@ msgstr "%L 不允许有 ALTERNATIVE RETURN"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "%2$L处实参‘%1$s’类型不匹配；将 %3$s 传递给 %4$s"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "给予函数的实参太多"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, fuzzy, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "%L处只有内建运算符才能用于表达式中"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003：作为初始表达式的基本函数在%L处使用了非整数或非字符的参数"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "在%2$L处调用内建‘%1$s’的子例程不是 PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "在%2$L处调用内建‘%1$s’的子例程不是 PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "从 %s 转换到 %s，位于 %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "从 %s 转换到 %s，位于 %L"
@@ -64893,23 +64968,23 @@ msgstr "从 %s 转换到 %s，位于 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "不能将 %s 转换为 %s，于 %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "不能将 %s 转换为 %s，于 %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "%2$L处声明的‘%1$s’可能遮盖同名内建函数。为了调用内建函数，可能需要显式的 INTRINSIC 声明。"
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "%2$L处声明的‘%1$s’也是一个内建函数的名字。它只能通过一个显式接口或声明 EXTERNAL 来调用。"
@@ -65274,13 +65349,13 @@ msgstr "%s 属性与 %s 属性在%L处冲突"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "%C处的 ASYNCHRONOUS= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "%C处的 BLANK= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %L not allowed in Fortran 95"
@@ -65292,7 +65367,7 @@ msgstr "%C处的 DECIMAL= 不允许用在 Fortran 95 中"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "%C处的 ENCODING= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %L not allowed in Fortran 95"
@@ -65342,7 +65417,7 @@ msgstr "%L处的 CLOSE 语句需要一个 UNIT 数"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "%L处 CLOSE 语句中的 UNIT 数必须是非负的"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s 语句不允许出现在%C处的 PURE 程序中"
@@ -65439,7 +65514,7 @@ msgstr "名称表列‘%s’在中读取叙述于 %L 含有符号‘%s’该项
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -65508,7 +65583,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "%2$C处需要 %1$s 语句"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 语句在%C处语法错误"
@@ -65524,85 +65599,85 @@ msgstr "不允许按位置传递%L处的内部过程"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "DATA 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 PAD= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 DELIM= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C处的 PRINT 名字列表是一个扩展"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "%C处的 END 标记不允许出现在输出语句中"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C处 I/O 列表中需要逗号"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "%C处的 INQUIRE 语句中 IOLENGTH 标记无效"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "%L处的 INQUIRE 语句不能包含 FILE 和 UNIT 限定符"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L处的 INQUIRE 语句需要 FILE 或 UNIT 限定符"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "%L处的语句中 UNIT 数必须为非负的数"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "%L处的 INQUIRE 语句需要带有 ID= 指定的 PENDING="
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "%C处的 PURE 过程中不允许 WAIT 语句"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "%C处的 PURE 过程中不允许 WAIT 语句"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -65856,512 +65931,512 @@ msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "%2$L处派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "%C处类型指定无效"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "%C处 FORALL 游标语法错误"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "DATA 叙述不允许出现在 %C 处 %s 叙述中的名称“%s”不是个回圈名称"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "DATA 叙述不允许出现在 %C 处 %s 叙述中的名称“%s”不是个回圈名称"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s 语句在%C处不在循环内"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "%s 语句在%C处不在循环‘%s’内"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s 语句在%C处不在循环‘%s’内"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "%C处的 EXIT 语句终结了 !$OMP DO 循环"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "asm 语句中需要左值"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "%s 语句不允许出现在%C处的 PURE 程序中"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "影像控制叙述停止于 %C 在中重要区块"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "%L处的 UNIT 规格必须是 INTEGER 表达式或一个 CHARACTER 变量"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "停止编码于 %L 必须是缺省字符 KIND=%d"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr " 暂停   "
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "%s 语句不允许出现在%C处的 PURE 程序中"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant STAT tag found at %L "
 msgid "Redundant STAT tag found at %L"
 msgstr "%L处有多余的 STAT 标记"
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant ERRMSG tag found at %L "
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "%L有多余的 ERRMSG 标记"
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant STAT tag found at %L "
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "%L处有多余的 STAT 标记"
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "未定义 C++ 基类"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "%s 语句不允许出现在%C处的 PURE 程序中"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "%L有多余的 ERRMSG 标记"
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "无法解锁内存。\n"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "影像控制叙述同步于 %C 在中重要区块"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "无法赋值给%C处的有名常量"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "%C 处赋值 GOTO 语句"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "%C处 GOTO 中的语句标号列表不能为空"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "ISO C++ 不允许计算转移"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "%C处类型指定无效"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Fortran 2003：%L处 ALLOCATE 中有 typespec"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "%2$C处有非预期的 %1$s 语句"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "%C处 PURE 过程中分配对象错误"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal allocate-object at %C for a PURE procedure"
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "%C处 PURE 过程中的分配对象非法"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "配置的 coarray 于 %C 在中做共时区块"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "配置的 coarray 于 %C 在中重要区块"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "%C处的分配对象不是一个非过程指针或可分配的变量"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "%L处实体类型与 typepec 类型不兼容"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "%L实体的种别类型参数与类型限定中的种别类型参数不同"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "%C处可分配标量的外形规格说明"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "%L有多余的 ERRMSG 标记"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant SOURCE tag found at %L "
 msgid "Redundant SOURCE tag found at %L"
 msgstr "%L有多余的 SOURCE 标记"
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "%L处的 SOURCE 标记在分配列表中只需要一个单独的实体"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "%s 标记在%L处必须是标量"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "%L处有多余的 STAT 标记"
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object 于 %L 与已推迟类型参数需求还是 type-spec 或来源标签或铸型标签"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object 于 %L 与已推迟类型参数需求还是 type-spec 或来源标签或铸型标签"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "%C处 PURE 过程中的分配对象非法"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "取消配置的 coarray 于 %C 在中做共时区块"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "取消配置的 coarray 于 %C 在中重要区块"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "%C处的分配对象不是一个非过程指针或可分配的变量"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "影像控制叙述返回于 %C 在中重要区块"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "%C处的替代 RETURN 语句只允许出现在 SUBROUTINE 中"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "%C处 PROGRAM 语句格式无效"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "%C处需要组件引用"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "%C处在 CALL 以后有垃圾字符"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "%C处需要一个类型限定的过程或过程指针组件"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "%C处公共块名语法错误"
@@ -66369,224 +66444,224 @@ msgstr "%C处公共块名语法错误"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "%4$C处公共块‘%3$s’中的%2$L处的变量‘%1$s’必须声明为有与 C 可互操作的种别，因为公共块‘%5$s’是 bind(c)"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "%3$C处的公共块‘%2$s’中的变量‘%1$s’不能是 bind(c)，因为它不是全局的"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "符号‘%s’在%C处已经在一个 COMMON 块中"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, fuzzy, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "%2$C处已初始化的符号‘%1$s’仅可以是在 BLOCK DATA 中的 COMMON"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, fuzzy, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "%2$C处 COMMON 中符号‘%1$s’的数组规格必须是显式的"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "%2$C处 COMMON 中的符号‘%1$s’不能是个 POINTER 数组"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "%3$C处 COMMON 块‘%2$s’的中符号‘%1$s’间接地等价于另一个 COMMON 块‘%4$s’"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "%2$C处的组名列表‘%1$s’已经有一个基本类型 %3$s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "%2$C处组名列表‘%1$s’已经为 USE 相关因此不能被重新指定。"
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "%3$C处名字列表‘%2$s’中的假定大小数组‘%1$s’不被允许"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "派生类型组件%C不是允许的 EQUIVALENCE 成员"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "%C处 EQUIVALENCE 中的数组引用不能是个数组段"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "%C处的 EQUIVALENCE 需要两个或更多的对象"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "%3$C处的 EQUIVALENCE 试图间接地重叠 COMMON 块 %1$s 和 %2$s"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "%C处 EQUIVALENCE 中需要逗号"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "%L处的语句函数是递归的"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be scalar"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "%C处 CASE 中需要初始化表达式"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "%2$C处需要 SELECT 构造的块名‘%1$s’"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "%C处的 ENTRY 语句不能出现在嵌套的子程序中"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "%C处 SELECT TYPE 中的选择子不是一个有名变量；请使用 associate-name=>"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C处 CASE 规格语法错误"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C处 TYPE IS 规格语法错误"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C处 CLASS IS 规格语法错误"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "%C处 CASE 规格语法错误"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C处的 ELSEWHERE 语句不在 WHERE 块中"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "%2$C处的标号‘%1$s’不匹配 WHERE 标号‘%3$s’"
@@ -66627,12 +66702,12 @@ msgstr "错误的运算符"
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, fuzzy, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
 msgstr "错误的条件码"
@@ -67321,8 +67396,8 @@ msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
@@ -68742,177 +68817,177 @@ msgstr "%C处变量列表中有非预期的垃圾字符"
 msgid "Expected structure component name at %C"
 msgstr "%C处需要结构组件名"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forming reference to reference type %qT"
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "生成指向引用类型%qT的引用"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "%C处过程指针组件语法错误"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr()︰表达式不是一个变量"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_variable_attr(): Expression isn't a variable"
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr "gfc_variable_attr()︰表达式不是一个变量"
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_variable_attr(): Bad array reference"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "gfc_variable_attr()︰不当的数组引用"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Fortran 2003：%C处的结构构造函数丢失可选的参数"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "%2$C处结构构造函数中没有组件‘%1$s’的初始值设定！"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "%2$C处结构构造函数中没有组件‘%1$s’的初始值设定！"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "%2$C处无法构建 ABSTRACT 类型‘%1$s’"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "Fortran 2003：%C处的结构构造函数有有名的参数"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr "%2$C处名为 %1$s 的组件之后的组件初始值设定没有名字！"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "%C处结构构造函数中组件太多！"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "%2$C处结构构造函数中组件‘%1$s’被初始化两次！"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "%C处结构构造函数中组件太多！"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, fuzzy, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "%2$L处的组件‘%1$s’已被基类派生类型构造函数所设置"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "%2$C处的‘%1$s’是一个递归函数的名字同时也是返回值变量。请为直接递归使用一个显式的 RESULT 变量(12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "%C处的符号不适用于表达式"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
 msgstr "语句函数‘%s’在%C处缺少参数列表"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
 msgstr "函数定义在%C处需要形参列表"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "%qs缺少参数"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
 msgstr "%C处的实参数列中缺少关键字名"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "名字‘%s’在%C处不能用作已定义的运算符"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "%C处有名常量出现在 EQUIVALENCE 中"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "为 auto 变量%2$qE指定了%1$qs"
@@ -69247,495 +69322,495 @@ msgstr "‘%s’(位于 %L)有歧义"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "GENERIC 过程‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "%2$L处为内建函数‘%1$s’指定的类型被忽略"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "%2$L处的内建子例程‘%1$s’不应该有类型限定符"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, fuzzy, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "%2$L 处‘%1$s’声明的 INTRINSIC 不存在"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, fuzzy, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "在%2$L处由内建函数‘%1$s’声明的 INTRINSIC 在当前的标准设置中是不可用的，但在 %3$s 下可用。使用一个适当的 -std=* 选项或启用 -fall-intrinsics 以便使用它。"
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, fuzzy, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "内部过程‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "内建函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "内部过程‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL 非 INTRINSIC 过程‘%s’不允许在%L处作为实际参数"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "%2$L处对‘%1$s’的引用找不到特定的 INTRINSIC 过程"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "%L处按值传递的实参不具有数字类型"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "不允许按位置传递%L处的内部过程"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL 非 INTRINSIC 过程‘%s’不允许在%L处作为实际参数"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Coindexed 实际参数于 %L 与 ultimate 指标成分"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "%2$L处的‘%1$s’是个数组且是可选的；如果它缺失, 它不能是一个 ELEMENTAL 过程的实际参数，除非有一个具有相同秩的非可选的参数(12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "%1$L处 ELEMENTAL 子程序‘%4$s’的 INTENT(%2$s) 哑‘%3$s’的实际参数是一个标量，但是另一个实际参数是一个数组"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "函数不能返回函数"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "%2$L处的泛型‘%1$s’没有指定的函数"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "%2$L处泛型函数‘%1$s’与特定的内建接口不一致"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "不能解析 %2$L处的函数‘%1$s’"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "%2$L处对非 PURE 函数‘%1$s’的引用出现在 FORALL %3$s 中"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "%2$L处的 ABSTRACT INTERFACE‘%1$s’不能被引用"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, fuzzy, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "函数‘%s’被声明为 CHARACTER(*)从而不能被使用在%L处，因为它不是一个虚参"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "不良的 C++ 方法函数类型"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, fuzzy, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "%2$L处用户定义的非 ELEMENTAL 函数‘%1$s’不允许出现在 WORKSHARE 构造中"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "%2$L处 ENTRY‘%1$s’不能递归调用，因为函数‘%3$s’并非 RECURSIVE"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%2$L处的函数‘%1$s’不能被递归调用，因为它并非 RECURSIVE"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "%2$L处 FORALL 块内对‘%1$s’子例程的调用不是 PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "%2$L处 FORALL 块内对‘%1$s’子例程的调用不是 PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "%L处子进程调用缺少替代返回限定"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "泛型‘%s’在%L处没有特定的子进程"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "%2$L处泛型子进程‘%1$s’与一个内建子进程接口不一致"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "不能解决%2$L处的指定子例程‘%1$s’"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "%2$L处的‘%1$s’的类型与%3$L处 CALL 的类型不一致"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "%2$L处 ENTRY‘%1$s’不能被递归调用，因为子进程‘%3$s’并非 RECURSIVE"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "%2$L处 SUBROUTINE‘%1$s’不能递归调用，因为它并非 RECURSIVE"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "不良的 C++ 方法函数类型"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L和%L处的操作数外形不相容"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, fuzzy, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "%L处按值传递的实参不能是数组或数组段"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "%L处未指定假定大小数组段的最右端上限"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L处数组索引必须是标量"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L处数组索引必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, fuzzy, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L处的子字符串起始索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L处的子字符串起始索引必须是标量"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L处的子字符串起始索引小于 1"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L处的子字符串终止索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L处的子字符串终止索引必须是标量"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L处的子字符串终止索引超过了字符串长度"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "%L处子串结束索引太大"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 POINTER 属性"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 ALLOCATABLE 属性"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L处不能指定两个或以上秩不为零的部分引用"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的数组在 %L 处必须是哑参数"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -69744,12 +69819,12 @@ msgstr "%L处假定外形的数组必须是一个虚参"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -69758,284 +69833,284 @@ msgstr "%L处假定外形的数组必须是一个虚参"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "“%s”是必须是一个模块过程或有显式接口的外部过程于 %L 处"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "用在一个规格说明表达式中的变量‘%s’在%L处的引用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "变量‘%s’在%L处的使用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "%2$L处非多态的传递对象哑元实参‘%1$s’"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 对象与 polymorphic allocatable subcomponent 于 %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "%C处类型指定无效"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 于 %L 与 type-spec 需求相同 character-length 参数作为在中声明"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -70044,285 +70119,285 @@ msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名字‘%s’在%C处不能用作已定义的运算符"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "数据转移组件于 %L 无法 polymorphic 除非它被处理由定义的输入/输出进程"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往叙述于 %L 树叶重要建构用于标贴于 %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -70330,192 +70405,193 @@ msgstr "%s 语句在%C处离开 OpenMP 结构块"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "变量必须不是 polymorphic 在中 intrinsic 指派于 %L - 检查该有匹配特定的副常式用于‘=’运算符"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:11803
-#, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#: fortran/resolve.c:11812
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -70523,965 +70599,965 @@ msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，于 %s:%d"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "引用%qs有歧义：出现在接口%qs和接口%qs中"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L处 ICHAR 的参数长度必须为 1"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字符成分‘%s’的‘%s’于 %L 与已推迟长度必须是指标或 ALLOCATABLE"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 于 %L 在中串行或绑定©类型 %s"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "作为延伸类型‘%s’于 %L 有 coarray 成分，亲代类型‘%s’应该也有一个"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -72178,157 +72254,157 @@ msgstr "%2$L处的‘%1$s’有在其 INTERFACE 体外指定的属性"
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "符号‘%s’于 %L 冲突与符号从模块‘%s’，use-associated 于 %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "%2$L处过程‘%1$s’不能有基本类型 %3$s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%2$L处的符号‘%1$s’不能有类型"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "%2$C处的组件‘%1$s’已在%3$L处的父类中"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "%2$C处的派生类型‘%1$s’在定义前使用"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "组件‘%s’在%C处是‘%s’的 PRIVATE 组件"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重复的语句标号 %d 出现在 %L 和%L处"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%2$C处的标号 %1$d 已作为分支目标引用"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%2$C处的标号 %1$d 已作为格式标号引用"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%2$C处的标号 %1$d 先前用作 FORMAT 标号"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%2$C处的标号 %1$d 先前用作分支目标"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "%C处的语句标号为零"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "%2$C处的名字‘%1$s’是从模块‘%4$s’对‘%3$s’有歧义的引用"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "%2$L处声明的派生类型‘%1$s’必须使用 BIND 属性方可与 C 互操作"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生类型‘%s’与绑定©属性于 %L 是空的，而也许会是不可访问由 C companion 处理器"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 POINTER 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L 处的过程指针组件‘%1$s’不能是%4$L处 BIND(C) 派生类型‘%3$s’的成员"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 ALLOCATABLE 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "%3$L处的派生类型‘%2$s’的组件‘%1$s’不能与 C 互操作，即使派生类型‘%4$s’是 BIND(C)"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "%3$L处派生类型‘%2$s’中的组件‘%1$s’不能与 C 互操作"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "%2$L处派生类型‘%1$s’不能有 SEQUENCE 属性，因为它是 BIND(C)"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "%2$L处符号‘%1$s’在指定类型之前被使用"
@@ -72366,85 +72442,85 @@ msgstr "%L 处  EQUIVALENCE 中不等的初始值设定重叠"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "在%L处建立临时数组"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "走过错误的表达式类型(%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, fuzzy, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "%2$L处的 COMMON 块‘%1$s’应该有同样的大小"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
 msgstr "累加数不是一个整常量"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "%L处数组引用错误"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "%L处的非法引用类型作为 EQUIVALENCE 对象"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "涉及%2$L处的‘%1$s’和%4$L处的‘%3$s’的等价规则不一致"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, fuzzy, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "%2$L处声明的变量‘%1$s’的等价设置违反了对齐需求"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, fuzzy, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "%3$L处‘%1$s’的等价设置不匹配 COMMON ‘%2$s’的次序"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, fuzzy, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "%3$L处‘%1$s’的等价设置造成了 COMMON‘%2$s’的一个无效的扩展"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "%4$L处 COMMON‘%3$s’中‘%2$s’之前需要填充 %1$d 字节; 重排序元素或使用 -fno-align-commons"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "%3$L处 COMMON 中‘%2$s’之前需要填充 %1$d 字节; 重排序元素或使用 -fno-align-commons"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON '%s' at %L does not exist"
 msgid "COMMON %qs at %L does not exist"
 msgstr "%2$L处的 COMMON‘%1$s’并不存在"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, fuzzy, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "%2$L处的 COMMON‘%1$s’需要 %3$d 字节填充在开始处；重排序元素或使用 -fno-align-commons"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, fuzzy, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "%L处的 COMMON 需要 %d 字节填充在开始处；重排序元素或使用 -fno-align-commons"
@@ -72464,72 +72540,72 @@ msgstr "%L处非常量初始化表达式"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "内建函数变量不是一个过程"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "%2$L处函数‘%1$s’的返回值没有设置"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, fuzzy, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
 msgstr "模块变量 %s 的后端声明已存在"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "%2$L处的虚参‘%1$s’被声明为 INTENT(OUT)，但没有设置"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "%2$L处的虚参‘%1$s’被声明为 INTENT(OUT)，但没有设置"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "%2$L处声明了未使用的变量‘%1$s’"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "%3$L处声明的的函数‘%2$s’的返回值‘%1$s’没有设置"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -72544,27 +72620,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "未知的内建操作"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "%L处参数列表函数未知"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -72600,24 +72676,24 @@ msgstr "Fortran 2003：%L处内部文件有名字列表"
 msgid "Bad IO basetype (%d)"
 msgstr "错误的 IO 基类型(%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "implicit mapping of assumed size array %qD"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 #| msgid "optional argument"
 msgid "optional class parameter"
 msgstr "可选参数"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, fuzzy, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare()：错误的语句代码"
@@ -72727,85 +72803,85 @@ msgstr "参数不匹配"
 msgid "unable to open file"
 msgstr "无法开启基本文件：%s"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "字节码流：符号节结尾有垃圾字符"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "不能解析 16 进制数"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "符号解析文件中有非预期的文件名 %s。需要 %s"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "不能解析文件偏移量"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "非预期的偏移"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "符号解析文件"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "符号解析文件"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, fuzzy, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "分辨率子识别号 "
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, fuzzy, gcc-internal-format
 #| msgid "bytecode stream generated with LTO version %d.%d instead of the expected %d.%d"
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "字节码流是由 LTO 版本 %d.%d 生成，而非预期的 %d.%d"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "cannot read LTO decls from %s"
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "无法从 “%s” 中读取 LTO decls"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "无法打开 %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "无法映射 %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "无法读取 %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "无法打开符号解析文件：%s"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "错误在的期间合并的转译单位"
@@ -73948,7 +74024,7 @@ msgstr "%qs后缺少宏名"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs后缺少文件名"
@@ -74154,17 +74230,17 @@ msgstr "未知的 TLS 模型%qs"
 msgid "unknown TLS model %qs"
 msgstr "未知的 TLS 模型 %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "不可识别的寄存名%qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在%qs的初始化附近)"
@@ -77119,6 +77195,9 @@ msgstr "(在%qs的初始化附近)"
 #~ msgid "%<num_tasks%> expression must be integral"
 #~ msgstr "num_threads 表达式必须是整型的"
 
+#~ msgid "%qE attribute can only be applied to Java class definitions"
+#~ msgstr "只能为 Java 类定义应用%qE属性"
+
 #~ msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 #~ msgstr "%qE已过时：g++ 的虚函数表现在默认与 COM 兼容"
 
diff --git a/gcc/po/zh_TW.po b/gcc/po/zh_TW.po
index a6e94cd8097..69cd0bee8b6 100644
--- a/gcc/po/zh_TW.po
+++ b/gcc/po/zh_TW.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2020-04-27 21:19+0000\n"
+"POT-Creation-Date: 2020-07-20 18:08+0000\n"
 "PO-Revision-Date: 2020-05-08 22:14+0800\n"
 "Last-Translator: Yi-Jyun Pan <pan93412@gmail.com>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@lists.linux.org.tw>\n"
@@ -1908,86 +1908,86 @@ msgstr "strfmon 格式的長度修飾符"
 msgid "<command-line>"
 msgstr "<命令列>"
 
-#: config/aarch64/aarch64.c:9890
+#: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "「%c」代碼不支援的運算元"
 
-#: config/aarch64/aarch64.c:9899 config/aarch64/aarch64.c:9912
-#: config/aarch64/aarch64.c:9924 config/aarch64/aarch64.c:9935
-#: config/aarch64/aarch64.c:9951 config/aarch64/aarch64.c:9965
-#: config/aarch64/aarch64.c:9985 config/aarch64/aarch64.c:10059
-#: config/aarch64/aarch64.c:10070 config/aarch64/aarch64.c:10084
-#: config/aarch64/aarch64.c:10306 config/aarch64/aarch64.c:10324
+#: config/aarch64/aarch64.c:10004 config/aarch64/aarch64.c:10017
+#: config/aarch64/aarch64.c:10029 config/aarch64/aarch64.c:10040
+#: config/aarch64/aarch64.c:10056 config/aarch64/aarch64.c:10070
+#: config/aarch64/aarch64.c:10090 config/aarch64/aarch64.c:10164
+#: config/aarch64/aarch64.c:10175 config/aarch64/aarch64.c:10189
+#: config/aarch64/aarch64.c:10411 config/aarch64/aarch64.c:10429
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "「%%%c」的運算元無效"
 
-#: config/aarch64/aarch64.c:10003 config/aarch64/aarch64.c:10014
-#: config/aarch64/aarch64.c:10166 config/aarch64/aarch64.c:10177
+#: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
+#: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "無效指令："
 
-#: config/aarch64/aarch64.c:10026 config/aarch64/aarch64.c:10038
+#: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10052
+#: config/aarch64/aarch64.c:10157
 #, c-format
 msgid "incompatible register operand for '%%%c'"
 msgstr "「%%%c」的寄存器運算元不相容"
 
-#: config/aarch64/aarch64.c:10118 config/arm/arm.c:24045
+#: config/aarch64/aarch64.c:10223 config/arm/arm.c:24220
 #, c-format
 msgid "missing operand"
 msgstr "缺少運算元"
 
-#: config/aarch64/aarch64.c:10203
+#: config/aarch64/aarch64.c:10308
 #, c-format
 msgid "invalid constant"
 msgstr "常數無效"
 
-#: config/aarch64/aarch64.c:10206
+#: config/aarch64/aarch64.c:10311
 #, c-format
 msgid "invalid operand"
 msgstr "運算元無效"
 
-#: config/aarch64/aarch64.c:10332 config/aarch64/aarch64.c:10337
+#: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "無效的運算元前綴「%%%c」"
 
-#: config/aarch64/aarch64.c:10357
+#: config/aarch64/aarch64.c:10462
 #, c-format
 msgid "invalid address mode"
 msgstr "無效的定址模式"
 
-#: config/aarch64/aarch64.c:22579 config/arm/arm.c:33009
+#: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/aarch64/aarch64.c:22581 config/arm/arm.c:33011
+#: config/aarch64/aarch64.c:22754 config/arm/arm.c:33186
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/aarch64/aarch64.c:22596 config/aarch64/aarch64.c:22612
-#: config/arm/arm.c:33026 config/arm/arm.c:33042
+#: config/aarch64/aarch64.c:22769 config/aarch64/aarch64.c:22785
+#: config/arm/arm.c:33201 config/arm/arm.c:33217
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22620
+#: config/aarch64/aarch64.c:22793
 #, fuzzy
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "無效的運算元在中二進運算"
 
 #: config/alpha/alpha.c:5076 config/i386/i386.c:13037
-#: config/rs6000/rs6000.c:13291 config/sparc/sparc.c:9351
+#: config/rs6000/rs6000.c:13417 config/sparc/sparc.c:9351
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
@@ -2003,18 +2003,18 @@ msgid "invalid %%r value"
 msgstr "無效 %%r 值"
 
 #: config/alpha/alpha.c:5174 config/ia64/ia64.c:5531
-#: config/rs6000/rs6000.c:12985 config/xtensa/xtensa.c:2428
+#: config/rs6000/rs6000.c:13111 config/xtensa/xtensa.c:2428
 #, c-format
 msgid "invalid %%R value"
 msgstr "無效 %%R 值"
 
-#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:12905
+#: config/alpha/alpha.c:5180 config/rs6000/rs6000.c:13031
 #: config/xtensa/xtensa.c:2395
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
-#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:12933
+#: config/alpha/alpha.c:5188 config/rs6000/rs6000.c:13059
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
@@ -2044,7 +2044,7 @@ msgstr "無效 %%M 值"
 msgid "invalid %%U value"
 msgstr "無效 %%U 值"
 
-#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:12993
+#: config/alpha/alpha.c:5274 config/rs6000/rs6000.c:13119
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
@@ -2054,7 +2054,7 @@ msgstr "無效 %%s 值"
 msgid "invalid %%C value"
 msgstr "無效 %%C 值"
 
-#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12769
+#: config/alpha/alpha.c:5322 config/rs6000/rs6000.c:12895
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
@@ -2064,10 +2064,10 @@ msgstr "無效 %%E 值"
 msgid "unknown relocation unspec"
 msgstr "不明的不可預期重定位"
 
-#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5748
-#: config/gcn/gcn.c:5757 config/gcn/gcn.c:5817 config/gcn/gcn.c:5825
-#: config/gcn/gcn.c:5841 config/gcn/gcn.c:5859 config/gcn/gcn.c:5910
-#: config/gcn/gcn.c:6029 config/gcn/gcn.c:6140 config/rs6000/rs6000.c:13296
+#: config/alpha/alpha.c:5356 config/cr16/cr16.c:1570 config/gcn/gcn.c:5749
+#: config/gcn/gcn.c:5758 config/gcn/gcn.c:5818 config/gcn/gcn.c:5826
+#: config/gcn/gcn.c:5842 config/gcn/gcn.c:5860 config/gcn/gcn.c:5911
+#: config/gcn/gcn.c:6030 config/gcn/gcn.c:6141 config/rs6000/rs6000.c:13422
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無效的 %%xn 程式碼"
@@ -2155,35 +2155,35 @@ msgstr "無效的 UNSPEC 做為運算元"
 msgid "unrecognized supposed constant"
 msgstr "預期的常數無法識別"
 
-#: config/arm/arm.c:20413 config/arm/arm.c:20438 config/arm/arm.c:20448
-#: config/arm/arm.c:20457 config/arm/arm.c:20466
+#: config/arm/arm.c:20588 config/arm/arm.c:20613 config/arm/arm.c:20623
+#: config/arm/arm.c:20632 config/arm/arm.c:20641
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "無效的 Shift 運算元"
 
-#: config/arm/arm.c:23329 config/arm/arm.c:23347
+#: config/arm/arm.c:23504 config/arm/arm.c:23522
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "預測到的 Thumb 指令"
 
-#: config/arm/arm.c:23335
+#: config/arm/arm.c:23510
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在條件序列中預測到的指令"
 
-#: config/arm/arm.c:23453 config/arm/arm.c:23466 config/arm/arm.c:23491
+#: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/arm/arm.c:23568 config/arm/arm.c:23590 config/arm/arm.c:23600
-#: config/arm/arm.c:23610 config/arm/arm.c:23620 config/arm/arm.c:23659
-#: config/arm/arm.c:23677 config/arm/arm.c:23702 config/arm/arm.c:23717
-#: config/arm/arm.c:23744 config/arm/arm.c:23751 config/arm/arm.c:23769
-#: config/arm/arm.c:23776 config/arm/arm.c:23784 config/arm/arm.c:23805
-#: config/arm/arm.c:23812 config/arm/arm.c:23992 config/arm/arm.c:23999
-#: config/arm/arm.c:24026 config/arm/arm.c:24033 config/bfin/bfin.c:1440
+#: config/arm/arm.c:23743 config/arm/arm.c:23765 config/arm/arm.c:23775
+#: config/arm/arm.c:23785 config/arm/arm.c:23795 config/arm/arm.c:23834
+#: config/arm/arm.c:23852 config/arm/arm.c:23877 config/arm/arm.c:23892
+#: config/arm/arm.c:23919 config/arm/arm.c:23926 config/arm/arm.c:23944
+#: config/arm/arm.c:23951 config/arm/arm.c:23959 config/arm/arm.c:23980
+#: config/arm/arm.c:23987 config/arm/arm.c:24167 config/arm/arm.c:24174
+#: config/arm/arm.c:24201 config/arm/arm.c:24208 config/bfin/bfin.c:1440
 #: config/bfin/bfin.c:1447 config/bfin/bfin.c:1454 config/bfin/bfin.c:1461
 #: config/bfin/bfin.c:1470 config/bfin/bfin.c:1477 config/bfin/bfin.c:1484
 #: config/bfin/bfin.c:1491 config/nds32/nds32.c:3543
@@ -2191,13 +2191,13 @@ msgstr "不受支援的運算元用於編碼『%c』"
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
 
-#: config/arm/arm.c:23672
+#: config/arm/arm.c:23847
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "指令永不執行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:23693
+#: config/arm/arm.c:23868
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
@@ -2324,7 +2324,7 @@ msgstr "非預期的運算元"
 
 #: config/cris/cris.c:625 config/ft32/ft32.c:110 config/moxie/moxie.c:108
 #: final.c:3607 final.c:3609 fold-const.c:266 gcc.c:5423 gcc.c:5437
-#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6747
+#: rtl-error.c:101 toplev.c:328 vr-values.c:2486 cp/typeck.c:6807
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -2542,27 +2542,27 @@ msgstr "錯誤的 output_move_double 運算元"
 msgid "bad output_condmove_single operand"
 msgstr "錯誤的 output_condmove_single 運算元"
 
-#: config/gcn/gcn.c:5418 config/gcn/gcn.c:5442 config/gcn/gcn.c:5446
-#: config/gcn/gcn.c:5790 config/gcn/gcn.c:5801 config/gcn/gcn.c:5804
+#: config/gcn/gcn.c:5419 config/gcn/gcn.c:5443 config/gcn/gcn.c:5447
+#: config/gcn/gcn.c:5791 config/gcn/gcn.c:5802 config/gcn/gcn.c:5805
 #, c-format
 msgid "bad ADDR_SPACE_GLOBAL address"
 msgstr "錯誤 ADDR_SPACE_GLOBAL 地址"
 
-#: config/gcn/gcn.c:5558 config/gcn/gcn.c:5581 config/gcn/gcn.c:5613
-#: config/gcn/gcn.c:5629 config/gcn/gcn.c:5644 config/gcn/gcn.c:5663
-#: config/gcn/gcn.c:5739 config/gcn/gcn.c:5935 config/gcn/gcn.c:6050
+#: config/gcn/gcn.c:5559 config/gcn/gcn.c:5582 config/gcn/gcn.c:5614
+#: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
+#: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand %%xn code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/gcn/gcn.c:6038
+#: config/gcn/gcn.c:6039
 #, fuzzy, c-format
 #| msgid "c4x_operand_subword: invalid mode"
 msgid "operand %%xn code invalid for QImode"
 msgstr "c4x_operand_subword：無效模式"
 
-#: config/gcn/gcn.c:6120
+#: config/gcn/gcn.c:6121
 #, fuzzy, c-format
 msgid "invalid fp constant"
 msgstr "無效指令："
@@ -2709,7 +2709,7 @@ msgstr "對 %<__fpreg%> 的作業無效"
 msgid "invalid %%P operand"
 msgstr "無效的 %%P 運算元"
 
-#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:12923
+#: config/iq2000/iq2000.c:3134 config/rs6000/rs6000.c:13049
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -2766,7 +2766,7 @@ msgid "post-increment address is not a register"
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.c:2335 config/m32r/m32r.c:2350
-#: config/rs6000/rs6000.c:19593
+#: config/rs6000/rs6000.c:19840
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -2819,8 +2819,8 @@ msgstr "『%%%c』並非有效運算元前綴"
 #: config/mips/mips.c:9084 config/mips/mips.c:9087 config/mips/mips.c:9099
 #: config/mips/mips.c:9102 config/mips/mips.c:9162 config/mips/mips.c:9169
 #: config/mips/mips.c:9190 config/mips/mips.c:9205 config/mips/mips.c:9224
-#: config/mips/mips.c:9233 config/riscv/riscv.c:3209 config/riscv/riscv.c:3324
-#: config/riscv/riscv.c:3330 config/riscv/riscv.c:3339
+#: config/mips/mips.c:9233 config/riscv/riscv.c:3217 config/riscv/riscv.c:3332
+#: config/riscv/riscv.c:3338 config/riscv/riscv.c:3347
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "無效的使用的『%%%c』"
@@ -2955,178 +2955,228 @@ msgstr "堆疊溢出。\n"
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "嘗試在命令解譯器中執行「%s」以提升它的極值。\n"
 
-#: config/rs6000/rs6000.c:3631
+#: config/rs6000/rs6000.c:3696
 #, fuzzy
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx 需求硬體浮點數"
 
-#: config/rs6000/rs6000.c:3639
+#: config/rs6000/rs6000.c:3704
 #, fuzzy
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "-mvsx 需要索引的定址"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3709
 #, fuzzy
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx 和 -mno-altivec 是不相容的"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3711
 #, fuzzy
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec 停用 vsx"
 
-#: config/rs6000/rs6000.c:3780
+#: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%<-mquad-memory%> 需要 64 位元模式"
 
-#: config/rs6000/rs6000.c:3783
+#: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
 msgstr "%<-mquad-memory-atomic%> 需要 64 位元模式"
 
-#: config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3860
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> 無法在低位位元組在前模式中使用"
 
-#: config/rs6000/rs6000.c:10009
+#: config/rs6000/rs6000.c:10115
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/rs6000/rs6000.c:12561
+#: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
 msgstr "錯誤 128 位元移動"
 
-#: config/rs6000/rs6000.c:12742 config/xtensa/xtensa.c:2371
+#: config/rs6000/rs6000.c:12859
+#, fuzzy, c-format
+#| msgid "invalid %%J value"
+msgid "invalid %%A value"
+msgstr "無效 %%J 值"
+
+#: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%D value"
 msgstr "無效的 %%D 值"
 
-#: config/rs6000/rs6000.c:12757
+#: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:12778
+#: config/rs6000/rs6000.c:12904
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/rs6000/rs6000.c:12787
+#: config/rs6000/rs6000.c:12913
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/rs6000/rs6000.c:12796
+#: config/rs6000/rs6000.c:12922
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/rs6000/rs6000.c:12831
+#: config/rs6000/rs6000.c:12957
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/rs6000/rs6000.c:12841
+#: config/rs6000/rs6000.c:12967
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/rs6000/rs6000.c:12851
+#: config/rs6000/rs6000.c:12977
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/rs6000/rs6000.c:12866 config/xtensa/xtensa.c:2414
+#: config/rs6000/rs6000.c:12992 config/xtensa/xtensa.c:2414
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/rs6000/rs6000.c:12913
+#: config/rs6000/rs6000.c:13039
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/rs6000/rs6000.c:12960
+#: config/rs6000/rs6000.c:13086
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/rs6000/rs6000.c:13002
+#: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:13019
+#: config/rs6000/rs6000.c:13145
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/rs6000/rs6000.c:13031
+#: config/rs6000/rs6000.c:13157
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/rs6000/rs6000.c:13045 config/xtensa/xtensa.c:2383
+#: config/rs6000/rs6000.c:13171 config/xtensa/xtensa.c:2383
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/rs6000/rs6000.c:13095
+#: config/rs6000/rs6000.c:13221
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:13112 config/xtensa/xtensa.c:2435
+#: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/rs6000/rs6000.c:13169
+#: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:13238
+#: config/rs6000/rs6000.c:13364
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/rs6000/rs6000.c:14082
+#: config/rs6000/rs6000.c:14208
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 及 __ibm128 不能用在同個運算式中"
 
-#: config/rs6000/rs6000.c:14088
+#: config/rs6000/rs6000.c:14214
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 及 long double 不能用在同個運算式中"
 
-#: config/rs6000/rs6000.c:14094
+#: config/rs6000/rs6000.c:14220
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 及 long double 不能用在同個運算式中"
 
-#: config/rs6000/rs6000.c:22852
+#: config/rs6000/rs6000.c:23099
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/rs6000/rs6000.c:25800
+#: config/rs6000/rs6000.c:26116
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/rs6000/rs6000.c:25869
+#: config/rs6000/rs6000.c:26185
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/rs6000/rs6000.c:25945
+#: config/rs6000/rs6000.c:26261
 msgid "Bad GPR fusion"
 msgstr "錯誤 GPR 融合"
 
+#: config/rs6000/rs6000.c:26740
+#, fuzzy
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr "從 %<bfloat16_t%> 類型轉換無效"
+
+#: config/rs6000/rs6000.c:26742
+#, fuzzy
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr "轉換至 %<bfloat16_t%> 類型無效"
+
+#: config/rs6000/rs6000.c:26744
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr "從 %<__fpreg%> 的轉換無效"
+
+#: config/rs6000/rs6000.c:26746
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr "向 %<__fpreg%> 的轉換無效"
+
+#: config/rs6000/rs6000.c:26754
+#, fuzzy
+msgid "invalid conversion from type %<* __vector_quad%>"
+msgstr "從 %<bfloat16_t%> 類型轉換無效"
+
+#: config/rs6000/rs6000.c:26757
+#, fuzzy
+msgid "invalid conversion to type %<* __vector_quad%>"
+msgstr "轉換至 %<bfloat16_t%> 類型無效"
+
+#: config/rs6000/rs6000.c:26760
+#, fuzzy
+#| msgid "invalid conversion from %<__fpreg%>"
+msgid "invalid conversion from type %<* __vector_pair%>"
+msgstr "從 %<__fpreg%> 的轉換無效"
+
+#: config/rs6000/rs6000.c:26763
+#, fuzzy
+#| msgid "invalid conversion to %<__fpreg%>"
+msgid "invalid conversion to type %<* __vector_pair%>"
+msgstr "向 %<__fpreg%> 的轉換無效"
+
 #: config/s390/s390.c:7787
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
@@ -3137,92 +3187,92 @@ msgstr "符號記憶體參考是只有支援的於 z10 或稍後"
 msgid "cannot decompose address"
 msgstr "無法分解位址"
 
-#: config/s390/s390.c:7880
+#: config/s390/s390.c:7878
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "無效的比較運算子用於『E』輸出修飾鍵"
 
-#: config/s390/s390.c:7903
+#: config/s390/s390.c:7901
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "無效的參考用於『J』輸出修飾鍵"
 
-#: config/s390/s390.c:7921
+#: config/s390/s390.c:7919
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "無效的位址用於『O』輸出修飾鍵"
 
-#: config/s390/s390.c:7943
+#: config/s390/s390.c:7941
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "無效的位址用於『R』輸出修飾鍵"
 
-#: config/s390/s390.c:7961
+#: config/s390/s390.c:7959
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "記憶體參考預期的用於『S』輸出修飾鍵"
 
-#: config/s390/s390.c:7971
+#: config/s390/s390.c:7969
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "無效的位址用於『S』輸出修飾鍵"
 
-#: config/s390/s390.c:7992
+#: config/s390/s390.c:7990
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『N』輸出修飾鍵"
 
-#: config/s390/s390.c:8003
+#: config/s390/s390.c:8001
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『公尺』輸出修飾鍵"
 
-#: config/s390/s390.c:8089 config/s390/s390.c:8110
+#: config/s390/s390.c:8087 config/s390/s390.c:8108
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:8107
+#: config/s390/s390.c:8105
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無效的常數 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.c:8144
+#: config/s390/s390.c:8142
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:8151
+#: config/s390/s390.c:8149
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無效的運算式 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.c:8154
+#: config/s390/s390.c:8152
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "無效的運算式用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:11873
+#: config/s390/s390.c:11871
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/s390/s390.c:16172
+#: config/s390/s390.c:16238
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "回傳指標時目的與指標有/無號不一致"
 
-#: config/s390/s390.c:16182
+#: config/s390/s390.c:16248
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:16185
+#: config/s390/s390.c:16251
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:16193
+#: config/s390/s390.c:16259
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3493,8 +3543,8 @@ msgstr "({匿名})"
 #: c/gimple-parser.c:2193 c/gimple-parser.c:2230 c/gimple-parser.c:2309
 #: c/gimple-parser.c:2336 c/c-parser.c:3240 c/c-parser.c:3427
 #: c/c-parser.c:3460 c/c-parser.c:11296 c/gimple-parser.c:2027
-#: c/gimple-parser.c:2066 cp/parser.c:13681 cp/parser.c:30000
-#: cp/parser.c:30593
+#: c/gimple-parser.c:2066 cp/parser.c:13686 cp/parser.c:30025
+#: cp/parser.c:30618
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
@@ -3514,7 +3564,7 @@ msgstr "需要 %<;%>"
 #: c/gimple-parser.c:1456 c/gimple-parser.c:1472 c/gimple-parser.c:1494
 #: c/gimple-parser.c:1524 c/gimple-parser.c:1550 c/gimple-parser.c:1756
 #: c/gimple-parser.c:1949 c/gimple-parser.c:1969 c/gimple-parser.c:2103
-#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30641
+#: c/gimple-parser.c:2266 c/c-parser.c:7172 cp/parser.c:30666
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -3522,7 +3572,7 @@ msgstr "預期 %<)%>"
 #: c/c-parser.c:4074 c/c-parser.c:4806 c/c-parser.c:4950 c/c-parser.c:5023
 #: c/c-parser.c:5024 c/c-parser.c:5438 c/c-parser.c:5474 c/c-parser.c:7274
 #: c/c-parser.c:9272 c/c-parser.c:10162 c/c-parser.c:10451 c/c-parser.c:13073
-#: c/gimple-parser.c:1733 cp/parser.c:30605
+#: c/gimple-parser.c:1733 cp/parser.c:30630
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -3541,21 +3591,21 @@ msgstr "預期 %<;%>，%<,%>或 %<)%>"
 #: c/gimple-parser.c:1430 c/gimple-parser.c:1490 c/gimple-parser.c:1508
 #: c/gimple-parser.c:1543 c/gimple-parser.c:1918 c/gimple-parser.c:1929
 #: c/gimple-parser.c:1935 c/gimple-parser.c:2100 c/gimple-parser.c:2263
-#: c/c-parser.c:13431 cp/parser.c:30596
+#: c/c-parser.c:13431 cp/parser.c:30621
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
 
-#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30608
-#: cp/parser.c:34267
+#: c/c-parser.c:4946 c/c-parser.c:4948 c/c-parser.c:13001 cp/parser.c:30633
+#: cp/parser.c:34293
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
 
 #: c/c-parser.c:5608 c/c-parser.c:11639 c/c-parser.c:17941 c/c-parser.c:18724
 #: c/c-parser.c:21766 c/gimple-parser.c:385 c/gimple-parser.c:2269
-#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19216
-#: cp/parser.c:30602
+#: c/c-parser.c:3228 c/c-parser.c:3450 c/c-parser.c:11191 cp/parser.c:19221
+#: cp/parser.c:30627
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -3566,12 +3616,12 @@ msgstr "需要 %<{%>"
 #: c/c-parser.c:15394 c/c-parser.c:15521 c/c-parser.c:20133 c/c-parser.c:20775
 #: c/c-parser.c:20834 c/gimple-parser.c:568 c/gimple-parser.c:871
 #: c/gimple-parser.c:2317 c/gimple-parser.c:2344 c/c-parser.c:7179
-#: c/c-parser.c:13534 cp/parser.c:30635 cp/parser.c:32280 cp/parser.c:35058
+#: c/c-parser.c:13534 cp/parser.c:30660 cp/parser.c:32306 cp/parser.c:35084
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
 
-#: c/c-parser.c:6736 cp/parser.c:30522
+#: c/c-parser.c:6736 cp/parser.c:30547
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
@@ -3580,7 +3630,7 @@ msgstr "預期 %<while%>"
 #: c/c-parser.c:9343 c/c-parser.c:10054 c/c-parser.c:14363 c/c-parser.c:15477
 #: c/gimple-parser.c:1021 c/gimple-parser.c:1047 c/gimple-parser.c:1175
 #: c/gimple-parser.c:1178 c/gimple-parser.c:1512 c/gimple-parser.c:1518
-#: cp/parser.c:29998 cp/parser.c:30611
+#: cp/parser.c:30023 cp/parser.c:30636
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -3590,18 +3640,18 @@ msgstr "預期 %<,%>"
 msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
-#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32854
-#: cp/parser.c:32928
+#: c/c-parser.c:10862 c/c-parser.c:10894 c/c-parser.c:11134 cp/parser.c:32880
+#: cp/parser.c:32954
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30620
+#: c/c-parser.c:11552 c/gimple-parser.c:1348 cp/parser.c:30645
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30644
+#: c/c-parser.c:14864 c/c-parser.c:15758 cp/parser.c:30669
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -3609,19 +3659,19 @@ msgstr "預期 %<,%>或 %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15386 c/c-parser.c:17397 c/c-parser.c:17441 c/c-parser.c:17673
 #: c/c-parser.c:18117 c/c-parser.c:20340 c/c-parser.c:20972
-#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30623
+#: c/gimple-parser.c:725 c/c-parser.c:5497 cp/parser.c:30648
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
 #: c/c-parser.c:17689 c/c-parser.c:17989 c/gimple-parser.c:1566
 #: c/gimple-parser.c:1598 c/gimple-parser.c:1608 c/gimple-parser.c:2354
-#: cp/parser.c:30599 cp/parser.c:33073
+#: cp/parser.c:30624 cp/parser.c:33099
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
 
-#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39683
+#: c/c-parser.c:18767 c/c-parser.c:18757 cp/parser.c:39709
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
@@ -3631,7 +3681,7 @@ msgstr "預期 %<# pragma omp section%>或 %<}%>"
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:1337 cp/parser.c:16636 cp/parser.c:30617
+#: c/gimple-parser.c:1337 cp/parser.c:16641 cp/parser.c:30642
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -3642,36 +3692,36 @@ msgstr "預期 %<<%>"
 msgid "expected label"
 msgstr "預期的頻道"
 
-#: cp/call.c:3866
+#: cp/call.c:3868
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate:"
 msgstr "備選 1："
 
-#: cp/call.c:7217
+#: cp/call.c:7220
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "啟用使用者定義的指令"
 
-#: cp/call.c:7351 cp/pt.c:2031 cp/pt.c:24632
+#: cp/call.c:7387 cp/pt.c:2031 cp/pt.c:24688
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidate 是："
 
-#: cp/call.c:11685
+#: cp/call.c:11715
 msgid "candidate 1:"
 msgstr "備選 1："
 
-#: cp/call.c:11686
+#: cp/call.c:11716
 msgid "candidate 2:"
 msgstr "備選 2："
 
-#: cp/decl.c:3258
+#: cp/decl.c:3260
 msgid "jump to label %qD"
 msgstr "跳轉至標籤 %qD"
 
-#: cp/decl.c:3259
+#: cp/decl.c:3261
 msgid "jump to case label"
 msgstr "跳轉至 case 標籤"
 
@@ -3775,7 +3825,7 @@ msgstr "<template parameter error>"
 msgid "<statement>"
 msgstr "<statement>"
 
-#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2202
+#: cp/error.c:2118 cp/error.c:3161 c-family/c-pretty-print.c:2203
 #, fuzzy, gcc-internal-format
 msgid "<unknown>"
 msgstr "<unknown>"
@@ -3969,52 +4019,52 @@ msgstr "轉換演員陣容暫離 constness"
 msgid "source type is not polymorphic"
 msgstr "來源型態不是 polymorphic"
 
-#: cp/typeck.c:6452 c/c-typeck.c:4396
+#: cp/typeck.c:6512 c/c-typeck.c:4396
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "單位元減的運算元類型錯誤"
 
-#: cp/typeck.c:6453 c/c-typeck.c:4383
+#: cp/typeck.c:6513 c/c-typeck.c:4383
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "單位元加的運算元類型錯誤"
 
-#: cp/typeck.c:6480 c/c-typeck.c:4440
+#: cp/typeck.c:6540 c/c-typeck.c:4440
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的引數類型錯誤"
 
-#: cp/typeck.c:6497 c/c-typeck.c:4448
+#: cp/typeck.c:6557 c/c-typeck.c:4448
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能對該類型的引數求絕對值"
 
-#: cp/typeck.c:6509 c/c-typeck.c:4470
+#: cp/typeck.c:6569 c/c-typeck.c:4470
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能對該類型的引數求共軛"
 
-#: cp/typeck.c:6527
+#: cp/typeck.c:6587
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "在中引數到一元！"
 
-#: cp/typeck.c:6573
+#: cp/typeck.c:6633
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "沒有 pre-increment 運算子用於型態"
 
-#: cp/typeck.c:6575
+#: cp/typeck.c:6635
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "沒有 post-increment 運算子用於型態"
 
-#: cp/typeck.c:6577
+#: cp/typeck.c:6637
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "沒有 pre-decrement 運算子用於型態"
 
-#: cp/typeck.c:6579
+#: cp/typeck.c:6639
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "沒有 post-decrement 運算子用於型態"
@@ -4058,17 +4108,17 @@ msgstr "%C 處 BOZ 常數中有無效字元"
 msgid "elemental binary operation"
 msgstr "elemental 二進運算"
 
-#: fortran/check.c:3702
+#: fortran/check.c:3709
 #, fuzzy, c-format
 msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgstr "引數『a%d』和『a%d』用於 intrinsic『%s』"
 
-#: fortran/check.c:3910 fortran/check.c:3991 fortran/check.c:4056
+#: fortran/check.c:3917 fortran/check.c:3998 fortran/check.c:4063
 #, fuzzy, c-format
 msgid "arguments '%s' and '%s' for intrinsic %s"
 msgstr "引數『%s』和『%s』用於 intrinsic %s"
 
-#: fortran/check.c:4388 fortran/intrinsic.c:4766
+#: fortran/check.c:4401 fortran/intrinsic.c:4778
 #, fuzzy, c-format
 msgid "arguments '%s' and '%s' for intrinsic '%s'"
 msgstr "引數『%s』和『%s』用於 intrinsic『%s』"
@@ -4147,7 +4197,7 @@ msgstr ""
 msgid "Driving:"
 msgstr "驅動："
 
-#: fortran/interface.c:3401 fortran/intrinsic.c:4449
+#: fortran/interface.c:3404 fortran/intrinsic.c:4461
 #, fuzzy
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "實際引數到含義=出/INOUT"
@@ -4164,7 +4214,7 @@ msgstr "內部單位在中寫入"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4725
+#: fortran/io.c:4727
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s 標籤與查詢"
@@ -4270,11 +4320,11 @@ msgstr "區塊 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2100 fortran/resolve.c:11845
+#: fortran/parse.c:2100 fortran/resolve.c:11855
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.c:2103 fortran/resolve.c:11896 fortran/resolve.c:11899
+#: fortran/parse.c:2103 fortran/resolve.c:11906 fortran/resolve.c:11909
 msgid "pointer assignment"
 msgstr "指標賦值"
 
@@ -4282,235 +4332,235 @@ msgstr "指標賦值"
 msgid "simple IF"
 msgstr "簡單的 IF"
 
-#: fortran/resolve.c:2300 fortran/resolve.c:2494
+#: fortran/resolve.c:2302 fortran/resolve.c:2496
 #, fuzzy
 msgid "elemental procedure"
 msgstr "elemental 程序"
 
-#: fortran/resolve.c:2397
+#: fortran/resolve.c:2399
 #, fuzzy
 #| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.c:2402
+#: fortran/resolve.c:2404
 #, fuzzy
 msgid "asynchronous argument"
 msgstr "不足引數"
 
-#: fortran/resolve.c:2407
+#: fortran/resolve.c:2409
 #, fuzzy
 msgid "optional argument"
 msgstr "無效的 PHI 引數"
 
-#: fortran/resolve.c:2412
+#: fortran/resolve.c:2414
 #, fuzzy
 #| msgid "pointer assignment"
 msgid "pointer argument"
 msgstr "指標賦值"
 
-#: fortran/resolve.c:2417
+#: fortran/resolve.c:2419
 #, fuzzy
 msgid "target argument"
 msgstr "太多引數"
 
-#: fortran/resolve.c:2422
+#: fortran/resolve.c:2424
 #, fuzzy
 msgid "value argument"
 msgstr "無效的 PHI 引數"
 
-#: fortran/resolve.c:2427
+#: fortran/resolve.c:2429
 #, fuzzy
 #| msgid "no arguments"
 msgid "volatile argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.c:2432
+#: fortran/resolve.c:2434
 #, fuzzy
 msgid "assumed-shape argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.c:2437
+#: fortran/resolve.c:2439
 #, fuzzy
 msgid "assumed-rank argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.c:2442
+#: fortran/resolve.c:2444
 #, fuzzy
 msgid "coarray argument"
 msgstr "陣列指派"
 
-#: fortran/resolve.c:2447
+#: fortran/resolve.c:2449
 msgid "parametrized derived type argument"
 msgstr ""
 
-#: fortran/resolve.c:2452
+#: fortran/resolve.c:2454
 #, fuzzy
 #| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "沒有參數"
 
-#: fortran/resolve.c:2457
+#: fortran/resolve.c:2459
 msgid "NO_ARG_CHECK attribute"
 msgstr ""
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
-#: fortran/resolve.c:2464
+#: fortran/resolve.c:2466
 #, fuzzy
 msgid "assumed-type argument"
 msgstr "不匹配的引數"
 
-#: fortran/resolve.c:2475
+#: fortran/resolve.c:2477
 msgid "array result"
 msgstr ""
 
-#: fortran/resolve.c:2480
+#: fortran/resolve.c:2482
 #, fuzzy
 msgid "pointer or allocatable result"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:2487
+#: fortran/resolve.c:2489
 #, fuzzy
 msgid "result with non-constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:2499
+#: fortran/resolve.c:2501
 #, fuzzy
 msgid "bind(c) procedure"
 msgstr "模組程序"
 
-#: fortran/resolve.c:4013
+#: fortran/resolve.c:4015
 #, fuzzy, c-format
 msgid "Invalid context for NULL() pointer at %%L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:4029
+#: fortran/resolve.c:4031
 #, fuzzy, c-format
 #| msgid "Operand of unary numeric operator '%s' at %%L is %s"
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "單位元數值運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:4046
+#: fortran/resolve.c:4048
 #, c-format
 msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4051
+#: fortran/resolve.c:4053
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元數值運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4066
+#: fortran/resolve.c:4068
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字串粘貼運算子(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4108
+#: fortran/resolve.c:4110
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "邏輯運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4131
+#: fortran/resolve.c:4133
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "運算元的.not。運算子於 %%L 是 %s"
 
-#: fortran/resolve.c:4145
+#: fortran/resolve.c:4147
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L 處複數不能比較大小"
 
-#: fortran/resolve.c:4243
+#: fortran/resolve.c:4245
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L 處邏輯值必須與 %s 比較，而不是 %s"
 
-#: fortran/resolve.c:4249
+#: fortran/resolve.c:4251
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比較運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4262
+#: fortran/resolve.c:4264
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:4265
+#: fortran/resolve.c:4267
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:4268
+#: fortran/resolve.c:4270
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:4272
+#: fortran/resolve.c:4274
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4358
+#: fortran/resolve.c:4360
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "不一致分級用於運算子於 %%L 和 %%L"
 
-#: fortran/resolve.c:7175
+#: fortran/resolve.c:7177
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.c:7179
+#: fortran/resolve.c:7181
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.c:7183
+#: fortran/resolve.c:7185
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.c:7187
+#: fortran/resolve.c:7189
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.c:7191
+#: fortran/resolve.c:7193
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.c:7477 fortran/resolve.c:7480
+#: fortran/resolve.c:7479 fortran/resolve.c:7482
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.c:7857 fortran/resolve.c:7860
+#: fortran/resolve.c:7859 fortran/resolve.c:7862
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.c:8093 fortran/resolve.c:10035
+#: fortran/resolve.c:8095 fortran/resolve.c:10037
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.c:8137 fortran/resolve.c:10047
+#: fortran/resolve.c:8139 fortran/resolve.c:10049
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.c:9841
+#: fortran/resolve.c:9843
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.c:10059
+#: fortran/resolve.c:10061
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
@@ -4525,27 +4575,27 @@ msgstr "不同的字元長度 (%ld/%ld) 在中陣列建構子"
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "整數溢位時計算數目的記憶體到配置"
 
-#: fortran/trans-array.c:9737
+#: fortran/trans-array.c:9739
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
 
-#: fortran/trans-decl.c:6191
+#: fortran/trans-decl.c:6196
 #, fuzzy, c-format
 msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度不匹配宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-decl.c:6199
+#: fortran/trans-decl.c:6204
 #, fuzzy, c-format
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度是短於宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-expr.c:9527
+#: fortran/trans-expr.c:9534
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目標的分級重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:10941
+#: fortran/trans-expr.c:10948
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -4623,7 +4673,7 @@ msgstr "單元號碼在中 I/O 敘述太大"
 msgid "Assigned label is not a target label"
 msgstr "賦值標籤不是目的標籤"
 
-#: fortran/trans-stmt.c:1250
+#: fortran/trans-stmt.c:1251
 #, fuzzy, c-format
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "無效的影像號碼 %d 在中同步影像"
@@ -5109,7 +5159,7 @@ msgstr "警告關於建立的陣列暫時的"
 #: common.opt:652 common.opt:790 common.opt:1010 common.opt:1014
 #: common.opt:1018 common.opt:1022 common.opt:1642 common.opt:1698
 #: common.opt:1830 common.opt:1834 common.opt:2068 common.opt:2274
-#: common.opt:2983
+#: common.opt:2987
 #, fuzzy, no-c-format
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "沒做任何事。保留的用於回溯相容性。"
@@ -5721,8 +5771,8 @@ msgstr "為外部可見的名稱加入底線"
 #: common.opt:1917 common.opt:1960 common.opt:2349 common.opt:2385
 #: common.opt:2478 common.opt:2482 common.opt:2591 common.opt:2682
 #: common.opt:2690 common.opt:2698 common.opt:2706 common.opt:2807
-#: common.opt:2859 common.opt:2947 common.opt:3084 common.opt:3088
-#: common.opt:3092 common.opt:3096
+#: common.opt:2863 common.opt:2951 common.opt:3088 common.opt:3092
+#: common.opt:3096 common.opt:3100
 #, fuzzy, no-c-format
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
@@ -8353,107 +8403,101 @@ msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "當定義在主檔案中的巨集未被使用時給出警告"
 
 #: analyzer/analyzer.opt:103
-#, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
-msgid "Warn about code paths in which an uninitialized value is used."
-msgstr "對初始化為自身的變數給出警告。"
-
-#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Warn if the code is too complicated for the analyzer to fully explore."
 msgstr ""
 
-#: analyzer/analyzer.opt:111
+#: analyzer/analyzer.opt:107
 #, no-c-format
 msgid "Restrict the analyzer to run just the named checker."
 msgstr ""
 
-#: analyzer/analyzer.opt:115
+#: analyzer/analyzer.opt:111
 #, no-c-format
 msgid "Avoid combining multiple statements into one exploded edge."
 msgstr ""
 
-#: analyzer/analyzer.opt:119
+#: analyzer/analyzer.opt:115
 #, no-c-format
 msgid "Issue a note when diagnostics are deduplicated."
 msgstr ""
 
-#: analyzer/analyzer.opt:123
+#: analyzer/analyzer.opt:119
 #, no-c-format
 msgid "Purge unneeded state during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:127
+#: analyzer/analyzer.opt:123
 #, no-c-format
 msgid "Merge similar-enough states during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:131
+#: analyzer/analyzer.opt:127
 #, no-c-format
 msgid "Enable transitivity of constraints during analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:135
+#: analyzer/analyzer.opt:131
 #, no-c-format
 msgid "Approximate the effect of function calls to simplify analysis."
 msgstr ""
 
-#: analyzer/analyzer.opt:139
+#: analyzer/analyzer.opt:135
 #, no-c-format
 msgid "Emit more verbose descriptions of control flow in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:143
+#: analyzer/analyzer.opt:139
 #, no-c-format
 msgid "Emit more verbose descriptions of state changes in diagnostics."
 msgstr ""
 
-#: analyzer/analyzer.opt:147
+#: analyzer/analyzer.opt:143
 #, no-c-format
 msgid "Control which events are displayed in diagnostic paths."
 msgstr ""
 
-#: analyzer/analyzer.opt:151
+#: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "-fdump-<type>\t傾印各種編譯器內部到檔案"
 
-#: analyzer/analyzer.opt:155
+#: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
 msgid "Dump various analyzer internals to stderr."
 msgstr "-fdump-<type>\t傾印各種編譯器內部到檔案"
 
-#: analyzer/analyzer.opt:159
+#: analyzer/analyzer.opt:155
 #, no-c-format
 msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:163
+#: analyzer/analyzer.opt:159
 #, no-c-format
 msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:167
+#: analyzer/analyzer.opt:163
 #, no-c-format
 msgid "Emit diagnostics showing the location of nodes in the exploded graph."
 msgstr ""
 
-#: analyzer/analyzer.opt:171
+#: analyzer/analyzer.opt:167
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:175
+#: analyzer/analyzer.opt:171
 #, no-c-format
 msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
 msgstr ""
 
-#: analyzer/analyzer.opt:179
+#: analyzer/analyzer.opt:175
 #, no-c-format
 msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
 msgstr ""
 
-#: analyzer/analyzer.opt:183
+#: analyzer/analyzer.opt:179
 #, no-c-format
 msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
 msgstr ""
@@ -13196,9 +13240,8 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "generation of Branch Likely instructions enabled, but not supported by architecture"
-msgid "Use instructions for a future architecture."
-msgstr "產生 Branch Likely 指令被啟用，但並不為架構所支援"
+msgid "Use instructions added in ISA 3.1."
+msgstr "使用向量/純量 (VSX) 指令"
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
@@ -13211,6 +13254,11 @@ msgstr "產生載入/儲存多重指令"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "不使用未對齊的記憶體參照"
 
+#: config/rs6000/rs6000.opt:584
+#, fuzzy, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr "產生載入/儲存多重指令"
+
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
 #| msgid "Select ABI calling convention"
@@ -18524,7 +18572,7 @@ msgstr ""
 
 #: common.opt:2213
 #, no-c-format
-msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
 msgstr ""
 
 #: common.opt:2217
@@ -19211,396 +19259,396 @@ msgstr "展開所有迭代次數已知的循環"
 msgid "Perform loop unrolling for all loops."
 msgstr "展開所有循環"
 
-#: common.opt:2863
+#: common.opt:2867
 #, fuzzy, no-c-format
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "允許最佳化用於浮點算術該項也許會變更"
 
-#: common.opt:2868
+#: common.opt:2872
 #, fuzzy, no-c-format
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "如同 -fassociative-math 用於運算式該項包含除法。"
 
-#: common.opt:2876
+#: common.opt:2880
 #, fuzzy, no-c-format
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "允許可能違反 IEEE 或 ISO 標準的最佳化"
 
-#: common.opt:2880
+#: common.opt:2884
 #, fuzzy, no-c-format
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "外提循環內的測試敘述"
 
-#: common.opt:2884
+#: common.opt:2888
 #, fuzzy, no-c-format
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "進行循環剝離"
 
-#: common.opt:2888
+#: common.opt:2892
 #, no-c-format
 msgid "Version loops based on whether indices have a stride of one."
 msgstr ""
 
-#: common.opt:2892
+#: common.opt:2896
 #, fuzzy, no-c-format
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "僅為異常處理產生堆疊展開表"
 
-#: common.opt:2896
+#: common.opt:2900
 #, fuzzy, no-c-format
 msgid "Use the bfd linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2900
+#: common.opt:2904
 #, fuzzy, no-c-format
 msgid "Use the gold linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2904
+#: common.opt:2908
 #, fuzzy, no-c-format
 msgid "Use the lld LLVM linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2916
+#: common.opt:2920
 #, fuzzy, no-c-format
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "進行變數追蹤"
 
-#: common.opt:2924
+#: common.opt:2928
 #, fuzzy, no-c-format
 msgid "Perform variable tracking by annotating assignments."
 msgstr "施行變數追蹤由 notating 指派"
 
-#: common.opt:2930
+#: common.opt:2934
 #, fuzzy, no-c-format
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "切換 -fvar-tracking-assignments"
 
-#: common.opt:2938
+#: common.opt:2942
 #, fuzzy, no-c-format
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:2943
+#: common.opt:2947
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:2951
+#: common.opt:2955
 #, fuzzy, no-c-format
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:2955
+#: common.opt:2959
 #, fuzzy, no-c-format
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "啟用基本區塊 vectorization (SLP) 於樹"
 
-#: common.opt:2959
+#: common.opt:2963
 #, no-c-format
 msgid "-fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2963
+#: common.opt:2967
 #, no-c-format
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2979
+#: common.opt:2983
 #, fuzzy, no-c-format
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
 
-#: common.opt:2987
+#: common.opt:2991
 #, fuzzy, no-c-format
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "啟用複製傳用的 scalar-evolution 資訊。"
 
-#: common.opt:2997
+#: common.opt:3001
 #, fuzzy, no-c-format
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "為組譯輸出加入額外註釋"
 
-#: common.opt:3001
+#: common.opt:3005
 #, fuzzy, no-c-format
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[預設|內部|隱藏|保護的]\t設定預設符號可視性"
 
-#: common.opt:3020
+#: common.opt:3024
 #, no-c-format
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:3036
+#: common.opt:3040
 #, no-c-format
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:3040
+#: common.opt:3044
 #, no-c-format
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:3044
+#: common.opt:3048
 #, fuzzy, no-c-format
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "在最佳化中使用運算式值樣本提供的資訊"
 
-#: common.opt:3048
+#: common.opt:3052
 #, fuzzy, no-c-format
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "建構網頁和分割 unrelated 使用的單一變數"
 
-#: common.opt:3052
+#: common.opt:3056
 #, fuzzy, no-c-format
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "啟用條件無作用程式碼 elimination 用於內建呼叫"
 
-#: common.opt:3056
+#: common.opt:3060
 #, fuzzy, no-c-format
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "進行全程式最佳化"
 
-#: common.opt:3060
+#: common.opt:3064
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:3064
+#: common.opt:3068
 #, fuzzy, no-c-format
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:3068
+#: common.opt:3072
 #, fuzzy, no-c-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "將初始化為零的資料存放在 bss 區段中"
 
-#: common.opt:3072
+#: common.opt:3076
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:3076
+#: common.opt:3080
 #, fuzzy, no-c-format
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
 
-#: common.opt:3080
+#: common.opt:3084
 #, fuzzy, no-c-format
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
 
-#: common.opt:3100
+#: common.opt:3104
 #, no-c-format
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:3104
+#: common.opt:3108
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:3108
+#: common.opt:3112
 #, fuzzy, no-c-format
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "產生除錯資訊在中 DWARF v2 (或稍後) 格式"
 
-#: common.opt:3112
+#: common.opt:3116
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "產生預設擴充格式的除錯資訊"
 
-#: common.opt:3116
+#: common.opt:3120
 #, fuzzy, no-c-format
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "為每個函式產生單一的離開點"
 
-#: common.opt:3120
+#: common.opt:3124
 #, no-c-format
 msgid "Compute locview reset points based on insn length estimates."
 msgstr ""
 
-#: common.opt:3128
+#: common.opt:3132
 #, no-c-format
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3132
+#: common.opt:3136
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:3136
+#: common.opt:3140
 #, no-c-format
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:3140
+#: common.opt:3144
 #, fuzzy, no-c-format
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "記錄 gcc 命令列切換在中 DWARF DW_AT_producer。"
 
-#: common.opt:3144
+#: common.opt:3148
 #, fuzzy, no-c-format
 msgid "Generate debug information in separate .dwo files."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:3148
+#: common.opt:3152
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "產生 STABS 格式的除錯資訊"
 
-#: common.opt:3152
+#: common.opt:3156
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "產生擴充 STABS 格式的除錯資訊"
 
-#: common.opt:3156
+#: common.opt:3160
 #, no-c-format
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:3160
+#: common.opt:3164
 #, fuzzy, no-c-format
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "不 emit DWARF 增加位於之後已選版本"
 
-#: common.opt:3164
+#: common.opt:3168
 #, no-c-format
 msgid "Add description attributes to some DWARF DIEs that have no name attribute."
 msgstr ""
 
-#: common.opt:3168
+#: common.opt:3172
 #, fuzzy, no-c-format
 msgid "Toggle debug information generation."
 msgstr "切換除錯資訊產生"
 
-#: common.opt:3172
+#: common.opt:3176
 #, no-c-format
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:3179
+#: common.opt:3183
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "產生 VMS 格式的除錯資訊"
 
-#: common.opt:3183
+#: common.opt:3187
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "產生 XCOFF 格式的除錯資訊"
 
-#: common.opt:3187
+#: common.opt:3191
 #, fuzzy, no-c-format
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "產生 XCOFF 擴充格式的除錯資訊"
 
-#: common.opt:3205
+#: common.opt:3209
 #, fuzzy, no-c-format
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "產生 isel 指令"
 
-#: common.opt:3209
+#: common.opt:3213
 #, no-c-format
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3216
+#: common.opt:3220
 #, fuzzy, no-c-format
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\t設定<dir>為預設外掛程式目錄"
 
-#: common.opt:3220
+#: common.opt:3224
 #, fuzzy, no-c-format
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <dir>\t設定<dir>為 multilib 包含子目錄"
 
-#: common.opt:3245
+#: common.opt:3249
 #, fuzzy, no-c-format
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t置放輸出進入<檔案>"
 
-#: common.opt:3249
+#: common.opt:3253
 #, fuzzy, no-c-format
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "啟用函式取樣"
 
-#: common.opt:3259
+#: common.opt:3263
 #, fuzzy, no-c-format
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "與 -pedantic 類似，但將它們視作錯誤"
 
-#: common.opt:3299
+#: common.opt:3303
 #, fuzzy, no-c-format
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "不顯示編譯的函式或逝去的時間"
 
-#: common.opt:3331
+#: common.opt:3335
 #, fuzzy, no-c-format
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "啟用詳細輸出"
 
-#: common.opt:3335
+#: common.opt:3339
 #, fuzzy, no-c-format
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "顯示編譯器版本"
 
-#: common.opt:3339
+#: common.opt:3343
 #, fuzzy, no-c-format
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "不顯示警告"
 
-#: common.opt:3349
+#: common.opt:3353
 #, fuzzy, no-c-format
 msgid "Create a shared library."
 msgstr "建立共用函式庫"
 
-#: common.opt:3394
+#: common.opt:3398
 #, fuzzy, no-c-format
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3398
+#: common.opt:3402
 #, fuzzy, no-c-format
 msgid "Create a dynamically linked position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3402
+#: common.opt:3406
 #, fuzzy, no-c-format
 msgid "Create a static position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3409
+#: common.opt:3413
 #, no-c-format
 msgid "Use caller save register across calls if possible."
 msgstr ""
@@ -20809,8 +20857,8 @@ msgstr "約束於執行時檢查數量插入的由 vectorizer's 迴圈定版用
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
 msgstr "約束於執行時檢查數量插入的由 vectorizer's 迴圈定版用於對齊檢查"
 
-#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1389
-#: cp/cvt.c:1645
+#: go/gofrontend/expressions.cc:116 c-family/c-warn.c:672 cp/cvt.c:1388
+#: cp/cvt.c:1644
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "計算出的值未被使用"
@@ -20841,7 +20889,7 @@ msgid "expected boolean type"
 msgstr "預期的布林值型態"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
-#: cp/parser.c:36331 cp/parser.c:36338
+#: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20919,7 +20967,7 @@ msgstr "不足引數"
 #: go/gofrontend/expressions.cc:10076 go/gofrontend/expressions.cc:10157
 #: go/gofrontend/expressions.cc:10230 go/gofrontend/expressions.cc:11041
 #: go/gofrontend/expressions.cc:12098 go/gofrontend/expressions.cc:12112
-#: go/gofrontend/expressions.cc:12133 cp/pt.c:8945
+#: go/gofrontend/expressions.cc:12133 cp/pt.c:8954
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "太多引數"
@@ -21343,7 +21391,7 @@ msgstr "%qE 屬性衝突與屬性 %s"
 
 #: attribs.c:452 c-family/c-attribs.c:2080 c-family/c-attribs.c:2497
 #: c-family/c-attribs.c:3886 c-family/c-attribs.c:3900
-#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14810
+#: c-family/c-attribs.c:3914 c-family/c-attribs.c:3929 cp/decl.c:14819
 #: cp/friend.c:303 cp/tree.c:4792
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -21427,12 +21475,12 @@ msgstr "型態屬性忽略的之後型態已經定義"
 #: c-family/c-attribs.c:4363 c-family/c-attribs.c:4419
 #: c-family/c-attribs.c:4435 c-family/c-attribs.c:4529
 #: c-family/c-common.c:5694 c-family/c-common.c:5697 config/darwin.c:2062
-#: config/arm/arm.c:7149 config/arm/arm.c:7177 config/arm/arm.c:7194
+#: config/arm/arm.c:7246 config/arm/arm.c:7274 config/arm/arm.c:7291
 #: config/avr/avr.c:9675 config/csky/csky.c:6046 config/csky/csky.c:6068
 #: config/h8300/h8300.c:5347 config/h8300/h8300.c:5371
-#: config/i386/i386-options.c:3309 config/i386/i386-options.c:3467
-#: config/i386/i386-options.c:3699 config/ia64/ia64.c:785
-#: config/rs6000/rs6000.c:19357 ada/gcc-interface/utils.c:6436
+#: config/i386/i386-options.c:3313 config/i386/i386-options.c:3471
+#: config/i386/i386-options.c:3703 config/ia64/ia64.c:785
+#: config/rs6000/rs6000.c:19604 ada/gcc-interface/utils.c:6436
 #: ada/gcc-interface/utils.c:6464 ada/gcc-interface/utils.c:6481
 #: ada/gcc-interface/utils.c:6498 ada/gcc-interface/utils.c:6513
 #: ada/gcc-interface/utils.c:6529 ada/gcc-interface/utils.c:6555
@@ -21450,8 +21498,8 @@ msgstr "%qE 屬性被忽略"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2062 cp/decl.c:2073
-#: cp/decl.c:2676 cp/decl.c:3103
+#: attribs.c:998 cp/decl.c:1162 cp/decl.c:2018 cp/decl.c:2064 cp/decl.c:2075
+#: cp/decl.c:2678 cp/decl.c:3105
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -21571,7 +21619,7 @@ msgstr "參考 %qs 無法宣告 %<mutable%>"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量超過字串常數界"
 
-#: builtins.c:815 cp/name-lookup.c:5333
+#: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD 宣告的在此"
@@ -21859,7 +21907,7 @@ msgstr "缺少引數到 %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:7931 expr.c:11097
+#: builtins.c:7931 expr.c:11102
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack()%>"
@@ -22159,12 +22207,12 @@ msgstr "組譯篡改清單與輸出運算元衝突"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "組譯篡改清單與輸入運算元衝突"
 
-#: cfgexpand.c:6420
+#: cfgexpand.c:6421
 #, fuzzy, gcc-internal-format
 msgid "stack protector not protecting local variables: variable length buffer"
 msgstr "堆疊 protector 無法保護區域變數：變數長度緩衝區"
 
-#: cfgexpand.c:6424
+#: cfgexpand.c:6425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
 msgstr "堆疊 protector 無法保護函式：所有本地陣列是少於 %d 位元組長"
@@ -22680,306 +22728,306 @@ msgstr "基本區塊無法 laid 向下順序的"
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "bb 記事數量在中 insn 鏈接 (%d) !=n_basic_blocks (%d)"
 
-#: cgraph.c:3136
+#: cgraph.c:3138
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "呼叫邊計數為負"
 
-#: cgraph.c:3232
+#: cgraph.c:3234
 #, gcc-internal-format
 msgid "missing indirect call in speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3237
+#: cgraph.c:3239
 #, gcc-internal-format
 msgid "indirect call in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3267
+#: cgraph.c:3269
 #, gcc-internal-format
 msgid "speculative edges are not adjacent"
 msgstr ""
 
-#: cgraph.c:3273
+#: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
 msgstr ""
 
-#: cgraph.c:3279 cgraph.c:3309
+#: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
 msgstr ""
 
-#: cgraph.c:3286
+#: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3297
+#: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
 msgstr ""
 
-#: cgraph.c:3316
+#: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing direct call for speculation %i"
 msgstr "缺少形狀參數用於呼叫到 %s 於 %L"
 
-#: cgraph.c:3334
+#: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing barrier after block %i"
 msgid "missing ref for speculation %i"
 msgstr "在區塊 %i 之後缺少邊界"
 
-#: cgraph.c:3343
+#: cgraph.c:3345
 #, gcc-internal-format, gfc-internal-format
 msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
 msgstr ""
 
-#: cgraph.c:3372
+#: cgraph.c:3374
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "為邊 %s->%s 設定 AUX 欄位"
 
-#: cgraph.c:3379
+#: cgraph.c:3381
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3384
+#: cgraph.c:3386
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: cgraph.c:3389
+#: cgraph.c:3391
 #, fuzzy, gcc-internal-format
 msgid "inline clone count is not compatible"
 msgstr "內聯仿本被所需的"
 
-#: cgraph.c:3396
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "tp_first_run must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: cgraph.c:3401
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "假定符號可能無效"
 
-#: cgraph.c:3406
+#: cgraph.c:3408
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "外部可見的內聯仿本"
 
-#: cgraph.c:3411
+#: cgraph.c:3413
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "內聯仿本與位址佔用"
 
-#: cgraph.c:3416
+#: cgraph.c:3418
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "內聯仿本被所需的"
 
-#: cgraph.c:3423
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "calls_comdat_local is set outside of a comdat group"
 msgstr ""
 
-#: cgraph.c:3428
+#: cgraph.c:3430
 #, gcc-internal-format
 msgid "invalid calls_comdat_local flag"
 msgstr ""
 
-#: cgraph.c:3435
+#: cgraph.c:3437
 #, fuzzy, gcc-internal-format
 msgid "malloc attribute should be used for a function that returns a pointer"
 msgstr "回傳與值在中函式不具任何傳回類型"
 
-#: cgraph.c:3443
+#: cgraph.c:3445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux 欄位設定用於間接邊緣從 %s"
 
-#: cgraph.c:3449 cgraph.c:3509
+#: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
 msgid "edge count is not compatible with function count"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: cgraph.c:3457
+#: cgraph.c:3459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "間接邊緣從 %s 未被標記為間接或已關聯的 indirectinfo(_I)，相應敘述是："
 
-#: cgraph.c:3465 cgraph.c:3536
+#: cgraph.c:3467 cgraph.c:3538
 #, gcc-internal-format
 msgid "edge has both call_stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3477
+#: cgraph.c:3479
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3487
+#: cgraph.c:3489
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 錯誤"
 
-#: cgraph.c:3492
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多個內聯呼叫者"
 
-#: cgraph.c:3499
+#: cgraph.c:3501
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "為非內聯的呼叫者設定了 inlined_to pointer"
 
-#: cgraph.c:3526
+#: cgraph.c:3528
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "呼叫者邊緣頻率 %i 不匹配 BB 頻率 %i"
 
-#: cgraph.c:3557
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "收到的郵件邊緣計數不匹配 PHI 引數數量"
 
-#: cgraph.c:3574
+#: cgraph.c:3576
 #, gcc-internal-format
 msgid "reference has both stmt and lto_stmt_uid set"
 msgstr ""
 
-#: cgraph.c:3585
+#: cgraph.c:3587
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlinedto 指標是設定並不是找到任何 predecessors(_T)"
 
-#: cgraph.c:3590
+#: cgraph.c:3592
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 參照自身"
 
-#: cgraph.c:3601
+#: cgraph.c:3603
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "節點有錯誤的 cloneof(_O)"
 
-#: cgraph.c:3614
+#: cgraph.c:3616
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "節點有錯誤的仿本清單"
 
-#: cgraph.c:3620
+#: cgraph.c:3622
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: cgraph.c:3625
+#: cgraph.c:3627
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "節點有錯誤的 prevclone 指標(_C)"
 
-#: cgraph.c:3630
+#: cgraph.c:3632
 #, fuzzy, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: cgraph.c:3642
+#: cgraph.c:3644
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "別名有呼叫邊緣"
 
-#: cgraph.c:3648
+#: cgraph.c:3650
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "別名有 non-alias 參考"
 
-#: cgraph.c:3653
+#: cgraph.c:3655
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "別名有超過一個別名參考"
 
-#: cgraph.c:3660
+#: cgraph.c:3662
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "分析的別名沒有任何參考"
 
-#: cgraph.c:3669
+#: cgraph.c:3671
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "沒有邊緣超出 thunk 節點"
 
-#: cgraph.c:3674
+#: cgraph.c:3676
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超過一個邊緣超出 thunk 節點"
 
-#: cgraph.c:3679
+#: cgraph.c:3681
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk 未被猜想到有內文"
 
-#: cgraph.c:3713
+#: cgraph.c:3715
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3721
+#: cgraph.c:3723
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "邊緣指到不對的宣告："
 
-#: cgraph.c:3730
+#: cgraph.c:3732
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "間接邊緣與不明被呼叫端相應到 callstmt 與已知宣告(_S)："
 
-#: cgraph.c:3740
+#: cgraph.c:3742
 #, fuzzy, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "缺少callgraph 邊緣用於呼叫 stmt："
 
-#: cgraph.c:3750
+#: cgraph.c:3752
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "需要敘述"
 
-#: cgraph.c:3763
+#: cgraph.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "邊緣 %s->%s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3775
+#: cgraph.c:3777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "間接邊緣從 %s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3790 cgraph.c:3803
+#: cgraph.c:3792 cgraph.c:3805
 #, gcc-internal-format
 msgid "missing origin for a node in a nested list"
 msgstr ""
 
-#: cgraph.c:3795
+#: cgraph.c:3797
 #, fuzzy, gcc-internal-format
 msgid "origin points to a different parent"
 msgstr "轉換的暫存器到不同的大小"
 
-#: cgraph.c:3810
+#: cgraph.c:3812
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: cgraph.c:3921 varpool.c:303
+#: cgraph.c:3923 varpool.c:303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
 msgstr "%s：區段 %s 缺少"
@@ -23070,12 +23118,12 @@ msgid "%<weakref%> attribute ignored because variable is initialized"
 msgstr "%<weakref%> 屬性忽略的因為變數被初始化的"
 
 #. include_self=
-#: cgraphunit.c:1076 c/c-decl.c:11805
+#: cgraphunit.c:1076 c/c-decl.c:11812
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F 使用過但從未定義"
 
-#: cgraphunit.c:1078 c/c-decl.c:11815
+#: cgraphunit.c:1078 c/c-decl.c:11822
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
@@ -23234,7 +23282,7 @@ msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO 支援未被已啟用在中這個組態"
 
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
-#: toplev.c:1728 objc/objc-act.c:461
+#: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
@@ -23568,22 +23616,22 @@ msgstr ""
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) 找到在中變數位置"
 
-#: emit-rtl.c:2930
+#: emit-rtl.c:2885
 #, gcc-internal-format
 msgid "invalid rtl sharing found in the insn"
 msgstr "在 insn 中找到無效的 rtl 分享"
 
-#: emit-rtl.c:2932
+#: emit-rtl.c:2887
 #, gcc-internal-format
 msgid "shared rtx"
 msgstr "共享的 rtx"
 
-#: emit-rtl.c:2934
+#: emit-rtl.c:2889
 #, gcc-internal-format
 msgid "internal consistency failure"
 msgstr "內部一致性錯誤"
 
-#: emit-rtl.c:4070
+#: emit-rtl.c:4025
 #, gcc-internal-format
 msgid "ICE: emit_insn used where emit_jump_insn needed:\n"
 msgstr "ICE：需要 emit_jump_insn 時使用了 emit_insn used where：\n"
@@ -23644,7 +23692,7 @@ msgstr "region_array 不匹配 region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array 不匹配 region_tree"
 
-#: except.c:3517 tree.c:14717 value-prof.c:517
+#: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "開啟 %s 失敗：%s"
@@ -23674,12 +23722,12 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:11109
+#: expr.c:11114
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性錯誤：%s"
 
-#: expr.c:11123
+#: expr.c:11128
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性警告：%s"
@@ -23694,7 +23742,7 @@ msgstr "有效引數到 %qs 是：%s"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "影格大小的 %wd 位元組是大於 %wd 位元組"
 
-#: final.c:4809 toplev.c:1552 tree-cfgcleanup.c:1499
+#: final.c:4809 toplev.c:1557 tree-cfgcleanup.c:1499
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "無法開啟最後的 insn 傾印檔案 %qs：%m"
@@ -23714,37 +23762,37 @@ msgstr "大定點常數隱含地截短至定點型態"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.c:5913 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
+#: fold-const.c:5927 tree-ssa-reassoc.c:2726 tree-ssa-reassoc.c:3606
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
 
-#: fold-const.c:6366 fold-const.c:6380
+#: fold-const.c:6380 fold-const.c:6394
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較結果始終為 %d"
 
-#: fold-const.c:6524
+#: fold-const.c:6538
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "對兩個不匹配的不等比較取 %<or%> 的結果總為 1"
 
-#: fold-const.c:6529
+#: fold-const.c:6543
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "對兩個互斥的相等比較取 %<and%> 的結果永遠是 0"
 
-#: fold-const.c:9191
+#: fold-const.c:9205
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "假設帶正負號溢位不發生時縮小常數在中比較"
 
-#: fold-const.c:9591
+#: fold-const.c:9605
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "假設帶正負號溢位不發生時合併常數周圍比較"
 
-#: fold-const.c:12891
+#: fold-const.c:12905
 #, fuzzy, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折疊檢查：原來的樹變更的由折疊"
@@ -24375,13 +24423,13 @@ msgstr "函式回傳局部變數的位址"
 msgid "function returns address of local variable"
 msgstr "函式回傳局部變數的位址"
 
-#: gimple-ssa-isolate-paths.c:412 tree.c:13082 tree.c:13119 c/c-typeck.c:2929
+#: gimple-ssa-isolate-paths.c:412 tree.c:13084 tree.c:13121 c/c-typeck.c:2929
 #: c/c-typeck.c:3015 c/c-typeck.c:10615 c/c-typeck.c:10632
-#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7060 cp/call.c:8888
-#: cp/constexpr.c:852 cp/constexpr.c:3337 cp/cvt.c:1069 cp/cvt.c:1107
-#: cp/decl.c:7972 cp/decl2.c:5543 cp/decl2.c:5588 cp/pt.c:8753
-#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1775 cp/typeck.c:1987
-#: cp/typeck.c:4031 cp/typeck.c:9589
+#: c/gimple-parser.c:2416 c/gimple-parser.c:2424 cp/call.c:7063 cp/call.c:8917
+#: cp/constexpr.c:852 cp/constexpr.c:3353 cp/cvt.c:1068 cp/cvt.c:1106
+#: cp/decl.c:7969 cp/decl2.c:5532 cp/decl2.c:5577 cp/pt.c:8762
+#: cp/semantics.c:1928 cp/semantics.c:4261 cp/typeck.c:1817 cp/typeck.c:2029
+#: cp/typeck.c:4089 cp/typeck.c:9649
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "宣告的在此"
@@ -24945,10 +24993,10 @@ msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1810 c/c-decl.c:3832 c/c-decl.c:4105
-#: c/c-typeck.c:8743 cp/class.c:1386 cp/class.c:3162 cp/constexpr.c:956
-#: cp/decl.c:4076 cp/decl.c:11613 cp/decl.c:12084 cp/decl.c:12093
+#: c/c-typeck.c:8743 cp/class.c:1393 cp/class.c:3187 cp/constexpr.c:956
+#: cp/decl.c:4078 cp/decl.c:11613 cp/decl.c:12091 cp/decl.c:12100
 #: cp/friend.c:386 cp/friend.c:396 cp/parser.c:3333 cp/parser.c:3472
-#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22263
+#: cp/parser.c:3523 cp/parser.c:6542 cp/parser.c:22279
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -25119,7 +25167,7 @@ msgstr "%qE 尚未指定在中封閉平行"
 msgid "enclosing %<target%>"
 msgstr "封閉任務"
 
-#: gimplify.c:7502 gimplify.c:8811
+#: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
@@ -25171,13 +25219,13 @@ msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
 msgstr ""
 
-#: gimplify.c:8543 gimplify.c:12389
+#: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
 msgstr ""
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
-#: gimplify.c:12382
+#: gimplify.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause on %qs construct"
@@ -25188,148 +25236,148 @@ msgstr "尚未支援程式碼模式 %<large%>"
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:8979
+#: gimplify.c:8982
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:9153
+#: gimplify.c:9156
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: gimplify.c:9442
+#: gimplify.c:9445
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:9499
+#: gimplify.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:9527
+#: gimplify.c:9530
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:9703
+#: gimplify.c:9706
 #, gcc-internal-format
 msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
 msgstr ""
 
-#: gimplify.c:9913
+#: gimplify.c:9916
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:9962
+#: gimplify.c:9965
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10209
+#: gimplify.c:10212
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:10264
+#: gimplify.c:10267
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:10355
+#: gimplify.c:10358
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
 msgstr ""
 
-#: gimplify.c:10501
+#: gimplify.c:10505
 #, gcc-internal-format
 msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
 msgstr ""
 
-#: gimplify.c:10520
+#: gimplify.c:10524
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD 範本宣告無效"
 
-#: gimplify.c:10619
+#: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
 msgstr ""
 
-#: gimplify.c:10953
+#: gimplify.c:10957
 #, gcc-internal-format
 msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
 msgstr ""
 
-#: gimplify.c:11493 gimplify.c:11752
+#: gimplify.c:11441 gimplify.c:11700
 #, gcc-internal-format
 msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
 msgstr ""
 
-#: gimplify.c:12320
+#: gimplify.c:12268
 #, gcc-internal-format
 msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
 msgstr ""
 
-#: gimplify.c:12344
+#: gimplify.c:12292
 #, gcc-internal-format
 msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
 msgstr ""
 
-#: gimplify.c:12364
+#: gimplify.c:12312
 #, gcc-internal-format
 msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
 msgstr ""
 
-#: gimplify.c:12416
+#: gimplify.c:12364
 #, gcc-internal-format
 msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
 msgstr ""
 
-#: gimplify.c:13274 omp-low.c:3254
+#: gimplify.c:13222 omp-low.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: gimplify.c:13292
+#: gimplify.c:13240
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:13305
+#: gimplify.c:13253
 #, gcc-internal-format
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:13318
+#: gimplify.c:13266
 #, gcc-internal-format
 msgid "more than one %<depend%> clause with %<source%> modifier on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:13329
+#: gimplify.c:13277
 #, gcc-internal-format
 msgid "%<depend%> clause with %<source%> modifier specified together with %<depend%> clauses with %<sink%> modifier on the same construct"
 msgstr ""
 
-#: gimplify.c:14619
+#: gimplify.c:14567
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失敗"
 
-#: gimplify.c:15170
+#: gimplify.c:15118
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "透過 %<...%> 傳遞時 %qT 被提升為 %qT"
 
-#: gimplify.c:15175
+#: gimplify.c:15123
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您應該向 %<va_arg%> 傳遞 %qT 而不是 %qT)"
 
-#: gimplify.c:15182
+#: gimplify.c:15130
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果執行到這段程式碼，程式將中止"
@@ -25407,7 +25455,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.c:504
+#: internal-fn.c:506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "無效的使用的 %<auto%>"
@@ -25685,48 +25733,48 @@ msgstr "陣列邊界不匹配"
 msgid "the extra base is defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: ipa-devirt.c:3852
+#: ipa-devirt.c:3855
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3861
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3891
+#: ipa-devirt.c:3894
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3899
+#: ipa-devirt.c:3902
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3907
+#: ipa-devirt.c:3910
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3918
+#: ipa-devirt.c:3921
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-fnsummary.c:4289
+#: ipa-fnsummary.c:4295
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "無效的函式在中 gimple 呼叫"
 
-#: ipa-fnsummary.c:4358
+#: ipa-fnsummary.c:4364
 #, fuzzy, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "ipa 內聯概要缺少在中輸入檔案"
@@ -25757,38 +25805,38 @@ msgstr "函式也許是 candidate 用於屬性 %<%s%>如果它是已知到回傳
 msgid "ipa reference summary is missing in ltrans unit"
 msgstr "ipa 參考概要缺少在中 ltrans 單位"
 
-#: ipa-sra.c:1468
+#: ipa-sra.c:1470
 #, gcc-internal-format
 msgid "Access offset before parent offset"
 msgstr ""
 
-#: ipa-sra.c:1473
+#: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
 msgstr ""
 
-#: ipa-sra.c:1478
+#: ipa-sra.c:1480
 #, gcc-internal-format
 msgid "Access terminates outside of its parent"
 msgstr ""
 
-#: ipa-sra.c:1490
+#: ipa-sra.c:1492
 #, gcc-internal-format
 msgid "Access overlaps with its sibling"
 msgstr ""
 
-#: ipa-sra.c:1509
+#: ipa-sra.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "verification failed: %s"
 msgid "IPA-SRA access verification failed"
 msgstr "驗證失敗：%s"
 
-#: ipa-sra.c:2470
+#: ipa-sra.c:2472
 #, gcc-internal-format
 msgid "Function %qs, parameter %u, has IPA-SRA accesses which overlap"
 msgstr ""
 
-#: ipa-sra.c:2473
+#: ipa-sra.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Function %s, parameter %u, is used but does not have any certain IPA-SRA access"
 msgstr ""
@@ -25841,57 +25889,57 @@ msgstr "一句 %<asm%> 中運算元約束不一致"
 msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "最大值條件儲存對數量該可以是 sunk"
 
-#: lto-cgraph.c:1110
+#: lto-cgraph.c:1118
 #, gcc-internal-format
 msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1115
+#: lto-cgraph.c:1123
 #, gcc-internal-format
 msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
 msgstr ""
 
-#: lto-cgraph.c:1280
+#: lto-cgraph.c:1288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "位元碼串流：找到多重實體的 cgraph 節點 %d"
 
-#: lto-cgraph.c:1456
+#: lto-cgraph.c:1464
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "位元碼串流：找不到任何呼叫者當讀取邊緣"
 
-#: lto-cgraph.c:1462
+#: lto-cgraph.c:1470
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "位元碼串流：找不到任何被呼叫端當讀取邊緣"
 
-#: lto-cgraph.c:1539
+#: lto-cgraph.c:1547
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "位元碼串流：找到清空 cgraph 節點"
 
-#: lto-cgraph.c:1655
+#: lto-cgraph.c:1663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "最多 %i 側寫檔運行被支援。也許已損壞側寫檔？"
 
-#: lto-cgraph.c:1680
+#: lto-cgraph.c:1688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "側寫檔資訊在中 %s 已損壞"
 
-#: lto-cgraph.c:1718
+#: lto-cgraph.c:1726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "找不到 LTO cgraph 在中 %s"
 
-#: lto-cgraph.c:1728
+#: lto-cgraph.c:1736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "找不到 LTO 區段 refs 在中 %s"
 
-#: lto-cgraph.c:1805
+#: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -26152,52 +26200,52 @@ msgstr ""
 msgid "%<depend%> clause with %<sink%> modifier refers to iteration never in the iteration space"
 msgstr ""
 
-#: omp-general.c:1751
+#: omp-general.c:1807
 #, gcc-internal-format
 msgid "%qs specifies a conflicting level of parallelism"
 msgstr ""
 
-#: omp-general.c:1754
+#: omp-general.c:1810
 #, fuzzy, gcc-internal-format
 msgid "... to the previous %qs clause here"
 msgstr "在之前使用的在此"
 
-#: omp-general.c:1785
+#: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
 msgstr ""
 
-#: omp-general.c:1827
+#: omp-general.c:1883
 #, gcc-internal-format
 msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1834
+#: omp-general.c:1890
 #, gcc-internal-format
 msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
 msgstr ""
 
-#: omp-general.c:1843
+#: omp-general.c:1899
 #, fuzzy, gcc-internal-format
 msgid "... with %qs clause here"
 msgstr "切換開始在此"
 
-#: omp-general.c:1851
+#: omp-general.c:1907
 #, gcc-internal-format
 msgid "... without %qs clause near to here"
 msgstr ""
 
-#: omp-low.c:2382 omp-offload.c:1205
+#: omp-low.c:2382 omp-offload.c:1215
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2385 omp-offload.c:1206
+#: omp-low.c:2385 omp-offload.c:1216
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2389 omp-offload.c:1240
+#: omp-low.c:2389 omp-offload.c:1250
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
@@ -26419,52 +26467,52 @@ msgstr "無效的條目到 OpenMP 結構化訊息塊"
 msgid "invalid branch to/from %s structured block"
 msgstr "無效的分支到/從 OpenMP 結構化訊息塊"
 
-#: omp-offload.c:663
+#: omp-offload.c:673
 #, gcc-internal-format
 msgid "%<-fopenacc-dim%> operand is malformed at %qs"
 msgstr ""
 
-#: omp-offload.c:1238
+#: omp-offload.c:1248
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-offload.c:1242 omp-offload.c:1274
+#: omp-offload.c:1252 omp-offload.c:1284
 #, gcc-internal-format
 msgid "containing loop here"
 msgstr ""
 
-#: omp-offload.c:1247
+#: omp-offload.c:1257
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1249
+#: omp-offload.c:1259
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
 msgstr ""
 
-#: omp-offload.c:1254
+#: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
 msgid "routine %qD declared here"
 msgstr "%qD 宣告的在此"
 
-#: omp-offload.c:1267
+#: omp-offload.c:1277
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
 msgstr ""
 
-#: omp-offload.c:1408
+#: omp-offload.c:1418
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
 msgstr ""
 
-#: omp-offload.c:1416
+#: omp-offload.c:1426
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
 msgstr ""
 
-#: omp-offload.c:1418
+#: omp-offload.c:1428
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
 msgstr ""
@@ -27831,140 +27879,140 @@ msgstr "-fstack-protector 在此目標平臺上不受支援"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: toplev.c:1496
+#: toplev.c:1501
 #, gcc-internal-format
 msgid "instruction scheduling not supported on this target machine"
 msgstr "指令調度在此目標平臺上不受支援"
 
-#: toplev.c:1500
+#: toplev.c:1505
 #, gcc-internal-format
 msgid "this target machine does not have delayed branches"
 msgstr "此目標平臺沒有延遲轉移指令"
 
-#: toplev.c:1514
+#: toplev.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore 在此目標平臺上不受支援"
 
-#: toplev.c:1559
+#: toplev.c:1564
 #, fuzzy, gcc-internal-format
 msgid "could not close zeroed insn dump file %qs: %m"
 msgstr "無法關閉零的 insn 傾印檔案 %qs：%m"
 
-#: toplev.c:1594
+#: toplev.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the \"%s\" debug format"
 msgid "target system does not support the %qs debug format"
 msgstr "目的系統不支援「%s」除錯格式"
 
-#: toplev.c:1607
+#: toplev.c:1612
 #, fuzzy, gcc-internal-format
 msgid "variable tracking requested, but useless unless producing debug info"
 msgstr "變數追蹤要求的，但是無用的除非產生除錯資訊"
 
-#: toplev.c:1611
+#: toplev.c:1616
 #, fuzzy, gcc-internal-format
 msgid "variable tracking requested, but not supported by this debug format"
 msgstr "變數追蹤要求的，並不是支援的由這個除錯格式"
 
-#: toplev.c:1650
+#: toplev.c:1655
 #, fuzzy, gcc-internal-format
 msgid "var-tracking-assignments changes selective scheduling"
 msgstr "var-tracking-assignments 變更選擇性排程"
 
-#: toplev.c:1681
+#: toplev.c:1686
 #, gcc-internal-format
 msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1697
+#: toplev.c:1702
 #, gcc-internal-format
 msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
 msgstr ""
 
-#: toplev.c:1707
+#: toplev.c:1712
 #, gcc-internal-format
 msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
 msgstr ""
 
-#: toplev.c:1736
+#: toplev.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections 在此目標平臺上不受支援"
 
-#: toplev.c:1742
+#: toplev.c:1747
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections 在此目標平臺上不受支援"
 
-#: toplev.c:1750
+#: toplev.c:1755
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays 在此目標平臺上不受支援"
 
-#: toplev.c:1756
+#: toplev.c:1761
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays 在此目標平臺上不受支援(嘗試 -march 開關)"
 
-#: toplev.c:1766
+#: toplev.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays 不支援與 -Os 並用"
 
-#: toplev.c:1778
+#: toplev.c:1783
 #, fuzzy, gcc-internal-format
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math 已停用；其他選項需優先權"
 
-#: toplev.c:1788
+#: toplev.c:1793
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
 msgstr ""
 
-#: toplev.c:1798
+#: toplev.c:1803
 #, gcc-internal-format
 msgid "%<-fstack-check=%> and %<-fstack-clash_protection%> are mutually exclusive; disabling %<-fstack-check=%>"
 msgstr ""
 
-#: toplev.c:1816
+#: toplev.c:1821
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector 在此目標平臺上不受支援"
 
-#: toplev.c:1828
+#: toplev.c:1833
 #, fuzzy, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fdata-sections 在此目標平臺上不受支援"
 
-#: toplev.c:2132
+#: toplev.c:2137
 #, gcc-internal-format
 msgid "error writing to %s: %m"
 msgstr "寫入 %s 時發生錯誤：%m"
 
-#: toplev.c:2134
+#: toplev.c:2139
 #, gcc-internal-format
 msgid "error closing %s: %m"
 msgstr "關閉 %s 時發生錯誤：%m"
 
-#: toplev.c:2251
+#: toplev.c:2256
 #, gcc-internal-format
 msgid "mpfr not configured to handle all floating modes"
 msgstr ""
 
-#: toplev.c:2327
+#: toplev.c:2332
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with %<-E%>"
 msgstr "%qs 是不相容的與 %qs"
 
-#: toplev.c:2342
+#: toplev.c:2347
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -28059,175 +28107,175 @@ msgstr "%Kasm 不允許在中 %<transaction_safe%> 函式"
 msgid "ignoring loop annotation"
 msgstr ""
 
-#: tree-cfg.c:2968
+#: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "常數無法 recomputed 時 ADDR_EXPR 變更"
 
-#: tree-cfg.c:2973
+#: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "副作用無法 recomputed 時 ADDR_EXPR 變更"
 
-#: tree-cfg.c:2988
+#: tree-cfg.c:3018
 #, fuzzy, gcc-internal-format
 msgid "%<DECL_GIMPLE_REG_P%> set on a variable with address taken"
 msgstr "DECL_GIMPLE_REG_P 設定於變數與位址佔用"
 
-#: tree-cfg.c:2994
+#: tree-cfg.c:3024
 #, fuzzy, gcc-internal-format
 msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
 msgstr "位址佔用，但是 ADDRESSABLE 位元無法設定"
 
-#: tree-cfg.c:3016
+#: tree-cfg.c:3046
 #, fuzzy, gcc-internal-format
 msgid "invalid expression for min lvalue"
 msgstr "無效的運算式用於最小 lvalue"
 
-#: tree-cfg.c:3027
+#: tree-cfg.c:3057
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in indirect reference"
 msgstr "無效的運算元在中間接參考"
 
-#: tree-cfg.c:3052
+#: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
 msgid "non-scalar %qs"
 msgstr "non-scalar 型態"
 
-#: tree-cfg.c:3066
+#: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size operand to %qs"
 msgstr "無效的位置或大小運算元到 BIT_FIELD_REF"
 
-#: tree-cfg.c:3072
+#: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
 msgid "integral result type precision does not match field size of %qs"
 msgstr "積分結果型態精確度不匹配欄位大小的 BIT_FIELD_REF"
 
-#: tree-cfg.c:3081
+#: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "模式精確度的 non-integral 結果不匹配欄位大小的 BIT_FIELD_REF"
 
-#: tree-cfg.c:3089
+#: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
 msgid "%qs of non-mode-precision operand"
 msgstr "Shift 的 non-integer 運算元"
 
-#: tree-cfg.c:3096
+#: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "無效的位置或大小運算元到 BIT_FIELD_REF"
 
-#: tree-cfg.c:3107
+#: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs reference"
 msgstr "型態不匹配在中陣列參照"
 
-#: tree-cfg.c:3123
+#: tree-cfg.c:3153
 #, gcc-internal-format
 msgid "non-top-level %qs"
 msgstr ""
 
-#: tree-cfg.c:3138
+#: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "%%R 的運算元無效"
 
-#: tree-cfg.c:3149 tree-cfg.c:3158 tree-cfg.c:3175 tree-cfg.c:3809
-#: tree-cfg.c:3838 tree-cfg.c:3855 tree-cfg.c:3876 tree-cfg.c:3922
-#: tree-cfg.c:3943 tree-cfg.c:3997 tree-cfg.c:4017 tree-cfg.c:4053
-#: tree-cfg.c:4074 tree-cfg.c:4106 tree-cfg.c:4182 tree-cfg.c:4214
-#: tree-cfg.c:4226 tree-cfg.c:4285 tree-cfg.c:4310 tree-cfg.c:4383
-#: tree-cfg.c:4461
+#: tree-cfg.c:3179 tree-cfg.c:3188 tree-cfg.c:3205 tree-cfg.c:3839
+#: tree-cfg.c:3868 tree-cfg.c:3885 tree-cfg.c:3906 tree-cfg.c:3952
+#: tree-cfg.c:3973 tree-cfg.c:4027 tree-cfg.c:4047 tree-cfg.c:4083
+#: tree-cfg.c:4104 tree-cfg.c:4136 tree-cfg.c:4212 tree-cfg.c:4244
+#: tree-cfg.c:4256 tree-cfg.c:4315 tree-cfg.c:4340 tree-cfg.c:4413
+#: tree-cfg.c:4491
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs"
 msgstr "型態不匹配在中 nontype 參數包裝"
 
-#: tree-cfg.c:3169
+#: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
 msgid "invalid %qs offset operator"
 msgstr "無效的偏移運算元的 MEM_REF"
 
-#: tree-cfg.c:3193
+#: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "轉換的 SSA_NAME 左側的手側邊"
 
-#: tree-cfg.c:3201
+#: tree-cfg.c:3231
 #, fuzzy, gcc-internal-format
 msgid "conversion of register to a different size in %qs"
 msgstr "轉換的暫存器到不同的大小"
 
-#: tree-cfg.c:3221 tree-cfg.c:3247
+#: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
 msgid "invalid address operand in %qs"
 msgstr "無效的位址運算元在中 MEM_REF"
 
-#: tree-cfg.c:3228 tree-cfg.c:3254
+#: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
 msgid "invalid offset operand in %qs"
 msgstr "無效的偏移運算元在中 MEM_REF"
 
-#: tree-cfg.c:3235 tree-cfg.c:3261
+#: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "錯誤地使用了 %qD"
 
-#: tree-cfg.c:3268 tree-cfg.c:4473
+#: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
 #| msgid "simple IF"
 msgid "%qs in gimple IL"
 msgstr "簡單的 IF"
 
-#: tree-cfg.c:3321
+#: tree-cfg.c:3351
 #, fuzzy, gcc-internal-format
 msgid "gimple call has two targets"
 msgstr "gimple 呼叫有兩目標"
 
-#: tree-cfg.c:3330
+#: tree-cfg.c:3360
 #, fuzzy, gcc-internal-format
 msgid "gimple call has no target"
 msgstr "gimple 呼叫沒有任何目標"
 
-#: tree-cfg.c:3337
+#: tree-cfg.c:3367
 #, fuzzy, gcc-internal-format
 msgid "invalid function in gimple call"
 msgstr "無效的函式在中 gimple 呼叫"
 
-#: tree-cfg.c:3347
+#: tree-cfg.c:3377
 #, fuzzy, gcc-internal-format
 msgid "non-function in gimple call"
 msgstr "non-function 在中 gimple 呼叫"
 
-#: tree-cfg.c:3358
+#: tree-cfg.c:3388
 #, fuzzy, gcc-internal-format
 msgid "invalid pure const state for function"
 msgstr "無效的 pure 常數狀態用於函式"
 
-#: tree-cfg.c:3367
+#: tree-cfg.c:3397
 #, fuzzy, gcc-internal-format
 msgid "invalid LHS in gimple call"
 msgstr "無效的 LHS 在中 gimple 呼叫"
 
-#: tree-cfg.c:3375
+#: tree-cfg.c:3405
 #, fuzzy, gcc-internal-format
 msgid "LHS in %<noreturn%> call"
 msgstr "LHS 在中 noreturn 呼叫"
 
-#: tree-cfg.c:3389
+#: tree-cfg.c:3419
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in gimple call"
 msgstr "無效的轉換在中 gimple 呼叫"
 
-#: tree-cfg.c:3398
+#: tree-cfg.c:3428
 #, fuzzy, gcc-internal-format
 msgid "invalid static chain in gimple call"
 msgstr "無效的靜態鏈接在中 gimple 呼叫"
 
-#: tree-cfg.c:3409
+#: tree-cfg.c:3439
 #, fuzzy, gcc-internal-format
 msgid "static chain with function that doesn%'t use one"
 msgstr "靜態鏈接與函式該 doesn%'t 使用一個"
@@ -28238,516 +28286,516 @@ msgstr "靜態鏈接與函式該 doesn%'t 使用一個"
 #. __builtin_unreachable internally, for example when IPA figures
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
-#: tree-cfg.c:3427
+#: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: tree-cfg.c:3450
+#: tree-cfg.c:3480
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to gimple call"
 msgstr "無效的引數到 gimple 呼叫"
 
-#: tree-cfg.c:3470
+#: tree-cfg.c:3500
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in gimple comparison"
 msgstr "無效的運算元在中 gimple 比較"
 
-#: tree-cfg.c:3486
+#: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
 msgid "mismatching comparison operand types"
 msgstr "不匹配比較運算元類型"
 
-#: tree-cfg.c:3503
+#: tree-cfg.c:3533
 #, fuzzy, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
 msgstr "無效的向量比較所產生的型態"
 
-#: tree-cfg.c:3518
+#: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
 msgid "non-vector operands in vector comparison"
 msgstr "non-vector 運算元在中向量比較"
 
-#: tree-cfg.c:3527
+#: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
 msgid "invalid vector comparison resulting type"
 msgstr "無效的向量比較所產生的型態"
 
-#: tree-cfg.c:3534
+#: tree-cfg.c:3564
 #, fuzzy, gcc-internal-format
 msgid "bogus comparison result type"
 msgstr "假造的比較結果型態"
 
-#: tree-cfg.c:3556
+#: tree-cfg.c:3586
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of unary operation"
 msgstr "non-register 做為 LHS 的一元作業"
 
-#: tree-cfg.c:3562
+#: tree-cfg.c:3592
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in unary operation"
 msgstr "無效的運算元在中一元作業"
 
-#: tree-cfg.c:3585
+#: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
 msgid "invalid vector types in nop conversion"
 msgstr "無效的類型在中 nop 轉換"
 
-#: tree-cfg.c:3614
+#: tree-cfg.c:3644
 #, fuzzy, gcc-internal-format
 msgid "invalid types in nop conversion"
 msgstr "無效的類型在中 nop 轉換"
 
-#: tree-cfg.c:3629
+#: tree-cfg.c:3659
 #, fuzzy, gcc-internal-format
 msgid "invalid types in address space conversion"
 msgstr "無效的類型在中位址空間轉換"
 
-#: tree-cfg.c:3643
+#: tree-cfg.c:3673
 #, fuzzy, gcc-internal-format
 msgid "invalid types in fixed-point conversion"
 msgstr "無效的類型在中定點轉換"
 
-#: tree-cfg.c:3658
+#: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
 msgid "invalid types in conversion to floating-point"
 msgstr "無效的類型在中轉換到浮點數"
 
-#: tree-cfg.c:3673
+#: tree-cfg.c:3703
 #, fuzzy, gcc-internal-format
 msgid "invalid types in conversion to integer"
 msgstr "無效的類型在中轉換到整數"
 
-#: tree-cfg.c:3713
+#: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in %qs expression"
 msgstr "型態不匹配在中位址運算式"
 
-#: tree-cfg.c:3735
+#: tree-cfg.c:3765
 #, fuzzy, gcc-internal-format
 msgid "invalid types for %qs"
 msgstr "程式碼「%c」的運算元無效"
 
-#: tree-cfg.c:3746
+#: tree-cfg.c:3776
 #, gcc-internal-format
 msgid "%qs should be from a scalar to a like vector"
 msgstr ""
 
-#: tree-cfg.c:3760
+#: tree-cfg.c:3790
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in unary operation"
 msgstr "non-trivial 轉換在中一元作業"
 
-#: tree-cfg.c:3785
+#: tree-cfg.c:3815
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of binary operation"
 msgstr "non-register 做為 LHS 的二進運算"
 
-#: tree-cfg.c:3792
+#: tree-cfg.c:3822
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in binary operation"
 msgstr "無效的運算元在中二進運算"
 
-#: tree-cfg.c:3897
+#: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
 msgstr "無效的 non-vector 運算元到向量值的加上"
 
-#: tree-cfg.c:3908
+#: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "無效的指標模式 %qs"
 
-#: tree-cfg.c:4114
+#: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
 msgid "vector type expected in %qs"
 msgstr "向量類型預期的在中向量 permute 運算式"
 
-#: tree-cfg.c:4127
+#: tree-cfg.c:4157
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in binary expression"
 msgstr "型態不匹配在中二進位運算式"
 
-#: tree-cfg.c:4155
+#: tree-cfg.c:4185
 #, fuzzy, gcc-internal-format
 msgid "non-register as LHS of ternary operation"
 msgstr "non-register 做為 LHS 的三進作業"
 
-#: tree-cfg.c:4164
+#: tree-cfg.c:4194
 #, fuzzy, gcc-internal-format
 msgid "invalid operands in ternary operation"
 msgstr "無效的運算元在中三進作業"
 
-#: tree-cfg.c:4196
+#: tree-cfg.c:4226
 #, gcc-internal-format
 msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4238 tree-cfg.c:4297
+#: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
 msgid "vector types expected in %qs"
 msgstr "向量類型預期的在中向量 permute 運算式"
 
-#: tree-cfg.c:4253
+#: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
 msgid "vectors with different element number found in %qs"
 msgstr "向量與不同的元件號碼找到在中向量 permute 運算式"
 
-#: tree-cfg.c:4269
+#: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "無效的循環移位指令"
 
-#: tree-cfg.c:4329
+#: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "不支援的組合：%s"
 
-#: tree-cfg.c:4338
+#: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
 msgid "invalid position or size in %qs"
 msgstr "無效的位置或大小運算元到 BIT_FIELD_REF"
 
-#: tree-cfg.c:4344
+#: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
 msgid "%qs into non-mode-precision operand"
 msgstr "Shift 的 non-integer 運算元"
 
-#: tree-cfg.c:4354
+#: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: tree-cfg.c:4364
+#: tree-cfg.c:4394
 #, fuzzy, gcc-internal-format
 msgid "%qs not at element boundary"
 msgstr "%qD 並非型態"
 
-#: tree-cfg.c:4419
+#: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
 msgid "non-trivial conversion in %qs"
 msgstr "non-trivial 轉換於指派"
 
-#: tree-cfg.c:4428
+#: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
 msgid "%qs LHS in clobber statement"
 msgstr "在中敘述"
 
-#: tree-cfg.c:4447
+#: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R 的運算元無效"
 
-#: tree-cfg.c:4488 tree-cfg.c:4514
+#: tree-cfg.c:4518 tree-cfg.c:4544
 #, fuzzy, gcc-internal-format
 msgid "invalid RHS for gimple memory store: %qs"
 msgstr "無效的 rhs 用於 gimple 記憶體儲存"
 
-#: tree-cfg.c:4548 tree-cfg.c:4566
+#: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "左移次數大於或等於類型寬度"
 
-#: tree-cfg.c:4557 tree-cfg.c:4574
+#: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of vector %qs elements"
 msgstr "不正確引數數量到函式 %qE"
 
-#: tree-cfg.c:4582
+#: tree-cfg.c:4612
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
 msgstr ""
 
-#: tree-cfg.c:4591
+#: tree-cfg.c:4621
 #, gcc-internal-format
 msgid "vector %qs with non-NULL element index"
 msgstr ""
 
-#: tree-cfg.c:4598
+#: tree-cfg.c:4628
 #, gcc-internal-format
 msgid "vector %qs element is not a GIMPLE value"
 msgstr ""
 
-#: tree-cfg.c:4607
+#: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
 msgid "non-vector %qs with elements"
 msgstr "比較向量與不同的元件類型"
 
-#: tree-cfg.c:4618
+#: tree-cfg.c:4648
 #, fuzzy, gcc-internal-format
 msgid "%qs with an always-false condition"
 msgstr "ASSERT_EXPR 與 always-false 條件"
 
-#: tree-cfg.c:4677
+#: tree-cfg.c:4707
 #, fuzzy, gcc-internal-format
 msgid "invalid operand in return statement"
 msgstr "無效的運算元在中回傳敘述"
 
-#: tree-cfg.c:4692 c/gimple-parser.c:2422
+#: tree-cfg.c:4722 c/gimple-parser.c:2422
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion in return statement"
 msgstr "無效的轉換在中回傳敘述"
 
-#: tree-cfg.c:4716
+#: tree-cfg.c:4746
 #, fuzzy, gcc-internal-format
 msgid "goto destination is neither a label nor a pointer"
 msgstr "前往目的是 neither 標貼 nor 指標"
 
-#: tree-cfg.c:4735
+#: tree-cfg.c:4765
 #, fuzzy, gcc-internal-format
 msgid "invalid operand to switch statement"
 msgstr "無效的運算元到開關敘述"
 
-#: tree-cfg.c:4743
+#: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
 msgid "non-integral type switch statement"
 msgstr "無效的運算元到開關敘述"
 
-#: tree-cfg.c:4753
+#: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
 msgid "invalid default case label in switch statement"
 msgstr "%<default%> 標籤未出現在 switch 敘述內"
 
-#: tree-cfg.c:4765
+#: tree-cfg.c:4795
 #, fuzzy, gcc-internal-format
 msgid "invalid %<CASE_CHAIN%>"
 msgstr "無效的 CASE_CHAIN"
 
-#: tree-cfg.c:4771
+#: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
 msgid "invalid case label in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4778
+#: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
 msgid "invalid case range in switch statement"
 msgstr "無效的運算元到開關敘述"
 
-#: tree-cfg.c:4788
+#: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4798
+#: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
 msgid "type precision mismatch in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4807
+#: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted in switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: tree-cfg.c:4850
+#: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
 #| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: tree-cfg.c:4859
+#: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "不正確條目在中 label_to_block_map"
 
-#: tree-cfg.c:4869
+#: tree-cfg.c:4899
 #, fuzzy, gcc-internal-format
 msgid "incorrect setting of landing pad number"
 msgstr "不正確集合降落填充數字"
 
-#: tree-cfg.c:4885
+#: tree-cfg.c:4915
 #, fuzzy, gcc-internal-format
 msgid "invalid comparison code in gimple cond"
 msgstr "無效的比較編碼在中 gimple cond"
 
-#: tree-cfg.c:4893
+#: tree-cfg.c:4923
 #, fuzzy, gcc-internal-format
 msgid "invalid labels in gimple cond"
 msgstr "無效的標貼在中 gimple cond"
 
-#: tree-cfg.c:4976 tree-cfg.c:4985
+#: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> result"
 msgstr "無效的 PHI 結果"
 
-#: tree-cfg.c:4995
+#: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
 msgid "missing %<PHI%> def"
 msgstr "缺少PHI def"
 
-#: tree-cfg.c:5009
+#: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
 msgid "invalid %<PHI%> argument"
 msgstr "無效的 PHI 引數"
 
-#: tree-cfg.c:5016
+#: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "不相容的類型在中 PHI 引數 %u"
 
-#: tree-cfg.c:5114
+#: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
 msgid "%<verify_gimple%> failed"
 msgstr "verifygimple 失敗(_G)"
 
-#: tree-cfg.c:5171
+#: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
 msgid "dead statement in EH table"
 msgstr "dead STMT 在中 EH 表格"
 
-#: tree-cfg.c:5187
+#: tree-cfg.c:5217
 #, gcc-internal-format
 msgid "location references block not in block tree"
 msgstr ""
 
-#: tree-cfg.c:5236
+#: tree-cfg.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "local declaration from a different function"
 msgstr "隱含宣告函式 %qE"
 
-#: tree-cfg.c:5339
+#: tree-cfg.c:5369
 #, fuzzy, gcc-internal-format
 msgid "gimple_bb (phi) is set to a wrong basic block"
 msgstr "gimplebb (phi) 是設定為錯誤的基本區塊(_B)"
 
-#: tree-cfg.c:5348
+#: tree-cfg.c:5378
 #, fuzzy, gcc-internal-format
 msgid "PHI node with location"
 msgstr "從這個地方"
 
-#: tree-cfg.c:5359 tree-cfg.c:5406
+#: tree-cfg.c:5389 tree-cfg.c:5436
 #, gcc-internal-format
 msgid "incorrect sharing of tree nodes"
 msgstr "對樹結區段的共享不正確"
 
-#: tree-cfg.c:5367
+#: tree-cfg.c:5397
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
 msgstr ""
 
-#: tree-cfg.c:5394
+#: tree-cfg.c:5424
 #, fuzzy, gcc-internal-format
 msgid "gimple_bb (stmt) is set to a wrong basic block"
 msgstr "gimplebb (stmt) 是設定為錯誤的基本區塊(_B)"
 
-#: tree-cfg.c:5434
+#: tree-cfg.c:5464
 #, fuzzy, gcc-internal-format
 msgid "statement marked for throw, but doesn%'t"
 msgstr "敘述標記的用於丟擲，但是 doesn%'t"
 
-#: tree-cfg.c:5440
+#: tree-cfg.c:5470
 #, fuzzy, gcc-internal-format
 msgid "statement marked for throw in middle of block"
 msgstr "敘述標記的用於丟擲在中中間的區塊"
 
-#: tree-cfg.c:5462
+#: tree-cfg.c:5492
 #, fuzzy, gcc-internal-format
 msgid "verify_gimple failed"
 msgstr "verifygimple 失敗(_G)"
 
-#: tree-cfg.c:5484
+#: tree-cfg.c:5514
 #, fuzzy, gcc-internal-format
 msgid "ENTRY_BLOCK has IL associated with it"
 msgstr "ENTRY_BLOCK 有 IL 關聯的與它"
 
-#: tree-cfg.c:5491
+#: tree-cfg.c:5521
 #, fuzzy, gcc-internal-format
 msgid "EXIT_BLOCK has IL associated with it"
 msgstr "EXIT_BLOCK 有 IL 關聯的與它"
 
-#: tree-cfg.c:5498
+#: tree-cfg.c:5528
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fallthru to exit from bb %d"
 msgstr "fallthru 到離開從 bb %d"
 
-#: tree-cfg.c:5522
+#: tree-cfg.c:5552
 #, fuzzy, gcc-internal-format
 msgid "nonlocal label "
 msgstr "nonlocal 標貼 "
 
-#: tree-cfg.c:5531
+#: tree-cfg.c:5561
 #, fuzzy, gcc-internal-format
 msgid "EH landing pad label "
 msgstr "EH 降落填充標貼 "
 
-#: tree-cfg.c:5540 tree-cfg.c:5549 tree-cfg.c:5574
+#: tree-cfg.c:5570 tree-cfg.c:5579 tree-cfg.c:5604
 #, fuzzy, gcc-internal-format
 msgid "label "
 msgstr "標貼 "
 
-#: tree-cfg.c:5564
+#: tree-cfg.c:5594
 #, gcc-internal-format, gfc-internal-format
 msgid "control flow in the middle of basic block %d"
 msgstr "基本區塊 %d 中出現流程控制"
 
-#: tree-cfg.c:5597
+#: tree-cfg.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fallthru 邊緣之後控制敘述在中 bb %d"
 
-#: tree-cfg.c:5610
+#: tree-cfg.c:5640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
 msgstr "真/假邊緣之後 non-GIMPLE_COND 在中 bb %d"
 
-#: tree-cfg.c:5633 tree-cfg.c:5655 tree-cfg.c:5672 tree-cfg.c:5741
+#: tree-cfg.c:5663 tree-cfg.c:5685 tree-cfg.c:5702 tree-cfg.c:5771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong outgoing edge flags at end of bb %d"
 msgstr "錯誤的外送的郵件邊緣旗標於結束的 bb %d"
 
-#: tree-cfg.c:5643
+#: tree-cfg.c:5673
 #, gcc-internal-format, gfc-internal-format
 msgid "explicit goto at end of bb %d"
 msgstr "基本區塊 %d 末尾明確的 goto"
 
-#: tree-cfg.c:5677
+#: tree-cfg.c:5707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "return edge does not point to exit in bb %d"
 msgstr "回傳邊緣不點到離開在中 bb %d"
 
-#: tree-cfg.c:5707
+#: tree-cfg.c:5737
 #, fuzzy, gcc-internal-format
 msgid "found default case not at the start of case vector"
 msgstr "找到預設大小寫無法於開始的大小寫向量"
 
-#: tree-cfg.c:5715
+#: tree-cfg.c:5745
 #, fuzzy, gcc-internal-format
 msgid "case labels not sorted: "
 msgstr "大小寫標貼無法排序："
 
-#: tree-cfg.c:5732
+#: tree-cfg.c:5762
 #, gcc-internal-format, gfc-internal-format
 msgid "extra outgoing edge %d->%d"
 msgstr "多餘的出邊 %d->%d"
 
-#: tree-cfg.c:5755
+#: tree-cfg.c:5785
 #, gcc-internal-format, gfc-internal-format
 msgid "missing edge %i->%i"
 msgstr "缺少邊 %i->%i"
 
-#: tree-cfg.c:9383
+#: tree-cfg.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> 函式做回傳"
 
-#: tree-cfg.c:9404 tree-cfg.c:9436
+#: tree-cfg.c:9434 tree-cfg.c:9466
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "控制達到結束的 non-void 函式"
 
-#: tree-cfg.c:9502
+#: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: tree-cfg.c:9507 cp/cvt.c:1111
+#: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "忽略傳回值的函式宣告的與屬性 warn_unused_result"
@@ -28762,47 +28810,47 @@ msgstr "%q+D 重定義"
 msgid "in expansion of macro %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: tree-eh.c:4894
+#: tree-eh.c:4904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i 有多重 EH 邊緣"
 
-#: tree-eh.c:4906
+#: tree-eh.c:4916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
 msgstr "BB %i 無法丟擲但是有 EH 邊緣"
 
-#: tree-eh.c:4914
+#: tree-eh.c:4924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i 最後一筆敘述有不正確設定 lp"
 
-#: tree-eh.c:4920
+#: tree-eh.c:4930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "BB %i 缺少 EH 邊緣"
 
-#: tree-eh.c:4926
+#: tree-eh.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "不正確 EH 邊緣 %i->%i"
 
-#: tree-eh.c:4960 tree-eh.c:4979
+#: tree-eh.c:4970 tree-eh.c:4989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "BB %i 缺少邊緣"
 
-#: tree-eh.c:4996
+#: tree-eh.c:5006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i 太多 fallthru 邊緣"
 
-#: tree-eh.c:5005
+#: tree-eh.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i 有不正確邊緣"
 
-#: tree-eh.c:5011
+#: tree-eh.c:5021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i 有不正確 fallthru 邊緣"
@@ -29309,12 +29357,12 @@ msgstr "stmt (%p) 標記的已修改之後最佳化回合："
 msgid "verify_ssa failed"
 msgstr "verify_ssa 失敗"
 
-#: tree-streamer-in.c:353
+#: tree-streamer-in.c:354
 #, fuzzy, gcc-internal-format
 msgid "machine independent builtin code out of range"
 msgstr "機器獨立內建編碼超出範圍"
 
-#: tree-streamer-in.c:359
+#: tree-streamer-in.c:360
 #, fuzzy, gcc-internal-format
 msgid "target specific builtin not available"
 msgstr "目標特定的內建無法使用"
@@ -29379,7 +29427,7 @@ msgstr "陣列下標超出陣列邊界"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: tree-vrp.c:3656 tree-vrp.c:3923 tree-vrp.c:4033
+#: tree-vrp.c:3656 tree-vrp.c:3909 tree-vrp.c:4019
 #, gcc-internal-format
 msgid "while referencing %qD"
 msgstr ""
@@ -29389,27 +29437,27 @@ msgstr ""
 msgid "defined here %qD"
 msgstr "聯合定義的在此"
 
-#: tree-vrp.c:3913
+#: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: tree-vrp.c:3918
+#: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: tree-vrp.c:3940
+#: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: tree-vrp.c:4011
+#: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "陣列下標是下列的陣列邊界"
 
-#: tree-vrp.c:4025
+#: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "陣列下標是以上的陣列邊界"
@@ -29484,32 +29532,32 @@ msgstr "樹檢查：存取的運算元 %d 的 %s 與 %d 運算元在中 %s，於
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 ompclause %s 與 %d 運算元在中 %s(_C)，於 %s:%d"
 
-#: tree.c:13077
+#: tree.c:13079
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.c:13080
+#: tree.c:13082
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.c:13103
+#: tree.c:13105
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.c:13106
+#: tree.c:13108
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.c:13112
+#: tree.c:13114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型態被不宜用：%s"
 
-#: tree.c:13115
+#: tree.c:13117
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "類型已過時"
@@ -29534,232 +29582,232 @@ msgstr "類型已過時"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13883
+#: tree.c:13894
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13924
+#: tree.c:13935
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13926
+#: tree.c:13937
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13928
+#: tree.c:13939
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.c:13951
+#: tree.c:13962
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.c:13964
+#: tree.c:13975
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.c:14000
+#: tree.c:14011
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14002
+#: tree.c:14013
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14004
+#: tree.c:14015
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.c:14043
+#: tree.c:14054
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.c:14045
+#: tree.c:14056
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "%s：時間戳記與圖檔案不匹配\n"
 
-#: tree.c:14047
+#: tree.c:14058
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:14064
+#: tree.c:14075
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14066 tree.c:14077
+#: tree.c:14077 tree.c:14088
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14068 tree.c:14079
+#: tree.c:14079 tree.c:14090
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.c:14075
+#: tree.c:14086
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%qD 不是相容與 %qD"
 
-#: tree.c:14387
+#: tree.c:14398
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "環境變數 %qs 無法定義"
 
-#: tree.c:14392
+#: tree.c:14403
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14404
+#: tree.c:14415
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.c:14423
+#: tree.c:14434
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14431
+#: tree.c:14442
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.c:14437
+#: tree.c:14448
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.c:14453
+#: tree.c:14464
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.c:14463
+#: tree.c:14474
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.c:14473
+#: tree.c:14484
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.c:14494
+#: tree.c:14505
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.c:14500
+#: tree.c:14511
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.c:14511
+#: tree.c:14522
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14522
+#: tree.c:14533
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.c:14540
+#: tree.c:14551
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14547
+#: tree.c:14558
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.c:14554
+#: tree.c:14565
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14570
+#: tree.c:14581
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.c:14578
+#: tree.c:14589
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.c:14586
+#: tree.c:14597
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.c:14596
+#: tree.c:14607
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: tree.c:14605
+#: tree.c:14616
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: tree.c:14627
+#: tree.c:14638
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.c:14642
+#: tree.c:14653
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.c:14649
+#: tree.c:14660
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.c:14662
+#: tree.c:14673
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.c:14675
+#: tree.c:14686
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14681
+#: tree.c:14692
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.c:14688
+#: tree.c:14699
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.c:14700
+#: tree.c:14711
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.c:14710
+#: tree.c:14721
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -29888,87 +29936,87 @@ msgstr "%q+D 需要的對齊邊界大於實作的對齊邊界 %wu"
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D 的存儲大小不明"
 
-#: varasm.c:5004
+#: varasm.c:5003
 #, fuzzy, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "初始設定式用於整數/定點值太複雜"
 
-#: varasm.c:5009
+#: varasm.c:5008
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "浮點值的初始值設定不是一個浮點常數"
 
-#: varasm.c:5348
+#: varasm.c:5347
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "無效的初始值用於成員 %qE"
 
-#: varasm.c:5604
+#: varasm.c:5603
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D 的內聯宣告出現在其被呼叫之後"
 
-#: varasm.c:5656
+#: varasm.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%q+D 的弱宣告必須在定義之前"
 
-#: varasm.c:5692
+#: varasm.c:5691
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D 的弱宣告必須是公共的"
 
-#: varasm.c:5696
+#: varasm.c:5695
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "不支援 %q+D 的弱宣告"
 
-#: varasm.c:5725 varasm.c:6045
+#: varasm.c:5724 varasm.c:6044
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "此配置下只支援弱別名"
 
-#: varasm.c:5920
+#: varasm.c:5919
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref 未被支援在中這個組態"
 
-#: varasm.c:5948
+#: varasm.c:5947
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on this target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: varasm.c:6004
+#: varasm.c:6003
 #, fuzzy, gcc-internal-format
 #| msgid "-pg not supported on this platform"
 msgid "symver is only supported on ELF platforms"
 msgstr "-pg 在此平臺上不受支援"
 
-#: varasm.c:6023
+#: varasm.c:6022
 #, fuzzy, gcc-internal-format
 #| msgid "weakref %q+D ultimately targets itself"
 msgid "%qs symbol %q+D ultimately targets itself"
 msgstr "weakref %q+D 最終參照其自身"
 
-#: varasm.c:6025
+#: varasm.c:6024
 #, fuzzy, gcc-internal-format
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "weakref %q+D 必須有靜態鏈結"
 
-#: varasm.c:6032
+#: varasm.c:6031
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "別名定義不支援在中這個組態"
 
-#: varasm.c:6042
+#: varasm.c:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s 不為這個配置所支援"
 
-#: varasm.c:6260 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6259 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可見性屬性在此配置下不受支援；已忽略"
@@ -30571,7 +30619,7 @@ msgstr "%qE 屬性追隨 %qE"
 msgid "type was previously declared %qE"
 msgstr "型態是在之前宣告 %qE"
 
-#: c-family/c-attribs.c:3367 cp/class.c:4618
+#: c-family/c-attribs.c:3367 cp/class.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -30593,7 +30641,7 @@ msgstr "%qD 不是相容與 %qD"
 msgid "%qE argument is not a function"
 msgstr "cleanup 引數不是一個函式"
 
-#: c-family/c-attribs.c:3487 cp/name-lookup.c:5011
+#: c-family/c-attribs.c:3487 cp/name-lookup.c:5013
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "不宜用訊息並非字串"
@@ -30976,12 +31024,12 @@ msgstr "enum 常數定義的在此"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9371
+#: c-family/c-common.c:3460 cp/semantics.c:663 cp/typeck.c:9431
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建議在做為真值的賦值敘述前後加上括號"
 
-#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15201
+#: c-family/c-common.c:3547 c/c-decl.c:4620 c/c-decl.c:6798 c/c-typeck.c:15217
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "錯誤地使用了 %<restrict%>"
@@ -31138,12 +31186,12 @@ msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
 #: c-family/c-common.c:5854 c-family/c-common.c:6644 c-family/c-common.c:6691
-#: c-family/c-common.c:6764 c-family/c-common.c:6837 c/c-typeck.c:3660
+#: c-family/c-common.c:6766 c-family/c-common.c:6839 c/c-typeck.c:3660
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供給函式 %qE 的引數太少"
 
-#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6863
+#: c-family/c-common.c:5859 c-family/c-common.c:6697 c-family/c-common.c:6865
 #: c/c-typeck.c:3524
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
@@ -31245,7 +31293,7 @@ msgstr "索引 %E 指出偏移大於大小的 %qT"
 msgid "size of array is too large"
 msgstr "大小的陣列太大"
 
-#: c-family/c-common.c:6674 c-family/c-common.c:6796
+#: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
@@ -31257,127 +31305,127 @@ msgstr "引數 %d(屬於 %qE)類型不相容"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "傳遞參數 %d (屬於 %qE)時將整數賦給指標，未作類型轉換"
 
-#: c-family/c-common.c:6722
+#: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "左引數必須是切片"
 
-#: c-family/c-common.c:6930
+#: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "不正確引數數量到函式 %qE"
 
-#: c-family/c-common.c:6944
+#: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "引數 1 的 %qE 必須是 non-void 指標類型"
 
-#: c-family/c-common.c:6953
+#: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.c:6964
+#: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "引數 1 的 %qE 必須是指標到非零值大小物件"
 
-#: c-family/c-common.c:6985
+#: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.c:6993
+#: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.c:6999
+#: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.c:7007
+#: c-family/c-common.c:7009
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "大小不匹配在中引數 %d 的 %qE"
 
-#: c-family/c-common.c:7019
+#: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "non-integer 記憶體式樣引數 %d 的 %qE"
 
-#: c-family/c-common.c:7032
+#: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "無效的記憶體式樣引數 %d 的 %qE"
 
-#: c-family/c-common.c:7433
+#: c-family/c-common.c:7435
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.c:8053
+#: c-family/c-common.c:8055
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "索引值是超出約束"
 
-#: c-family/c-common.c:8095 c-family/c-common.c:8144 c-family/c-common.c:8160
+#: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:8248
+#: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: c-family/c-common.c:8268
+#: c-family/c-common.c:8270
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: c-family/c-common.c:8271
+#: c-family/c-common.c:8273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: c-family/c-common.c:8275
+#: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "大小的陣列 %qE 是負"
 
-#: c-family/c-common.c:8278
+#: c-family/c-common.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "陣列大小為負數"
 
-#: c-family/c-common.c:8283
+#: c-family/c-common.c:8285
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8286
+#: c-family/c-common.c:8288
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8291
+#: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "大小的陣列 %qE 是負"
 
-#: c-family/c-common.c:8294
+#: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.c:8365
+#: c-family/c-common.c:8367
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -31433,531 +31481,531 @@ msgstr "%qE 是一個無法辨識的格式字串函式類型"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "格式字串出現在待格式化的引數之後"
 
-#: c-family/c-format.c:1236
+#: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "函式可能是 %qs format 屬性的備選"
 
-#: c-family/c-format.c:1327 c-family/c-format.c:1348 c-family/c-format.c:2782
+#: c-family/c-format.c:1329 c-family/c-format.c:1350 c-family/c-format.c:2784
 #, gcc-internal-format
 msgid "missing $ operand number in format"
 msgstr "格式字串缺少 $ 運算元號"
 
-#: c-family/c-format.c:1357
+#: c-family/c-format.c:1359
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %%n$ operand number formats"
 msgstr "%s 不支援 %%n$ 運算元號格式字串"
 
-#: c-family/c-format.c:1364
+#: c-family/c-format.c:1366
 #, gcc-internal-format
 msgid "operand number out of range in format"
 msgstr "格式字元中運算元號越界"
 
-#: c-family/c-format.c:1387
+#: c-family/c-format.c:1389
 #, gcc-internal-format, gfc-internal-format
 msgid "format argument %d used more than once in %s format"
 msgstr "格式引數 %d 在 %s 格式字串中使用不止一次"
 
-#: c-family/c-format.c:1420
+#: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
 #| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$ 運算元號在不使用運算元號的格式後被使用"
 
-#: c-family/c-format.c:1451
+#: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
 #| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "格式引數 %d 在被使用的 $ 風格的格式引數 %d 前未被使用"
 
-#: c-family/c-format.c:1554
+#: c-family/c-format.c:1556
 #, gcc-internal-format
 msgid "format not a string literal, format string not checked"
 msgstr "格式字串不是一個字面字串，格式字串未被檢查"
 
-#: c-family/c-format.c:1569 c-family/c-format.c:1572
+#: c-family/c-format.c:1571 c-family/c-format.c:1574
 #, gcc-internal-format
 msgid "format not a string literal and no format arguments"
 msgstr "格式字串不是一個字面字串而且沒有待格式化的引數"
 
-#: c-family/c-format.c:1575
+#: c-family/c-format.c:1577
 #, gcc-internal-format
 msgid "format not a string literal, argument types not checked"
 msgstr "格式字串不是一個字面字串，沒有進行引數類型檢查"
 
-#: c-family/c-format.c:1592
+#: c-family/c-format.c:1594
 #, gcc-internal-format
 msgid "too many arguments for format"
 msgstr "提供給格式字串的引數太多"
 
-#: c-family/c-format.c:1597
+#: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "$ 風格的格式字串中有未使用的引數"
 
-#: c-family/c-format.c:1600
+#: c-family/c-format.c:1602
 #, gcc-internal-format, gfc-internal-format
 msgid "zero-length %s format string"
 msgstr "格式字串 %s 長度為 0"
 
-#: c-family/c-format.c:1604
+#: c-family/c-format.c:1606
 #, gcc-internal-format
 msgid "format is a wide character string"
 msgstr "格式字串是一個寬字串"
 
-#: c-family/c-format.c:1608
+#: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
 msgid "format string is not an array of type %qs"
 msgstr "格式字串引數並非字串型態"
 
-#: c-family/c-format.c:1611
+#: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
 msgstr "未終止的格式字串"
 
-#: c-family/c-format.c:2025
+#: c-family/c-format.c:2027
 #, gcc-internal-format
 msgid "%s used with %<%%%c%> %s format"
 msgstr "%s 與 %<%%%c%> %s 格式並用"
 
-#: c-family/c-format.c:2035
+#: c-family/c-format.c:2037
 #, gcc-internal-format, gfc-internal-format
 msgid "%s does not support %s"
 msgstr "%s 不支援 %s"
 
-#: c-family/c-format.c:2045
+#: c-family/c-format.c:2047
 #, gcc-internal-format
 msgid "%s does not support %s with the %<%%%c%> %s format"
 msgstr "%s 不支援 %s 出現在 %<%%%c%> %s 格式字串中"
 
-#: c-family/c-format.c:2059
+#: c-family/c-format.c:2061
 #, gcc-internal-format, gfc-internal-format
 msgid "%s used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:2072
+#: c-family/c-format.c:2074
 #, gcc-internal-format
 msgid "%qc conversion used unquoted"
 msgstr ""
 
-#: c-family/c-format.c:2190 c-family/c-format.c:2521
+#: c-family/c-format.c:2192 c-family/c-format.c:2523
 #, gcc-internal-format, gfc-internal-format
 msgid "repeated %s in format"
 msgstr "格式字串中有重複的 %s"
 
-#: c-family/c-format.c:2201
+#: c-family/c-format.c:2203
 #, gcc-internal-format
 msgid "missing fill character at end of strfmon format"
 msgstr "strfmon 格式字串末尾缺少填充字元"
 
-#: c-family/c-format.c:2303
+#: c-family/c-format.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "zero width in %s format"
 msgstr "%s 格式字串中欄位寬為 0"
 
-#: c-family/c-format.c:2326
+#: c-family/c-format.c:2328
 #, gcc-internal-format, gfc-internal-format
 msgid "empty left precision in %s format"
 msgstr "%s 格式字串中左精度為空"
 
-#: c-family/c-format.c:2417
+#: c-family/c-format.c:2419
 #, gcc-internal-format, gfc-internal-format
 msgid "empty precision in %s format"
 msgstr "%s 格式字串中精度為空"
 
-#: c-family/c-format.c:2495
+#: c-family/c-format.c:2497
 #, gcc-internal-format
 msgid "%s does not support the %qs %s length modifier"
 msgstr "%s 不支援 %qs %s 長度修飾符"
 
-#: c-family/c-format.c:2551
+#: c-family/c-format.c:2553
 #, gcc-internal-format
 msgid "unknown conversion type character %qc in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:2563
+#: c-family/c-format.c:2565
 #, gcc-internal-format
 msgid "%s does not support the %<%%%c%> %s format"
 msgstr "%s 不支援 %<%%%c%> %s 格式"
 
-#: c-family/c-format.c:2595
+#: c-family/c-format.c:2597
 #, gcc-internal-format
 msgid "%s ignored with %s and %<%%%c%> %s format"
 msgstr "%s 與 %s 和  %<%%%c%> %s 格式字串合用時被忽略"
 
-#: c-family/c-format.c:2600
+#: c-family/c-format.c:2602
 #, gcc-internal-format, gfc-internal-format
 msgid "%s ignored with %s in %s format"
 msgstr "%s 和 %s 出現在 %s 格式字串中時被忽略"
 
-#: c-family/c-format.c:2607
+#: c-family/c-format.c:2609
 #, gcc-internal-format
 msgid "use of %s and %s together with %<%%%c%> %s format"
 msgstr "同時使用 %s 和 %s，在 %<%%%c%> %s 格式字串中"
 
-#: c-family/c-format.c:2612
+#: c-family/c-format.c:2614
 #, gcc-internal-format, gfc-internal-format
 msgid "use of %s and %s together in %s format"
 msgstr "同時使用 %s 和 %s，在 %s 格式字串中"
 
-#: c-family/c-format.c:2639
+#: c-family/c-format.c:2641
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year in some locales"
 msgstr "%<%%%c%> 在某些區域設定下只給出 2 位表示的年分"
 
-#: c-family/c-format.c:2643
+#: c-family/c-format.c:2645
 #, gcc-internal-format
 msgid "%<%%%c%> yields only last 2 digits of year"
 msgstr "%<%%%c%> 只給出 2 位表示的年分"
 
-#: c-family/c-format.c:2670
+#: c-family/c-format.c:2672
 #, gcc-internal-format
 msgid "no closing %<]%> for %<%%[%> format"
 msgstr "%<%%[%> 格式沒有相對的 %<]%>"
 
-#: c-family/c-format.c:2699
+#: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "將 %qs 長度修飾符和%qc 類型字元一起使用"
 
-#: c-family/c-format.c:2721
+#: c-family/c-format.c:2723
 #, gcc-internal-format
 msgid "%s does not support the %<%%%s%c%> %s format"
 msgstr "%s 不支援 %<%%%s%c%> %s 格式"
 
-#: c-family/c-format.c:2759
+#: c-family/c-format.c:2761
 #, gcc-internal-format
 msgid "operand number specified with suppressed assignment"
 msgstr "為格式字串指定的運算元號取消了賦值"
 
-#: c-family/c-format.c:2763
+#: c-family/c-format.c:2765
 #, gcc-internal-format
 msgid "operand number specified for format taking no argument"
 msgstr "為格式字串指定的運算元號不帶參數"
 
-#: c-family/c-format.c:3113
+#: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "格式字串中有重複的 %s"
 
-#: c-family/c-format.c:3115
+#: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "格式字串中有重複的 %s"
 
-#: c-family/c-format.c:3116
+#: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
 #| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "格式字串嵌有 %<\\0%>"
 
-#: c-family/c-format.c:3119
+#: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qs instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: c-family/c-format.c:3171
+#: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
 msgid "unquoted attribute in format"
 msgstr "最佳化等級屬性不匹配"
 
-#: c-family/c-format.c:3184
+#: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "無效的引數到內建函式"
 
-#: c-family/c-format.c:3198
+#: c-family/c-format.c:3200
 #, gcc-internal-format
 msgid "unquoted identifier or keyword %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3226
+#: c-family/c-format.c:3228
 #, gcc-internal-format
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr ""
 
-#: c-family/c-format.c:3270
+#: c-family/c-format.c:3272
 #, gcc-internal-format
 msgid "quoted %qs directive in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3277 c-family/c-format.c:3548
+#: c-family/c-format.c:3279 c-family/c-format.c:3550
 #, gcc-internal-format
 msgid "contraction %<%.*s%> in format; use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3317
+#: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3330
+#: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "格式字串尾有可疑的 %<%%%>"
 
-#: c-family/c-format.c:3351
+#: c-family/c-format.c:3353
 #, fuzzy, gcc-internal-format
 msgid "inconsistent capitalization in format"
 msgstr "non-constant 初始化運算式於 %L"
 
-#: c-family/c-format.c:3358
+#: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3378
+#: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3385
+#: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3443
+#: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "格式字串尾有可疑的 %<%%%>"
 
-#: c-family/c-format.c:3503
+#: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3522
+#: c-family/c-format.c:3524
 #, gcc-internal-format
 msgid "unquoted preprocessing directive %<%.*s%> in format"
 msgstr ""
 
-#: c-family/c-format.c:3558
+#: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "格式字串中有重複的 %s"
 
-#: c-family/c-format.c:3560
+#: c-family/c-format.c:3562
 #, gcc-internal-format
 msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
 msgstr ""
 
-#: c-family/c-format.c:3572
+#: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "格式字串中有重複的 %s"
 
-#: c-family/c-format.c:3574
+#: c-family/c-format.c:3576
 #, gcc-internal-format
 msgid "use the apostrophe directive %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3586
+#: c-family/c-format.c:3588
 #, gcc-internal-format
 msgid "space followed by punctuation character %<%c%>"
 msgstr ""
 
-#: c-family/c-format.c:3597
+#: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "格式字串中有重複的 %s"
 
-#: c-family/c-format.c:3599
+#: c-family/c-format.c:3601
 #, gcc-internal-format
 msgid "if using %qs is not feasible, use %qs instead"
 msgstr ""
 
-#: c-family/c-format.c:3628
+#: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "格式字串尾有可疑的 %<%%%>"
 
-#: c-family/c-format.c:3668
+#: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
 #| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "格式字串尾有可疑的 %<%%%>"
 
-#: c-family/c-format.c:3685
+#: c-family/c-format.c:3687
 #, gcc-internal-format
 msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
 msgstr ""
 
-#: c-family/c-format.c:3705
+#: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
 msgid "unquoted non-graph characters in format"
 msgstr "Nonconforming 定位字元於 %C"
 
-#: c-family/c-format.c:3712
+#: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3744
+#: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3751
+#: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Do not generate #line directives"
 msgid "unterminated quoting directive"
 msgstr "不產生 #line 指令"
 
-#: c-family/c-format.c:3760
+#: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
 #| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "格式字串中出現無效的類型轉換字元 %qc"
 
-#: c-family/c-format.c:3830
+#: c-family/c-format.c:3832
 #, gcc-internal-format
 msgid "spurious trailing %<%%%> in format"
 msgstr "格式字串尾有可疑的 %<%%%>"
 
-#: c-family/c-format.c:3890
+#: c-family/c-format.c:3892
 #, gcc-internal-format
 msgid "conversion lacks type at end of format"
 msgstr "格式字串末尾的轉換缺少類型"
 
-#: c-family/c-format.c:3919
+#: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "處理 #ident 指令"
 
-#: c-family/c-format.c:3930
+#: c-family/c-format.c:3932
 #, gcc-internal-format
 msgid "unmatched quoting directive"
 msgstr ""
 
-#: c-family/c-format.c:3945
+#: c-family/c-format.c:3947
 #, gcc-internal-format
 msgid "%qc directive redundant after prior occurence of the same"
 msgstr ""
 
-#: c-family/c-format.c:3951
+#: c-family/c-format.c:3953
 #, gcc-internal-format
 msgid "unmatched color reset directive"
 msgstr ""
 
-#: c-family/c-format.c:3963
+#: c-family/c-format.c:3965
 #, gcc-internal-format
 msgid "%qc conversion used within a quoted sequence"
 msgstr ""
 
-#: c-family/c-format.c:4003
+#: c-family/c-format.c:4005
 #, gcc-internal-format
 msgid "embedded %<\\0%> in format"
 msgstr "格式字串嵌有 %<\\0%>"
 
-#: c-family/c-format.c:4019
+#: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated assembly dialect alternative"
 msgid "unterminated color directive"
 msgstr "未結束的組譯風格指示"
 
-#: c-family/c-format.c:4141
+#: c-family/c-format.c:4143
 #, gcc-internal-format, gfc-internal-format
 msgid "writing through null pointer (argument %d)"
 msgstr "對空指標參照內容的寫作業(引數 %d)"
 
-#: c-family/c-format.c:4152
+#: c-family/c-format.c:4154
 #, gcc-internal-format, gfc-internal-format
 msgid "reading through null pointer (argument %d)"
 msgstr "對空指標參照內容的讀作業(引數 %d)"
 
-#: c-family/c-format.c:4172
+#: c-family/c-format.c:4174
 #, gcc-internal-format, gfc-internal-format
 msgid "writing into constant object (argument %d)"
 msgstr "對常數物件的寫作業(引數 %d)"
 
-#: c-family/c-format.c:4184
+#: c-family/c-format.c:4186
 #, gcc-internal-format, gfc-internal-format
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "格式字串引數 %d 有多餘的類型限定"
 
-#: c-family/c-format.c:4726
+#: c-family/c-format.c:4728
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%>預期引數的型態 %<%s%s%>，但是引數 %d 有型態 %qT"
 
-#: c-family/c-format.c:4735
+#: c-family/c-format.c:4737
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%>預期匹配 %<%s%s%>引數"
 
-#: c-family/c-format.c:4745
+#: c-family/c-format.c:4747
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%>預期引數的型態 %<%T%s%>，但是引數 %d 有型態 %qT"
 
-#: c-family/c-format.c:4754
+#: c-family/c-format.c:4756
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%>預期匹配 %<%T%s%>引數"
 
-#: c-family/c-format.c:4816 c-family/c-format.c:4822 c-family/c-format.c:5015
+#: c-family/c-format.c:4818 c-family/c-format.c:4824 c-family/c-format.c:5017
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> 未被定義為一個類型"
 
-#: c-family/c-format.c:4829 c-family/c-format.c:5025
+#: c-family/c-format.c:4831 c-family/c-format.c:5027
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> 未被定義為 %<long%> 或 %<long long%>"
 
-#: c-family/c-format.c:4877
+#: c-family/c-format.c:4879
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> 未被定義為一個類型"
 
-#: c-family/c-format.c:4921
+#: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
 #| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> 未被定義為一個類型"
 
-#: c-family/c-format.c:4947
+#: c-family/c-format.c:4949
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> 未被定義為一個類型"
 
-#: c-family/c-format.c:4964
+#: c-family/c-format.c:4966
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> 未被定義為一個類型"
 
-#: c-family/c-format.c:4970
+#: c-family/c-format.c:4972
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: c-family/c-format.c:5200
+#: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "待格式化的引數不是 %<...%>"
 
-#: c-family/c-format.c:5212
+#: c-family/c-format.c:5214
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime 格式字串無法格式化引數"
@@ -32118,7 +32166,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.c:723 cp/semantics.c:9043
+#: c-family/c-omp.c:723 cp/semantics.c:9059
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -32133,17 +32181,17 @@ msgstr "無效的型態用於迭代變數 %qE"
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.c:765 cp/semantics.c:8932
+#: c-family/c-omp.c:765 cp/semantics.c:8948
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.c:871 cp/semantics.c:8551
+#: c-family/c-omp.c:871 cp/semantics.c:8567
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.c:878 cp/semantics.c:8938
+#: c-family/c-omp.c:878 cp/semantics.c:8954
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
@@ -32153,7 +32201,7 @@ msgstr "缺少遞增運算式"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.c:1009 cp/semantics.c:8666
+#: c-family/c-omp.c:1009 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -32780,7 +32828,7 @@ msgid "wrong type argument to %s"
 msgstr "錯誤的型態引數到 %s"
 
 #: c-family/c-warn.c:56 c-family/c-warn.c:69 cp/constexpr.c:2736
-#: cp/constexpr.c:5479
+#: cp/constexpr.c:5495
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常數運算式溢出"
@@ -33472,7 +33520,7 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr ""
 
 #: c-family/c-warn.c:2240 c/c-typeck.c:11993 c/c-typeck.c:12161
-#: cp/typeck.c:5266
+#: cp/typeck.c:5324
 #, fuzzy, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "比較介於類型 %qT 和 %qT"
@@ -33556,7 +33604,7 @@ msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
 msgstr[0] "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5688
+#: c-family/c-warn.c:2779 c/c-typeck.c:5485 cp/call.c:5690
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -33576,7 +33624,7 @@ msgstr ""
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
 msgstr ""
 
-#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:633
+#: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "聯合定義的在此"
@@ -33596,7 +33644,7 @@ msgstr "%qs 並非有效選項到前置處理器"
 msgid "too many input files"
 msgstr "輸入檔案太多"
 
-#: common/config/aarch64/aarch64-common.c:512 config/aarch64/aarch64.c:14359
+#: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "-mcpu 開關的值 %qs 錯誤"
@@ -33629,14 +33677,14 @@ msgid "unrecognized option passed to %%:target_mode_check"
 msgstr ""
 
 #: common/config/arm/arm-common.c:331 common/config/arm/arm-common.c:395
-#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14291
-#: config/aarch64/aarch64.c:14329
+#: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
+#: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
-#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14294
+#: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -34172,401 +34220,408 @@ msgstr "別名定義不支援在中 Mach-O; 忽略"
 msgid "profiler support for VxWorks"
 msgstr "對 VxWorks 的取樣支援"
 
-#: config/aarch64/aarch64-builtins.c:1439
-#: config/aarch64/aarch64-builtins.c:1669 config/arm/arm-builtins.c:3105
+#: config/aarch64/aarch64-builtins.c:1445
+#: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引數必須是常數"
 
-#: config/aarch64/aarch64-builtins.c:1510 config/arm/arm-builtins.c:3450
+#: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "遮罩必須是一個立即數值"
 
-#: config/aarch64/aarch64-builtins.c:1513
+#: config/aarch64/aarch64-builtins.c:1519
 #, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1758
+#: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "引數必須是常數"
 
-#: config/aarch64/aarch64-builtins.c:1813
+#: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "%s 不支援 %s"
 
-#: config/aarch64/aarch64-builtins.c:1847
+#: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "引數必須是常數"
 
-#: config/aarch64/aarch64-builtins.c:2395
-#: config/aarch64/aarch64-builtins.c:2415
+#: config/aarch64/aarch64-builtins.c:2404
+#: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "預期 %qT 但是引數是的型態 %qT"
 
-#: config/aarch64/aarch64-builtins.c:2399
+#: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "預期 %qT 但是引數是的型態 %qT"
 
-#: config/aarch64/aarch64-c.c:275
+#: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<# pragma GCC optimize%>並非字串或數字"
 
-#: config/aarch64/aarch64-c.c:283
+#: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明 # pragma GCC 輔助處理器 %E"
 
-#: config/aarch64/aarch64.c:1327
+#: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
 #| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "new 不能用於函式類型"
 
-#: config/aarch64/aarch64.c:1401 config/aarch64/aarch64.c:1415
+#: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "預期 %<,%>或 %<)%>"
 
-#: config/aarch64/aarch64.c:1845
+#: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "複雜引數必須有浮點型態"
 
-#: config/aarch64/aarch64.c:1848
+#: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with the use of vector types"
 msgstr "%qs 是不相容的與 %qs"
 
-#: config/aarch64/aarch64.c:1852
+#: config/aarch64/aarch64.c:1936
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of floating-point types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1855
+#: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1871
+#: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the SVE ISA extension"
 msgstr "不使用 SPE ABI 延伸"
 
-#: config/aarch64/aarch64.c:1872
+#: config/aarch64/aarch64.c:1956
 #, gcc-internal-format
 msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
 #. We can't gracefully recover at this point, so make this a
 #. fatal error.
-#: config/aarch64/aarch64.c:5341
+#: config/aarch64/aarch64.c:5426
 #, fuzzy, gcc-internal-format
 msgid "arguments of type %qT require the SVE ISA extension"
 msgstr "引數到 decltype 必須是運算式"
 
-#: config/aarch64/aarch64.c:5653
+#: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/aarch64/aarch64.c:5775 config/aarch64/aarch64.c:5838
-#: config/aarch64/aarch64.c:5958 config/aarch64/aarch64.c:16117
-#: config/arm/arm.c:6976 config/arm/arm.c:7006 config/arm/arm.c:28383
+#: config/aarch64/aarch64.c:5869 config/aarch64/aarch64.c:5932
+#: config/aarch64/aarch64.c:6052 config/aarch64/aarch64.c:16239
+#: config/arm/arm.c:7073 config/arm/arm.c:7103 config/arm/arm.c:28558
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5907
+#: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
 msgid "%qE requires the SVE ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/aarch64/aarch64.c:5910
+#: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/aarch64/aarch64.c:6086
+#: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13836
+#: config/aarch64/aarch64.c:13959
 #, gcc-internal-format
 msgid "unknown flag passed in %<-moverride=%s%> (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13880
+#: config/aarch64/aarch64.c:14003
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13936
+#: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid format for sve_width"
 msgstr "運算元的約束無效"
 
-#: config/aarch64/aarch64.c:13948
+#: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "無效 %%h 值"
 
-#: config/aarch64/aarch64.c:13968
+#: config/aarch64/aarch64.c:14091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "無效的範圍 %s 在中選項 %s"
 
-#: config/aarch64/aarch64.c:13986
+#: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "不明 spec 函式 %qs"
 
-#: config/aarch64/aarch64.c:14139
+#: config/aarch64/aarch64.c:14262
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14148
+#: config/aarch64/aarch64.c:14271
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14156
+#: config/aarch64/aarch64.c:14279
 #, fuzzy, gcc-internal-format
 #| msgid "Specify the register allocation order"
 msgid "specify a system register with a small string length."
 msgstr "指定指派暫存器的順序"
 
-#: config/aarch64/aarch64.c:14166 config/rs6000/rs6000.c:4307
+#: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/aarch64/aarch64.c:14231
+#: config/aarch64/aarch64.c:14354
 #, gcc-internal-format
 msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14247
+#: config/aarch64/aarch64.c:14370
 #, gcc-internal-format
 msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14332
+#: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s;"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/aarch64/aarch64.c:14356
+#: config/aarch64/aarch64.c:14479
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:14363
+#: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/aarch64/aarch64.c:14471
+#: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "無效的引數到內建函式"
 
-#: config/aarch64/aarch64.c:14473
+#: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "無效的引數到內建函式"
 
-#: config/aarch64/aarch64.c:14497
+#: config/aarch64/aarch64.c:14620
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:14500
+#: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-march%>"
 msgstr "不明值 %qs 的 -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:14504
+#: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "%qs 後缺少檔案名稱"
 
-#: config/aarch64/aarch64.c:14532
+#: config/aarch64/aarch64.c:14655
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:14535
+#: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/aarch64/aarch64.c:14666 config/arm/arm.c:3251
+#: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "切換 -mcpu=%s 衝突與 -march=%s 切換"
 
-#: config/aarch64/aarch64.c:14722
+#: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "%s 不支援 %s"
 
-#: config/aarch64/aarch64.c:14729
+#: config/aarch64/aarch64.c:14852
 #, gcc-internal-format
 msgid "return address signing is only supported for %<-mabi=lp64%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14801
+#: config/aarch64/aarch64.c:14924
 #, gcc-internal-format
 msgid "code model %qs with %<-f%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14804
+#: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/aarch64/aarch64.c:14975
+#: config/aarch64/aarch64.c:15098
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14978
+#: config/aarch64/aarch64.c:15101
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:14982 config/aarch64/aarch64.c:15024
-#: config/aarch64/aarch64.c:15131
+#: config/aarch64/aarch64.c:15105 config/aarch64/aarch64.c:15147
+#: config/aarch64/aarch64.c:15254
 #, gcc-internal-format
 msgid "invalid feature modifier %s of value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15017
+#: config/aarch64/aarch64.c:15140
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15020
+#: config/aarch64/aarch64.c:15143
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15047
+#: config/aarch64/aarch64.c:15170
 #, gcc-internal-format
 msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15051
+#: config/aarch64/aarch64.c:15174
 #, gcc-internal-format
 msgid "invalid protection type (\"%s\") in %<target(\"branch-protection=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15086
+#: config/aarch64/aarch64.c:15209
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15127
+#: config/aarch64/aarch64.c:15250
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.c:15183 config/aarch64/aarch64.c:15356
+#: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> 格式錯誤"
 
-#: config/aarch64/aarch64.c:15227
+#: config/aarch64/aarch64.c:15352
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15235
+#: config/aarch64/aarch64.c:15360
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:15289
+#: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.c:15346 config/arm/arm.c:32215
-#: config/rs6000/rs6000.c:23178 config/s390/s390.c:15518
+#: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
+#: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/aarch64/aarch64.c:15373
+#: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.c:15382
+#: config/aarch64/aarch64.c:15507
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:16759 config/rs6000/rs6000-call.c:5747
-#, gcc-internal-format
-msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
+#: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
+#: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
+#: config/s390/s390.c:12047
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
-#: config/aarch64/aarch64.c:17832
+#: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
+#: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
+#: config/s390/s390.c:12042
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.c:18004
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.c:17834
+#: config/aarch64/aarch64.c:18006
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.c:22440 config/i386/i386.c:22138
+#: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "不支援的組合：%s"
 
-#: config/aarch64/aarch64.c:22450 config/aarch64/aarch64.c:22471
+#: config/aarch64/aarch64.c:22623 config/aarch64/aarch64.c:22644
 #, gcc-internal-format
 msgid "GCC does not currently support mixed size types for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22454
+#: config/aarch64/aarch64.c:22627
 #, gcc-internal-format
 msgid "GCC does not currently support return type %qT for %<simd%> functions"
 msgstr ""
 
-#: config/aarch64/aarch64.c:22458
+#: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.c:22475
+#: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.c:22497
+#: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
 #| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
@@ -34759,17 +34814,17 @@ msgstr "%qs 屬性的引數不是「ilink1」或「ilink2」"
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qs 屬性的引數不是「ilink1」或「ilink2」"
 
-#: config/arc/arc.c:2130 config/arm/arm.c:7117 config/arm/arm.c:7135
-#: config/arm/arm.c:7311 config/avr/avr.c:9695 config/avr/avr.c:9711
+#: config/arc/arc.c:2130 config/arm/arm.c:7214 config/arm/arm.c:7232
+#: config/arm/arm.c:7408 config/avr/avr.c:9695 config/avr/avr.c:9711
 #: config/bfin/bfin.c:4693 config/bfin/bfin.c:4754 config/bfin/bfin.c:4783
 #: config/csky/csky.c:6006 config/csky/csky.c:6034
 #: config/epiphany/epiphany.c:491 config/gcn/gcn.c:323
-#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3264
-#: config/i386/i386-options.c:3441 config/i386/i386-options.c:3497
-#: config/i386/i386-options.c:3548 config/i386/i386-options.c:3585
+#: config/h8300/h8300.c:5323 config/i386/i386-options.c:3268
+#: config/i386/i386-options.c:3445 config/i386/i386-options.c:3501
+#: config/i386/i386-options.c:3552 config/i386/i386-options.c:3589
 #: config/m68k/m68k.c:792 config/mcore/mcore.c:3066 config/nvptx/nvptx.c:5053
-#: config/riscv/riscv.c:2924 config/rl78/rl78.c:820 config/rl78/rl78.c:889
-#: config/rs6000/rs6000.c:19253 config/rx/rx.c:2719 config/rx/rx.c:2745
+#: config/riscv/riscv.c:2932 config/rl78/rl78.c:820 config/rl78/rl78.c:889
+#: config/rs6000/rs6000.c:19500 config/rx/rx.c:2719 config/rx/rx.c:2745
 #: config/s390/s390.c:1054 config/s390/s390.c:1141 config/sh/sh.c:8428
 #: config/sh/sh.c:8446 config/sh/sh.c:8470 config/sh/sh.c:8541
 #: config/sh/sh.c:8564 config/stormy16/stormy16.c:2229 config/v850/v850.c:2010
@@ -34925,12 +34980,12 @@ msgstr "不明 IRA 演算法 %qs"
 msgid "invalid type for %<asm%> flag output"
 msgstr "無效的型態用於製作函式"
 
-#: config/arm/arm-builtins.c:3087
+#: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "輔助處理器未啟用"
 
-#: config/arm/arm-builtins.c:3090
+#: config/arm/arm-builtins.c:3099
 #, fuzzy, gcc-internal-format
 msgid "%Kcoproc must be a constant immediate in range [0-%d] enabled with +cdecp<N>"
 msgstr "引數必須是常數"
@@ -34938,196 +34993,196 @@ msgstr "引數必須是常數"
 #. Here we mention the builtin name to follow the same
 #. format that the C/C++ frontends use for referencing
 #. a given argument index.
-#: config/arm/arm-builtins.c:3098
+#: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "引數必須是常數"
 
-#: config/arm/arm-builtins.c:3216
+#: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections 在此目標平臺上不受支援"
 
-#: config/arm/arm-builtins.c:3323
+#: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s 預期整數實字在中範圍 [%d，%d]"
 
-#: config/arm/arm-builtins.c:3327
+#: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "遮罩必須是一個立即數值"
 
-#: config/arm/arm-builtins.c:3350
+#: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3372
+#: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3394
+#: config/arm/arm-builtins.c:3403
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3472
+#: config/arm/arm-builtins.c:3481
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:3550 config/arm/arm-builtins.c:3654
+#: config/arm/arm-builtins.c:3559 config/arm/arm-builtins.c:3663
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "選擇子必須是立即數值"
 
-#: config/arm/arm-builtins.c:3558 config/arm/arm-builtins.c:3603
-#: config/arm/arm-builtins.c:3661 config/arm/arm-builtins.c:3670
+#: config/arm/arm-builtins.c:3567 config/arm/arm-builtins.c:3612
+#: config/arm/arm-builtins.c:3670 config/arm/arm-builtins.c:3679
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3563 config/arm/arm-builtins.c:3672
+#: config/arm/arm-builtins.c:3572 config/arm/arm-builtins.c:3681
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3568 config/arm/arm-builtins.c:3674
+#: config/arm/arm-builtins.c:3577 config/arm/arm-builtins.c:3683
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3740
+#: config/arm/arm-builtins.c:3749
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "遮罩必須是一個立即數值"
 
-#: config/arm/arm-builtins.c:3745
+#: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 屬性引數應該被介於 0 到 255"
 
-#: config/arm/arm-builtins.c:3933
+#: config/arm/arm-builtins.c:3942
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3935
+#: config/arm/arm-builtins.c:3944
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3937
+#: config/arm/arm-builtins.c:3946
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3939
+#: config/arm/arm-builtins.c:3948
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3945
+#: config/arm/arm-builtins.c:3954
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3947
+#: config/arm/arm-builtins.c:3956
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3952
+#: config/arm/arm-builtins.c:3961
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3954
+#: config/arm/arm-builtins.c:3963
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3956
+#: config/arm/arm-builtins.c:3965
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3958
+#: config/arm/arm-builtins.c:3967
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3960
+#: config/arm/arm-builtins.c:3969
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3962
+#: config/arm/arm-builtins.c:3971
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3964
+#: config/arm/arm-builtins.c:3973
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3966
+#: config/arm/arm-builtins.c:3975
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3968
+#: config/arm/arm-builtins.c:3977
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3970
+#: config/arm/arm-builtins.c:3979
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3972
+#: config/arm/arm-builtins.c:3981
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3974
+#: config/arm/arm-builtins.c:3983
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3976
+#: config/arm/arm-builtins.c:3985
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3978
+#: config/arm/arm-builtins.c:3987
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3980
+#: config/arm/arm-builtins.c:3989
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3982
+#: config/arm/arm-builtins.c:3991
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3984
+#: config/arm/arm-builtins.c:3993
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3986
+#: config/arm/arm-builtins.c:3995
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -35137,293 +35192,293 @@ msgstr ""
 msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
 msgstr ""
 
-#: config/arm/arm.c:2911
+#: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-mvsx 和 -mpaired 是不相容的"
 
-#: config/arm/arm.c:2917
+#: config/arm/arm.c:2918
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "目標 CPU 不支援手臂模式"
 
-#: config/arm/arm.c:2921
+#: config/arm/arm.c:2922
 #, fuzzy, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "啟用返回支援是只有有意義的時編譯用於姆指"
 
-#: config/arm/arm.c:2924
+#: config/arm/arm.c:2925
 #, fuzzy, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "啟用被呼叫端交互作用支援是只有有意義的時編譯用於姆指"
 
-#: config/arm/arm.c:2932
+#: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g 與 -mno-apcs-frame 並用可能不能給出有意義的除錯資訊"
 
-#: config/arm/arm.c:2937
+#: config/arm/arm.c:2938
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2940
+#: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "無法使用 -mtp=cp15 與 16-bit 姆指"
 
-#: config/arm/arm.c:2944
+#: config/arm/arm.c:2945
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC 是不相容的與姆指"
 
-#: config/arm/arm.c:2957
+#: config/arm/arm.c:2958
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
 msgstr ""
 
-#: config/arm/arm.c:2962
+#: config/arm/arm.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only supports non-pic code on M-profile targets"
 msgstr ""
 
-#: config/arm/arm.c:2967
+#: config/arm/arm.c:2968
 #, fuzzy, gcc-internal-format
 msgid "%s incompatible with %<-mword-relocations%>"
 msgstr "-fjni 是不相容的與 -freduced-reflection"
 
-#: config/arm/arm.c:3082
+#: config/arm/arm.c:3083
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "目的 CPU 不支援 THUMB 指令"
 
-#: config/arm/arm.c:3132
+#: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "目標 CPU 不支援 unaligned 存取"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check 和 -mno-apcs-frame 互不相容"
 
-#: config/arm/arm.c:3490
+#: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic 和 -mapcs-reent 互不相容"
 
-#: config/arm/arm.c:3493
+#: config/arm/arm.c:3494
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "不支援 APCS 重入程式碼。已忽略"
 
-#: config/arm/arm.c:3516
+#: config/arm/arm.c:3517
 #, gcc-internal-format
 msgid "option %<-mstructure-size-boundary%> is deprecated"
 msgstr ""
 
-#: config/arm/arm.c:3524
+#: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "結構大小邊界只能是設定為 8, 32 或 64"
 
-#: config/arm/arm.c:3526
+#: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "結構大小邊界只能是設定為 8 或 32"
 
-#: config/arm/arm.c:3551
+#: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 是不相容的與 -msingle-pic-base"
 
-#: config/arm/arm.c:3563 config/arm/arm.c:32229
+#: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/arm/arm.c:3571
+#: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
 #| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= 不與 -fpic 並用時不起作用"
 
-#: config/arm/arm.c:3580
+#: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
 #| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "「%s」不能做為 PIC 暫存器"
 
-#: config/arm/arm.c:3602 config/pru/pru.c:643
+#: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition 不支援於這個架構"
 
-#: config/arm/arm.c:3746
+#: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable 與 -msdata=%s 互不相容"
 
-#: config/arm/arm.c:3798
+#: config/arm/arm.c:3799
 #, fuzzy, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt 需求 AAPCS 相容 ABI 用於適當作業"
 
-#: config/arm/arm.c:3801
+#: config/arm/arm.c:3802
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi 需要相應 CPU 的支援"
 
-#: config/arm/arm.c:3809
+#: config/arm/arm.c:3810
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "目的 CPU 不支援交互工作"
 
-#: config/arm/arm.c:3822
+#: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS 不支援 -mcaller-super-interworking"
 
-#: config/arm/arm.c:3825
+#: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS 不支援 -mcallee-super-interworking"
 
-#: config/arm/arm.c:3830
+#: config/arm/arm.c:3831
 #, fuzzy, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 以及沒有 ldrh"
 
-#: config/arm/arm.c:3833
+#: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "目的 CPU 不支援 THUMB 指令"
 
-#: config/arm/arm.c:3838
+#: config/arm/arm.c:3839
 #, gcc-internal-format
 msgid "ARMv8-M Security Extensions incompatible with selected FPU"
 msgstr ""
 
-#: config/arm/arm.c:3850
+#: config/arm/arm.c:3851
 #, gcc-internal-format
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3858
+#: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:6098
+#: config/arm/arm.c:6099
 #, fuzzy, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS 衍生的 PCS 變體"
 
-#: config/arm/arm.c:6100
+#: config/arm/arm.c:6101
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadic 函式必須使用基底 AAPCS 變體"
 
-#: config/arm/arm.c:6120
+#: config/arm/arm.c:6121
 #, fuzzy, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS 變體"
 
-#: config/arm/arm.c:6318
+#: config/arm/arm.c:6373
 #, fuzzy, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 hard-float VFP ABI"
 
-#: config/arm/arm.c:6378
+#: config/arm/arm.c:6462
 #, gcc-internal-format
 msgid "argument of type %qT not permitted with -mgeneral-regs-only"
 msgstr ""
 
-#: config/arm/arm.c:6762 config/arm/arm.c:6970 config/arm/arm.c:7003
-#: config/arm/arm.c:28376
+#: config/arm/arm.c:6846 config/arm/arm.c:7067 config/arm/arm.c:7100
+#: config/arm/arm.c:28551
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:7260
+#: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 屬性只有套用到函式，無法 %s"
 
-#: config/arm/arm.c:7272
+#: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: config/arm/arm.c:7281
+#: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 屬性只有套用到函式，無法 %s"
 
-#: config/arm/arm.c:7303 config/arm/arm.c:7355
+#: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: config/arm/arm.c:7322
+#: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 屬性沒有任何效果於單位本地函式"
 
-#: config/arm/arm.c:7371
+#: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 屬性只有套用到函數型式"
 
-#: config/arm/arm.c:9322
+#: config/arm/arm.c:9423
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.c:13060
+#: config/arm/arm.c:13161
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:13063
+#: config/arm/arm.c:13164
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:25234
+#: config/arm/arm.c:25409
 #, fuzzy, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "無法計算真實位置的重疊參數"
 
-#: config/arm/arm.c:25896
+#: config/arm/arm.c:26071
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "非預期的模組結束"
 
-#: config/arm/arm.c:26155
+#: config/arm/arm.c:26330
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高暫存器彈堆疊時沒有可用的低暫存器"
 
-#: config/arm/arm.c:26407
+#: config/arm/arm.c:26582
 #, fuzzy, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/arm/arm.c:26653
+#: config/arm/arm.c:26828
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:32244
+#: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
@@ -35431,22 +35486,22 @@ msgstr "無效的向量型態用於屬性 %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:32252
+#: config/arm/arm.c:32427
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:32265
+#: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
 
-#: config/arm/arm.c:32279
+#: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "目標屬性或 pragma 變更 SPE ABI"
 
-#: config/arm/arm.c:33257
+#: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
 msgid "asm flags not supported in thumb1 mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
@@ -35526,17 +35581,17 @@ msgstr "-fpic 未被支援"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC 未被支援"
 
-#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4920
+#: config/avr/avr.c:1040 config/avr/avr.c:1045 config/riscv/riscv.c:4951
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "函式屬性 %qs，%qs 和 %qs 彼此互斥"
 
-#: config/avr/avr.c:1066 config/riscv/riscv.c:4932
+#: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs 函式無法有引數"
 
-#: config/avr/avr.c:1069 config/riscv/riscv.c:4929
+#: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs 函式無法回傳值"
@@ -35805,7 +35860,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "%<__int128%>未被支援由這個目標"
 
 #: config/bpf/bpf.c:880 config/mips/mips.c:17025 config/nios2/nios2.c:3600
-#: config/riscv/riscv-builtins.c:219
+#: config/riscv/riscv-builtins.c:222
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to built-in function"
 msgstr "無效的引數到內建函式"
@@ -36148,53 +36203,53 @@ msgstr ""
 msgid "too many arguments passed in sgpr registers"
 msgstr "在暫存器中傳遞參數"
 
-#: config/gcn/gcn.c:2095
+#: config/gcn/gcn.c:2096
 #, gcc-internal-format
 msgid "A non-default set of initial values has been requested, which violates the ABI!"
 msgstr ""
 
-#: config/gcn/gcn.c:2331
+#: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong type of argument %s"
 msgstr "錯誤的型態引數到 %s"
 
-#: config/gcn/gcn.c:3114
+#: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "巢狀的函式 trampolines 不支援於這個目標"
 
-#: config/gcn/gcn.c:3223
+#: config/gcn/gcn.c:3224
 #, fuzzy, gcc-internal-format
 #| msgid "DW_LOC_OP %s not implemented"
 msgid "TLS is not implemented for GCN."
 msgstr "DW_LOC_OP %s 尚未實作"
 
-#: config/gcn/gcn.c:3834
+#: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
 msgid "Builtin not implemented"
 msgstr "Finalization 於 %L 不是未實作"
 
-#: config/gcn/gcn.c:4803
+#: config/gcn/gcn.c:4804
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (64), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4804
+#: config/gcn/gcn.c:4805
 #, gcc-internal-format
 msgid "using vector_length (64), ignoring runtime setting"
 msgstr ""
 
-#: config/gcn/gcn.c:4816 config/nvptx/nvptx.c:5688
+#: config/gcn/gcn.c:4817 config/nvptx/nvptx.c:5688
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
 
-#: config/gcn/gcn.c:4844 config/gcn/gcn.c:4871
+#: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "offload dimension out of range (%d)"
 msgstr "運算元號超出範圍"
 
-#: config/gcn/gcn.c:5299
+#: config/gcn/gcn.c:5300
 #, gcc-internal-format
 msgid "local data-share memory exhausted"
 msgstr ""
@@ -36331,136 +36386,136 @@ msgstr "%qs 的引數必須是一個 2 位無號原文"
 msgid "parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的參數無效：%s"
 
-#: config/i386/i386-expand.c:7909
+#: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine cannot be called directly"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386-expand.c:8313 config/i386/i386-expand.c:9776
+#: config/i386/i386-expand.c:8320 config/i386/i386-expand.c:9783
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後一筆引數必須是 2-bit 即時"
 
-#: config/i386/i386-expand.c:8708
+#: config/i386/i386-expand.c:8715
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fifth 引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:8803
+#: config/i386/i386-expand.c:8810
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:9707
+#: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386-expand.c:9722
+#: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386-expand.c:9755
+#: config/i386/i386-expand.c:9762
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386-expand.c:9795
+#: config/i386/i386-expand.c:9802
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386-expand.c:9808
+#: config/i386/i386-expand.c:9815
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386-expand.c:9818
+#: config/i386/i386-expand.c:9825
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:9823 config/i386/i386-expand.c:10729
+#: config/i386/i386-expand.c:9830 config/i386/i386-expand.c:10736
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:9963
+#: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引數必須是常數"
 
-#: config/i386/i386-expand.c:9968
+#: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "錯誤指令："
 
-#: config/i386/i386-expand.c:9974 config/i386/i386-expand.c:10294
+#: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "對樹結區段的共享不正確"
 
-#: config/i386/i386-expand.c:10276
+#: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386-expand.c:10282
+#: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386-expand.c:10285
+#: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386-expand.c:10727
+#: config/i386/i386-expand.c:10734
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386-expand.c:10809 config/rs6000/rs6000-call.c:9814
+#: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: config/i386/i386-expand.c:11003
+#: config/i386/i386-expand.c:11010
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE 需要不明 isa 選項"
 
-#: config/i386/i386-expand.c:11007
+#: config/i386/i386-expand.c:11014
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE 需要 isa 選項 %s"
 
-#: config/i386/i386-expand.c:11678
+#: config/i386/i386-expand.c:11685
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後一筆引數必須是即時"
 
-#: config/i386/i386-expand.c:12434 config/i386/i386-expand.c:12646
+#: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386-expand.c:12699
+#: config/i386/i386-expand.c:12706
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386-expand.c:12705
+#: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "錯誤指令："
 
-#: config/i386/i386-expand.c:12724
+#: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
@@ -36849,146 +36904,146 @@ msgstr ""
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.c:3087
+#: config/i386/i386-options.c:3089
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3122
+#: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.c:3130
+#: config/i386/i386-options.c:3134
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.c:3224
+#: config/i386/i386-options.c:3228
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.c:3226
+#: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386-options.c:3230
+#: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.c:3277 config/i386/i386-options.c:3328
+#: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386-options.c:3282
+#: config/i386/i386-options.c:3286
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3289 config/i386/i386-options.c:3517
+#: config/i386/i386-options.c:3293 config/i386/i386-options.c:3521
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386-options.c:3295
+#: config/i386/i386-options.c:3299
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386-options.c:3320 config/i386/i386-options.c:3363
+#: config/i386/i386-options.c:3324 config/i386/i386-options.c:3367
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.c:3324
+#: config/i386/i386-options.c:3328
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386-options.c:3332 config/i386/i386-options.c:3381
+#: config/i386/i386-options.c:3336 config/i386/i386-options.c:3385
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3342 config/i386/i386-options.c:3359
+#: config/i386/i386-options.c:3346 config/i386/i386-options.c:3363
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.c:3346
+#: config/i386/i386-options.c:3350
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386-options.c:3350 config/i386/i386-options.c:3377
+#: config/i386/i386-options.c:3354 config/i386/i386-options.c:3381
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3367 config/i386/i386-options.c:3385
+#: config/i386/i386-options.c:3371 config/i386/i386-options.c:3389
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.c:3373
+#: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386-options.c:3477 config/rs6000/rs6000.c:19366
+#: config/i386/i386-options.c:3481 config/rs6000/rs6000.c:19613
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386-options.c:3504
+#: config/i386/i386-options.c:3508
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386-options.c:3525
+#: config/i386/i386-options.c:3529
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386-options.c:3559 config/i386/i386-options.c:3569
+#: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386-options.c:3596 config/i386/i386-options.c:3618
+#: config/i386/i386-options.c:3600 config/i386/i386-options.c:3622
 #: config/ia64/ia64.c:812 config/s390/s390.c:1151
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/i386/i386-options.c:3606 config/i386/i386-options.c:3628
+#: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/i386/i386-options.c:3660
+#: config/i386/i386-options.c:3664
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386-options.c:3667
+#: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "插斷函式必須沒有任何引數"
 
-#: config/i386/i386-options.c:3678
+#: config/i386/i386-options.c:3682
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.c:3681
+#: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
@@ -37442,7 +37497,7 @@ msgstr "%qE 無法同時有 %<mips16%> 和 %<nomips16%>屬性"
 msgid "%qE redeclared with conflicting %qs attributes"
 msgstr "%qE redeclared 與衝突 %qs 屬性"
 
-#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2952
+#: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 屬性需要字串常數引數"
@@ -38549,52 +38604,52 @@ msgstr "%qE 屬性允許只有整數常數引數"
 msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
 msgstr ""
 
-#: config/riscv/riscv.c:354
+#: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/riscv/riscv.c:2572 config/riscv/riscv.c:2614
+#: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/riscv/riscv.c:2963
+#: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/riscv/riscv.c:4594
+#: config/riscv/riscv.c:4625
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4635
+#: config/riscv/riscv.c:4666
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4639
+#: config/riscv/riscv.c:4670
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.c:4643
+#: config/riscv/riscv.c:4674
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.c:4653
+#: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/riscv/riscv.c:4666
+#: config/riscv/riscv.c:4697
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.c:4958
+#: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs 函式無法有引數"
@@ -38712,345 +38767,346 @@ msgstr "數字必須是 0 或 1"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "#pragma longcall 末尾有無用字元"
 
-#: config/rs6000/rs6000-c.c:928
+#: config/rs6000/rs6000-c.c:934
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:932
+#: config/rs6000/rs6000-c.c:938
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:942 config/rs6000/rs6000-c.c:993
-#: config/rs6000/rs6000-c.c:1263 config/rs6000/rs6000-c.c:1329
-#: config/rs6000/rs6000-c.c:1695 config/rs6000/rs6000-c.c:1742
+#: config/rs6000/rs6000-c.c:948 config/rs6000/rs6000-c.c:999
+#: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
+#: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:1066 config/rs6000/rs6000-c.c:1149
-#: config/rs6000/rs6000-c.c:1507
+#: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
+#: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:1258
+#: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s 只有接受 1 引數"
 
-#: config/rs6000/rs6000-c.c:1634
+#: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: config/rs6000/rs6000-c.c:1833
+#: config/rs6000/rs6000-c.c:1839
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:1837
+#: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s 不為這個配置所支援"
 
-#: config/rs6000/rs6000-c.c:1846
+#: config/rs6000/rs6000-c.c:1852
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "對 AltiVec 內建函式來說無效的參陣列合"
 
-#: config/rs6000/rs6000-call.c:5845
+#: config/rs6000/rs6000-call.c:5875
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 回傳向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#: config/rs6000/rs6000-call.c:6035
+#: config/rs6000/rs6000-call.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000-call.c:6210
+#: config/rs6000/rs6000-call.c:6240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000-call.c:6480
+#: config/rs6000/rs6000-call.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000-call.c:7220
+#: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/rs6000/rs6000-call.c:7395
+#: config/rs6000/rs6000-call.c:7425
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 傳遞向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#: config/rs6000/rs6000-call.c:8187
+#: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/rs6000/rs6000-call.c:8505
+#: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this subtarget"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs 在此子目的上不受支援"
 
-#: config/rs6000/rs6000-call.c:8546
+#: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/rs6000/rs6000-call.c:8577
+#: config/rs6000/rs6000-call.c:8660
 #, gcc-internal-format
 msgid "%<__builtin_mtfsb0%> and %<__builtin_mtfsb1%> not supported with %<-msoft-float%>"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:8589
+#: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
 msgid "Argument must be a constant between 0 and 31."
 msgstr "引數必須是常數"
 
-#: config/rs6000/rs6000-call.c:8615
+#: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: config/rs6000/rs6000-call.c:8630
+#: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 3."
 msgstr "%L 處 ACOS 的參數必須在 -1 和 1 之間"
 
-#: config/rs6000/rs6000-call.c:8655
+#: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: config/rs6000/rs6000-call.c:8660
+#: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: config/rs6000/rs6000-call.c:8679
+#: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Argument must be a value between 0 and 7."
 msgstr "%L 處 ACOS 的參數必須在 -1 和 1 之間"
 
-#: config/rs6000/rs6000-call.c:8720
+#: config/rs6000/rs6000-call.c:8803
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/rs6000/rs6000-call.c:8804
+#: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8815
+#: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8826
+#: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8837
+#: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8851
+#: config/rs6000/rs6000-call.c:8934
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8869
+#: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8885
+#: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:8924
+#: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "引數必須是常數"
 
-#: config/rs6000/rs6000-call.c:8982
+#: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000-call.c:9255
-#, fuzzy, gcc-internal-format
-msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "%srtd%s 被忽略在中 64 位元模式"
-
-#: config/rs6000/rs6000-call.c:9304
+#: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:9306
+#: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000-call.c:9451
+#: config/rs6000/rs6000-call.c:9465
+#, fuzzy, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr "%srtd%s 被忽略在中 64 位元模式"
+
+#: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s 只有接受 1 引數"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000-call.c:9470
+#: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "%qs 是無效的引數到 -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000-call.c:9498
+#: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs 是無效的引數到 -mcpu="
 
-#: config/rs6000/rs6000-call.c:9524
+#: config/rs6000/rs6000-call.c:9734
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000-call.c:9577
+#: config/rs6000/rs6000-call.c:9787
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "引數 3 必須是一個 4 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:9602
+#: config/rs6000/rs6000-call.c:9812
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "引數 3 必須是 2-bit 無正負號實字"
 
-#: config/rs6000/rs6000-call.c:9622
+#: config/rs6000/rs6000-call.c:9832
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/rs6000/rs6000-call.c:9634
+#: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "引數 1 必須是映射"
 
-#: config/rs6000/rs6000-call.c:9646
+#: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/rs6000/rs6000-call.c:9660
+#: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000-call.c:9672
+#: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "數字必須是 0 或 1"
 
-#: config/rs6000/rs6000-call.c:9680
+#: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: config/rs6000/rs6000-call.c:9747 config/rs6000/rs6000-call.c:10087
+#: config/rs6000/rs6000-call.c:9957 config/rs6000/rs6000-call.c:10297
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/rs6000/rs6000-call.c:9912
+#: config/rs6000/rs6000-call.c:10122
 #, fuzzy, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "無法解析的過載用於 Altivec 內建 %qF"
 
-#: config/rs6000/rs6000-call.c:10134
+#: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "%q+D 的第二個參數類型應該是 %<char **%>"
 
-#: config/rs6000/rs6000-call.c:10149
+#: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be [0, 12]"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/rs6000/rs6000-call.c:10343
+#: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
 msgid "%qs is only valid for the cell processor"
 msgstr "內建函式 %s 是只有有效用於儲存格處理器"
 
-#: config/rs6000/rs6000-call.c:10345 config/rs6000/rs6000-call.c:10347
-#: config/rs6000/rs6000-call.c:10349 config/rs6000/rs6000-call.c:10355
-#: config/rs6000/rs6000-call.c:10357 config/rs6000/rs6000-call.c:10363
-#: config/rs6000/rs6000-call.c:10369 config/rs6000/rs6000-call.c:10373
-#: config/rs6000/rs6000-call.c:10375 config/rs6000/rs6000-call.c:10379
-#: config/rs6000/rs6000-call.c:10383
+#: config/rs6000/rs6000-call.c:10555 config/rs6000/rs6000-call.c:10557
+#: config/rs6000/rs6000-call.c:10559 config/rs6000/rs6000-call.c:10565
+#: config/rs6000/rs6000-call.c:10567 config/rs6000/rs6000-call.c:10573
+#: config/rs6000/rs6000-call.c:10579 config/rs6000/rs6000-call.c:10581
+#: config/rs6000/rs6000-call.c:10583 config/rs6000/rs6000-call.c:10587
+#: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
+#: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000-call.c:10352 config/rs6000/rs6000-call.c:10360
-#: config/rs6000/rs6000-call.c:10366
+#: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
+#: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs and %qs options"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000-call.c:10381
+#: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000-call.c:10386
+#: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000-call.c:10389
+#: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported with the current options"
 msgstr "內建函式 %s 未被支援與目前的選項"
 
-#: config/rs6000/rs6000-call.c:13016
+#: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "內部錯誤：內建函式 %s 有未預期的傳回類型 %s"
 
-#: config/rs6000/rs6000-call.c:13038
+#: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
@@ -39071,224 +39127,229 @@ msgstr "使用暫存器 r2 和 r5"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3154 config/rs6000/rs6000.c:3157
-#: config/rs6000/rs6000.c:3160
+#: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
+#: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: config/rs6000/rs6000.c:3261
+#: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架構，正在啟用"
 
-#: config/rs6000/rs6000.c:3454
+#: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位元 Darwin 下不受支援；它與已安裝的 C 和 C++ 函式庫不相容"
 
-#: config/rs6000/rs6000.c:3593
+#: config/rs6000/rs6000.c:3658
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 不支援在中這個目標"
 
-#: config/rs6000/rs6000.c:3610
+#: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring 在低位位元組在前的系統上不受支援"
 
-#: config/rs6000/rs6000.c:3689
+#: config/rs6000/rs6000.c:3754
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:3697
+#: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-mcmodel 不相容的與其他光碟內容表選項"
 
 #. TARGET_VSX = 1 implies Power 7 and newer
-#: config/rs6000/rs6000.c:3722 config/rs6000/rs6000.c:3730
-#: config/rs6000/rs6000.c:3737 config/rs6000/rs6000.c:3744
-#: config/rs6000/rs6000.c:3752 config/rs6000/rs6000.c:3771
-#: config/rs6000/rs6000.c:3833 config/rs6000/rs6000.c:3860
-#: config/rs6000/rs6000.c:3887 config/rs6000/rs6000.c:3902
-#: config/rs6000/rs6000.c:3910 config/rs6000/rs6000.c:3939
-#: config/rs6000/rs6000.c:3941 config/rs6000/rs6000.c:4027
-#: config/rs6000/rs6000.c:4040 config/rs6000/rs6000.c:4049
-#: config/rs6000/rs6000.c:4197
+#: config/rs6000/rs6000.c:3787 config/rs6000/rs6000.c:3795
+#: config/rs6000/rs6000.c:3802 config/rs6000/rs6000.c:3809
+#: config/rs6000/rs6000.c:3817 config/rs6000/rs6000.c:3836
+#: config/rs6000/rs6000.c:3898 config/rs6000/rs6000.c:3925
+#: config/rs6000/rs6000.c:3952 config/rs6000/rs6000.c:3967
+#: config/rs6000/rs6000.c:3975 config/rs6000/rs6000.c:4004
+#: config/rs6000/rs6000.c:4006 config/rs6000/rs6000.c:4092
+#: config/rs6000/rs6000.c:4105 config/rs6000/rs6000.c:4114
+#: config/rs6000/rs6000.c:4262 config/rs6000/rs6000.c:4275
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: config/rs6000/rs6000.c:3930
+#: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "目標屬性或 pragma 變更長兩倍大小"
 
-#: config/rs6000/rs6000.c:3956
+#: config/rs6000/rs6000.c:4021
 #, gcc-internal-format
 msgid "%qs requires full ISA 2.06 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3965
+#: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "使用我進階精確度長雙倍"
 
-#: config/rs6000/rs6000.c:3968
+#: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
 msgid "Using IBM extended precision %<long double%>"
 msgstr "使用 IBM 進階精確度長雙倍"
 
-#: config/rs6000/rs6000.c:3987
+#: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s 不支援 %s"
 
-#: config/rs6000/rs6000.c:3996
+#: config/rs6000/rs6000.c:4061
 #, gcc-internal-format
 msgid "The %<-mfloat128%> option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4019
+#: config/rs6000/rs6000.c:4084
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4106
+#: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "不明 vectorization 函式庫 ABI 型態 (%s) 用於 -mveclibabi=切換"
 
-#: config/rs6000/rs6000.c:4129 config/rs6000/rs6000.c:4144
+#: config/rs6000/rs6000.c:4194 config/rs6000/rs6000.c:4209
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目標屬性或 pragma 變更 AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4157
+#: config/rs6000/rs6000.c:4222
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目標屬性或 pragma 變更 darwin64 ABI"
 
-#: config/rs6000/rs6000.c:4302
+#: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/rs6000/rs6000.c:4319
+#: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs 並非有效類別名稱"
 
-#: config/rs6000/rs6000.c:4327
+#: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "需要 call-clobbered 目標暫存器"
 
-#: config/rs6000/rs6000.c:4623
+#: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/rs6000/rs6000.c:4660
+#: config/rs6000/rs6000.c:4743
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:7184
+#: config/rs6000/rs6000.c:7267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000.c:16737
+#: config/rs6000/rs6000.c:9945
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you can't set it to other values."
+msgstr ""
+
+#: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
 
-#: config/rs6000/rs6000.c:19039
+#: config/rs6000/rs6000.c:19280
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.c:19121
+#: config/rs6000/rs6000.c:19362
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/rs6000/rs6000.c:19123
+#: config/rs6000/rs6000.c:19364
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/rs6000/rs6000.c:19125
+#: config/rs6000/rs6000.c:19366
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/rs6000/rs6000.c:19127
+#: config/rs6000/rs6000.c:19368
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
 
-#: config/rs6000/rs6000.c:19133
+#: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:19136
+#: config/rs6000/rs6000.c:19377
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
 
-#: config/rs6000/rs6000.c:19141
+#: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:19144
+#: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:23150
+#: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.c:23153
+#: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.c:23155
+#: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.c:23692
+#: config/rs6000/rs6000.c:23942
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23851
+#: config/rs6000/rs6000.c:24101
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23883
+#: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/rs6000/rs6000.c:24139
+#: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
@@ -39625,142 +39686,142 @@ msgstr ""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/s390/s390.c:9873
+#: config/s390/s390.c:9871
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部變數大小總和超過架構極值。"
 
-#: config/s390/s390.c:11210
+#: config/s390/s390.c:11208
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函式 %qs 是 %wd 位元組超出使用者提供的堆疊限制的 %d 位元組。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:11226
+#: config/s390/s390.c:11224
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函式 %qs 是 %wd 位元組該項是超過半堆疊大小。動態檢查會無法是 reliable。沒有檢查發出用於這個函式。"
 
-#: config/s390/s390.c:11254
+#: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "影格大小的 %qs 是 %wd 位元組"
 
-#: config/s390/s390.c:11258
+#: config/s390/s390.c:11256
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs 使用動態堆疊指派"
 
-#: config/s390/s390.c:12900
+#: config/s390/s390.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: config/s390/s390.c:15158
+#: config/s390/s390.c:15224
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/s390/s390.c:15165
+#: config/s390/s390.c:15231
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.c:15200
+#: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:15203
+#: config/s390/s390.c:15269
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.c:15232
+#: config/s390/s390.c:15298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:15236
+#: config/s390/s390.c:15302
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬體十進位浮點數指令無法使用在中 ESA/390 模式"
 
-#: config/s390/s390.c:15248
+#: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp can%'t 被已用於接合與 -msoft-float"
 
-#: config/s390/s390.c:15257
+#: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支援"
 
-#: config/s390/s390.c:15263
+#: config/s390/s390.c:15329
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "堆疊大小必須大於堆疊防護值"
 
-#: config/s390/s390.c:15265
+#: config/s390/s390.c:15331
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "堆疊大小不能大於 64K"
 
-#: config/s390/s390.c:15268
+#: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard 意味著使用 -mstack-size"
 
-#: config/s390/s390.c:15281
+#: config/s390/s390.c:15347
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15284
+#: config/s390/s390.c:15350
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-prologue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15287
+#: config/s390/s390.c:15353
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-check requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15290
+#: config/s390/s390.c:15356
 #, gcc-internal-format
 msgid "-mtpf-trace-hook-epilogue-target requires integer in range 0..4095"
 msgstr ""
 
-#: config/s390/s390.c:15350
+#: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 屬性被支援只有用於 SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.c:15386
+#: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: config/s390/s390.c:15393
+#: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/s390/s390.c:15423
+#: config/s390/s390.c:15489
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.c:15584 config/s390/s390.c:15634 config/s390/s390.c:15651
+#: config/s390/s390.c:15650 config/s390/s390.c:15700 config/s390/s390.c:15717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15590
+#: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "%<__int128%>未被支援由這個目標"
@@ -40192,8 +40253,8 @@ msgstr "屬性 %qs 套用到陣列類型只有"
 msgid "could not read the BRIG file"
 msgstr "無法寫入回應檔案 %s"
 
-#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2113
-#: cp/typeck.c:8408 cp/typeck.c:9196
+#: c/c-convert.c:101 c/c-typeck.c:2200 c/c-typeck.c:12638 cp/typeck.c:2155
+#: cp/typeck.c:8468 cp/typeck.c:9256
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如預期地被忽略"
@@ -40476,7 +40537,7 @@ msgstr "%q+D 的宣告隱藏了先前的一個非變數宣告"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: c/c-decl.c:3024 cp/name-lookup.c:2840
+#: c/c-decl.c:3024 cp/name-lookup.c:2842
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD 的宣告隱藏了一個全域宣告"
@@ -40548,7 +40609,7 @@ msgstr "%qE undeclared (先使用在中這個函式)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每個 undeclared 識別碼被報告只一次用於每個函式看來在中"
 
-#: c/c-decl.c:3791 cp/decl.c:3147
+#: c/c-decl.c:3791 cp/decl.c:3149
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "標籤 %qE 在所有函式外被參照"
@@ -40578,7 +40639,7 @@ msgstr "跳轉至敘述運算式中"
 msgid "duplicate label declaration %qE"
 msgstr "重複的標籤定義 %qE"
 
-#: c/c-decl.c:4007 cp/decl.c:3553
+#: c/c-decl.c:4007 cp/decl.c:3555
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複的標籤 %qD"
@@ -40790,7 +40851,7 @@ msgstr "不能將帶有 volatile 欄位的物件放入暫存器"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "uninitialized 常數 %qD 無效在中 C++"
 
-#: c/c-decl.c:5568 cp/decl.c:7933
+#: c/c-decl.c:5568 cp/decl.c:7930
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -41135,7 +41196,7 @@ msgstr "型態名稱宣告的做為函式回傳陣列"
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.c:6788 cp/decl.c:12138
+#: c/c-decl.c:6788 cp/decl.c:12145
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
@@ -41445,7 +41506,7 @@ msgstr "巢狀的 %<struct %E%> 重定義"
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "定義輸入 %qs 運算式無效在中 C++"
 
-#: c/c-decl.c:8084 cp/decl.c:4991
+#: c/c-decl.c:8084 cp/decl.c:4993
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
@@ -41495,7 +41556,7 @@ msgstr "結構不包含任何具名成員"
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.c:8488 cp/decl.c:13089
+#: c/c-decl.c:8488 cp/decl.c:13096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
@@ -41531,7 +41592,7 @@ msgstr "巢狀的 %<enum %E%> 重定義"
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> 重宣告"
 
-#: c/c-decl.c:8862 cp/decl.c:15536
+#: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
@@ -41562,7 +41623,7 @@ msgstr "列舉值溢出"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.c:9159 cp/decl.c:5296 cp/decl.c:16095
+#: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
@@ -41593,7 +41654,7 @@ msgstr "沒有前一個原型用於 %qD"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.c:9288 cp/decl.c:16230
+#: c/c-decl.c:9288 cp/decl.c:16239
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
@@ -41708,12 +41769,12 @@ msgstr "引數 %qD 與內建原型不符"
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.c:9921 cp/decl.c:17115
+#: c/c-decl.c:9928 cp/decl.c:17123
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.c:9940 cp/decl.c:17147
+#: c/c-decl.c:9947 cp/decl.c:17155
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
@@ -41721,265 +41782,265 @@ msgstr "參數 %qD 設定並不是使用"
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:10036
+#: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> 迴圈初始宣告是只有允許的在中 C99 模式"
 
-#: c/c-decl.c:10041
+#: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "使用選項 -std=c99 或 -std=gnu99 到編譯您的編碼"
 
-#: c/c-decl.c:10048
+#: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 
-#: c/c-decl.c:10080
+#: c/c-decl.c:10087
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的靜態變數 %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:10084
+#: c/c-decl.c:10091
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-decl.c:10091
+#: c/c-decl.c:10098
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:10096
+#: c/c-decl.c:10103
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:10100
+#: c/c-decl.c:10107
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:10104
+#: c/c-decl.c:10111
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 non-variable %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:10398
+#: c/c-decl.c:10405
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不相容的位址空間限定元 %qs 和 %qs"
 
-#: c/c-decl.c:10457 c/c-decl.c:10464
+#: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定宣告"
 
-#: c/c-decl.c:10492 c/c-decl.c:10876 c/c-decl.c:11271
+#: c/c-decl.c:10499 c/c-decl.c:10883 c/c-decl.c:11278
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.c:10504 cp/parser.c:30413
+#: c/c-decl.c:10511 cp/parser.c:30438
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
 
-#: c/c-decl.c:10517
+#: c/c-decl.c:10524
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支援 %<long long%>"
 
-#: c/c-decl.c:10746 c/c-parser.c:9995
+#: c/c-decl.c:10753 c/c-parser.c:9995
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:10792
+#: c/c-decl.c:10799
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支援飽和類型"
 
-#: c/c-decl.c:10863 c/c-decl.c:11429
+#: c/c-decl.c:10870 c/c-decl.c:11436
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重複的 %qE"
 
-#: c/c-decl.c:10923
+#: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:10945
+#: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:10988
+#: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:11107
+#: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:11157
+#: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:11228
+#: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.c:11252 c/c-decl.c:11525 c/c-parser.c:9009
+#: c/c-decl.c:11259 c/c-decl.c:11532 c/c-parser.c:9009
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定點類型不支援用於這個目標"
 
-#: c/c-decl.c:11254
+#: c/c-decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支援定點類型"
 
-#: c/c-decl.c:11289
+#: c/c-decl.c:11296
 #, fuzzy, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++查找的 %qD 會回傳欄位，不是型態"
 
-#: c/c-decl.c:11302
+#: c/c-decl.c:11309
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE 不是一個 typedef 類型，也不是一個內建類型"
 
-#: c/c-decl.c:11351
+#: c/c-decl.c:11358
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: c/c-decl.c:11372
+#: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
-#: c/c-decl.c:11374
+#: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.c:11376
+#: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: c/c-decl.c:11390 c/c-parser.c:8374
+#: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支援 %qE"
 
-#: c/c-decl.c:11393 c/c-parser.c:8377
+#: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支援 %qE"
 
-#: c/c-decl.c:11405
+#: c/c-decl.c:11412
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> 出現在 %<extern%> 之前"
 
-#: c/c-decl.c:11414
+#: c/c-decl.c:11421
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> 出現在 %<static%> 之前"
 
-#: c/c-decl.c:11427
+#: c/c-decl.c:11434
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:11435
+#: c/c-decl.c:11442
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣告指定了多個存儲類別"
 
-#: c/c-decl.c:11443
+#: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-decl.c:11522
+#: c/c-decl.c:11529
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>被使用而無需 %<_Fract%>或 %<_Accum%>"
 
-#: c/c-decl.c:11537
+#: c/c-decl.c:11544
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: c/c-decl.c:11564
+#: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.c:11590 c/c-decl.c:11606 c/c-decl.c:11632
+#: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.c:12031 cp/semantics.c:5624
+#: c/c-decl.c:12038 cp/semantics.c:5624
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:12035 cp/semantics.c:5628
+#: c/c-decl.c:12042 cp/semantics.c:5628
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:386 c/c-typeck.c:11920 cp/typeck.c:4906
+#: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:396 c/c-typeck.c:11929 cp/typeck.c:4914
+#: c/c-fold.c:397 c/c-typeck.c:11929 cp/typeck.c:4972
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:397 c/c-typeck.c:11858 cp/typeck.c:4854
+#: c/c-fold.c:398 c/c-typeck.c:11858 cp/typeck.c:4912
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次數為負"
 
-#: c/c-fold.c:405 c/c-typeck.c:11948 cp/typeck.c:4922
+#: c/c-fold.c:406 c/c-typeck.c:11948 cp/typeck.c:4980
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:406 c/c-typeck.c:11882 cp/typeck.c:4865
+#: c/c-fold.c:407 c/c-typeck.c:11882 cp/typeck.c:4923
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次數大於或等於類型寬度"
 
-#: c/c-fold.c:413 c/c-typeck.c:11940
+#: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:414 c/c-typeck.c:11869
+#: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -42000,7 +42061,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: c/c-parser.c:1296 cp/parser.c:30647
+#: c/c-parser.c:1296 cp/parser.c:30672
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -42046,7 +42107,7 @@ msgid "unknown type name %qE"
 msgstr "不明型態名稱 %qE"
 
 #: c/c-parser.c:1969 c/c-parser.c:12498 c/c-parser.c:18659 c/c-parser.c:19170
-#: c/c-parser.c:19679 cp/parser.c:40091 cp/parser.c:43923
+#: c/c-parser.c:19679 cp/parser.c:40117 cp/parser.c:43949
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -42067,7 +42128,7 @@ msgstr "%q+D 不能有 section 屬性"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.c:2034 cp/parser.c:32843 cp/parser.c:32917
+#: c/c-parser.c:2034 cp/parser.c:32869 cp/parser.c:32943
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -42082,8 +42143,8 @@ msgstr "前綴屬性被忽略用於實作"
 msgid "unexpected attribute"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11503
-#: cp/parser.c:11710
+#: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
+#: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -42125,7 +42186,7 @@ msgstr "檔案作用欄位中出現 %<auto%> 空宣告"
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: c/c-parser.c:2381 cp/parser.c:13840
+#: c/c-parser.c:2381 cp/parser.c:13845
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要 %<,%> 或 %<;%>"
@@ -42153,7 +42214,7 @@ msgstr "ISO C99 不支援 %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支援 %<_Static_assert%>"
 
-#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43531
+#: c/c-parser.c:2611 c/c-parser.c:7402 c/c-parser.c:12559 cp/parser.c:43557
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字串"
@@ -42183,7 +42244,7 @@ msgstr "運算式在中靜態假設不是常數"
 msgid "static assertion failed: %E"
 msgstr "靜態假設失敗：%E"
 
-#: c/c-parser.c:2649 cp/semantics.c:9686
+#: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "靜態假設失敗：%E"
@@ -42230,14 +42291,14 @@ msgstr "範本參數 %d 無效"
 #: c/c-parser.c:12087 c/c-parser.c:12140 c/c-parser.c:12156 c/c-parser.c:12202
 #: c/c-parser.c:12986 c/c-parser.c:13019 c/c-parser.c:15269 c/c-parser.c:15379
 #: c/c-parser.c:15652 c/c-parser.c:17751 c/c-parser.c:20193 c/c-parser.c:20384
-#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8693
-#: cp/parser.c:30650 cp/parser.c:33699 cp/parser.c:33729 cp/parser.c:33799
-#: cp/parser.c:36297 cp/parser.c:36419 cp/parser.c:41637 cp/parser.c:43235
+#: c/gimple-parser.c:1776 c/gimple-parser.c:1814 cp/parser.c:8698
+#: cp/parser.c:30675 cp/parser.c:33725 cp/parser.c:33755 cp/parser.c:33825
+#: cp/parser.c:36323 cp/parser.c:36445 cp/parser.c:41663 cp/parser.c:43261
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
 
-#: c/c-parser.c:3204 cp/parser.c:19435
+#: c/c-parser.c:3204 cp/parser.c:19445
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列舉表以逗號結尾"
@@ -42322,7 +42383,7 @@ msgstr "需要指定宣告或 %<...%>"
 msgid "parentheses must be omitted if attribute argument list is empty"
 msgstr ""
 
-#: c/c-parser.c:4903 cp/parser.c:26871
+#: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE 屬性沒有任何效果"
@@ -42333,7 +42394,7 @@ msgstr "%qE 屬性沒有任何效果"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 
-#: c/c-parser.c:4987 cp/parser.c:26937
+#: c/c-parser.c:4987 cp/parser.c:26953
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
@@ -42393,7 +42454,7 @@ msgstr "ISO C90 禁止混合的宣告和編碼"
 msgid "expected %<}%> before %<else%>"
 msgstr "預期 %<}%>之前 %<else%>expected %<}%> before %<else%>預期 %<}%>之前 %<else%>"
 
-#: c/c-parser.c:5793 cp/parser.c:11833
+#: c/c-parser.c:5793 cp/parser.c:11838
 #, fuzzy, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> 而無需前一個 %<if%>"
@@ -42408,7 +42469,7 @@ msgstr "標籤位於複合敘述末尾"
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
 #: c/c-parser.c:5831 c/c-parser.c:6293 c/gimple-parser.c:2276
-#: cp/parser.c:11453
+#: cp/parser.c:11458
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要敘述"
@@ -42433,17 +42494,17 @@ msgstr "標貼只能是部分的敘述和宣告並非敘述"
 msgid "expected identifier or %<*%>"
 msgstr "需要識別碼或 %<*%>"
 
-#: c/c-parser.c:6400 cp/parser.c:13214
+#: c/c-parser.c:6400 cp/parser.c:13219
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建議大括號周圍清空內文在中 %<if%> 敘述"
 
-#: c/c-parser.c:6442 cp/parser.c:13217
+#: c/c-parser.c:6442 cp/parser.c:13222
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建議大括號周圍清空內文在中 %<else%> 敘述"
 
-#: c/c-parser.c:6576 cp/parser.c:12110
+#: c/c-parser.c:6576 cp/parser.c:12115
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建議明確的大括號到避免模稜兩可的 %<else%>"
@@ -42463,12 +42524,12 @@ msgstr "多重迭代變數在中快速列舉類型"
 msgid "invalid iterating variable in fast enumeration"
 msgstr "無效的迭代變數在中快速列舉類型"
 
-#: c/c-parser.c:6946 cp/parser.c:12382
+#: c/c-parser.c:6946 cp/parser.c:12387
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6952 cp/parser.c:12388
+#: c/c-parser.c:6952 cp/parser.c:12393
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -42484,8 +42545,8 @@ msgstr "缺少收集在中快速列舉類型"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重複的 cv 限定"
 
-#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20209
-#: cp/parser.c:20226 cp/parser.c:20240
+#: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
+#: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
 #| msgid "%J  first type here"
 msgid "first seen here"
@@ -42514,12 +42575,12 @@ msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:7877 cp/typeck.c:4689
+#: c/c-parser.c:7877 cp/typeck.c:4747
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:7883 cp/typeck.c:4694
+#: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "型態的欄位宣告的在此"
@@ -42922,61 +42983,61 @@ msgstr "objective-c 方法宣告被預期"
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33759
+#: c/c-parser.c:12003 c/c-parser.c:12060 cp/parser.c:33785
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:12024 cp/parser.c:33719
+#: c/c-parser.c:12024 cp/parser.c:33745
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: c/c-parser.c:12027 cp/parser.c:33722
+#: c/c-parser.c:12027 cp/parser.c:33748
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "缺少%<=%>(之後 %<setter%>屬性)missing %<=%> (after %<setter%> attribute)缺少%<=%>(之後 %<setter%>屬性)"
 
-#: c/c-parser.c:12041 cp/parser.c:33737
+#: c/c-parser.c:12041 cp/parser.c:33763
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:12046 cp/parser.c:33743
+#: c/c-parser.c:12046 cp/parser.c:33769
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.c:12053 cp/parser.c:33751
+#: c/c-parser.c:12053 cp/parser.c:33777
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:12247 cp/parser.c:43571
+#: c/c-parser.c:12247 cp/parser.c:43597
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:12291 c/c-parser.c:19167 c/c-parser.c:19458 c/c-parser.c:19517
-#: c/c-parser.c:19601 cp/parser.c:40088 cp/parser.c:40418 cp/parser.c:40506
-#: cp/parser.c:40577 cp/parser.c:43618 cp/parser.c:43633 cp/parser.c:43648
-#: cp/parser.c:43664 cp/parser.c:43680 cp/parser.c:43696 cp/parser.c:43723
-#: cp/parser.c:43736 cp/parser.c:43759 cp/parser.c:43772
+#: c/c-parser.c:19601 cp/parser.c:40114 cp/parser.c:40444 cp/parser.c:40532
+#: cp/parser.c:40603 cp/parser.c:43644 cp/parser.c:43659 cp/parser.c:43674
+#: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
+#: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:12314 cp/parser.c:43749
+#: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:12401 cp/parser.c:43842
+#: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.c:12408 cp/parser.c:43848
+#: c/c-parser.c:12408 cp/parser.c:43874
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
@@ -42986,18 +43047,18 @@ msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp secti
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43877 cp/parser.c:43910
+#: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:12480 cp/parser.c:43608
+#: c/c-parser.c:12480 cp/parser.c:43634
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
 #: c/c-parser.c:12817 c/c-parser.c:15763 c/c-parser.c:21198 c/c-parser.c:21206
-#: cp/parser.c:34165 cp/parser.c:36770 cp/parser.c:42687 cp/parser.c:42695
+#: cp/parser.c:34191 cp/parser.c:36796 cp/parser.c:42713 cp/parser.c:42721
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
@@ -43017,53 +43078,53 @@ msgstr "預期 %<,%>或 %<)%>"
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:13255 cp/semantics.c:7466
+#: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:13297 cp/parser.c:34844
+#: c/c-parser.c:13297 cp/parser.c:34870
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:13374 cp/parser.c:34908
+#: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:13376 cp/parser.c:34910
+#: c/c-parser.c:13376 cp/parser.c:34936
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:13496 cp/parser.c:35021
+#: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35039
-#: cp/parser.c:40410 cp/parser.c:40498
+#: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
+#: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.c:13569 cp/parser.c:35094
+#: c/c-parser.c:13569 cp/parser.c:35120
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:13576 cp/parser.c:35101
+#: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:13578 cp/parser.c:35103
+#: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:13584 cp/parser.c:35109
+#: c/c-parser.c:13584 cp/parser.c:35135
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -43085,12 +43146,12 @@ msgstr "%<num_threads%> 值必須是正值"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13792 cp/semantics.c:7669
+#: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13839 cp/semantics.c:7699
+#: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
@@ -43100,22 +43161,22 @@ msgstr "『%s』於 %L 必須是 nonnegative"
 msgid "expected constant integer expression"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.c:13914 cp/parser.c:35334
+#: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:13975 cp/parser.c:35399
+#: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:14041 cp/parser.c:35468
+#: c/c-parser.c:14041 cp/parser.c:35494
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.c:14044 cp/parser.c:35471
+#: c/c-parser.c:14044 cp/parser.c:35497
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
@@ -43130,53 +43191,53 @@ msgstr "numthreads 運算式必須是積分(_T)"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:14192 cp/parser.c:34616
+#: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多引數"
 
-#: c/c-parser.c:14226 cp/parser.c:34649
+#: c/c-parser.c:14226 cp/parser.c:34675
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:14393 cp/semantics.c:7831
+#: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 屬性引數不是整數常數"
 
-#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35503 cp/parser.c:35513
+#: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:14491 cp/parser.c:35551
+#: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:14544 cp/parser.c:35619
+#: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42346
+#: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:14782 cp/parser.c:35870
+#: c/c-parser.c:14782 cp/parser.c:35896
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "宣告中同時使用了 %<long%> 和 %<void%>"
 
-#: c/c-parser.c:14836 cp/parser.c:35886
+#: c/c-parser.c:14836 cp/parser.c:35912
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:14840 cp/parser.c:35889
+#: c/c-parser.c:14840 cp/parser.c:35915
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
@@ -43186,7 +43247,7 @@ msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:14875 cp/parser.c:35909
+#: c/c-parser.c:14875 cp/parser.c:35935
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -43221,23 +43282,23 @@ msgstr "崩潰引數需要正面的常數整數運算式"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:15506 cp/parser.c:36551
+#: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs 是不相容的與 %qs"
 
-#: c/c-parser.c:15553 cp/parser.c:36599 cp/parser.c:36828 cp/parser.c:36878
+#: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:15640 cp/parser.c:36674
+#: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.c:15738 cp/parser.c:36775
+#: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -43252,79 +43313,79 @@ msgstr "無效的排程 kind"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:16082 cp/parser.c:37109
+#: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37120 cp/parser.c:37483
+#: c/c-parser.c:16093 c/c-parser.c:16417 cp/parser.c:37146 cp/parser.c:37509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.c:16137 cp/parser.c:37167
+#: c/c-parser.c:16137 cp/parser.c:37193
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.c:16278 cp/parser.c:37345
+#: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.c:16406 cp/parser.c:37472
+#: c/c-parser.c:16406 cp/parser.c:37498
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:16539 cp/parser.c:40925
+#: c/c-parser.c:16539 cp/parser.c:40951
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16549 cp/parser.c:40935
+#: c/c-parser.c:16549 cp/parser.c:40961
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-parser.c:16569 cp/parser.c:40955
+#: c/c-parser.c:16569 cp/parser.c:40981
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:16580 cp/parser.c:40966
+#: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "無效的輸入宣告"
 
-#: c/c-parser.c:16587 cp/parser.c:40973
+#: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-parser.c:16595 cp/parser.c:40981
+#: c/c-parser.c:16595 cp/parser.c:41007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:16606 cp/parser.c:40999
+#: c/c-parser.c:16606 cp/parser.c:41025
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:16616 cp/parser.c:41009
+#: c/c-parser.c:16616 cp/parser.c:41035
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:16709 cp/parser.c:41096
+#: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.c:16725 cp/parser.c:41113
+#: c/c-parser.c:16725 cp/parser.c:41139
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -43339,7 +43400,7 @@ msgstr "%qE 未被宣告"
 msgid "expected function name"
 msgstr "預期的函式"
 
-#: c/c-parser.c:16996 cp/parser.c:42930
+#: c/c-parser.c:16996 cp/parser.c:42956
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -43350,67 +43411,67 @@ msgstr "%qD 不是一個成員範本函式"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17059 cp/parser.c:42984 cp/parser.c:43029
+#: c/c-parser.c:17059 cp/parser.c:43010 cp/parser.c:43055
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17090 cp/parser.c:43058
+#: c/c-parser.c:17090 cp/parser.c:43084
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:17091 cp/parser.c:43060
+#: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:17135 cp/parser.c:41314
+#: c/c-parser.c:17135 cp/parser.c:41340
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:17287 cp/parser.c:37650
+#: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:17296 cp/parser.c:37659
+#: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:17303 cp/parser.c:37666
+#: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:17358 cp/parser.c:37721
+#: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<acq_rel%> or %<release%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17367 cp/parser.c:37730
+#: c/c-parser.c:17367 cp/parser.c:37756
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17376 cp/parser.c:37739
+#: c/c-parser.c:17376 cp/parser.c:37765
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> incompatible with %<acq_rel%> or %<acquire%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17642 cp/parser.c:37944 cp/parser.c:37970
+#: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:17646 cp/parser.c:38001 cp/parser.c:38017
+#: c/c-parser.c:17646 cp/parser.c:38027 cp/parser.c:38043
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:17695 cp/semantics.c:9322 cp/semantics.c:9332
+#: c/c-parser.c:17695 cp/semantics.c:9338 cp/semantics.c:9348
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
@@ -43420,58 +43481,58 @@ msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:17804 cp/semantics.c:9397
+#: c/c-parser.c:17804 cp/semantics.c:9413
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: c/c-parser.c:17861 cp/parser.c:38202
+#: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "需要 %<:%>，%<,%>，%<;%>，%<}%> 或 %<__attribute__%>"
 
-#: c/c-parser.c:17873 cp/parser.c:38218
+#: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:17909 cp/parser.c:38251
+#: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:17916 cp/parser.c:38258
+#: c/c-parser.c:17916 cp/parser.c:38284
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
 
-#: c/c-parser.c:17975 cp/parser.c:38863
+#: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:17980 cp/parser.c:38869
+#: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:18035 cp/parser.c:38920
+#: c/c-parser.c:18035 cp/parser.c:38946
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:18046 cp/parser.c:38931
+#: c/c-parser.c:18046 cp/parser.c:38957
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:18064 cp/parser.c:38959
+#: c/c-parser.c:18064 cp/parser.c:38985
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:18134 cp/semantics.c:8919 cp/semantics.c:9010
+#: c/c-parser.c:18134 cp/semantics.c:8935 cp/semantics.c:9026
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
@@ -43481,73 +43542,73 @@ msgstr "預期的迭代宣告或初始化"
 msgid "not enough perfectly nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.c:18284 cp/parser.c:39273
+#: c/c-parser.c:18284 cp/parser.c:39299
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.c:18331 cp/parser.c:39069 cp/parser.c:39111 cp/pt.c:17552
+#: c/c-parser.c:18331 cp/parser.c:39095 cp/parser.c:39137 cp/pt.c:17586
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.c:18465 cp/parser.c:39392
+#: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-parser.c:18678 cp/parser.c:39609
+#: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:18886 cp/parser.c:39808
+#: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.c:19158 cp/parser.c:40079
+#: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:19407 cp/parser.c:40348
+#: c/c-parser.c:19407 cp/parser.c:40374
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19423 cp/parser.c:40364
+#: c/c-parser.c:19423 cp/parser.c:40390
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.c:19471 cp/parser.c:40590
+#: c/c-parser.c:19471 cp/parser.c:40616
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:19543 cp/parser.c:40445
+#: c/c-parser.c:19543 cp/parser.c:40471
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19555 cp/parser.c:40457
+#: c/c-parser.c:19555 cp/parser.c:40483
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19629 cp/parser.c:40534
+#: c/c-parser.c:19629 cp/parser.c:40560
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19642 cp/parser.c:40547
+#: c/c-parser.c:19642 cp/parser.c:40573
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:19861 cp/parser.c:40804
+#: c/c-parser.c:19861 cp/parser.c:40830
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -43562,58 +43623,58 @@ msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:20035 cp/parser.c:41465
+#: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "預期 selection-statement"
 
-#: c/c-parser.c:20088 cp/parser.c:41517
+#: c/c-parser.c:20088 cp/parser.c:41543
 #, gcc-internal-format
 msgid "selector %qs not allowed for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.c:20113 cp/parser.c:41541
+#: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s 只有接受 2 引數"
 
-#: c/c-parser.c:20140 cp/parser.c:41580 cp/pt.c:11321
+#: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:20143 cp/parser.c:41583 cp/pt.c:11338
+#: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.c:20167 cp/parser.c:41611 cp/pt.c:11324
+#: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: c/c-parser.c:20212 cp/parser.c:41655
+#: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "需要字面字串"
 
-#: c/c-parser.c:20234 cp/parser.c:41677 cp/pt.c:11328
+#: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.c:20245 cp/parser.c:41688
+#: c/c-parser.c:20245 cp/parser.c:41714
 #, fuzzy, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "內容 %qs 已經指定的在中 %<@synthesize%>"
 
-#: c/c-parser.c:20332 cp/parser.c:41774
+#: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:20407 cp/parser.c:41882
+#: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "預期 %<catch%>"
@@ -43623,13 +43684,13 @@ msgstr "預期 %<catch%>"
 msgid "variant %qD is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: c/c-parser.c:20433 cp/decl.c:7318
+#: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不相容"
 
-#: c/c-parser.c:20445 cp/decl.c:7327
+#: c/c-parser.c:20445 cp/decl.c:7321
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
@@ -43639,32 +43700,32 @@ msgstr ""
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:20496 cp/parser.c:41927
+#: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:20605 cp/parser.c:42032
+#: c/c-parser.c:20605 cp/parser.c:42058
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:20654 cp/parser.c:42081
+#: c/c-parser.c:20654 cp/parser.c:42107
 #, gcc-internal-format
 msgid "directive with only %<device_type%> clauses ignored"
 msgstr ""
 
-#: c/c-parser.c:20673 cp/parser.c:42106
+#: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.c:20680 cp/parser.c:42113
+#: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "預期 %<decltype%>"
 
-#: c/c-parser.c:20686 cp/parser.c:42120
+#: c/c-parser.c:20686 cp/parser.c:42146
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
@@ -43719,43 +43780,43 @@ msgstr "預期的函式"
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:21096 cp/parser.c:42580
+#: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:21160 cp/parser.c:42643
+#: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.c:21180 cp/parser.c:42669
+#: c/c-parser.c:21180 cp/parser.c:42695
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.c:21189 cp/parser.c:42678
+#: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: c/c-parser.c:21201 cp/parser.c:42690
+#: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.c:21213 cp/parser.c:42702
+#: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.c:21222 cp/parser.c:42711
+#: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.c:21236 cp/parser.c:42725
+#: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
@@ -43770,27 +43831,27 @@ msgstr ""
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-parser.c:21497 cp/semantics.c:8358
+#: c/c-parser.c:21497 cp/semantics.c:8374
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.c:21499 cp/semantics.c:8360
+#: c/c-parser.c:21499 cp/semantics.c:8376
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.c:21503 cp/semantics.c:8362
+#: c/c-parser.c:21503 cp/semantics.c:8378
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
 
-#: c/c-parser.c:21682 cp/parser.c:43459
+#: c/c-parser.c:21682 cp/parser.c:43485
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.c:21688 cp/parser.c:43465
+#: c/c-parser.c:21688 cp/parser.c:43491
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
@@ -43800,7 +43861,7 @@ msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> 函式呼叫無法在之內外異動作業或 %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:21705 cp/parser.c:43483
+#: c/c-parser.c:21705 cp/parser.c:43509
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
@@ -43816,7 +43877,7 @@ msgstr "封閉平行"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD 類型不完全"
 
-#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4459
+#: c/c-typeck.c:238 c/c-typeck.c:10461 c/c-typeck.c:10503 cp/call.c:4461
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "對 void 運算式的無效使用"
@@ -43940,7 +44001,7 @@ msgstr "提領 %<void *%> 指標"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "註標的值是 neither 陣列 nor 指標 nor 向量"
 
-#: c/c-typeck.c:2642 cp/typeck.c:3529 cp/typeck.c:3622
+#: c/c-typeck.c:2642 cp/typeck.c:3587 cp/typeck.c:3680
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "陣列下標不是一個整數"
@@ -43965,7 +44026,7 @@ msgstr "ISO C90 不允許非左值的陣列做為下標運算的左運算元"
 msgid "enum constant defined here"
 msgstr "enum 常數定義的在此"
 
-#: c/c-typeck.c:2926 cp/typeck.c:1773
+#: c/c-typeck.c:2926 cp/typeck.c:1815
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -44080,18 +44141,18 @@ msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "提供給函式 %qE 的引數太少"
 
-#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:4952 cp/typeck.c:5221
+#: c/c-typeck.c:3847 c/c-typeck.c:3875 cp/typeck.c:5010 cp/typeck.c:5279
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "比較與字串實字結果於未規定行為"
 
-#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:4979 cp/typeck.c:5003
+#: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比較指標和整數"
 
-#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:4982 cp/typeck.c:5006
+#: c/c-typeck.c:3858 c/c-typeck.c:3869 cp/typeck.c:5040 cp/typeck.c:5064
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -44117,7 +44178,7 @@ msgstr "函式指標不能相減"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:3987 cp/typeck.c:5905
+#: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -44374,7 +44435,7 @@ msgstr "當將一個指標轉換為大小不同的整數時給出警告"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: c/c-typeck.c:5896 cp/typeck.c:8243
+#: c/c-typeck.c:5896 cp/typeck.c:8303
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
@@ -44551,7 +44612,7 @@ msgstr "賦值的左手邊可能是 format 屬性的備選時"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:7138 cp/typeck.c:9349
+#: c/c-typeck.c:7138 cp/typeck.c:9409
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
@@ -44724,7 +44785,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字串常數初始化的陣列類型不合適"
 
-#: c/c-typeck.c:7912 cp/typeck.c:2149
+#: c/c-typeck.c:7912 cp/typeck.c:2191
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "對非左值陣列的無效使用"
@@ -44755,7 +44816,7 @@ msgstr "初始值設定中的元素在載入時無法被計算出"
 msgid "invalid initializer"
 msgstr "無效的初始值設定"
 
-#: c/c-typeck.c:8310 cp/decl.c:6709
+#: c/c-typeck.c:8310 cp/decl.c:6713
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
@@ -44901,7 +44962,7 @@ msgstr "標量初始值設定項中有多餘元素"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允許 %<goto *expr;%>"
 
-#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9797
+#: c/c-typeck.c:10581 c/gimple-parser.c:2404 cp/typeck.c:9857
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
@@ -44942,7 +45003,7 @@ msgstr "在 ISO C 中，%<long%> 開關運算式不被轉換為 %<int%>"
 msgid "case label is not an integer constant expression"
 msgstr "大小寫標貼不是整數常數運算式"
 
-#: c/c-typeck.c:10868 cp/parser.c:11624
+#: c/c-typeck.c:10868 cp/parser.c:11629
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 標籤出現在開關敘述外"
@@ -44952,17 +45013,17 @@ msgstr "case 標籤出現在開關敘述外"
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> 標籤未出現在 switch 敘述內"
 
-#: c/c-typeck.c:11052 cp/parser.c:13050
+#: c/c-typeck.c:11052 cp/parser.c:13055
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:11054 cp/parser.c:13073
+#: c/c-typeck.c:11054 cp/parser.c:13078
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:11059 cp/parser.c:13063
+#: c/c-typeck.c:11059 cp/parser.c:13068
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "中斷敘述使用的與 OpenMP 用於迴圈"
@@ -44979,7 +45040,7 @@ msgstr "break 敘述不在循環或開關敘述內"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:11092 cp/cp-gimplify.c:499
+#: c/c-typeck.c:11092 cp/cp-gimplify.c:500
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "敘述不起作用"
@@ -44989,22 +45050,22 @@ msgstr "敘述不起作用"
 msgid "expression statement has incomplete type"
 msgstr "運算式敘述類型不完全"
 
-#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5235
+#: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "比較向量與不同的元件類型"
 
-#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5248
+#: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "比較向量與不同的元件號碼的"
 
-#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5283
+#: c/c-typeck.c:12003 c/c-typeck.c:12171 cp/typeck.c:5341
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: c/c-typeck.c:12017 cp/typeck.c:4941
+#: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -45056,7 +45117,7 @@ msgid "ordered comparison of pointer with null pointer"
 msgstr "已排序的比較的指標與空指標"
 
 #: c/c-typeck.c:12230 c/c-typeck.c:12233 c/c-typeck.c:12240 c/c-typeck.c:12243
-#: cp/typeck.c:5306 cp/typeck.c:5313
+#: cp/typeck.c:5364 cp/typeck.c:5371
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指標與整數 0 比較大小"
@@ -45086,53 +45147,53 @@ msgstr "需要標量時使用了聯合類型"
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.c:12840 cp/semantics.c:9470
+#: c/c-typeck.c:12840 cp/semantics.c:9486
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9481
-#: cp/semantics.c:9491
+#: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
+#: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "預期 %<;%>之後類別定義"
 
-#: c/c-typeck.c:12896 cp/semantics.c:9526
+#: c/c-typeck.c:12896 cp/semantics.c:9542
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14569 c/c-typeck.c:14640
+#: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14555
-#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7368
+#: c/c-typeck.c:12952 c/c-typeck.c:14430 c/c-typeck.c:14571
+#: cp/semantics.c:4766 cp/semantics.c:7226 cp/semantics.c:7384
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12961 c/c-typeck.c:14579 cp/semantics.c:4776
-#: cp/semantics.c:7387
+#: c/c-typeck.c:12961 c/c-typeck.c:14595 cp/semantics.c:4776
+#: cp/semantics.c:7403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD 不是一個成員範本函式"
 
-#: c/c-typeck.c:12969 c/c-typeck.c:14588
+#: c/c-typeck.c:12969 c/c-typeck.c:14604
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot dereference %qE in %qs clause"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7414
+#: c/c-typeck.c:12980 cp/semantics.c:4792 cp/semantics.c:7430
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12984 c/c-typeck.c:14605 cp/semantics.c:4796
-#: cp/semantics.c:7418
+#: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
+#: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -45142,8 +45203,8 @@ msgstr "%qE 並非變數在中子句 %qs"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:13000 c/c-typeck.c:14612 c/c-typeck.c:14722
-#: cp/semantics.c:4814 cp/semantics.c:7425 cp/semantics.c:7604
+#: c/c-typeck.c:13000 c/c-typeck.c:14628 c/c-typeck.c:14738
+#: cp/semantics.c:4814 cp/semantics.c:7441 cp/semantics.c:7620
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
@@ -45316,12 +45377,12 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:14112 c/c-typeck.c:14796 cp/semantics.c:8045
+#: c/c-typeck.c:14112 c/c-typeck.c:14812 cp/semantics.c:8061
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:14124 cp/semantics.c:8088
+#: c/c-typeck.c:14124 cp/semantics.c:8104
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
@@ -45346,8 +45407,8 @@ msgstr ""
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:14203 c/c-typeck.c:14715 c/c-typeck.c:14920
-#: cp/semantics.c:6595 cp/semantics.c:7597 cp/semantics.c:7892
+#: c/c-typeck.c:14203 c/c-typeck.c:14731 c/c-typeck.c:14936
+#: cp/semantics.c:6595 cp/semantics.c:7613 cp/semantics.c:7908
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -45362,19 +45423,19 @@ msgstr "%qD 出現一次以上在中資料子句"
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14651
-#: c/c-typeck.c:14658 c/c-typeck.c:14674 c/c-typeck.c:14685
+#: c/c-typeck.c:14239 c/c-typeck.c:14270 c/c-typeck.c:14519 c/c-typeck.c:14667
+#: c/c-typeck.c:14674 c/c-typeck.c:14690 c/c-typeck.c:14701
 #: cp/semantics.c:6623 cp/semantics.c:6631 cp/semantics.c:6688
 #: cp/semantics.c:6695 cp/semantics.c:6739 cp/semantics.c:7317
-#: cp/semantics.c:7476 cp/semantics.c:7483 cp/semantics.c:7501
-#: cp/semantics.c:7512
+#: cp/semantics.c:7492 cp/semantics.c:7499 cp/semantics.c:7517
+#: cp/semantics.c:7528
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14661 c/c-typeck.c:14688
-#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7486
-#: cp/semantics.c:7515
+#: c/c-typeck.c:14242 c/c-typeck.c:14273 c/c-typeck.c:14677 c/c-typeck.c:14704
+#: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
+#: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
@@ -45445,119 +45506,119 @@ msgstr ""
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:14515 c/c-typeck.c:14671 cp/semantics.c:7313
-#: cp/semantics.c:7498
+#: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
+#: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14523 c/c-typeck.c:14677 cp/semantics.c:7321
-#: cp/semantics.c:7504
+#: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
+#: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14562 cp/semantics.c:7375
+#: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14631 c/c-typeck.c:14729 cp/semantics.c:7455
-#: cp/semantics.c:7611
+#: c/c-typeck.c:14647 c/c-typeck.c:14745 cp/semantics.c:7471
+#: cp/semantics.c:7627
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14710 cp/semantics.c:7591
+#: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14738 cp/semantics.c:7621
+#: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:14752 cp/semantics.c:7637
+#: c/c-typeck.c:14768 cp/semantics.c:7653
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14755 cp/semantics.c:7640
+#: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:14772
+#: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is not a pointer"
 msgstr "來源並非指標"
 
-#: c/c-typeck.c:14779
+#: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:14809 c/c-typeck.c:14881 cp/semantics.c:8034
+#: c/c-typeck.c:14825 c/c-typeck.c:14897 cp/semantics.c:8050
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: c/c-typeck.c:14903 cp/semantics.c:7860
+#: c/c-typeck.c:14919 cp/semantics.c:7876
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:14970 cp/semantics.c:8147
+#: c/c-typeck.c:14986 cp/semantics.c:8163
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: c/c-typeck.c:14980
+#: c/c-typeck.c:14996
 #, gcc-internal-format
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:14999 cp/semantics.c:7986
+#: c/c-typeck.c:15015 cp/semantics.c:8002
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:15011 cp/semantics.c:7999
+#: c/c-typeck.c:15027 cp/semantics.c:8015
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15022 c/c-typeck.c:15030 cp/semantics.c:8008
-#: cp/semantics.c:8026
+#: c/c-typeck.c:15038 c/c-typeck.c:15046 cp/semantics.c:8024
+#: cp/semantics.c:8042
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-typeck.c:15045 cp/semantics.c:7966
+#: c/c-typeck.c:15061 cp/semantics.c:7982
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15062 cp/semantics.c:8016
+#: c/c-typeck.c:15078 cp/semantics.c:8032
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:15229
+#: c/c-typeck.c:15245
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:15234
+#: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "給 %<va_arg%> 的第一個參數的類型不是 %<va_list%>"
 
-#: c/c-typeck.c:15240
+#: c/c-typeck.c:15256
 #, fuzzy, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++需求升級的型態，無法 enum 型態，在中 %<va_arg%>"
@@ -45754,824 +45815,824 @@ msgid "expected case label"
 msgstr "需要類別名"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
-#: cp/call.c:3652
+#: cp/call.c:3654
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "  passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:3656
+#: cp/call.c:3658
 #, fuzzy
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  沒有已知轉換用於隱含的 %<this%> 參數從 %qT 到 %qT"
 
-#: cp/call.c:3663
+#: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
 #. Conversion of conversion function return value failed.
-#: cp/call.c:3670
+#: cp/call.c:3672
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:3676
+#: cp/call.c:3678
 #, fuzzy
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
-#: cp/call.c:3688 cp/pt.c:6807
+#: cp/call.c:3690 cp/pt.c:6816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/call.c:3716
+#: cp/call.c:3718
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T, %T) <built-in>"
 
-#: cp/call.c:3721
+#: cp/call.c:3723
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T) <built-in>"
 
-#: cp/call.c:3725
+#: cp/call.c:3727
 #, fuzzy, gcc-internal-format
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%D(%T) <built-in>"
 
-#: cp/call.c:3729
+#: cp/call.c:3731
 #, fuzzy, gcc-internal-format
 msgid "%s%qT (conversion)"
 msgstr "%s%T <conversion>"
 
-#: cp/call.c:3731
+#: cp/call.c:3733
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD (near match)"
 msgstr "%s%#D <near match>"
 
-#: cp/call.c:3733
+#: cp/call.c:3735
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD (deleted)"
 msgstr "%s%#D <deleted>"
 
-#: cp/call.c:3735
+#: cp/call.c:3737
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD (reversed)"
 msgstr "%s%#D <deleted>"
 
-#: cp/call.c:3737
+#: cp/call.c:3739
 #, gcc-internal-format
 msgid "%s%#qD (rewritten)"
 msgstr ""
 
-#: cp/call.c:3739
+#: cp/call.c:3741
 #, fuzzy, gcc-internal-format
 msgid "%s%#qD"
 msgstr "%s%#D"
 
-#: cp/call.c:3743
+#: cp/call.c:3745
 #, fuzzy, gcc-internal-format
 #| msgid "%J  other type here"
 msgid "  inherited here"
 msgstr "%J  其它類型在這裡"
 
-#: cp/call.c:3763
+#: cp/call.c:3765
 #, fuzzy, gcc-internal-format
 msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
 msgstr "  傳回類型 %qT 的明確的轉換函式無法轉換到 %qT 與合格轉換"
 
-#: cp/call.c:3769
+#: cp/call.c:3771
 #, fuzzy, gcc-internal-format
 msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
 msgstr "  轉換從傳回類型 %qT 的模板轉換函式特殊化到 %qT 不是精確的匹配"
 
-#: cp/call.c:3780
+#: cp/call.c:3782
 #, fuzzy, gcc-internal-format
 msgid "  substitution of deduced template arguments resulted in errors seen above"
 msgstr "  替代的 deduced 模板引數結果的在中錯誤看見以上的"
 
 #. Re-run template unification with diagnostics.
-#: cp/call.c:3785
+#: cp/call.c:3787
 #, fuzzy, gcc-internal-format
 msgid "  template argument deduction/substitution failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/call.c:3799
+#: cp/call.c:3801
 #, fuzzy, gcc-internal-format
 msgid "  a constructor taking a single argument of its own class type is invalid"
 msgstr "  建構子需單一引數的它的本身類別型態無效"
 
-#: cp/call.c:3806
+#: cp/call.c:3808
 #, gcc-internal-format
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:4199
+#: cp/call.c:4201
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "從 %qT 到 %qT 的轉換有歧義"
 
-#: cp/call.c:4345
+#: cp/call.c:4347
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4366
+#: cp/call.c:4368
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/call.c:4400 cp/call.c:11869 cp/cvt.c:855
+#: cp/call.c:4402 cp/call.c:11899 cp/cvt.c:855
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "無法轉換 %qE 從 %qT 到 %qT"
 
-#: cp/call.c:4548
+#: cp/call.c:4550
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:4551
+#: cp/call.c:4553
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "呼叫多載的 %<%D(%A)%> 有歧義"
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4775
+#: cp/call.c:4777
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "沒有物件不能呼叫成員函式指標 %E，考慮使用 .* 或 ->*"
 
-#: cp/call.c:4847
+#: cp/call.c:4849
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "對 %<(%T) (%A)%> 的呼叫沒有匹配"
 
-#: cp/call.c:4861
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "對 %<(%T) (%A)%> 的呼叫有歧義"
 
-#: cp/call.c:4913
+#: cp/call.c:4915
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "模稜兩可的過載用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4914
+#: cp/call.c:4916
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4917
+#: cp/call.c:4919
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:4919
+#: cp/call.c:4921
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:4921
+#: cp/call.c:4923
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4938
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4942
+#: cp/call.c:4944
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "沒有匹配用於三進 %<operator?:%> 在中 %<%E？%E：%E%>"
 
-#: cp/call.c:4951 cp/call.c:4995 cp/call.c:5005
+#: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4954
+#: cp/call.c:4956
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E%s%>"
 
-#: cp/call.c:4961
+#: cp/call.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4964
+#: cp/call.c:4966
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "沒有匹配用於 %<operator[]%> 在中 %<%E[%E]%>"
 
-#: cp/call.c:4972
+#: cp/call.c:4974
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4975
+#: cp/call.c:4977
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4981
+#: cp/call.c:4983
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4984
+#: cp/call.c:4986
 #, fuzzy, gcc-internal-format
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%s%E%>"
 
-#: cp/call.c:4999
+#: cp/call.c:5001
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E %s %E%>"
 
-#: cp/call.c:5008
+#: cp/call.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%s%E%>"
 
-#: cp/call.c:5118
+#: cp/call.c:5120
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
-#: cp/call.c:5185
+#: cp/call.c:5187
 #, fuzzy, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: cp/call.c:5202 cp/call.c:5209
+#: cp/call.c:5204 cp/call.c:5211
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
 
-#: cp/call.c:5265
+#: cp/call.c:5267
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5345
+#: cp/call.c:5347
 #, fuzzy, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "秒運算元到條件式運算子是的型態 %<void%>，但是第三運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:5350
+#: cp/call.c:5352
 #, fuzzy, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "第三運算元到條件式運算子是的型態 %<void%>，但是第二運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:5399 cp/call.c:5516 cp/call.c:5664
+#: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "運算元到 ?:有不同的類型 %qT 和 %qT"
 
-#: cp/call.c:5403
+#: cp/call.c:5405
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5592
+#: cp/call.c:5594
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他結果的條件"
 
-#: cp/call.c:5608
+#: cp/call.c:5610
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5620
+#: cp/call.c:5622
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "列舉和非列舉類型一起出現在條件運算式中"
 
-#: cp/call.c:6223
+#: cp/call.c:6225
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> 沒有出現在字尾 %qs 中，嘗試使用字首運算子"
 
-#: cp/call.c:6225
+#: cp/call.c:6227
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "沒有 %<%D(整數)%>宣告的用於後綴 %qs"
 
-#: cp/call.c:6303
+#: cp/call.c:6305
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.c:6359
+#: cp/call.c:6361
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: cp/call.c:6361
+#: cp/call.c:6363
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.c:6431
+#: cp/call.c:6434
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在 %q#T 和 %q#T 間比較"
 
-#: cp/call.c:6815
+#: cp/call.c:6818
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.c:6818
+#: cp/call.c:6821
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.c:6857
+#: cp/call.c:6860
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.c:7021
+#: cp/call.c:7024
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "沒有相應 deallocation 函式用於 %qD"
 
-#: cp/call.c:7027
+#: cp/call.c:7030
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "沒有合適的 %<operator %s%> 給 %qT"
 
-#: cp/call.c:7045
+#: cp/call.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7047 cp/decl.c:7981
+#: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "宣告的在此"
 
-#: cp/call.c:7052
+#: cp/call.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:7054 cp/decl.c:7982
+#: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "宣告的在此"
 
-#: cp/call.c:7059
+#: cp/call.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D 無法存取"
 
-#: cp/call.c:7168
+#: cp/call.c:7171
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "將 NULL 做為非指標引數 %P 傳遞給 %qD"
 
-#: cp/call.c:7171 cp/call.c:7190 cp/decl.c:9647 cp/typeck.c:4128
+#: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "宣告的在此"
 
-#: cp/call.c:7175
+#: cp/call.c:7178
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "將 NULL 轉換到非指標類型 %qT"
 
-#: cp/call.c:7187
+#: cp/call.c:7190
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "轉換 %<false%> 到指標類型用於引數 %P 的 %qD"
 
-#: cp/call.c:7194
+#: cp/call.c:7197
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "轉換 %<false%> 到指標類型 %qT"
 
-#: cp/call.c:7261
+#: cp/call.c:7264
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化引數 %P，屬於 %qD"
 
-#: cp/call.c:7281
+#: cp/call.c:7284
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/call.c:7327
+#: cp/call.c:7363
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "太多大括號周圍初始設定式用於 %qT"
 
-#: cp/call.c:7338
+#: cp/call.c:7374
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/call.c:7347
+#: cp/call.c:7383
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "無效的使用者定義的轉換從 %qT 到 %qT"
 
-#: cp/call.c:7387 cp/cvt.c:227
+#: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/call.c:7442 cp/call.c:7449
+#: cp/call.c:7465 cp/call.c:7472
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "轉換到 %qT 從初始設定式清單會使用明確的建構子 %qD"
 
-#: cp/call.c:7445
+#: cp/call.c:7468
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/call.c:7715
+#: cp/call.c:7738
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7719
+#: cp/call.c:7742
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7730
+#: cp/call.c:7753
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7733
+#: cp/call.c:7756
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/call.c:7772
+#: cp/call.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "無法將位元段 %qE 繫結到 %qT"
 
-#: cp/call.c:7775 cp/call.c:7793
+#: cp/call.c:7798 cp/call.c:7816
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能將緊實的欄位 %qE 繫結到 %qT"
 
-#: cp/call.c:7778
+#: cp/call.c:7801
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "無法將右值 %qE 繫結到 %qT"
 
-#: cp/call.c:7897
+#: cp/call.c:7920
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: cp/call.c:7921 cp/cvt.c:1978
+#: cp/call.c:7944 cp/cvt.c:1977
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7988
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:8001
+#: cp/call.c:8024
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:8011
+#: cp/call.c:8034
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:8079
+#: cp/call.c:8102
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/call.c:8088
+#: cp/call.c:8111
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "呼叫到 %qD 使用預設引數用於參數 %P, 該項不是未定義"
 
-#: cp/call.c:8192
+#: cp/call.c:8215
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函式的引數可能是 format 屬性的備選"
 
-#: cp/call.c:8251
+#: cp/call.c:8274
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/call.c:8678
+#: cp/call.c:8701
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:8681 cp/call.c:11309
+#: cp/call.c:8704 cp/call.c:11338
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: cp/call.c:8718
+#: cp/call.c:8747
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT 是 %qT 的一個不可存取的基礎類別"
 
-#: cp/call.c:8886
+#: cp/call.c:8915
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/call.c:9017
+#: cp/call.c:9046
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.c:9416
+#: cp/call.c:9445
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:9419
+#: cp/call.c:9448
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.c:9424
+#: cp/call.c:9453
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:9429
+#: cp/call.c:9458
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:9444
+#: cp/call.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.c:9446
+#: cp/call.c:9475
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9448
+#: cp/call.c:9477
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/call.c:9451
+#: cp/call.c:9480
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9454
+#: cp/call.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.c:9456
+#: cp/call.c:9485
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:9477
+#: cp/call.c:9506
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.c:9479
+#: cp/call.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:9481
+#: cp/call.c:9510
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: cp/call.c:9484
+#: cp/call.c:9513
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:9487
+#: cp/call.c:9516
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/call.c:9490
+#: cp/call.c:9519
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:9501
+#: cp/call.c:9530
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:9513
+#: cp/call.c:9542
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:9530
+#: cp/call.c:9559
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:9533
+#: cp/call.c:9562
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:9543
+#: cp/call.c:9572
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:9546
+#: cp/call.c:9575
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:9549
+#: cp/call.c:9578
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:9558
+#: cp/call.c:9587
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:9580
+#: cp/call.c:9609
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/call.c:9680
+#: cp/call.c:9709
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "常數參考它自己"
 
-#: cp/call.c:9954 cp/typeck.c:9284
+#: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "無法轉換 %qT 到 %qT"
 
-#: cp/call.c:9976
+#: cp/call.c:10005
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "沒有匹配函式用於呼叫到 %<%T::運算子 %T(%A)%#V%>"
 
-#: cp/call.c:10008
+#: cp/call.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:10055
+#: cp/call.c:10084
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.c:10093 cp/pt.c:16025 cp/typeck.c:3127
+#: cp/call.c:10122 cp/pt.c:16059 cp/typeck.c:3169
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
 
-#: cp/call.c:10095
+#: cp/call.c:10124
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  用於 function-style 演員陣容，移除冗餘 %<::%D%>"
 
-#: cp/call.c:10287
+#: cp/call.c:10316
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:10290
+#: cp/call.c:10319
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "對多載的 %<%s(%A)%> 的呼叫有歧義"
 
-#: cp/call.c:10311
+#: cp/call.c:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/call.c:10316
+#: cp/call.c:10345
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "建構式回傳值"
 
-#: cp/call.c:10317
+#: cp/call.c:10346
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "解構函式回傳值"
 
-#: cp/call.c:10340
+#: cp/call.c:10369
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "沒有物件無法呼叫成員函式 %qD"
 
-#: cp/call.c:11307
+#: cp/call.c:11336
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "傳遞 %qT 時選擇 %qT 而不是 %qT"
 
-#: cp/call.c:11376
+#: cp/call.c:11405
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "選擇 %qD 而不是 %qD"
 
-#: cp/call.c:11377
+#: cp/call.c:11406
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:11380
+#: cp/call.c:11409
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  因為前者的引數類型轉換序列更好"
 
-#: cp/call.c:11629
+#: cp/call.c:11659
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "預設引數不匹配在中過載解析度"
 
-#: cp/call.c:11633
+#: cp/call.c:11663
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidate 1:%q+#F"
 
-#: cp/call.c:11635
+#: cp/call.c:11665
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidate 2:%q+#F"
 
-#: cp/call.c:11681
+#: cp/call.c:11711
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.c:12083
+#: cp/call.c:12113
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暫時的約束到 %qD 只有持續直到建構子離開"
 
-#: cp/call.c:12238
+#: cp/call.c:12268
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:12242
+#: cp/call.c:12272
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -46606,551 +46667,551 @@ msgstr "無法從基礎類別 %qT 轉換到衍生類別 %qT，透過虛基礎類
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/class.c:1149
+#: cp/class.c:1156
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
 msgstr "衝突與前一個宣告在此"
 
-#: cp/class.c:1152
+#: cp/class.c:1159
 #, fuzzy, gcc-internal-format
 msgid "version inherited from %qT declared here"
 msgstr "衝突與前一個宣告在此"
 
-#: cp/class.c:1172
+#: cp/class.c:1179
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:1174 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
+#: cp/class.c:1181 cp/decl.c:1705 cp/decl.c:1714 cp/decl.c:1739 cp/decl.c:1762
 #: cp/name-lookup.c:2280 cp/name-lookup.c:2565
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前一個宣告 %q+#D"
 
-#: cp/class.c:1217
+#: cp/class.c:1224
 #, gcc-internal-format
 msgid "conflicting access specifications for method %q+D, ignored"
 msgstr "方法 %q+D 的權限設定衝突，已忽略"
 
-#: cp/class.c:1220
+#: cp/class.c:1227
 #, gcc-internal-format
 msgid "conflicting access specifications for field %qE, ignored"
 msgstr "欄位 %qE 的權限設定衝突，已忽略"
 
-#: cp/class.c:1289
+#: cp/class.c:1296
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local method %q+#D with same name"
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
 msgstr " 因為局部方法 %q+#D 與之同名"
 
-#: cp/class.c:1293
+#: cp/class.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local method %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:1299
+#: cp/class.c:1306
 #, fuzzy, gcc-internal-format
 #| msgid "  because of local member %q+#D with same name"
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
 msgstr " 因為局部成員 %q+#D 與之同名"
 
-#: cp/class.c:1303
+#: cp/class.c:1310
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "local member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:1359
+#: cp/class.c:1366
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
 msgstr ""
 
-#: cp/class.c:1362 cp/class.c:1369 cp/class.c:1376 cp/class.c:1388
-#: cp/cvt.c:1092
+#: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
+#: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/class.c:1367
+#: cp/class.c:1374
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
 msgstr ""
 
-#: cp/class.c:1374
+#: cp/class.c:1381
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
 msgstr ""
 
-#: cp/class.c:1382
+#: cp/class.c:1389
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
 msgstr ""
 
-#: cp/class.c:1685
+#: cp/class.c:1692
 #, fuzzy, gcc-internal-format
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "無法衍生從 %<final%> 基底 %qT 在中衍生類型 %qT"
 
-#: cp/class.c:2148
+#: cp/class.c:2155
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "類別 %qT 中所有成員函式都是私有的"
 
-#: cp/class.c:2160
+#: cp/class.c:2167
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T 僅定義了一個私有解構函式且沒有夥伴"
 
-#: cp/class.c:2201
+#: cp/class.c:2208
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T 僅定義了一個私有建構式且沒有夥伴"
 
-#: cp/class.c:2205
+#: cp/class.c:2212
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2479
+#: cp/class.c:2504
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD 的最終多載在 %qT 中不唯一"
 
-#: cp/class.c:2841
+#: cp/class.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:2844
+#: cp/class.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D 標記的強制變更，但是不強制變更"
 
-#: cp/class.c:2859
+#: cp/class.c:2884
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D 標記的最後的，但是不是虛擬"
 
-#: cp/class.c:2922
+#: cp/class.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D 被隱藏"
 
-#: cp/class.c:2923
+#: cp/class.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  為 %q+D"
 
-#: cp/class.c:2958
+#: cp/class.c:2983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/class.c:2968 cp/parser.c:20876
+#: cp/class.c:2993 cp/parser.c:20886
 #, fuzzy, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: cp/class.c:3161
+#: cp/class.c:3186
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3347
+#: cp/class.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "位元段 %q+#D 有非整數的類型"
 
-#: cp/class.c:3363
+#: cp/class.c:3393
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位元段 %q+D 的寬度不是一個整數常數"
 
-#: cp/class.c:3368
+#: cp/class.c:3398
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位元段 %q+D 寬度為負"
 
-#: cp/class.c:3373
+#: cp/class.c:3403
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位元段 %q+D 寬度為 0"
 
-#: cp/class.c:3383
+#: cp/class.c:3413
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D 的寬度超過了它的類型"
 
-#: cp/class.c:3389
+#: cp/class.c:3419
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D 太小而不能存放 %q#T 的所有可能值"
 
-#: cp/class.c:3450
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有建構式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3453
+#: cp/class.c:3483
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有解構函式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3455
+#: cp/class.c:3485
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3459
+#: cp/class.c:3489
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/class.c:3575
+#: cp/class.c:3605
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D 不能是靜態的，因為它是聯合的成員"
 
-#: cp/class.c:3588
+#: cp/class.c:3618
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:3601
+#: cp/class.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "欄位 %q+D 無效地宣告為函式類型"
 
-#: cp/class.c:3607
+#: cp/class.c:3637
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "data member %q+D invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/class.c:3678
+#: cp/class.c:3708
 #, fuzzy, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "忽略包裝的屬性因為解裝 non-POD 欄位 %q+#D"
 
-#: cp/class.c:3729
+#: cp/class.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3732
+#: cp/class.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3763
+#: cp/class.c:3794
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了聯合 %qT 中的多個欄位"
 
-#: cp/class.c:3765
+#: cp/class.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "initialized member %q+D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:3808
+#: cp/class.c:3839
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "欄位 %q+#D 與類別同名"
 
-#: cp/class.c:3836
+#: cp/class.c:3867
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T 有指標資料成員"
 
-#: cp/class.c:3841
+#: cp/class.c:3872
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<%T(const %T&)%>"
 msgid "  but does not declare %<%T(const %T&)%>"
 msgstr "  但沒有多載 %<%T(const %T&)%>"
 
-#: cp/class.c:3843
+#: cp/class.c:3874
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  或 %<operator=(const %T&)%>"
 
-#: cp/class.c:3847
+#: cp/class.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override %<operator=(const %T&)%>"
 msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "  也沒有多載 %<operator=(const %T&)%>"
 
-#: cp/class.c:3849
+#: cp/class.c:3880
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointer member %q+D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:4287
+#: cp/class.c:4318
 #, gcc-internal-format
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4290
+#: cp/class.c:4321
 #, gcc-internal-format
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr ""
 
-#: cp/class.c:4604
+#: cp/class.c:4648
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "為非虛方法 %q+D 指定了初始值設定項"
 
-#: cp/class.c:4637
+#: cp/class.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "destructor for %qT is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/class.c:5039
+#: cp/class.c:5191
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法強制變更兩者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:5060
+#: cp/class.c:5212
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "方法宣告 %qE 強迫 %qE 方法"
 
-#: cp/class.c:5716 cp/constexpr.c:254
+#: cp/class.c:5868 cp/constexpr.c:254
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "封入類別的 constexpr 非靜態成員函式 %q+#D 並非實字型態"
 
-#: cp/class.c:5742
+#: cp/class.c:5894
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T 不是實字因為："
 
-#: cp/class.c:5745
+#: cp/class.c:5897
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5748
+#: cp/class.c:5900
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/class.c:5751
+#: cp/class.c:5903
 #, fuzzy, gcc-internal-format
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "運算式 %qE 不指定 constexpr 函式"
 
-#: cp/class.c:5759
+#: cp/class.c:5911
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是彙總，沒有 trivial 預設建構函式，而沒有任何 constexpr 建構子該並非複製或移動建構子"
 
-#: cp/class.c:5792
+#: cp/class.c:5944
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  基礎類別 %qT 的 %q+T 是 non-literal"
 
-#: cp/class.c:5807
+#: cp/class.c:5959
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5814
+#: cp/class.c:5966
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5935
+#: cp/class.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基礎類別 %q#T 有一個非虛解構函式"
 
-#: cp/class.c:5964
+#: cp/class.c:6116
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "類別中有非靜態參照 %q+#D，卻沒有提供建構式"
 
-#: cp/class.c:5970
+#: cp/class.c:6122
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "類別中有非靜態常數成員 %q+#D 卻沒有建構式"
 
-#: cp/class.c:6291
+#: cp/class.c:6443
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，直接基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6303
+#: cp/class.c:6455
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，虛基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6548
+#: cp/class.c:6703
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D 的偏移量與 ABI 不相容，並且在 GCC 的未來版本中可能會有變化"
 
-#: cp/class.c:6718
+#: cp/class.c:6873
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "大小的陣列 %qE 太大"
 
-#: cp/class.c:7004
+#: cp/class.c:7159
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "無效的使用的 %<...%>與 non-slice"
 
-#: cp/class.c:7006
+#: cp/class.c:7161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: cp/class.c:7011
+#: cp/class.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:7039
+#: cp/class.c:7194
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:7041
+#: cp/class.c:7196
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:7050 cp/class.c:7081
+#: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:7058
+#: cp/class.c:7213
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:7060
+#: cp/class.c:7215
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:7079
+#: cp/class.c:7234
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:7193 cp/parser.c:24604
+#: cp/class.c:7348 cp/parser.c:24620
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:7330
+#: cp/class.c:7485
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T 有虛擬函式和可存取 non-virtual 解構式"
 
-#: cp/class.c:7361
+#: cp/class.c:7516
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "型態透明類別 %qT 沒有任何欄位"
 
-#: cp/class.c:7367
+#: cp/class.c:7522
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "型態透明類別 %qT 有基礎類別"
 
-#: cp/class.c:7371
+#: cp/class.c:7526
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "型態透明類別 %qT 有虛擬函式"
 
-#: cp/class.c:7377
+#: cp/class.c:7532
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7539
+#: cp/class.c:7694
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/class.c:7550
+#: cp/class.c:7705
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "試圖完成結構，但為先前的解析錯誤所插斷"
 
-#: cp/class.c:8057
+#: cp/class.c:8212
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "語言字串 %<\"%E\"%> 不可識別"
 
-#: cp/class.c:8147
+#: cp/class.c:8302
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "無法解析多載函式 %qD，基於向類型 %qT 的轉換"
 
-#: cp/class.c:8292
+#: cp/class.c:8447
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "沒有可將函式 %qD 轉換到類型 %q#T 的匹配項"
 
-#: cp/class.c:8319
+#: cp/class.c:8474
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "將多載函式 %qD 轉換為類型 %q#T 有歧義"
 
-#: cp/class.c:8346
+#: cp/class.c:8501
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成員指標 %qD"
 
-#: cp/class.c:8349
+#: cp/class.c:8504
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
-#: cp/class.c:8425 cp/class.c:8467
+#: cp/class.c:8580 cp/class.c:8622
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "類型資訊不充分"
 
-#: cp/class.c:8445
+#: cp/class.c:8600
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "無法將 %qE 從類型 %qT 轉換到類型 %qT"
 
-#: cp/class.c:8718
+#: cp/class.c:8873
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %q#D changes meaning of %qD"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/class.c:8721
+#: cp/class.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
@@ -47232,7 +47293,7 @@ msgstr "%<constexpr%> 無法用於類型宣告"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E並非常數運算式"
 
-#: cp/constexpr.c:1660 cp/constexpr.c:7410
+#: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
@@ -47291,7 +47352,7 @@ msgstr "試圖配置已經配置的變數"
 msgid "deallocation of storage that was not previously allocated"
 msgstr "%qD 的宣告隱藏了先前的一個局部變數"
 
-#: cp/constexpr.c:2250 cp/constexpr.c:7442
+#: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "呼叫到 non-constexpr 函式 %qD"
@@ -47350,375 +47411,374 @@ msgstr "整型運算式 %qE 不是常數"
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:3332
+#: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3335
+#: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3340
+#: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3343
+#: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:3526
+#: cp/constexpr.c:3542
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:3566
+#: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:3583 cp/constexpr.c:3682 cp/constexpr.c:5527
-#: cp/constexpr.c:5624 cp/constexpr.c:7362
+#: cp/constexpr.c:3599 cp/constexpr.c:3698 cp/constexpr.c:5543
+#: cp/constexpr.c:5640 cp/constexpr.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:3589
+#: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "可變的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:3620 cp/constexpr.c:3642
+#: cp/constexpr.c:3636 cp/constexpr.c:3658
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:3622
+#: cp/constexpr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "存取 %qD 成員以代替初始化的 %qD 成員在中常數運算式"
 
-#: cp/constexpr.c:4392 cp/constexpr.c:6162
+#: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:4412
+#: cp/constexpr.c:4428
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "存取值的 %qE 透過 %qT glvalue 在中常數運算式"
 
-#: cp/constexpr.c:4455
+#: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:4457 cp/constexpr.c:4464
+#: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "宣告的在此"
 
-#: cp/constexpr.c:4462
+#: cp/constexpr.c:4478
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "使用的值的物件被建構在中常數運算式"
 
-#: cp/constexpr.c:4467
+#: cp/constexpr.c:4483
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:4474
+#: cp/constexpr.c:4490
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD 已用於它的本身初始設定式"
 
-#: cp/constexpr.c:4479
+#: cp/constexpr.c:4495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D 不是常數"
 
-#: cp/constexpr.c:4482
+#: cp/constexpr.c:4498
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D 是易變的"
 
-#: cp/constexpr.c:4487 cp/constexpr.c:4494
+#: cp/constexpr.c:4503 cp/constexpr.c:4510
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD 未被初始化的與常數運算式"
 
-#: cp/constexpr.c:4500
+#: cp/constexpr.c:4516
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/constexpr.c:4503
+#: cp/constexpr.c:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/constexpr.c:4749
+#: cp/constexpr.c:4765
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:4810
+#: cp/constexpr.c:4826
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD"
 msgstr ""
 
-#: cp/constexpr.c:4823
+#: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/constexpr.c:5215 cp/constexpr.c:6455
+#: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:5321
+#: cp/constexpr.c:5337
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:5423
+#: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:5424
+#: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
 msgstr ""
 
-#: cp/constexpr.c:5489
+#: cp/constexpr.c:5505
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5502
+#: cp/constexpr.c:5518
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:5684 cp/constexpr.c:8006
+#: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:6122 cp/constexpr.c:7556
+#: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:6174
+#: cp/constexpr.c:6190
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:6188
+#: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:6289 cp/constexpr.c:6307 cp/constexpr.c:6323
-#: cp/constexpr.c:7832 cp/constexpr.c:8177
+#: cp/constexpr.c:6305 cp/constexpr.c:7829 cp/constexpr.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:6422
+#: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "預期 template-id"
 
-#: cp/constexpr.c:6428
+#: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: cp/constexpr.c:6458
+#: cp/constexpr.c:6436
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.c:6686
+#: cp/constexpr.c:6664
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:6694
+#: cp/constexpr.c:6672
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:6709
+#: cp/constexpr.c:6687
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:6719
+#: cp/constexpr.c:6697
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:6739
+#: cp/constexpr.c:6717
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.c:6753
+#: cp/constexpr.c:6731
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.c:7302
+#: cp/constexpr.c:7293
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/constexpr.c:7526
+#: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:7529
+#: cp/constexpr.c:7526
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:7576
+#: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.c:7609
+#: cp/constexpr.c:7606
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.c:7648
+#: cp/constexpr.c:7645
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:7779
+#: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:7846
+#: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "虛函式不能是夥伴"
 
-#: cp/constexpr.c:7861
+#: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:7925
+#: cp/constexpr.c:7922
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:7975
+#: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.c:7982
+#: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.c:8055
+#: cp/constexpr.c:8052
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.c:8153
+#: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:8185
+#: cp/constexpr.c:8182
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.c:8215
+#: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:8232
+#: cp/constexpr.c:8229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
 
-#: cp/cp-gimplify.c:213
+#: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
 msgstr ""
 
-#: cp/cp-gimplify.c:1595
+#: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: cp/cp-gimplify.c:1598
+#: cp/cp-gimplify.c:1599
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/cp-gimplify.c:1610
+#: cp/cp-gimplify.c:1611
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:2990
+#: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/cp-gimplify.c:3012 cp/cp-gimplify.c:3024 cp/decl.c:3926 cp/method.c:955
+#: cp/cp-gimplify.c:3078 cp/cp-gimplify.c:3090 cp/decl.c:3928 cp/method.c:955
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD 並非型態"
 
-#: cp/cp-gimplify.c:3030
+#: cp/cp-gimplify.c:3096
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/cp-gimplify.c:3047
+#: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/cp-gimplify.c:3058
+#: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/cp-gimplify.c:3070
+#: cp/cp-gimplify.c:3136
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
 
-#: cp/cp-gimplify.c:3159
+#: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "evaluating %qs"
@@ -47767,7 +47827,7 @@ msgstr "轉換到 non-const 參考類型 %q#T 從 rvalue 的型態 %qT"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/cvt.c:498 cp/typeck.c:7774
+#: cp/cvt.c:498 cp/typeck.c:7834
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "從 %qT 轉換到 %qT 並未提領指標"
@@ -47810,293 +47870,293 @@ msgstr "需要浮點數值時使用了 %q#T"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "請求從 %qT 轉換到非標量類型 %qT"
 
-#: cp/cvt.c:1062
+#: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1064
+#: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1080
+#: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1082
+#: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1090
+#: cp/cvt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/cvt.c:1104
+#: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1158
+#: cp/cvt.c:1157
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "偽解構函式未被呼叫"
 
-#: cp/cvt.c:1252
+#: cp/cvt.c:1251
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "轉換到虛值將無法存取物件的不完整型態 %qT"
 
-#: cp/cvt.c:1256
+#: cp/cvt.c:1255
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1261
+#: cp/cvt.c:1260
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1266
+#: cp/cvt.c:1265
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1271
+#: cp/cvt.c:1270
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1276
+#: cp/cvt.c:1275
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中敘述"
 
-#: cp/cvt.c:1280
+#: cp/cvt.c:1279
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1296
+#: cp/cvt.c:1295
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "轉換到虛值將無法存取物件的型態 %qT"
 
-#: cp/cvt.c:1300
+#: cp/cvt.c:1299
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1305
+#: cp/cvt.c:1304
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1310
+#: cp/cvt.c:1309
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1315
+#: cp/cvt.c:1314
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1320
+#: cp/cvt.c:1319
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中敘述"
 
-#: cp/cvt.c:1324
+#: cp/cvt.c:1323
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1338
+#: cp/cvt.c:1337
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/cvt.c:1343
+#: cp/cvt.c:1342
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1348
+#: cp/cvt.c:1347
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1353
+#: cp/cvt.c:1352
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1358
+#: cp/cvt.c:1357
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1363
+#: cp/cvt.c:1362
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中敘述"
 
-#: cp/cvt.c:1368
+#: cp/cvt.c:1367
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1409
+#: cp/cvt.c:1408
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "轉換到虛值將無法存取物件 %qE 的不完整型態 %qT"
 
-#: cp/cvt.c:1413
+#: cp/cvt.c:1412
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1418
+#: cp/cvt.c:1417
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1422
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1428
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1433
+#: cp/cvt.c:1432
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中敘述"
 
-#: cp/cvt.c:1437
+#: cp/cvt.c:1436
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中用於遞增運算式"
 
-#: cp/cvt.c:1490
+#: cp/cvt.c:1489
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "轉換到虛值無法解析位址的多載化函式"
 
-#: cp/cvt.c:1494
+#: cp/cvt.c:1493
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "秒運算元的條件運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1498
+#: cp/cvt.c:1497
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "第三運算元的條件運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1502
+#: cp/cvt.c:1501
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "右運算元的逗號運算子無法解析位址的多載化函式"
 
-#: cp/cvt.c:1506
+#: cp/cvt.c:1505
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "左運算元的逗號運算子無法解析位址的多載化函式"
 
-#: cp/cvt.c:1510
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "敘述無法解析位址的多載化函式"
 
-#: cp/cvt.c:1514
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "用於遞增運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1530
+#: cp/cvt.c:1529
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "秒運算元的條件運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1535
+#: cp/cvt.c:1534
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "第三運算元的條件運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1540
+#: cp/cvt.c:1539
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "右運算元的逗號運算子是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1545
+#: cp/cvt.c:1544
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "左運算元的逗號運算子是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1550
+#: cp/cvt.c:1549
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "敘述是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1555
+#: cp/cvt.c:1554
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "用於遞增運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1583
+#: cp/cvt.c:1582
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "秒運算元的條件運算式沒有任何效果"
 
-#: cp/cvt.c:1588
+#: cp/cvt.c:1587
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/cvt.c:1593
+#: cp/cvt.c:1592
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "右運算元的逗號運算子沒有任何效果"
 
-#: cp/cvt.c:1597
+#: cp/cvt.c:1596
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "左運算元的逗號運算子沒有任何效果"
 
-#: cp/cvt.c:1601
+#: cp/cvt.c:1600
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "敘述沒有任何效果"
 
-#: cp/cvt.c:1605
+#: cp/cvt.c:1604
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: cp/cvt.c:1760
+#: cp/cvt.c:1759
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "將 NULL 轉換為非指標類型"
 
-#: cp/cvt.c:1878
+#: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/cvt.c:1893
+#: cp/cvt.c:1892
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT 的預設類型轉換有歧義"
 
-#: cp/cvt.c:1896
+#: cp/cvt.c:1895
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  備選轉換包括 %qD 和 %qD"
@@ -48165,7 +48225,7 @@ msgstr "從先前的宣告 %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl.c:1264 cp/decl.c:14963
+#: cp/decl.c:1264 cp/decl.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -48370,12 +48430,12 @@ msgstr "%q+D 的上一個宣告在此"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:2059
+#: cp/decl.c:2061
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.c:2071
+#: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD"
 msgstr "刪除的定義的 %qD"
@@ -48388,44 +48448,44 @@ msgstr "刪除的定義的 %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2535
+#: cp/decl.c:2537
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/decl.c:2673
+#: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "『setter』屬性的內容 %qD 衝突與前一個宣告"
 
 #. Reject two definitions.
-#: cp/decl.c:2927 cp/decl.c:2956 cp/decl.c:2994 cp/decl.c:3011 cp/decl.c:3109
+#: cp/decl.c:2929 cp/decl.c:2958 cp/decl.c:2996 cp/decl.c:3013 cp/decl.c:3111
 #: cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "重複定義的 %q#D"
 
-#: cp/decl.c:2943
+#: cp/decl.c:2945
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD 衝突與使用的函式"
 
-#: cp/decl.c:2953
+#: cp/decl.c:2955
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D 無法宣告的在中類別"
 
-#: cp/decl.c:2967 cp/decl.c:3021
+#: cp/decl.c:2969 cp/decl.c:3023
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯與 %<gnu_inline%> 屬性"
 
-#: cp/decl.c:2970 cp/decl.c:3024
+#: cp/decl.c:2972 cp/decl.c:3026
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯而無需 %<gnu_inline%> 屬性"
 
-#: cp/decl.c:2980
+#: cp/decl.c:2982
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -48433,869 +48493,869 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:3041
+#: cp/decl.c:3043
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "重新宣告的朋友 %q#D 可能無法有預設模板引數"
 
-#: cp/decl.c:3055
+#: cp/decl.c:3057
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local 宣告的 %q#D 追隨 non-thread-local 宣告"
 
-#: cp/decl.c:3058
+#: cp/decl.c:3060
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local 宣告的 %q#D 追隨 thread-local 宣告"
 
-#: cp/decl.c:3073 cp/decl.c:3117 cp/name-lookup.c:2275 cp/name-lookup.c:2718
+#: cp/decl.c:3075 cp/decl.c:3119 cp/name-lookup.c:2275 cp/name-lookup.c:2718
 #: cp/name-lookup.c:2742
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "重新宣告的 %q#D"
 
-#: cp/decl.c:3100
+#: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3168
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3167
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前一個宣告"
 
-#: cp/decl.c:3261
+#: cp/decl.c:3263
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  從這裡"
 
-#: cp/decl.c:3284 cp/decl.c:3512
+#: cp/decl.c:3286 cp/decl.c:3514
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  離開 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3312
+#: cp/decl.c:3314
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3315
+#: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  輸入範圍的 %q+#D 該項有 non-trivial 解構式"
 
-#: cp/decl.c:3329 cp/decl.c:3483
+#: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  進入 try 區塊"
 
-#: cp/decl.c:3335 cp/decl.c:3465 cp/decl.c:3485
+#: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  進入 catch 區塊"
 
-#: cp/decl.c:3341 cp/decl.c:3495
+#: cp/decl.c:3343 cp/decl.c:3497
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  輸入 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3347 cp/decl.c:3487
+#: cp/decl.c:3349 cp/decl.c:3489
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3354 cp/decl.c:3489
+#: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "需要敘述"
 
-#: cp/decl.c:3472
+#: cp/decl.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3475
+#: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  輸入範圍的 %q+#D 該項有 non-trivial 解構式"
 
-#: cp/decl.c:3527 cp/parser.c:13060 cp/parser.c:13081
+#: cp/decl.c:3529 cp/parser.c:13065 cp/parser.c:13086
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3933 cp/parser.c:6581
+#: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD 使用時未帶範本參數"
 
-#: cp/decl.c:3944
+#: cp/decl.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T 並非類別"
 
-#: cp/decl.c:3972 cp/decl.c:4065
+#: cp/decl.c:3974 cp/decl.c:4067
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類別範本，在%q#T 中 "
 
-#: cp/decl.c:3973
+#: cp/decl.c:3975
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/decl.c:3986
+#: cp/decl.c:3988
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "查找的 %qT 在中 %qT 是模稜兩可的"
 
-#: cp/decl.c:3995
+#: cp/decl.c:3997
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非類別模板"
 
-#: cp/decl.c:4002
+#: cp/decl.c:4004
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非型態"
 
-#: cp/decl.c:4074
+#: cp/decl.c:4076
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "範本參數與範本不符"
 
-#: cp/decl.c:4398
+#: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求的對齊邊界不是 2 的某次方"
 
-#: cp/decl.c:4890
+#: cp/decl.c:4892
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有建構式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:4893
+#: cp/decl.c:4895
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有構構函式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:4896
+#: cp/decl.c:4898
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/decl.c:4915
+#: cp/decl.c:4917
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:4918
+#: cp/decl.c:4920
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "屬性用於 %q#T 必須追隨 %qs 關鍵字"
 
-#: cp/decl.c:4960
+#: cp/decl.c:4962
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一個宣告指定了多個類型"
 
-#: cp/decl.c:4965
+#: cp/decl.c:4967
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "對 C++ 內建類型 %qT 的重宣告"
 
-#: cp/decl.c:4982
+#: cp/decl.c:4984
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: cp/decl.c:5015
+#: cp/decl.c:5017
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 宣告中缺少類型名"
 
-#: cp/decl.c:5023
+#: cp/decl.c:5025
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允許匿名結構"
 
-#: cp/decl.c:5030
+#: cp/decl.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:5033
+#: cp/decl.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:5038
+#: cp/decl.c:5040
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: cp/decl.c:5041
+#: cp/decl.c:5043
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能為建構式指定 %<explicit%>"
 
-#: cp/decl.c:5044
+#: cp/decl.c:5046
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:5048
+#: cp/decl.c:5050
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:5052
+#: cp/decl.c:5054
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:5056
+#: cp/decl.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:5060
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:5064
+#: cp/decl.c:5066
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> 被忽略在中這個宣告"
 
-#: cp/decl.c:5067 cp/decl.c:5070 cp/decl.c:5073
+#: cp/decl.c:5069 cp/decl.c:5072 cp/decl.c:5075
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/decl.c:5095
+#: cp/decl.c:5097
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/decl.c:5098
+#: cp/decl.c:5100
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/decl.c:5170
+#: cp/decl.c:5172
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略屬性套用到類別型態 %qT 外側的定義"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:5174
+#: cp/decl.c:5176
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略屬性套用到附屬型態 %qT 而無需關聯的宣告"
 
-#: cp/decl.c:5244 cp/decl2.c:851
+#: cp/decl.c:5246 cp/decl2.c:851
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD 被初始化的 (使用 decltype 做為替代)"
 
-#: cp/decl.c:5253
+#: cp/decl.c:5255
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D 宣告有 %<extern%> 並被初始化"
 
-#: cp/decl.c:5283
+#: cp/decl.c:5285
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/decl.c:5307
+#: cp/decl.c:5309
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/decl.c:5315
+#: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D 宣告為範本"
 
-#: cp/decl.c:5316
+#: cp/decl.c:5318
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/decl.c:5328
+#: cp/decl.c:5330
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允許將 %<%T::%D%> 定義為 %<%T::%D%>"
 
-#: cp/decl.c:5340
+#: cp/decl.c:5342
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允許成員 %qD 的初始化"
 
-#: cp/decl.c:5390
+#: cp/decl.c:5392
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.c:5431
+#: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:5436
+#: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
 
-#: cp/decl.c:5510
+#: cp/decl.c:5512
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "變數 %q#D 有初始值設定，但是類型不完全"
 
-#: cp/decl.c:5516 cp/decl.c:6567
+#: cp/decl.c:5518 cp/decl.c:6571
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "陣列 %q#D 的元素類型不完全"
 
-#: cp/decl.c:5526
+#: cp/decl.c:5528
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合 %q#D 類型不完全，無法被定義"
 
-#: cp/decl.c:5562
+#: cp/decl.c:5564
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD 宣告為參照卻未被初始化"
 
-#: cp/decl.c:5649
+#: cp/decl.c:5651
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名稱已用於 GNU-style 指定的初始設定式用於陣列"
 
-#: cp/decl.c:5655
+#: cp/decl.c:5657
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名稱 %qD 用在 GNU 風格的陣列指定元素初始值設定中"
 
-#: cp/decl.c:5674
+#: cp/decl.c:5676
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值設定不受支援"
 
-#: cp/decl.c:5678
+#: cp/decl.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:5734
+#: cp/decl.c:5736
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值設定無法決定 %qD 的大小"
 
-#: cp/decl.c:5741
+#: cp/decl.c:5743
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD 缺少陣列大小"
 
-#: cp/decl.c:5753
+#: cp/decl.c:5755
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小為 0 的陣列 %qD"
 
-#: cp/decl.c:5793
+#: cp/decl.c:5795
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "貯藏大小的 %qD isn%'t 已知"
 
-#: cp/decl.c:5817
+#: cp/decl.c:5819
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "貯藏大小的 %qD isn%'t 常數"
 
-#: cp/decl.c:5868
+#: cp/decl.c:5870
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:5872
+#: cp/decl.c:5874
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:5878
+#: cp/decl.c:5880
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  您可以解決方法這個由移除初始設定式"
 
-#: cp/decl.c:5920
+#: cp/decl.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.c:5927
+#: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:5936
+#: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:5944
+#: cp/decl.c:5946
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T 沒有任何 user-provided 預設建構函式"
 
-#: cp/decl.c:5948
+#: cp/decl.c:5950
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建構子未被 user-provided 因為它是明確的缺席在中類別本體"
 
-#: cp/decl.c:5951
+#: cp/decl.c:5953
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建構子不初始化 %q+#D"
 
-#: cp/decl.c:6117
+#: cp/decl.c:6121
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無效類型 %qT 做為類型為 %qT 的向量的初始化設定"
 
-#: cp/decl.c:6159
+#: cp/decl.c:6163
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT 的初始化設定必須在大括號內"
 
-#: cp/decl.c:6194
+#: cp/decl.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E]=%>已用於 GNU-style 指定的初始設定式用於類別 %qT"
 
-#: cp/decl.c:6202
+#: cp/decl.c:6206
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/decl.c:6223
+#: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/decl.c:6254
+#: cp/decl.c:6258
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.c:6293 cp/decl.c:6539 cp/typeck2.c:1475 cp/typeck2.c:1800
-#: cp/typeck2.c:1848 cp/typeck2.c:1895
+#: cp/decl.c:6297 cp/decl.c:6543 cp/typeck2.c:1475 cp/typeck2.c:1804
+#: cp/typeck2.c:1852 cp/typeck2.c:1899
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
 
-#: cp/decl.c:6330
+#: cp/decl.c:6334
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.c:6340
+#: cp/decl.c:6344
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.c:6458
+#: cp/decl.c:6462
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: cp/decl.c:6569
+#: cp/decl.c:6573
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "元件的陣列 %q#T 有不完整型態"
 
-#: cp/decl.c:6582
+#: cp/decl.c:6586
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "variable-sized 複合實字"
 
-#: cp/decl.c:6637
+#: cp/decl.c:6641
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/decl.c:6658
+#: cp/decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "純量物件 %qD 需求一個元件在中初始設定式"
 
-#: cp/decl.c:6703
+#: cp/decl.c:6707
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在中 C++98 %qD 必須被初始化的由建構子，無法由 %<{...}%>"
 
-#: cp/decl.c:6850
+#: cp/decl.c:6854
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "陣列 %qD 被有括號的字面字串 %qE 所初始化"
 
-#: cp/decl.c:6885
+#: cp/decl.c:6889
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "建構式中對靜態成員的初始化無效"
 
-#: cp/decl.c:6887
+#: cp/decl.c:6891
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:6890
+#: cp/decl.c:6894
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:6895
+#: cp/decl.c:6899
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一個類別外的初始化)"
 
-#: cp/decl.c:7073
+#: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/decl.c:7341
+#: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7359
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/decl.c:7370
+#: cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/decl.c:7375
+#: cp/decl.c:7369
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.c:7380
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.c:7385
+#: cp/decl.c:7379
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.c:7435
+#: cp/decl.c:7429
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.c:7453 cp/decl.c:13717
+#: cp/decl.c:7447 cp/decl.c:13726
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/decl.c:7457 cp/decl.c:13721
+#: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:7504
+#: cp/decl.c:7498
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "無效的使用的成員函式 (did 您忘記%<()%>?)"
 
-#: cp/decl.c:7616
+#: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7663
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隱藏了早先的類型宣告 %q#D"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 屬性只有套用到變數和函式"
 
-#: cp/decl.c:7881
+#: cp/decl.c:7878
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.c:7967
+#: cp/decl.c:7964
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/decl.c:7970
+#: cp/decl.c:7967
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7977
+#: cp/decl.c:7974
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/decl.c:8003
+#: cp/decl.c:8000
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8012
+#: cp/decl.c:8009
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.c:8238
+#: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: cp/decl.c:8247 cp/decl.c:8332
+#: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs 指定的用於結構欄位"
 
-#: cp/decl.c:8251
+#: cp/decl.c:8248
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:8254
+#: cp/decl.c:8251
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:8299
+#: cp/decl.c:8296
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:8325
+#: cp/decl.c:8322
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:8334
+#: cp/decl.c:8331
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:8355
+#: cp/decl.c:8352
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:8384
+#: cp/decl.c:8381
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:8389
+#: cp/decl.c:8386
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/decl.c:8394
+#: cp/decl.c:8391
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "無法分解位址"
 
-#: cp/decl.c:8398
+#: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "來源是的不完整類別型態"
 
-#: cp/decl.c:8407
+#: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: cp/decl.c:8854
+#: cp/decl.c:8853
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8856
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.c:8862
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9090
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.c:9095
+#: cp/decl.c:9094
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.c:9098
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.c:9114
+#: cp/decl.c:9113
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9115
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.c:9142
+#: cp/decl.c:9141
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.c:9144
+#: cp/decl.c:9143
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.c:9150
+#: cp/decl.c:9149
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.c:9153
+#: cp/decl.c:9152
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.c:9155
+#: cp/decl.c:9154
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.c:9161
+#: cp/decl.c:9160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.c:9164
+#: cp/decl.c:9163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.c:9166
+#: cp/decl.c:9165
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.c:9172
+#: cp/decl.c:9171
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.c:9175
+#: cp/decl.c:9174
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.c:9177
+#: cp/decl.c:9176
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.c:9184
+#: cp/decl.c:9183
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:9191
+#: cp/decl.c:9190
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.c:9223
+#: cp/decl.c:9222
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.c:9263
+#: cp/decl.c:9262
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.c:9274
+#: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: cp/decl.c:9281
+#: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.c:9284
+#: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
@@ -49575,7 +49635,7 @@ msgstr "陣列維數溢出"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:10559 cp/pt.c:15746
+#: cp/decl.c:10559 cp/pt.c:15780
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
@@ -49749,7 +49809,7 @@ msgstr "缺少宣告識別碼：使用了保留字 %qD"
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12981
+#: cp/decl.c:11193 cp/decl.c:11202 cp/decl.c:12988
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
@@ -49956,846 +50016,846 @@ msgstr "%qE 屬性被忽略"
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.c:11964
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:12016
+#: cp/decl.c:12023
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:12039
+#: cp/decl.c:12046
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.c:12043
+#: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:12048
+#: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:12055
+#: cp/decl.c:12062
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.c:12064
+#: cp/decl.c:12071
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.c:12069
+#: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/decl.c:12089
+#: cp/decl.c:12096
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:12102
+#: cp/decl.c:12109
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.c:12116
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:12119
+#: cp/decl.c:12126
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.c:12144
+#: cp/decl.c:12151
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.c:12156
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.c:12162
+#: cp/decl.c:12169
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.c:12169
+#: cp/decl.c:12176
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> 函式回傳了一個非 void 的回傳值"
 
-#: cp/decl.c:12178 cp/pt.c:28963
+#: cp/decl.c:12185 cp/pt.c:29031
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.c:12209
+#: cp/decl.c:12216
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.c:12211
+#: cp/decl.c:12218
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:12216
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:12217
+#: cp/decl.c:12224
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:12225
+#: cp/decl.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:12226
+#: cp/decl.c:12233
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:12244
+#: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "建構式不能被宣告為虛函式"
 
-#: cp/decl.c:12261
+#: cp/decl.c:12268
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:12266
+#: cp/decl.c:12273
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.c:12270
+#: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.c:12280
+#: cp/decl.c:12287
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.c:12284
+#: cp/decl.c:12291
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.c:12297
+#: cp/decl.c:12304
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.c:12324
+#: cp/decl.c:12331
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12371
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:12377 cp/decl.c:12384
+#: cp/decl.c:12384 cp/decl.c:12391
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.c:12386
+#: cp/decl.c:12393
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12422
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:12416
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12496
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.c:12560
+#: cp/decl.c:12567
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.c:12586
+#: cp/decl.c:12593
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.c:12591
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.c:12621
+#: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:12623
+#: cp/decl.c:12630
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:12631
+#: cp/decl.c:12638
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.c:12671
+#: cp/decl.c:12678
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.c:12680
+#: cp/decl.c:12687
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.c:12683
+#: cp/decl.c:12690
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.c:12694
+#: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:12697
+#: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.c:12700
+#: cp/decl.c:12707
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.c:12710
+#: cp/decl.c:12717
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:12717
+#: cp/decl.c:12724
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:12723
+#: cp/decl.c:12730
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:12729
+#: cp/decl.c:12736
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:12735
+#: cp/decl.c:12742
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:12741
+#: cp/decl.c:12748
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12764
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.c:12760
+#: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.c:12789
+#: cp/decl.c:12796
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.c:12794
+#: cp/decl.c:12801
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:12798
+#: cp/decl.c:12805
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.c:12822
+#: cp/decl.c:12829
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.c:12911
+#: cp/decl.c:12918
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.c:12919
+#: cp/decl.c:12926
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.c:12921
+#: cp/decl.c:12928
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.c:12925
+#: cp/decl.c:12932
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.c:12938
+#: cp/decl.c:12945
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.c:12958
+#: cp/decl.c:12965
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.c:12962
+#: cp/decl.c:12969
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:12972
+#: cp/decl.c:12979
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.c:12987
+#: cp/decl.c:12994
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:13006
+#: cp/decl.c:13013
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.c:13015 cp/parser.c:18438
+#: cp/decl.c:13022 cp/parser.c:18443
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能將參數 %q+D 宣告為具有抽象類型 %qT"
 
-#: cp/decl.c:13018
+#: cp/decl.c:13025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.c:13021
+#: cp/decl.c:13028
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.c:13072 cp/parser.c:3328
+#: cp/decl.c:13079 cp/parser.c:3328
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: cp/decl.c:13076
+#: cp/decl.c:13083
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
-#: cp/decl.c:13097
+#: cp/decl.c:13104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:13100
+#: cp/decl.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:13116
+#: cp/decl.c:13123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.c:13137
+#: cp/decl.c:13144
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.c:13147
+#: cp/decl.c:13154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:13157
+#: cp/decl.c:13164
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.c:13171
+#: cp/decl.c:13178
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.c:13178
+#: cp/decl.c:13185
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.c:13185 cp/decl.c:13198
+#: cp/decl.c:13192 cp/decl.c:13205
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:13191
+#: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:13204
+#: cp/decl.c:13211
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.c:13213
+#: cp/decl.c:13220
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:13219
+#: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:13227 cp/decl.c:13554
+#: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "無法開啟 %s"
 
-#: cp/decl.c:13236
+#: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.c:13239
+#: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.c:13301
+#: cp/decl.c:13309
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.c:13306
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.c:13326
+#: cp/decl.c:13334
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:13329
+#: cp/decl.c:13337
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:13379 cp/decl.c:13390
+#: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:13384
+#: cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.c:13418 cp/decl.c:13426 cp/decl.c:13433 cp/decl.c:13440
+#: cp/decl.c:13426 cp/decl.c:13434 cp/decl.c:13441 cp/decl.c:13448
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:13495
+#: cp/decl.c:13503
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.c:13498
+#: cp/decl.c:13506
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.c:13504
+#: cp/decl.c:13512
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:13508
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:13513
+#: cp/decl.c:13521
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.c:13525
+#: cp/decl.c:13533
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.c:13529
+#: cp/decl.c:13537
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:13537
+#: cp/decl.c:13545
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.c:13544
+#: cp/decl.c:13552
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.c:13545
+#: cp/decl.c:13553
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.c:13588
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
 
-#: cp/decl.c:13597
+#: cp/decl.c:13606
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.c:13636
+#: cp/decl.c:13645
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.c:13643
+#: cp/decl.c:13652
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.c:13649
+#: cp/decl.c:13658
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.c:13657
+#: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.c:13664
+#: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:13684
+#: cp/decl.c:13693
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.c:13696
+#: cp/decl.c:13705
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.c:13701
+#: cp/decl.c:13710
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.c:13868
+#: cp/decl.c:13877
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.c:13871
+#: cp/decl.c:13880
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.c:13958
+#: cp/decl.c:13967
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:13962
+#: cp/decl.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:13984
+#: cp/decl.c:13993
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "無效的參數類型 %qT"
 
-#: cp/decl.c:13992
+#: cp/decl.c:14001
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.c:14019
+#: cp/decl.c:14028
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.c:14021
+#: cp/decl.c:14030
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
 
-#: cp/decl.c:14268
+#: cp/decl.c:14277
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.c:14347
+#: cp/decl.c:14356
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.c:14354
+#: cp/decl.c:14363
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.c:14384
+#: cp/decl.c:14393
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.c:14390
+#: cp/decl.c:14399
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.c:14400
+#: cp/decl.c:14409
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
 #. 13.4.0.3
-#: cp/decl.c:14426
+#: cp/decl.c:14435
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
 #. Variadic.
-#: cp/decl.c:14437
+#: cp/decl.c:14446
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.c:14463
+#: cp/decl.c:14472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.c:14464
+#: cp/decl.c:14473
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.c:14476
+#: cp/decl.c:14485
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.c:14477
+#: cp/decl.c:14486
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.c:14488
+#: cp/decl.c:14497
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:14489 cp/decl.c:14499
+#: cp/decl.c:14498 cp/decl.c:14508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.c:14500
+#: cp/decl.c:14509
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:14514
+#: cp/decl.c:14523
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.c:14538
+#: cp/decl.c:14547
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:14545
+#: cp/decl.c:14554
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:14547
+#: cp/decl.c:14556
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:14556
+#: cp/decl.c:14565
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:14558
+#: cp/decl.c:14567
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:14574
+#: cp/decl.c:14583
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.c:14593
+#: cp/decl.c:14602
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.c:14600
+#: cp/decl.c:14609
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.c:14612
+#: cp/decl.c:14621
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.c:14667
+#: cp/decl.c:14676
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.c:14693
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.c:14695
+#: cp/decl.c:14704
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.c:14703
+#: cp/decl.c:14712
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.c:14704 cp/decl.c:14711
+#: cp/decl.c:14713 cp/decl.c:14720
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14719
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -50807,96 +50867,96 @@ msgstr "%qT 做為列舉被參照"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:14725
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.c:14779 cp/name-lookup.c:4480
+#: cp/decl.c:14788 cp/name-lookup.c:4482
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.c:14809 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
-#: cp/pt.c:9647
+#: cp/decl.c:14818 cp/friend.c:302 cp/parser.c:3153 cp/parser.c:6302
+#: cp/pt.c:9656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.c:14814
+#: cp/decl.c:14823
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:14823 cp/name-lookup.c:4719 cp/name-lookup.c:4830
-#: cp/parser.c:6591 cp/parser.c:28376
+#: cp/decl.c:14832 cp/name-lookup.c:4721 cp/name-lookup.c:4832
+#: cp/parser.c:6591 cp/parser.c:28401
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.c:14926
+#: cp/decl.c:14935
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.c:14962
+#: cp/decl.c:14971
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.c:15102
+#: cp/decl.c:15111
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.c:15109
+#: cp/decl.c:15118
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:15120
+#: cp/decl.c:15129
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/decl.c:15145
+#: cp/decl.c:15154
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.c:15175
+#: cp/decl.c:15184
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.c:15177
+#: cp/decl.c:15186
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.c:15322
+#: cp/decl.c:15331
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:15325 cp/decl.c:15333 cp/decl.c:15343 cp/decl.c:15926
-#: cp/parser.c:19339
+#: cp/decl.c:15334 cp/decl.c:15342 cp/decl.c:15352 cp/decl.c:15935
+#: cp/parser.c:19344
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.c:15330
+#: cp/decl.c:15339
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.c:15340
+#: cp/decl.c:15349
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.c:15413
+#: cp/decl.c:15422
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -50905,72 +50965,72 @@ msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:15560
+#: cp/decl.c:15569
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.c:15728
+#: cp/decl.c:15737
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:15738
+#: cp/decl.c:15747
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:15787
+#: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:15788
+#: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:15799
+#: cp/decl.c:15808
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.c:15819
+#: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.c:15924 cp/parser.c:19337
+#: cp/decl.c:15933 cp/parser.c:19342
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/decl.c:15964
+#: cp/decl.c:15973
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.c:16139 cp/typeck.c:9971
+#: cp/decl.c:16148 cp/typeck.c:10031
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.c:17003
+#: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:17005 cp/typeck.c:9851
+#: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.c:17241
+#: cp/decl.c:17250
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.c:17619
+#: cp/decl.c:17628
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -51010,7 +51070,7 @@ msgstr "不能 delete 一個函式。只有參照物件的指標才是 %<delete%
 msgid "deleting %qT is undefined"
 msgstr "刪除 %qT 未定義"
 
-#: cp/decl2.c:582 cp/pt.c:5767
+#: cp/decl2.c:582 cp/pt.c:5776
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D 宣告為範本"
@@ -51020,7 +51080,7 @@ msgstr "%q#D 宣告為範本"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "模板參數清單提供 don%'t 匹配模板參數的 %qD"
 
-#: cp/decl2.c:637 cp/pt.c:5724
+#: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "解構函式 %qD 被宣告為一個成員範本"
@@ -51358,152 +51418,152 @@ msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5538
+#: cp/decl2.c:5527
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.c:5541
+#: cp/decl2.c:5530
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
 
-#: cp/decl2.c:5585
+#: cp/decl2.c:5574
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl2.c:5607
+#: cp/decl2.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "在範本外使用 %<typename%>"
 
-#: cp/error.c:3876
+#: cp/error.c:3868
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "沒有參數"
 
-#: cp/error.c:3968
+#: cp/error.c:3960
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4319
+#: cp/error.c:4311
 #, fuzzy, gcc-internal-format
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4324
+#: cp/error.c:4316
 #, fuzzy, gcc-internal-format
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "明確的轉換運算子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4329
+#: cp/error.c:4321
 #, fuzzy, gcc-internal-format
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4334
+#: cp/error.c:4326
 #, fuzzy, gcc-internal-format
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4339
+#: cp/error.c:4331
 #, fuzzy, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4344
+#: cp/error.c:4336
 #, fuzzy, gcc-internal-format
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "範圍的 enums 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4349
+#: cp/error.c:4341
 #, fuzzy, gcc-internal-format
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4354
+#: cp/error.c:4346
 #, fuzzy, gcc-internal-format
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4359
+#: cp/error.c:4351
 #, fuzzy, gcc-internal-format
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "強制變更控制項 (強制變更/最後的) 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4364
+#: cp/error.c:4356
 #, fuzzy, gcc-internal-format
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "非靜態資料成員初始設定式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4369
+#: cp/error.c:4361
 #, fuzzy, gcc-internal-format
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4374
+#: cp/error.c:4366
 #, fuzzy, gcc-internal-format
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4379
+#: cp/error.c:4371
 #, fuzzy, gcc-internal-format
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4384
+#: cp/error.c:4376
 #, fuzzy, gcc-internal-format
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4389
+#: cp/error.c:4381
 #, fuzzy, gcc-internal-format
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4439
+#: cp/error.c:4431
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "巢狀名指定中使用了不完全的類型 %qT"
 
-#: cp/error.c:4443
+#: cp/error.c:4435
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "對 %<%T::%D%> 的參照有歧義"
 
-#: cp/error.c:4457
+#: cp/error.c:4449
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of type %qT"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD 不是類型 %qT 的成員"
 
-#: cp/error.c:4461 cp/typeck.c:2517
+#: cp/error.c:4453 cp/typeck.c:2559
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/error.c:4483
+#: cp/error.c:4475
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of type %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD 不是類型 %qT 的成員"
 
-#: cp/error.c:4487 cp/typeck.c:3111
+#: cp/error.c:4479 cp/typeck.c:3153
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD 不是 %qD 的成員"
 
-#: cp/error.c:4498
+#: cp/error.c:4490
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%<::%D%> 尚未宣告"
 
-#: cp/error.c:4502
+#: cp/error.c:4494
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> 尚未宣告"
@@ -51685,346 +51745,346 @@ msgstr "value-initialization 的參考類型 %qT"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/init.c:631
+#: cp/init.c:633
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:695
+#: cp/init.c:697
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:753
+#: cp/init.c:755
 #, gcc-internal-format
 msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:779
+#: cp/init.c:781
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD 應該被初始化的在中成員初始值清單"
 
-#: cp/init.c:800
+#: cp/init.c:802
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/init.c:904
+#: cp/init.c:906
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:919 cp/init.c:945 cp/init.c:2483 cp/method.c:2051
+#: cp/init.c:921 cp/init.c:947 cp/init.c:2485 cp/method.c:2076
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:921 cp/init.c:939 cp/init.c:947 cp/init.c:2468 cp/init.c:2496
-#: cp/method.c:2054 cp/method.c:2065
+#: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
+#: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: cp/init.c:937 cp/init.c:2455 cp/method.c:2062
+#: cp/init.c:939 cp/init.c:2457 cp/method.c:2087
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:1114
+#: cp/init.c:1116
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D 將隨後被初始化"
 
-#: cp/init.c:1117
+#: cp/init.c:1119
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基礎類別 %qT 將在"
 
-#: cp/init.c:1121
+#: cp/init.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1123
+#: cp/init.c:1125
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  基礎類別 %qT"
 
-#: cp/init.c:1125
+#: cp/init.c:1127
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  時初始化的在此"
 
-#: cp/init.c:1142
+#: cp/init.c:1144
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "多重初始化施用於 %qD"
 
-#: cp/init.c:1146
+#: cp/init.c:1148
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "多重初始化施用於基底 %qT"
 
-#: cp/init.c:1231
+#: cp/init.c:1233
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化用於多重成員的 %qT"
 
-#: cp/init.c:1328
+#: cp/init.c:1330
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基礎類別 %q#T 應該是明確的初始化的在中複製建構函式"
 
-#: cp/init.c:1555 cp/init.c:1574
+#: cp/init.c:1557 cp/init.c:1576
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:1561
+#: cp/init.c:1563
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D 是一個靜態資料成員；它只能在定義時被初始化"
 
-#: cp/init.c:1568
+#: cp/init.c:1570
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/init.c:1607
+#: cp/init.c:1609
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "對沒有基礎類別的 %qT 的無名初始化"
 
-#: cp/init.c:1615
+#: cp/init.c:1617
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "對使用了多繼承的 %qT 的無名初始化"
 
-#: cp/init.c:1662
+#: cp/init.c:1664
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD 既是一個直接基礎類別又是一個間接虛基礎類別"
 
-#: cp/init.c:1670
+#: cp/init.c:1672
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/init.c:1673
+#: cp/init.c:1675
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/init.c:1785 cp/init.c:4614 cp/typeck2.c:1333
+#: cp/init.c:1787 cp/init.c:4616 cp/typeck2.c:1333
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/init.c:2094 cp/semantics.c:3449
+#: cp/init.c:2096 cp/semantics.c:3449
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/init.c:2150
+#: cp/init.c:2152
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全類型 %qT 沒有成員 %qD"
 
-#: cp/init.c:2164
+#: cp/init.c:2166
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "參照位元段 %qD 指標無效"
 
-#: cp/init.c:2250 cp/typeck.c:1985
+#: cp/init.c:2252 cp/typeck.c:2027
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/init.c:2257 cp/semantics.c:1927
+#: cp/init.c:2259 cp/semantics.c:1927
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "對非靜態資料成員 %qD 的無效使用"
 
-#: cp/init.c:2452
+#: cp/init.c:2454
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2460
+#: cp/init.c:2462
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2464
+#: cp/init.c:2466
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:2480
+#: cp/init.c:2482
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2488
+#: cp/init.c:2490
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2492
+#: cp/init.c:2494
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:2789
+#: cp/init.c:2791
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2800
+#: cp/init.c:2802
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2811
+#: cp/init.c:2813
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:3033
+#: cp/init.c:3035
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "整數溢出"
 
-#: cp/init.c:3043
+#: cp/init.c:3045
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "變數「%s」在 %L 處上下文中必須是常數"
 
-#: cp/init.c:3061
+#: cp/init.c:3063
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: cp/init.c:3077
+#: cp/init.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified directly, not by %<typedef%>"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/init.c:3079
+#: cp/init.c:3081
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/init.c:3089
+#: cp/init.c:3091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type %<void%> for new"
 msgid "invalid type %<void%> for %<new%>"
 msgstr "對 new 而言類型 %<void%> 無效"
 
-#: cp/init.c:3095
+#: cp/init.c:3097
 #, gcc-internal-format
 msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/init.c:3137
+#: cp/init.c:3139
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%> %q#T 時常數未初始化"
 
-#: cp/init.c:3281
+#: cp/init.c:3283
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合適的 %qD，在類別 %qT 中"
 
-#: cp/init.c:3288 cp/search.c:1039
+#: cp/init.c:3290 cp/search.c:1039
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "對成員 %qD 的請求有歧義"
 
-#: cp/init.c:3362
+#: cp/init.c:3364
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3365
+#: cp/init.c:3367
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3563
+#: cp/init.c:3565
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "parenthesized 初始設定式在中陣列新"
 
-#: cp/init.c:3857
+#: cp/init.c:3859
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: cp/init.c:3886
+#: cp/init.c:3888
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用於參照類型"
 
-#: cp/init.c:3895
+#: cp/init.c:3897
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用於函式類型"
 
-#: cp/init.c:3970
+#: cp/init.c:3972
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of operator %<delete []%>"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:3974
+#: cp/init.c:3976
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4523
+#: cp/init.c:4525
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值設定在完成之前結束"
 
-#: cp/init.c:4829
+#: cp/init.c:4831
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 時陣列大小不明"
 
-#: cp/init.c:4863
+#: cp/init.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of %<operator delete%>"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:4868
+#: cp/init.c:4870
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4883
+#: cp/init.c:4885
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "刪除物件的抽象類別型態 %qT 該項有 non-virtual 解構式將造成未定義的行為"
 
-#: cp/init.c:4888
+#: cp/init.c:4890
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "刪除物件的 polymorphic 類別型態 %qT 該項有 non-virtual 解構式也許造成未定義的行為"
 
-#: cp/init.c:5196
+#: cp/init.c:5198
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
@@ -52189,12 +52249,12 @@ msgstr ""
 msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
 msgstr ""
 
-#: cp/method.c:832 cp/method.c:2004
+#: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "非靜態常數成員 %q#D, can%'t 使用預設指派運算子"
 
-#: cp/method.c:838 cp/method.c:2010
+#: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "非靜態參考成員 %q#D, can%'t 使用預設指派運算子"
@@ -52220,162 +52280,166 @@ msgstr "錯誤的型態引數到 %s"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/method.c:1108
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "three-way comparison operator can only be defaulted in a class definition"
-msgstr "只能為 Java 類別定義套用 %qE 屬性"
-
-#: cp/method.c:1111
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to Java class definitions"
-msgid "equality comparison operator can only be defaulted in a class definition"
-msgstr "只能為 Java 類別定義套用 %qE 屬性"
-
-#: cp/method.c:1126
+#: cp/method.c:1115
 #, gcc-internal-format
 msgid "defaulted %qD must return %<bool%>"
 msgstr ""
 
-#: cp/method.c:1134
+#: cp/method.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take %<void%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "%qD 必須有 %<void%> 類型"
 
-#: cp/method.c:1158
+#: cp/method.c:1128
+#, fuzzy, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr "non-member 函式 %qD 無法有 cv-qualifier"
+
+#: cp/method.c:1155
+#, fuzzy, gcc-internal-format
+#| msgid "%qD is already a friend of %qT"
+msgid "defaulted %qD is not a friend of %qT"
+msgstr "%qD 已經是 %qT 的夥伴"
+
+#: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
 msgstr ""
 
-#: cp/method.c:1161
+#: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
 msgstr ""
 
-#: cp/method.c:1164
+#: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
 msgstr ""
 
-#: cp/method.c:1319
+#: cp/method.c:1324
 #, fuzzy, gcc-internal-format
 msgid "cannot default compare union %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/method.c:1355
+#: cp/method.c:1361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member %qD"
 msgid "cannot default compare reference member %qD"
 msgstr "不能建立參照參照成員 %qD 的指標"
 
-#: cp/method.c:1363
+#: cp/method.c:1370
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/method.c:1580
+#: cp/method.c:1394
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.c:1605
 #, fuzzy, gcc-internal-format
 msgid "synthesized method %qD first required here"
 msgstr "synthesized 方法 %qD 先必要項在此 "
 
-#: cp/method.c:1949
+#: cp/method.c:1974
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "聯合成員 %q+D 與 non-trivial %qD"
 
-#: cp/method.c:1960
+#: cp/method.c:1985
 #, fuzzy, gcc-internal-format
 msgid "defaulted destructor calls non-%<constexpr%> %qD"
 msgstr "缺席建構子呼叫 non-constexpr %q+D"
 
-#: cp/method.c:1961
+#: cp/method.c:1986
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
 msgstr "缺席建構子呼叫 non-constexpr %q+D"
 
-#: cp/method.c:2027
+#: cp/method.c:2052
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "初始設定式用於 %q+#D 無效"
 
-#: cp/method.c:2084
+#: cp/method.c:2109
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "缺席預設建構函式不初始化 %q+#D"
 
-#: cp/method.c:2095
+#: cp/method.c:2120
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "非靜態資料成員 %qD 有 Java 類別型態"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:2302
+#: cp/method.c:2327
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "缺席預設建構函式不初始化任何非靜態資料成員"
 
-#: cp/method.c:2345
+#: cp/method.c:2370
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:2479
+#: cp/method.c:2501
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "lambda 閉合型態有刪除的預設建構函式"
 
-#: cp/method.c:2482
+#: cp/method.c:2504
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "lambda 閉合型態有刪除的複製指派運算子"
 
-#: cp/method.c:2491
+#: cp/method.c:2513
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D 是隱含地宣告的做為刪除的因為 %qT 宣告移動建構子或移動指派運算子"
 
-#: cp/method.c:2502
+#: cp/method.c:2524
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:2510 cp/method.c:2534
+#: cp/method.c:2532 cp/method.c:2556
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D 是隱含地刪除的因為預設定義會被不當形式的："
 
-#: cp/method.c:2543
+#: cp/method.c:2565
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2960
+#: cp/method.c:2951
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
 msgstr "不匹配預期的簽名 %qD"
 
-#: cp/method.c:2963
+#: cp/method.c:2954
 #, fuzzy, gcc-internal-format
 msgid "expected signature: %qD"
 msgstr "不匹配預期的簽名 %qD"
 
-#: cp/method.c:2995
+#: cp/method.c:2986
 #, fuzzy, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
 msgstr "明確的缺席函式 %q+D 無法宣告的做為 constexpr 因為蘊含宣告不是 constexpr："
 
-#: cp/method.c:3015
+#: cp/method.c:3006
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "模板無法缺席"
 
-#: cp/method.c:3050
+#: cp/method.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD 無法缺席"
 
-#: cp/method.c:3059
+#: cp/method.c:3050
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "缺席函式 %q+D 與預設引數"
@@ -52419,222 +52483,222 @@ msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D 的宣告隱藏了一個參數"
 
-#: cp/name-lookup.c:2820
+#: cp/name-lookup.c:2822
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/name-lookup.c:2974
+#: cp/name-lookup.c:2976
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "全域宣告 %q+#D"
 
-#: cp/name-lookup.c:2976
+#: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
 msgstr "與先前的宣告 %q+#D 衝突"
 
-#: cp/name-lookup.c:3100
+#: cp/name-lookup.c:3102
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/name-lookup.c:3293
+#: cp/name-lookup.c:3295
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3296
+#: cp/name-lookup.c:3298
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4615
+#: cp/name-lookup.c:4617
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.c:4623
+#: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "列舉 %q+D 重宣告"
 
-#: cp/name-lookup.c:4632
+#: cp/name-lookup.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.c:4639
+#: cp/name-lookup.c:4641
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> 指定了解構函式"
 
-#: cp/name-lookup.c:4656
+#: cp/name-lookup.c:4658
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> 在 %qT 內指定了建構式"
 
-#: cp/name-lookup.c:4694
+#: cp/name-lookup.c:4696
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4711
+#: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qE"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.c:4727
+#: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.c:4810
+#: cp/name-lookup.c:4812
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.c:4850
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD 的宣告中有明確的限定"
 
-#: cp/name-lookup.c:4902
+#: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.c:4904
+#: cp/name-lookup.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/name-lookup.c:4913
+#: cp/name-lookup.c:4915
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD 應當已在 %qD 內部宣告過"
 
-#: cp/name-lookup.c:4961
+#: cp/name-lookup.c:4963
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/name-lookup.c:4968
+#: cp/name-lookup.c:4970
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD 屬性是無意義的自從成員的匿名命名空間提取本機符號"
 
-#: cp/name-lookup.c:4978 cp/name-lookup.c:5005
+#: cp/name-lookup.c:4980 cp/name-lookup.c:5007
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:4984
+#: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:5021 cp/name-lookup.c:7309
+#: cp/name-lookup.c:5023 cp/name-lookup.c:7311
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定 %qD 屬性被忽略"
 
-#: cp/name-lookup.c:5307
+#: cp/name-lookup.c:5309
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空間搜尋的用於 %qE"
 
-#: cp/name-lookup.c:5359
+#: cp/name-lookup.c:5361
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建議的替代方案："
 
-#: cp/name-lookup.c:5365
+#: cp/name-lookup.c:5367
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5892
+#: cp/name-lookup.c:5894
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5898
+#: cp/name-lookup.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/name-lookup.c:6167
+#: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D 無法定義 %qE"
 
-#: cp/name-lookup.c:6170
+#: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "結構定義的在此"
 
-#: cp/name-lookup.c:6926
+#: cp/name-lookup.c:6928
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.c:7303
+#: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: cp/name-lookup.c:7306
+#: cp/name-lookup.c:7308
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7409
+#: cp/name-lookup.c:7411
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "『%s』於 %L 是模稜兩可的"
 
-#: cp/name-lookup.c:7425
+#: cp/name-lookup.c:7427
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "這裡不允許命名空間別名 %qD，假定為 %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7445
+#: cp/name-lookup.c:7447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/name-lookup.c:7480
+#: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法屬性必須被指定的於結束只有"
 
-#: cp/name-lookup.c:7481
+#: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/name-lookup.c:7554
+#: cp/name-lookup.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX 進入 pop_everything ()\n"
 
-#: cp/name-lookup.c:7563
+#: cp/name-lookup.c:7565
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -52660,7 +52724,7 @@ msgstr "識別碼 %qE 是關鍵字在中 C++11"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.c:1363 cp/parser.c:41427
+#: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
@@ -52685,7 +52749,7 @@ msgstr "%<::%E%>未被宣告"
 msgid "request for member %qE in non-class type %qT"
 msgstr "要求用於成員 %qE 在中 non-class 型態 %qT"
 
-#: cp/parser.c:3005 cp/parser.c:19276
+#: cp/parser.c:3005 cp/parser.c:19281
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>未被宣告"
@@ -52765,7 +52829,7 @@ msgstr "無效的範本 ID"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮點實字無法出現在中 constant-expression"
 
-#: cp/parser.c:3200 cp/pt.c:19309
+#: cp/parser.c:3200 cp/pt.c:19354
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "演員陣容到型態不同於積分或列舉類型型態無法出現在中 constant-expression"
@@ -52887,7 +52951,7 @@ msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3382 cp/parser.c:27700
+#: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
@@ -53010,7 +53074,7 @@ msgstr ""
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "無法找到字串實字運算子 %qD 與 %qT，%qT 引數"
 
-#: cp/parser.c:4727 cp/parser.c:13626
+#: cp/parser.c:4727 cp/parser.c:13631
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "預期的宣告"
@@ -53112,12 +53176,12 @@ msgstr "%<~%T%> 宣告為 %qT 的一個成員"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名 %qD 用於解構函式宣告"
 
-#: cp/parser.c:6276 cp/parser.c:21434
+#: cp/parser.c:6276 cp/parser.c:21450
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
 
-#: cp/parser.c:6303 cp/typeck.c:2810 cp/typeck.c:2813 cp/typeck.c:2830
+#: cp/parser.c:6303 cp/typeck.c:2852 cp/typeck.c:2855 cp/typeck.c:2872
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD 不是一個範本"
@@ -53154,7 +53218,7 @@ msgstr "預期 nested-name-specifier"
 msgid "expected nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6917 cp/parser.c:9319
+#: cp/parser.c:6917 cp/parser.c:9324
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "類型可能無法被定義在中演員陣容"
@@ -53169,7 +53233,7 @@ msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.c:7110 cp/pt.c:19928
+#: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
@@ -53184,7 +53248,7 @@ msgstr "ISO C++ 不允許複合字面值"
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7825 cp/typeck.c:2698
+#: cp/parser.c:7825 cp/typeck.c:2740
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "錯誤地使用了 %qD"
@@ -53209,927 +53273,932 @@ msgstr "ISO C++不允許 %<alignof%> 與 non-type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "類型可能無法被定義在中 %<noexcept%> 運算式"
 
-#: cp/parser.c:8618 cp/parser.c:30169
+#: cp/parser.c:8618 cp/parser.c:30194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "類型可能無法被定義在中 new-expression"
 
-#: cp/parser.c:8764
+#: cp/parser.c:8683
+#, fuzzy, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr "__builtin_eh_return 在此目標平臺上不受支援"
+
+#: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "類型可能無法被定義在中 new-expression"
 
-#: cp/parser.c:8780
+#: cp/parser.c:8785
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的類型識別碼後面不能出現陣列邊界"
 
-#: cp/parser.c:8782
+#: cp/parser.c:8787
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/parser.c:8814
+#: cp/parser.c:8819
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8859
+#: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要運算式類型"
 
-#: cp/parser.c:8888
+#: cp/parser.c:8893
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:9017
+#: cp/parser.c:9022
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 宣告中的運算式必須具有整數或列舉類型"
 
-#: cp/parser.c:9424
+#: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "使用舊式的類型轉換"
 
-#: cp/parser.c:9573
+#: cp/parser.c:9578
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>運算子被視為兩正確角度中括號在中 C++11"
 
-#: cp/parser.c:9576
+#: cp/parser.c:9581
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建議 parentheses 周圍 %<>>%>運算式"
 
-#: cp/parser.c:9784
+#: cp/parser.c:9789
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
 msgstr "ISO C++不允許 ?:與省略的中間運算元"
 
-#: cp/parser.c:10073
+#: cp/parser.c:10078
 #, gcc-internal-format
 msgid "top-level comma expression in array subscript is deprecated"
 msgstr ""
 
-#: cp/parser.c:10223
+#: cp/parser.c:10228
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined within %<__builtin_offsetof%>"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/parser.c:10512
+#: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10522
+#: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10674
+#: cp/parser.c:10679
 #, gcc-internal-format
 msgid "non-local lambda expression cannot have a capture-default"
 msgstr ""
 
-#: cp/parser.c:10696
+#: cp/parser.c:10701
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "預期的結束的 capture-list"
 
-#: cp/parser.c:10711
+#: cp/parser.c:10716
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %<this%> 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:10716 cp/parser.c:10737 cp/parser.c:10929
+#: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "已經擷取 %qD 在中 lambda 運算式"
 
-#: cp/parser.c:10731
+#: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10751
+#: cp/parser.c:10756
 #, fuzzy, gcc-internal-format
 msgid "%<this%> cannot be captured by reference"
 msgstr "無法擷取 %qE 由參考"
 
-#: cp/parser.c:10770
+#: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10781
+#: cp/parser.c:10786
 #, gcc-internal-format
 msgid "%<&%> should come before %<...%>"
 msgstr ""
 
-#: cp/parser.c:10812
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10819
+#: cp/parser.c:10824
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10843
+#: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.c:10847 cp/parser.c:10857 cp/semantics.c:3633 cp/semantics.c:3645
+#: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+#D 宣告的在此"
 
-#: cp/parser.c:10853
+#: cp/parser.c:10858
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "擷取的變數 %qD 與 non-automatic 貯藏體持續時間"
 
-#: cp/parser.c:10891
+#: cp/parser.c:10896
 #, gcc-internal-format
 msgid "too many %<...%> in lambda capture"
 msgstr ""
 
-#: cp/parser.c:10902
+#: cp/parser.c:10907
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %qD 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:10907
+#: cp/parser.c:10912
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明確的 by-reference 擷取的 %qD 冗餘與 by-reference 擷取預設"
 
-#: cp/parser.c:10986
+#: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10990
+#: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11058
+#: cp/parser.c:11063
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
-#: cp/parser.c:11076
+#: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複的 %<volatile%>"
 
-#: cp/parser.c:11128
+#: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11516 cp/parser.c:11717
+#: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:11556
+#: cp/parser.c:11561
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "預期 labeled-statement"
 
-#: cp/parser.c:11605
+#: cp/parser.c:11610
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 標籤 %qE 未出現在 switch 敘述中"
 
-#: cp/parser.c:11724
+#: cp/parser.c:11729
 #, fuzzy, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "需要 %<typename%> 之前 %qE 因為 %qT 是附屬範圍"
 
-#: cp/parser.c:11733
+#: cp/parser.c:11738
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>名稱建構子，不是型態"
 
-#: cp/parser.c:11781
+#: cp/parser.c:11786
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:11946
+#: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11973
+#: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12150 cp/parser.c:30653
+#: cp/parser.c:12155 cp/parser.c:30678
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
 
-#: cp/parser.c:12191
+#: cp/parser.c:12196
 #, fuzzy, gcc-internal-format
 #| msgid "function returning an array"
 msgid "condition declares an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/parser.c:12193
+#: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
 msgid "condition declares a function"
 msgstr "欄位 %qE 宣告的做為函式"
 
-#: cp/parser.c:12233
+#: cp/parser.c:12238
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "類型可能無法被定義在中條件"
 
 #. Anything else is an error.
-#: cp/parser.c:12314 cp/parser.c:20746 cp/parser.c:23181
+#: cp/parser.c:12319 cp/parser.c:20756 cp/parser.c:23197
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "預期的初始設定式"
 
-#: cp/parser.c:12696
+#: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> 運算式的型態 %qT 有不完整型態"
 
-#: cp/parser.c:12780
+#: cp/parser.c:12785
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.c:12923 cp/parser.c:30656
+#: cp/parser.c:12928 cp/parser.c:30681
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
 
-#: cp/parser.c:12969
+#: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12993
+#: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13129
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:13132
+#: cp/parser.c:13137
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.c:13145 cp/parser.c:30659
+#: cp/parser.c:13150 cp/parser.c:30684
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
 
-#: cp/parser.c:13457 cp/parser.c:24950
+#: cp/parser.c:13462 cp/parser.c:24966
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多餘的 %<;%>"
 
-#: cp/parser.c:13549
+#: cp/parser.c:13554
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>無法於起始部分的區塊"
 
-#: cp/parser.c:13764
+#: cp/parser.c:13769
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13784
+#: cp/parser.c:13789
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合宣告和函式定義"
 
-#: cp/parser.c:13829
+#: cp/parser.c:13834
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:13884
+#: cp/parser.c:13889
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13887
+#: cp/parser.c:13892
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13938
+#: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13990
+#: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "預期的宣告"
 
-#: cp/parser.c:14008
+#: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "無效的初始設定式用於成員函式 %qD"
 
-#: cp/parser.c:14180
+#: cp/parser.c:14185
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> 使用的外側的類別"
 
-#: cp/parser.c:14219
+#: cp/parser.c:14224
 #, fuzzy, gcc-internal-format
 msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14227
 #, gcc-internal-format
 msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
 msgstr ""
 
-#: cp/parser.c:14289
+#: cp/parser.c:14294
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> 變更平均在中 C++11; 請移除它"
 
-#: cp/parser.c:14325
+#: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:14332
+#: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D 無效，在 %q#T 中"
 
-#: cp/parser.c:14413
+#: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
 msgid "type-specifier invalid in lambda"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:14432
+#: cp/parser.c:14437
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "類別定義不能被宣告為夥伴"
 
-#: cp/parser.c:14505 cp/parser.c:25464
+#: cp/parser.c:14510 cp/parser.c:25480
 #, fuzzy, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:14524
+#: cp/parser.c:14529
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in explicit-specifier"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:14528
+#: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14592
+#: cp/parser.c:14597
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無效的連繫規格"
 
-#: cp/parser.c:14696
+#: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14901
+#: cp/parser.c:14906
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "類型可能無法被定義在中 %<decltype%> 運算式"
 
-#: cp/parser.c:15064
+#: cp/parser.c:15069
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:15093
+#: cp/parser.c:15098
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:15097
+#: cp/parser.c:15102
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:15181
+#: cp/parser.c:15186
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有建構子需成員初始設定式"
 
-#: cp/parser.c:15208
+#: cp/parser.c:15213
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.c:15220 cp/pt.c:25968
+#: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.c:15232 cp/pt.c:25980
+#: cp/parser.c:15237 cp/pt.c:26048
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
 
-#: cp/parser.c:15284
+#: cp/parser.c:15289
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代錯誤的舊式基礎類別初始值設定"
 
-#: cp/parser.c:15356
+#: cp/parser.c:15361
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(限定的初始值設定隱含地是一個類型)"
 
-#: cp/parser.c:15757
+#: cp/parser.c:15762
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介於 %<「」%>和字尾識別碼"
 
-#: cp/parser.c:15763
+#: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "預期的字尾識別碼"
 
-#: cp/parser.c:15772
+#: cp/parser.c:15777
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "預期的清空字串之後 %<operator%> 關鍵字"
 
-#: cp/parser.c:15778
+#: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "無效的運算元在中三進作業"
 
-#: cp/parser.c:15812
+#: cp/parser.c:15817
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "預期的運算子"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15858
+#: cp/parser.c:15863
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:16037
+#: cp/parser.c:16042
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:16045
+#: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:16188
+#: cp/parser.c:16193
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無效的使用的模板模板參數 %qT"
 
-#: cp/parser.c:16424 cp/parser.c:16510 cp/parser.c:22952
+#: cp/parser.c:16429 cp/parser.c:16515 cp/parser.c:22968
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:16428 cp/parser.c:16514
+#: cp/parser.c:16433 cp/parser.c:16519
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:16581
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "預期 template-id"
 
-#: cp/parser.c:16643
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以 %<<::%> 開始一個範本引數清單"
 
-#: cp/parser.c:16647
+#: cp/parser.c:16652
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> 是 %<[%> 的另一種拼法。請在 %<<%> 和 %<::%> 間加上空格"
 
-#: cp/parser.c:16651
+#: cp/parser.c:16656
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用 %<-fpermissive%> G++將接受您的編碼)"
 
-#: cp/parser.c:16681
+#: cp/parser.c:16686
 #, fuzzy, gcc-internal-format
 msgid "invalid template-argument-list"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:16682
+#: cp/parser.c:16687
 #, gcc-internal-format
 msgid "function name as the left hand operand of %<<%> is ill-formed in C++2a; wrap the function name in %<()%>"
 msgstr ""
 
-#: cp/parser.c:16689
+#: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:16793
+#: cp/parser.c:16798
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "範本引數表語法錯誤"
 
 #. The name does not name a template.
-#: cp/parser.c:16878 cp/parser.c:17044 cp/parser.c:17249
+#: cp/parser.c:16883 cp/parser.c:17049 cp/parser.c:17254
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "預期 template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16924
+#: cp/parser.c:16929
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/parser.c:16926
+#: cp/parser.c:16931
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用 %<%T::template %D%> 來表示這是一個範本"
 
-#: cp/parser.c:17105
+#: cp/parser.c:17110
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:17214 cp/parser.c:17232 cp/parser.c:17403
+#: cp/parser.c:17219 cp/parser.c:17237 cp/parser.c:17408
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:17370
+#: cp/parser.c:17375
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:17507
+#: cp/parser.c:17512
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "明確的實體化不應該使用 %<inline%> 說明符"
 
-#: cp/parser.c:17511
+#: cp/parser.c:17516
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:17515
+#: cp/parser.c:17520
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<consteval%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:17574
+#: cp/parser.c:17579
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化範本有 C 連結"
 
-#: cp/parser.c:17795
+#: cp/parser.c:17800
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "預期的型態說明符"
 
-#: cp/parser.c:17988
+#: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:17994
+#: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:17999
+#: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18161
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "預期 template-id 用於型態"
 
-#: cp/parser.c:18286
+#: cp/parser.c:18291
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "預期 type-name"
 
-#: cp/parser.c:18396
+#: cp/parser.c:18401
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not constrain a type"
 msgstr "%qE 沒有命名一個類型"
 
-#: cp/parser.c:18397
+#: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
 msgid "concept defined here"
 msgstr "聯合定義的在此"
 
-#: cp/parser.c:18419
+#: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:18426
+#: cp/parser.c:18431
 #, gcc-internal-format
 msgid "unexpected placeholder in constrained result type"
 msgstr ""
 
-#: cp/parser.c:18669
+#: cp/parser.c:18674
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用於範圍的 enum 必須不使用 %<%D%>關鍵字"
 
-#: cp/parser.c:18745
+#: cp/parser.c:18750
 #, fuzzy, gcc-internal-format
 msgid "%<template%> must follow a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/parser.c:18906
+#: cp/parser.c:18911
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣告 %qD 不宣告任何事"
 
-#: cp/parser.c:18994
+#: cp/parser.c:18999
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/parser.c:18998
+#: cp/parser.c:19003
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/parser.c:19003
+#: cp/parser.c:19008
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "屬性忽略的於 elaborated-type-specifier 該並非前置宣告"
 
-#: cp/parser.c:19143
+#: cp/parser.c:19148
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD 是列舉類型模板"
 
-#: cp/parser.c:19154
+#: cp/parser.c:19159
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/parser.c:19169
+#: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:19226
+#: cp/parser.c:19231
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "預期 %<;%>或 %<{%>"
 
-#: cp/parser.c:19270
+#: cp/parser.c:19275
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "無法加入列舉值清單到模板具現化"
 
-#: cp/parser.c:19284
+#: cp/parser.c:19289
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:19296 cp/parser.c:24433
+#: cp/parser.c:19301 cp/parser.c:24449
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "宣告的 %qD 在中命名空間 %qD 該項不封閉 %qD"
 
-#: cp/parser.c:19301 cp/parser.c:24438
+#: cp/parser.c:19306 cp/parser.c:24454
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD 宣告出現在 %qD 中，而後者並不包含 %qD"
 
-#: cp/parser.c:19313 cp/parser.c:24451
+#: cp/parser.c:19318 cp/parser.c:24467
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "額外合格不允許"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19355
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/parser.c:19370
+#: cp/parser.c:19380
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而無需名稱"
 
-#: cp/parser.c:19373
+#: cp/parser.c:19383
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必須使用簡單的識別碼"
 
-#: cp/parser.c:19560
+#: cp/parser.c:19570
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a namespace-name"
 msgid "%qD is not a namespace-name; did you mean %qs?"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:19564
+#: cp/parser.c:19574
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:19568
+#: cp/parser.c:19578
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:19629
+#: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:19640
+#: cp/parser.c:19650
 #, gcc-internal-format
 msgid "standard attributes on namespaces must precede the namespace name"
 msgstr ""
 
-#: cp/parser.c:19659
+#: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:19669
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:19674
+#: cp/parser.c:19684
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:19678
+#: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "列舉量不能有屬性 %C"
 
-#: cp/parser.c:19681
+#: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/parser.c:19688
+#: cp/parser.c:19698
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/parser.c:19743
+#: cp/parser.c:19753
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:19897
+#: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "明確的轉換運算子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:19912
+#: cp/parser.c:19922
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "範本識別碼不允許出現在 using 宣告中"
 
-#: cp/parser.c:19942
+#: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:19952
+#: cp/parser.c:19962
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "存取宣告被不宜用在中 favour 的 using-declarations；建議：加入 %<using%> 關鍵字"
 
-#: cp/parser.c:20017
+#: cp/parser.c:20027
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "類型可能無法被定義在中別名模板宣告"
 
-#: cp/parser.c:20188
+#: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:20207 cp/parser.c:20224 cp/parser.c:20238
+#: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20214
+#: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/parser.c:20251
+#: cp/parser.c:20261
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not an %<asm%> qualifier"
 msgstr "%qT 不是一個命名空間"
 
-#: cp/parser.c:20267
+#: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> qualifier outside of function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/parser.c:20641
+#: cp/parser.c:20651
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition 未被允許在此"
 
-#: cp/parser.c:20652
+#: cp/parser.c:20662
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "an %<asm%> specification is not allowed on a function-definition"
 msgstr "函式定義中不允許出現 asm 指定"
 
-#: cp/parser.c:20656
+#: cp/parser.c:20666
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:20707
+#: cp/parser.c:20717
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "預期的建構子、解構式，或類型轉換"
 
-#: cp/parser.c:20827
+#: cp/parser.c:20837
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "初始設定式提供的用於函式"
 
-#: cp/parser.c:20869
+#: cp/parser.c:20879
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:20883
+#: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函式 %q+D 重宣告為內聯的"
 
-#: cp/parser.c:21354
+#: cp/parser.c:21370
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "陣列邊界不是一個整數常數"
 
-#: cp/parser.c:21480
+#: cp/parser.c:21496
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "無法定義成員的附屬 typedef %qT"
 
-#: cp/parser.c:21484
+#: cp/parser.c:21500
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>並非型態"
@@ -54138,437 +54207,437 @@ msgstr "%<%T::%E%>並非型態"
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:21513
+#: cp/parser.c:21529
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無效的宣告子"
 
-#: cp/parser.c:21521
+#: cp/parser.c:21537
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "將建構式做為範本用法無效"
 
-#: cp/parser.c:21523
+#: cp/parser.c:21539
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用 %<%T::%D%> 而不是 %<%T::%D%> 來以限定名指定建構式"
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:21632
+#: cp/parser.c:21648
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%q+D 在宣告前使用"
 
-#: cp/parser.c:21657
+#: cp/parser.c:21673
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "預期的宣告子"
 
-#: cp/parser.c:21776
+#: cp/parser.c:21792
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD 是一個命名空間"
 
-#: cp/parser.c:21778
+#: cp/parser.c:21794
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "無法表單成員指標的 non-class %q#T"
 
-#: cp/parser.c:21799
+#: cp/parser.c:21815
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "預期 ptr-operator"
 
-#: cp/parser.c:21860
+#: cp/parser.c:21876
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:21914
+#: cp/parser.c:21930
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:21951
+#: cp/parser.c:21967
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:22009
+#: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.c:22261
+#: cp/parser.c:22277
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/parser.c:22267 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2306
+#: cp/parser.c:22283 cp/typeck2.c:495 cp/typeck2.c:542 cp/typeck2.c:2310
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "無效的使用的 %qT"
 
-#: cp/parser.c:22293
+#: cp/parser.c:22309
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "類型可能無法被定義在中模板引數"
 
-#: cp/parser.c:22298
+#: cp/parser.c:22314
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:22404
+#: cp/parser.c:22420
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "預期 type-specifier"
 
-#: cp/parser.c:22679
+#: cp/parser.c:22695
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "預期 %<,%>或 %<...%>"
 
-#: cp/parser.c:22757
+#: cp/parser.c:22773
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:22936
+#: cp/parser.c:22952
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "預設參數只允許出現在函式參數中"
 
-#: cp/parser.c:22954
+#: cp/parser.c:22970
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:22960
+#: cp/parser.c:22976
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:22962
+#: cp/parser.c:22978
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/parser.c:23088
+#: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:23092
+#: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:23416
+#: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:23436
+#: cp/parser.c:23452
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:23474
+#: cp/parser.c:23490
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++不允許 C99 指定的初始設定式"
 
-#: cp/parser.c:23488
+#: cp/parser.c:23504
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:23513
+#: cp/parser.c:23529
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:23564
+#: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:23623 cp/parser.c:23751
+#: cp/parser.c:23639 cp/parser.c:23767
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "預期 class-name"
 
-#: cp/parser.c:23981
+#: cp/parser.c:23997
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:23984
+#: cp/parser.c:24000
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "預期 %<;%>之後結構定義"
 
-#: cp/parser.c:23987
+#: cp/parser.c:24003
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/parser.c:24375
+#: cp/parser.c:24391
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "預期 %<{%>或 %<:%>"
 
-#: cp/parser.c:24386
+#: cp/parser.c:24402
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "無法指定 %<override%> 用於類別"
 
-#: cp/parser.c:24394
+#: cp/parser.c:24410
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "全域合格的類別名稱無效"
 
-#: cp/parser.c:24401
+#: cp/parser.c:24417
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "限定名稱不名稱類別"
 
-#: cp/parser.c:24413
+#: cp/parser.c:24429
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:24419
+#: cp/parser.c:24435
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD 的宣告中類別名無效"
 
-#: cp/parser.c:24473
+#: cp/parser.c:24489
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "明確特例化前必須有 %<template <>%>"
 
-#: cp/parser.c:24505
+#: cp/parser.c:24521
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/parser.c:24541
+#: cp/parser.c:24557
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "無法解析 typename 型態"
 
-#: cp/parser.c:24606
+#: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T 的上一個定義"
 
-#: cp/parser.c:24696 cp/parser.c:30662
+#: cp/parser.c:24712 cp/parser.c:30687
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
 
-#: cp/parser.c:24720
+#: cp/parser.c:24736
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.c:24724
+#: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:24971
+#: cp/parser.c:24987
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "在中 C++03 class-key 必須被使用時宣告朋友"
 
-#: cp/parser.c:24989
+#: cp/parser.c:25005
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:25007
+#: cp/parser.c:25023
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:25105
+#: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:25112
+#: cp/parser.c:25128
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: cp/parser.c:25125
+#: cp/parser.c:25141
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:25275
+#: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD 與 non-integral 型態"
 
-#: cp/parser.c:25303
+#: cp/parser.c:25319
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函式定義上有 pure 指定"
 
-#: cp/parser.c:25323
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:25370
+#: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:25384
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:25458
+#: cp/parser.c:25474
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "無效的 pure 說明符 (只有 %<=0%>被允許)"
 
-#: cp/parser.c:25493
+#: cp/parser.c:25509
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "brace-enclosed 初始設定式未被允許在此"
 
-#: cp/parser.c:25623
+#: cp/parser.c:25639
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> 指定的一次以上在中 base-specified"
 
-#: cp/parser.c:25643
+#: cp/parser.c:25659
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超過一個存取說明符在中 base-specified"
 
-#: cp/parser.c:25667
+#: cp/parser.c:25683
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:25670
+#: cp/parser.c:25686
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(基礎類別隱含地是一個類型)"
 
-#: cp/parser.c:25885 cp/parser.c:25983
+#: cp/parser.c:25901 cp/parser.c:25999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:25991
+#: cp/parser.c:26007
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/parser.c:25997
+#: cp/parser.c:26013
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "動態異常規格被不宜用在中 C++0x; 使用 %<noexcept%> 做為替代"
 
-#: cp/parser.c:26041
+#: cp/parser.c:26057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:26082
+#: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:26194
+#: cp/parser.c:26210
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:26801
+#: cp/parser.c:26817
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: cp/parser.c:26815
+#: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要識別碼或 %<(%>"
 
 #. e.g. [[attr()]].
-#: cp/parser.c:26904
+#: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
 msgstr ""
 
-#: cp/parser.c:26933
+#: cp/parser.c:26949
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26941
+#: cp/parser.c:26957
 #, gcc-internal-format
 msgid "attribute %<nodiscard%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:26978
+#: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:27038
+#: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:27378 cp/parser.c:27387
+#: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
 msgid "expression must be enclosed in parentheses"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:27717
+#: cp/parser.c:27740
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.c:28048
+#: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求的位置不是一個整數常數"
 
-#: cp/parser.c:28056
+#: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求的對齊不是整數常數"
 
-#: cp/parser.c:28547
+#: cp/parser.c:28572
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.c:28552
+#: cp/parser.c:28577
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.c:28556
+#: cp/parser.c:28581
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -54577,551 +54646,551 @@ msgstr "範本參數表太少"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:28563
+#: cp/parser.c:28588
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.c:28960
+#: cp/parser.c:28985
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.c:29127
+#: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.c:29136
+#: cp/parser.c:29161
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:29142
+#: cp/parser.c:29167
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:29242
+#: cp/parser.c:29267
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts [-fconcepts-ts]"
 msgstr ""
 
-#: cp/parser.c:29251
+#: cp/parser.c:29276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/parser.c:29274
+#: cp/parser.c:29299
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.c:29283
+#: cp/parser.c:29308
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.c:29303
+#: cp/parser.c:29328
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.c:29408
+#: cp/parser.c:29433
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.c:29459
+#: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "沒有宣告任何東西"
 
-#: cp/parser.c:29506
+#: cp/parser.c:29531
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.c:29806
+#: cp/parser.c:29831
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.c:29819
+#: cp/parser.c:29844
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.c:30117
+#: cp/parser.c:30142
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:30269
+#: cp/parser.c:30294
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.c:30284
+#: cp/parser.c:30309
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.c:30419
+#: cp/parser.c:30444
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.c:30430
+#: cp/parser.c:30455
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.c:30435
+#: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.c:30461
+#: cp/parser.c:30486
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.c:30513
+#: cp/parser.c:30538
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.c:30516
+#: cp/parser.c:30541
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.c:30519
+#: cp/parser.c:30544
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.c:30525
+#: cp/parser.c:30550
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.c:30528
+#: cp/parser.c:30553
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.c:30531
+#: cp/parser.c:30556
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.c:30534
+#: cp/parser.c:30559
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.c:30537
+#: cp/parser.c:30562
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.c:30540
+#: cp/parser.c:30565
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.c:30543
+#: cp/parser.c:30568
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.c:30546
+#: cp/parser.c:30571
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.c:30549
+#: cp/parser.c:30574
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.c:30552
+#: cp/parser.c:30577
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.c:30555
+#: cp/parser.c:30580
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:30558
+#: cp/parser.c:30583
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.c:30561
+#: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.c:30567
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.c:30570
+#: cp/parser.c:30595
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.c:30573
+#: cp/parser.c:30598
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.c:30576
+#: cp/parser.c:30601
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.c:30579
+#: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.c:30582
+#: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "預期 %<@end%>"
 
-#: cp/parser.c:30614
+#: cp/parser.c:30639
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.c:30626
+#: cp/parser.c:30651
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:30629
+#: cp/parser.c:30654
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.c:30632
+#: cp/parser.c:30657
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.c:30638
+#: cp/parser.c:30663
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.c:30665
+#: cp/parser.c:30690
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:30967
+#: cp/parser.c:30992
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.c:31118
+#: cp/parser.c:31143
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.c:31123
+#: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.c:31243
+#: cp/parser.c:31268
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/parser.c:31383 cp/parser.c:31416
+#: cp/parser.c:31408 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/parser.c:31390 cp/parser.c:31422
+#: cp/parser.c:31415 cp/parser.c:31448
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.c:31391 cp/parser.c:31423
+#: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "預期 class-key"
 
-#: cp/parser.c:31398
+#: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/parser.c:31399
+#: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qD 宣告的在此"
 
-#: cp/parser.c:31480
+#: cp/parser.c:31506
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.c:31501
+#: cp/parser.c:31527
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.c:31749
+#: cp/parser.c:31775
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.c:31990 cp/parser.c:33304 cp/parser.c:33493
+#: cp/parser.c:32016 cp/parser.c:33330 cp/parser.c:33519
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.c:32059
+#: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:32129
+#: cp/parser.c:32155
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:32160
+#: cp/parser.c:32186
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.c:32564
+#: cp/parser.c:32590
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.c:32639 cp/parser.c:32657
+#: cp/parser.c:32665 cp/parser.c:32683
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.c:32651 cp/parser.c:32717
+#: cp/parser.c:32677 cp/parser.c:32743
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.c:32760
+#: cp/parser.c:32786
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.c:32966 cp/parser.c:32973 cp/parser.c:32980
+#: cp/parser.c:32992 cp/parser.c:32999 cp/parser.c:33006
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.c:33097
+#: cp/parser.c:33123
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.c:33269
+#: cp/parser.c:33295
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.c:33276
+#: cp/parser.c:33302
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.c:33552 cp/parser.c:33559 cp/parser.c:33566
+#: cp/parser.c:33578 cp/parser.c:33585 cp/parser.c:33592
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.c:34759
+#: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "預期的整數運算式"
 
-#: cp/parser.c:34776
+#: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:35750
+#: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:36409
+#: cp/parser.c:36435
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:38479
+#: cp/parser.c:38505
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:39030
+#: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:39117 cp/pt.c:17559
+#: cp/parser.c:39143 cp/pt.c:17593
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.c:39210
+#: cp/parser.c:39236
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: cp/parser.c:41386
+#: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
 
-#: cp/parser.c:42220
+#: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:42250
+#: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:42262
+#: cp/parser.c:42288
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:42365
+#: cp/parser.c:42391
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.c:42385 cp/semantics.c:5681
+#: cp/parser.c:42411 cp/semantics.c:5681
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42389 cp/semantics.c:5689
+#: cp/parser.c:42415 cp/semantics.c:5689
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42392 cp/pt.c:13799 cp/semantics.c:5695
+#: cp/parser.c:42418 cp/pt.c:13821 cp/semantics.c:5695
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42395 cp/semantics.c:5701
+#: cp/parser.c:42421 cp/semantics.c:5701
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:42913
+#: cp/parser.c:42939
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:42923
+#: cp/parser.c:42949
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD 不是一個成員範本函式"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:43277
+#: cp/parser.c:43303
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.c:43325 cp/semantics.c:9555
+#: cp/parser.c:43351 cp/semantics.c:9571
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:43327 cp/semantics.c:9557
+#: cp/parser.c:43353 cp/semantics.c:9573
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:43474
+#: cp/parser.c:43500
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: cp/parser.c:43477
+#: cp/parser.c:43503
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: cp/parser.c:43528
+#: cp/parser.c:43554
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "垃圾於結束的 %<# pragma GCC pchpreprocess%(_P)>"
 
-#: cp/parser.c:43814
+#: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<# pragma omp taskyield%>也許會只有被已用於複合陳述"
 
-#: cp/parser.c:43857
+#: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:43889
+#: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "# pragma GCC 選項未被允許內部函式"
 
-#: cp/parser.c:43969
+#: cp/parser.c:43995
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.c:44005
+#: cp/parser.c:44031
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "此上下文中不允許標準轉換"
 
-#: cp/parser.c:44206
+#: cp/parser.c:44232
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:44262
+#: cp/parser.c:44288
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -55403,7 +55472,7 @@ msgstr "擴展胚騰 %<%E%>不含任何引數包裝"
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "參數包裝無法展開的與 %<...%>："
 
-#: cp/pt.c:4244 cp/pt.c:5031
+#: cp/pt.c:4244 cp/pt.c:5040
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
@@ -55431,88 +55500,88 @@ msgstr "%q+D 的宣告隱藏了一個參數"
 msgid "template parameter %qD declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/pt.c:4967
+#: cp/pt.c:4976
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:5026
+#: cp/pt.c:5035
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到範本參數："
 
-#: cp/pt.c:5050
+#: cp/pt.c:5059
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:5054
+#: cp/pt.c:5063
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:5058 cp/pt.c:5069 cp/pt.c:5077
+#: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5075
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:5076
+#: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "提供給函式 %qE 的引數太多"
 
-#: cp/pt.c:5090
+#: cp/pt.c:5099
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:5092
+#: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:5138
+#: cp/pt.c:5147
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "參數包裝引數 %qE 必須是於結束的模板引數清單"
 
-#: cp/pt.c:5141
+#: cp/pt.c:5150
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "參數包裝引數 %qT 必須是於結束的模板引數清單"
 
-#: cp/pt.c:5164
+#: cp/pt.c:5173
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/pt.c:5210
+#: cp/pt.c:5219
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "型態 %qT 的模板引數 %qE 依存於模板參數"
 
-#: cp/pt.c:5272
+#: cp/pt.c:5281
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:5276
+#: cp/pt.c:5285
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "局部特化的 %qT 之後實體化的 %qT"
 
-#: cp/pt.c:5459
+#: cp/pt.c:5468
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 沒有預設參數"
@@ -55520,48 +55589,48 @@ msgstr "%qD 沒有預設參數"
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5481
+#: cp/pt.c:5490
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "參數包裝 %qE 必須是於結束的模板參數清單"
 
-#: cp/pt.c:5517
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "預設模板引數可能無法被已用於函式模板朋友重新宣告"
 
-#: cp/pt.c:5520
+#: cp/pt.c:5529
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "預設模板引數可能無法被已用於函式模板朋友宣告"
 
-#: cp/pt.c:5523
+#: cp/pt.c:5532
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "預設模板引數可能無法被已用於函式模板而無需 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:5526
+#: cp/pt.c:5535
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "預設模板引數可能無法被已用於局部特化"
 
-#: cp/pt.c:5529 cp/pt.c:5587
+#: cp/pt.c:5538 cp/pt.c:5596
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:5701
+#: cp/pt.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "參數 %qD 被宣告為 void"
 
-#: cp/pt.c:5708
+#: cp/pt.c:5717
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "範本類別沒具名字"
 
-#: cp/pt.c:5716
+#: cp/pt.c:5725
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
@@ -55571,500 +55640,500 @@ msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5739
+#: cp/pt.c:5748
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD 範本宣告無效"
 
-#: cp/pt.c:5883
+#: cp/pt.c:5892
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "對非範本 %q#D 的範本定義"
 
-#: cp/pt.c:5926
+#: cp/pt.c:5935
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 級的 %q#D 範本參數，卻給出了 %d 級"
 
-#: cp/pt.c:5940
+#: cp/pt.c:5949
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 個範本參數，為 %q#D"
 
-#: cp/pt.c:5943
+#: cp/pt.c:5952
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "得到 %d 個範本參數，為 %q#T"
 
-#: cp/pt.c:5945
+#: cp/pt.c:5954
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  但實際需要 %d 個"
 
-#: cp/pt.c:5966
+#: cp/pt.c:5975
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "模板引數到 %qD 不匹配原來的模板 %qD"
 
-#: cp/pt.c:5969
+#: cp/pt.c:5978
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用模板<>用於明確的特殊化"
 
-#: cp/pt.c:6105
+#: cp/pt.c:6114
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT 不是一個範本類型"
 
-#: cp/pt.c:6118
+#: cp/pt.c:6127
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD 的宣告中沒有 template 限定"
 
-#: cp/pt.c:6129
+#: cp/pt.c:6138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeclared 與 %d 模板參數"
 
-#: cp/pt.c:6133
+#: cp/pt.c:6142
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "前一個宣告 %q+D 使用 %d 模板參數"
 
-#: cp/pt.c:6171
+#: cp/pt.c:6180
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "範本參數 %q+#D"
 
-#: cp/pt.c:6172
+#: cp/pt.c:6181
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
 
-#: cp/pt.c:6183
+#: cp/pt.c:6192
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.c:6186 cp/pt.c:6235
+#: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:6197
+#: cp/pt.c:6206
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:6199
+#: cp/pt.c:6208
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:6232
+#: cp/pt.c:6241
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.c:6559 cp/pt.c:6628
+#: cp/pt.c:6568 cp/pt.c:6637
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE 並非有效模板引數用於型態 %qT"
 
-#: cp/pt.c:6562
+#: cp/pt.c:6571
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6565
+#: cp/pt.c:6574
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6578
+#: cp/pt.c:6587
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6582
+#: cp/pt.c:6591
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6631
+#: cp/pt.c:6640
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必須是成員指標的形式 %<&X::Y%>"
 
-#: cp/pt.c:6633
+#: cp/pt.c:6642
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/pt.c:6695
+#: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/pt.c:6704
+#: cp/pt.c:6713
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  類型 %qT 和 %qT 有不相容的 cv-qualifiers"
 
-#: cp/pt.c:6713
+#: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  不匹配的類型 %qT 和 %qT"
 
-#: cp/pt.c:6722
+#: cp/pt.c:6731
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  模板參數 %qD 並非參數包裝，但是引數 %qD 是"
 
-#: cp/pt.c:6733
+#: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  模板引數 %qE 不匹配成員指標常數 %qE"
 
-#: cp/pt.c:6743
+#: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE 不是 equivalent 到 %qE"
 
-#: cp/pt.c:6752
+#: cp/pt.c:6761
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/pt.c:6764
+#: cp/pt.c:6773
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  deduced 衝突類型用於參數 %qT (%qT 和 %qT)"
 
-#: cp/pt.c:6768
+#: cp/pt.c:6777
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 衝突值用於 non-type 參數 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6779
+#: cp/pt.c:6788
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6790
+#: cp/pt.c:6799
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/pt.c:6802
+#: cp/pt.c:6811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  無法轉換 %qE (型態 %qT) 輸入 %qT"
 
-#: cp/pt.c:6846
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/pt.c:6850
+#: cp/pt.c:6859
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT 未被衍生自 %qT"
 
-#: cp/pt.c:6861
+#: cp/pt.c:6870
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板參數的模板模板引數是不一致與其他 deduced 模板引數"
 
-#: cp/pt.c:6871
+#: cp/pt.c:6880
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  無法 deduce 模板用於 %qT 從 non-template 型態 %qT"
 
-#: cp/pt.c:6881
+#: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  模板引數 %qE 不匹配 %qD"
 
-#: cp/pt.c:6928
+#: cp/pt.c:6937
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qE 並非變數"
 
-#: cp/pt.c:6936
+#: cp/pt.c:6945
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6946
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6961
+#: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6970
+#: cp/pt.c:6979
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6977
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6995
+#: cp/pt.c:7004
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:7003
+#: cp/pt.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:7112
+#: cp/pt.c:7121
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為字面字串不能用在此上下文中"
 
-#: cp/pt.c:7270
+#: cp/pt.c:7279
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:7284
+#: cp/pt.c:7293
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:7370
+#: cp/pt.c:7379
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.c:7378
+#: cp/pt.c:7387
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.c:7396
+#: cp/pt.c:7405
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.c:7455
+#: cp/pt.c:7464
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.c:7457
+#: cp/pt.c:7466
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.c:7511
+#: cp/pt.c:7520
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.c:8060
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:8076
+#: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:8209
+#: cp/pt.c:8218
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.c:8238
+#: cp/pt.c:8247
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.c:8243
+#: cp/pt.c:8252
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.c:8259 cp/pt.c:8293 cp/pt.c:8347
+#: cp/pt.c:8268 cp/pt.c:8302 cp/pt.c:8356
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:8267
+#: cp/pt.c:8276
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.c:8275
+#: cp/pt.c:8284
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:8281
+#: cp/pt.c:8290
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.c:8284
+#: cp/pt.c:8293
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:8298
+#: cp/pt.c:8307
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.c:8301
+#: cp/pt.c:8310
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.c:8351
+#: cp/pt.c:8360
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
 
-#: cp/pt.c:8365
+#: cp/pt.c:8374
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:8368
+#: cp/pt.c:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:8432
+#: cp/pt.c:8441
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.c:8570 cp/pt.c:8883
+#: cp/pt.c:8579 cp/pt.c:8892
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.c:8585 cp/pt.c:8717
+#: cp/pt.c:8594 cp/pt.c:8726
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8713
+#: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8722
+#: cp/pt.c:8731
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:8747
+#: cp/pt.c:8756
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:8751
+#: cp/pt.c:8760
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/pt.c:8849
+#: cp/pt.c:8858
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9496
+#: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.c:9659
+#: cp/pt.c:9668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.c:9661
+#: cp/pt.c:9670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.c:9787 cp/pt.c:20847
+#: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "內部一致性錯誤"
 
-#: cp/pt.c:10150
+#: cp/pt.c:10159
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:10733
+#: cp/pt.c:10741
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.c:11904
+#: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: cp/pt.c:12407
+#: cp/pt.c:12425
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12804
+#: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: cp/pt.c:12888
+#: cp/pt.c:12910
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.c:12891
+#: cp/pt.c:12913
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.c:13459
+#: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:13558
+#: cp/pt.c:13580
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
@@ -56082,298 +56151,298 @@ msgstr "產生非類別類型 %qT 的成員函式指標"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:14598
+#: cp/pt.c:14623
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.c:14787
+#: cp/pt.c:14821
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.c:14789
+#: cp/pt.c:14823
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.c:14907
+#: cp/pt.c:14941
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.c:14909
+#: cp/pt.c:14943
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.c:15600
+#: cp/pt.c:15634
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.c:15602
+#: cp/pt.c:15636
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.c:15604
+#: cp/pt.c:15638
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.c:15617
+#: cp/pt.c:15651
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:15620
+#: cp/pt.c:15654
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:15668
+#: cp/pt.c:15702
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.c:15674
+#: cp/pt.c:15708
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.c:15680
+#: cp/pt.c:15714
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.c:15780
+#: cp/pt.c:15814
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.c:15800
+#: cp/pt.c:15834
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.c:15837
+#: cp/pt.c:15871
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.c:15845
+#: cp/pt.c:15879
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.c:15972
+#: cp/pt.c:16006
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:16150
+#: cp/pt.c:16184
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.c:16165
+#: cp/pt.c:16199
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.c:16167
+#: cp/pt.c:16201
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.c:16257
+#: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/pt.c:16380
+#: cp/pt.c:16414
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.c:16906 cp/pt.c:18710
+#: cp/pt.c:16940 cp/pt.c:18744
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.c:16910 cp/pt.c:18714
+#: cp/pt.c:16944 cp/pt.c:18748
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.c:18852
+#: cp/pt.c:18886
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.c:19854
+#: cp/pt.c:19901
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.c:19881
+#: cp/pt.c:19928
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.c:19886
+#: cp/pt.c:19933
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.c:19889
+#: cp/pt.c:19936
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.c:19894
+#: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.c:19942
+#: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "錯誤的引數數量到 %<__builtin_choose_expr%>"
 
-#: cp/pt.c:20246
+#: cp/pt.c:20293
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.c:20249
+#: cp/pt.c:20296
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.c:20571
+#: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.c:20573
+#: cp/pt.c:20620
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.c:20583
+#: cp/pt.c:20630
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.c:20598
+#: cp/pt.c:20645
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.c:20616
+#: cp/pt.c:20663
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.c:24629
+#: cp/pt.c:24685
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:24631
+#: cp/pt.c:24687
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:24637
+#: cp/pt.c:24693
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:24661 cp/pt.c:24756
+#: cp/pt.c:24717 cp/pt.c:24812
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:24667
+#: cp/pt.c:24723
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:24669
+#: cp/pt.c:24725
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:24688
+#: cp/pt.c:24744
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.c:24694 cp/pt.c:24751
+#: cp/pt.c:24750 cp/pt.c:24807
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.c:24699
+#: cp/pt.c:24755
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.c:24707
+#: cp/pt.c:24763
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.c:24743
+#: cp/pt.c:24799
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.c:24766 cp/pt.c:24850
+#: cp/pt.c:24822 cp/pt.c:24906
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.c:24771 cp/pt.c:24866
+#: cp/pt.c:24827 cp/pt.c:24922
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.c:24828
+#: cp/pt.c:24884
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.c:24830
+#: cp/pt.c:24886
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.c:24839
+#: cp/pt.c:24895
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.c:24855
+#: cp/pt.c:24911
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.c:24900
+#: cp/pt.c:24956
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
 
-#: cp/pt.c:25222
+#: cp/pt.c:25290
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -56386,140 +56455,140 @@ msgstr "在初次使用後明確特例化 %qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:25560
+#: cp/pt.c:25628
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.c:25756
+#: cp/pt.c:25824
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.c:26119
+#: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:26141
+#: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:26154
+#: cp/pt.c:26222
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:26166
+#: cp/pt.c:26234
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.c:26168
+#: cp/pt.c:26236
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:27521
+#: cp/pt.c:27589
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/pt.c:27782
+#: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/pt.c:27791
+#: cp/pt.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT 不是一個命名空間"
 
-#: cp/pt.c:27816
+#: cp/pt.c:27884
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.c:28726
+#: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.c:28733
+#: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:28834
+#: cp/pt.c:28902
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:28841
+#: cp/pt.c:28909
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:28856
+#: cp/pt.c:28924
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.c:28863
+#: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
-#: cp/pt.c:28927
+#: cp/pt.c:28995
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:28930
+#: cp/pt.c:28998
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:29004
+#: cp/pt.c:29072
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:29006
+#: cp/pt.c:29074
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:29048
+#: cp/pt.c:29116
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:29052
+#: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:29056
+#: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:29060
+#: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:29190
+#: cp/pt.c:29258
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "無效的 non-type 模板引數"
@@ -56735,7 +56804,7 @@ msgstr "在頂層使用 %<this%> 無效"
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "偽解構函式名的限定作用欄位無效"
 
-#: cp/semantics.c:2790 cp/typeck.c:2730
+#: cp/semantics.c:2790 cp/typeck.c:2772
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的類型 %qT 不匹配解構函式名 ~%qT"
@@ -56786,7 +56855,7 @@ msgstr "無效的基礎類別"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.c:3624 cp/semantics.c:10261
+#: cp/semantics.c:3624 cp/semantics.c:10277
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
@@ -56885,7 +56954,7 @@ msgstr ""
 
 #: cp/semantics.c:4806 cp/semantics.c:6579 cp/semantics.c:6663
 #: cp/semantics.c:6714 cp/semantics.c:7056 cp/semantics.c:7203
-#: cp/semantics.c:7432 cp/semantics.c:7875
+#: cp/semantics.c:7448 cp/semantics.c:7891
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -56926,7 +56995,7 @@ msgstr ""
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6591 cp/semantics.c:7888
+#: cp/semantics.c:6591 cp/semantics.c:7904
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
@@ -57051,120 +57120,120 @@ msgstr "%qD 出現一次以上在中資料子句"
 msgid "%qD is not lvalue expression nor array section in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:7583
+#: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "太多 %qs 子句"
 
-#: cp/semantics.c:7587
+#: cp/semantics.c:7603
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:7656
+#: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7686
+#: cp/semantics.c:7702
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7716
+#: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7729
+#: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/semantics.c:7752
+#: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: cp/semantics.c:7762
+#: cp/semantics.c:7778
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7816
+#: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: cp/semantics.c:8157
+#: cp/semantics.c:8173
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.c:8351
+#: cp/semantics.c:8367
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.c:8365
+#: cp/semantics.c:8381
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.c:8562
+#: cp/semantics.c:8578
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.c:9028
+#: cp/semantics.c:9044
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:9319 cp/semantics.c:9329
+#: cp/semantics.c:9335 cp/semantics.c:9345
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:9688
+#: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.c:9699
+#: cp/semantics.c:9715
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.c:9729
+#: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.c:9757
+#: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
 
-#: cp/semantics.c:10300
+#: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.c:10353
+#: cp/semantics.c:10369
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.c:10355
+#: cp/semantics.c:10371
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:10373
+#: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -57417,831 +57486,831 @@ msgstr "轉換介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "條件運算式介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:1519
+#: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "權威的類型不同用於相等的類型 %T 和 %T"
 
-#: cp/typeck.c:1526
+#: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "相同權威的型態節點用於不同的類型 %T 和 %T"
 
-#: cp/typeck.c:1686
+#: cp/typeck.c:1728
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs 用於成員函式無效"
 
-#: cp/typeck.c:1784
+#: cp/typeck.c:1826
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "無效的應用程式的 %<sizeof%> 到 bit-field"
 
-#: cp/typeck.c:1792
+#: cp/typeck.c:1834
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<sizeof%> 到運算式的函數型式"
 
-#: cp/typeck.c:1854
+#: cp/typeck.c:1896
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "無效的應用程式的 %<__alignof%>到 bit-field"
 
-#: cp/typeck.c:1865
+#: cp/typeck.c:1907
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<__alignof%>到運算式的函數型式"
 
-#: cp/typeck.c:1945
+#: cp/typeck.c:1987
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/typeck.c:1990
+#: cp/typeck.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/typeck.c:2158
+#: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "需位址的暫時的陣列"
 
-#: cp/typeck.c:2340
+#: cp/typeck.c:2382
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.c:2344
+#: cp/typeck.c:2386
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.c:2480 cp/typeck.c:3043
+#: cp/typeck.c:2522 cp/typeck.c:3085
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "要求用於成員 %qD 在中 %qE，該項是的指標類型 %qT (也許您 meant 以使用 %<->%> ?)"
 
-#: cp/typeck.c:2484 cp/typeck.c:3047
+#: cp/typeck.c:2526 cp/typeck.c:3089
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "對成員 %qD 的請求出現在 %qE 中，而後者具有非類別類型 %qT"
 
-#: cp/typeck.c:2515
+#: cp/typeck.c:2557
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "對非靜態資料成員 %qE 的使用無效"
 
-#: cp/typeck.c:2595
+#: cp/typeck.c:2637
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "無效的存取到非靜態資料成員 %qD  的空值物件"
 
-#: cp/typeck.c:2745
+#: cp/typeck.c:2787
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "物件類型 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/typeck.c:2754
+#: cp/typeck.c:2796
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被解構的類型是 %qT，但解構函式卻使用了 %qT"
 
-#: cp/typeck.c:2895
+#: cp/typeck.c:2937
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.c:2914
+#: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.c:2937
+#: cp/typeck.c:2979
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.c:2948
+#: cp/typeck.c:2990
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.c:2962
+#: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.c:3077 cp/typeck.c:3103
+#: cp/typeck.c:3119 cp/typeck.c:3145
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> 不是 %qT 的成員"
 
-#: cp/typeck.c:3142
+#: cp/typeck.c:3184
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT 不是 %qT 的基礎類別"
 
-#: cp/typeck.c:3195
+#: cp/typeck.c:3237
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD 不是一個成員範本函式"
 
-#: cp/typeck.c:3374
+#: cp/typeck.c:3432
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT 不是一個參照物件的類型"
 
-#: cp/typeck.c:3406
+#: cp/typeck.c:3464
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "無效的使用的陣列索引於成員指標"
 
-#: cp/typeck.c:3409
+#: cp/typeck.c:3467
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "無效的使用的一元 %<*%>於成員指標"
 
-#: cp/typeck.c:3412
+#: cp/typeck.c:3470
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "無效的使用的隱含轉換於成員指標"
 
-#: cp/typeck.c:3416
+#: cp/typeck.c:3474
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3481
+#: cp/typeck.c:3539
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "陣列參照缺少下標"
 
-#: cp/typeck.c:3578
+#: cp/typeck.c:3636
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/typeck.c:3616
+#: cp/typeck.c:3674
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下標運算的左運算元既非陣列也非指標"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3746
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用 %qE 時缺少物件"
 
-#: cp/typeck.c:3913
+#: cp/typeck.c:3971
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允許在程式裡呼叫 %<::main%>"
 
-#: cp/typeck.c:3934
+#: cp/typeck.c:3992
 #, fuzzy, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必須使用 %<.*%>或 %<->*%> 到呼叫成員指標函式在中 %<%E (...)%>，例如： %<(...->* %E) (...)%>"
 
-#: cp/typeck.c:3951
+#: cp/typeck.c:4009
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3954
+#: cp/typeck.c:4012
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3957
+#: cp/typeck.c:4015
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:4014
+#: cp/typeck.c:4072
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/typeck.c:4015
+#: cp/typeck.c:4073
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/typeck.c:4020
+#: cp/typeck.c:4078
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "太多引數到成員函式 %q#D"
 
-#: cp/typeck.c:4021
+#: cp/typeck.c:4079
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "太少引數到成員函式 %q#D"
 
-#: cp/typeck.c:4027
+#: cp/typeck.c:4085
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "太多引數到函式 %q#D"
 
-#: cp/typeck.c:4028
+#: cp/typeck.c:4086
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "太少引數到函式 %q#D"
 
-#: cp/typeck.c:4038
+#: cp/typeck.c:4096
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "太多引數到方法 %q#D"
 
-#: cp/typeck.c:4039
+#: cp/typeck.c:4097
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "太少引數到方法 %q#D"
 
-#: cp/typeck.c:4042
+#: cp/typeck.c:4100
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "給予函式的引數太多"
 
-#: cp/typeck.c:4043
+#: cp/typeck.c:4101
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "給予函式的引數太少"
 
-#: cp/typeck.c:4125
+#: cp/typeck.c:4183
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "參數 %P (屬於 %qD)的類型 %qT 不完全"
 
-#: cp/typeck.c:4131
+#: cp/typeck.c:4189
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "參數 %P 的類型 %qT 不完全"
 
-#: cp/typeck.c:4380
+#: cp/typeck.c:4438
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4391
+#: cp/typeck.c:4449
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4514 cp/typeck.c:4526
+#: cp/typeck.c:4572 cp/typeck.c:4584
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定從多載函式轉換到類型 %qT"
 
-#: cp/typeck.c:4572
+#: cp/typeck.c:4630
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算術運算式中使用了 NULL"
 
-#: cp/typeck.c:5022 cp/typeck.c:5031 cp/typeck.c:5322 cp/typeck.c:5331
+#: cp/typeck.c:5080 cp/typeck.c:5089 cp/typeck.c:5380 cp/typeck.c:5389
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允許比較指標和整數的值"
 
-#: cp/typeck.c:5237 cp/typeck.c:5250
+#: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/typeck.c:5273
+#: cp/typeck.c:5331
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.c:5361
+#: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮點引數間的無效比較"
 
-#: cp/typeck.c:5406
+#: cp/typeck.c:5464
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/typeck.c:5477
+#: cp/typeck.c:5535
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "運算元類型 %qT 和 %qT 對二進位 %qO 而言無效"
 
-#: cp/typeck.c:5827
+#: cp/typeck.c:5887
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允許在減法中使用類型為 %<void *%> 的指標"
 
-#: cp/typeck.c:5835
+#: cp/typeck.c:5895
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允許在減法中使用函式指標"
 
-#: cp/typeck.c:5843
+#: cp/typeck.c:5903
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允許在減法中使用參照方法的指標"
 
-#: cp/typeck.c:5896
+#: cp/typeck.c:5956
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指標算術中使用參照不完全類型的指標無效"
 
-#: cp/typeck.c:5975
+#: cp/typeck.c:6035
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "需位址的建構子 %qE"
 
-#: cp/typeck.c:5976
+#: cp/typeck.c:6036
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.c:5992
+#: cp/typeck.c:6052
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用 %qE 形成成員函式指標的用法無效。"
 
-#: cp/typeck.c:5995
+#: cp/typeck.c:6055
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  需要一個限定的識別碼"
 
-#: cp/typeck.c:6002
+#: cp/typeck.c:6062
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parentheses 周圍 %qE 無法用來表單成員函式指標"
 
-#: cp/typeck.c:6188
+#: cp/typeck.c:6248
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過提取一個未限定的或帶括號的非靜態成員函式的位址來形成一個成員函式指標。請使用 %<&%T::%D%>"
 
-#: cp/typeck.c:6194
+#: cp/typeck.c:6254
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過取已繫結的成員函式的位址來建構成員函式指標。請改用 %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:6229
+#: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "取臨時變數的位址"
 
-#: cp/typeck.c:6246
+#: cp/typeck.c:6306
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允許取函式 %<::main%> 的位址"
 
-#: cp/typeck.c:6304
+#: cp/typeck.c:6364
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能建立參照參照成員 %qD 的指標"
 
-#: cp/typeck.c:6324
+#: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "無法取得位元段 %qD 的位址"
 
-#: cp/typeck.c:6340
+#: cp/typeck.c:6400
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.c:6487
+#: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "需位址的運算式的型態 %<void%>"
 
-#: cp/typeck.c:6488
+#: cp/typeck.c:6548
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6611
+#: cp/typeck.c:6671
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/typeck.c:6612
+#: cp/typeck.c:6672
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++禁止遞減 enum"
 
-#: cp/typeck.c:6628
+#: cp/typeck.c:6688
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: cp/typeck.c:6630
+#: cp/typeck.c:6690
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: cp/typeck.c:6642
+#: cp/typeck.c:6702
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞增指標的型態 %qT"
 
-#: cp/typeck.c:6644
+#: cp/typeck.c:6704
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞減指標的型態 %qT"
 
-#: cp/typeck.c:6683
+#: cp/typeck.c:6743
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6696
+#: cp/typeck.c:6756
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6706
+#: cp/typeck.c:6766
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6714
+#: cp/typeck.c:6774
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6894
+#: cp/typeck.c:6954
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: cp/typeck.c:6916
+#: cp/typeck.c:6976
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求明確暫存器變數 %qD 的位址。"
 
-#: cp/typeck.c:6921
+#: cp/typeck.c:6981
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "請求宣告為 %<register%> 的 %qD 的位址"
 
-#: cp/typeck.c:6996
+#: cp/typeck.c:7056
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer 用於 non-class 型態必須不被 parenthesized"
 
-#: cp/typeck.c:7008
+#: cp/typeck.c:7068
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "運算式清單視為複合式表示式在中初始設定式"
 
-#: cp/typeck.c:7012
+#: cp/typeck.c:7072
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "運算式清單視為複合式表示式在中 mem-initializer"
 
-#: cp/typeck.c:7016
+#: cp/typeck.c:7076
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "運算式清單視為複合式表示式在中 functional 演員陣容"
 
-#: cp/typeck.c:7053
+#: cp/typeck.c:7113
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 運算式清單被看作複合運算式"
 
-#: cp/typeck.c:7140
+#: cp/typeck.c:7200
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "沒有語境到解析型態的 %qE"
 
-#: cp/typeck.c:7174
+#: cp/typeck.c:7234
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "演員陣容從型態 %qT 輸入 %qT 演員陣容暫離限定元"
 
-#: cp/typeck.c:7180
+#: cp/typeck.c:7240
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "staticcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:7187
+#: cp/typeck.c:7247
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:7211
+#: cp/typeck.c:7271
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "%qT 使用了局部類型 %qT"
 
-#: cp/typeck.c:7225
+#: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/typeck.c:7648
+#: cp/typeck.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 static_cast 無效"
 
-#: cp/typeck.c:7654 cp/typeck.c:7660 cp/typeck.c:9312
+#: cp/typeck.c:7714 cp/typeck.c:7720 cp/typeck.c:9372
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/typeck.c:7686
+#: cp/typeck.c:7746
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "從 %qT 轉換到 %qT"
 
-#: cp/typeck.c:7761
+#: cp/typeck.c:7821
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/typeck.c:7831
+#: cp/typeck.c:7891
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "從 %qT 到 %qT 的轉換損失精度"
 
-#: cp/typeck.c:7856
+#: cp/typeck.c:7916
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7867
+#: cp/typeck.c:7927
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "比較介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:7888 cp/typeck.c:8078
+#: cp/typeck.c:7948 cp/typeck.c:8138
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "從 %qT 到 %qT 的轉換增大了目的類型的對齊需求"
 
-#: cp/typeck.c:7905
+#: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允許在函式指標和物件指標間進行轉換"
 
-#: cp/typeck.c:7919
+#: cp/typeck.c:7979
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/typeck.c:7992
+#: cp/typeck.c:8052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它既不是指標，也不是參照，也不是資料成員指標"
 
-#: cp/typeck.c:8001
+#: cp/typeck.c:8061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它是一個指標函式類型的指標或參照"
 
-#: cp/typeck.c:8043
+#: cp/typeck.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:8113
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:8214 cp/typeck.c:8223
+#: cp/typeck.c:8274 cp/typeck.c:8283
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允許轉換為陣列類型 %qT"
 
-#: cp/typeck.c:8232
+#: cp/typeck.c:8292
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函式類型 %qT 的轉換無效"
 
-#: cp/typeck.c:8542
+#: cp/typeck.c:8602
 #, gcc-internal-format
 msgid "compound assignment with %<volatile%>-qualified left operand is deprecated"
 msgstr ""
 
-#: cp/typeck.c:8562
+#: cp/typeck.c:8622
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  在求 %<%Q(%#T, %#T)%> 值時"
 
-#: cp/typeck.c:8622
+#: cp/typeck.c:8682
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "指派到陣列從初始設定式清單"
 
-#: cp/typeck.c:8649
+#: cp/typeck.c:8709
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "將 %qT 賦值給 %qT 時類型不相容"
 
-#: cp/typeck.c:8663
+#: cp/typeck.c:8723
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "陣列使用的做為初始設定式"
 
-#: cp/typeck.c:8665
+#: cp/typeck.c:8725
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "無效的陣列指派"
 
-#: cp/typeck.c:8799
+#: cp/typeck.c:8859
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "  在成員函式指標轉換中"
 
-#: cp/typeck.c:8813
+#: cp/typeck.c:8873
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成員指標轉換經由虛基礎類別 %qT"
 
-#: cp/typeck.c:8860 cp/typeck.c:8879
+#: cp/typeck.c:8920 cp/typeck.c:8939
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "  在成員指標轉換中"
 
-#: cp/typeck.c:8960
+#: cp/typeck.c:9020
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到類型 %qT 的轉換無效，從類型 %qT"
 
-#: cp/typeck.c:9275
+#: cp/typeck.c:9335
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "無法轉換 %qT 到 %qT 在中預設引數"
 
-#: cp/typeck.c:9280
+#: cp/typeck.c:9340
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "無法轉換 %qT 到 %qT 在中引數傳遞"
 
-#: cp/typeck.c:9289
+#: cp/typeck.c:9349
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/typeck.c:9293
+#: cp/typeck.c:9353
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "無法轉換 %qT 到 %qT 在中回傳"
 
-#: cp/typeck.c:9298
+#: cp/typeck.c:9358
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/typeck.c:9330
+#: cp/typeck.c:9390
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "參數 %qP 的 %qD 也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9334
+#: cp/typeck.c:9394
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "參數也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9339
+#: cp/typeck.c:9399
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "目標的轉換也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9344
+#: cp/typeck.c:9404
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "目標的初始化也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9354
+#: cp/typeck.c:9414
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "left-hand 側邊的指派也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:9450
+#: cp/typeck.c:9510
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在傳遞引數 %P (屬於 %q+D)"
 
-#: cp/typeck.c:9532
+#: cp/typeck.c:9592
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.c:9535
+#: cp/typeck.c:9595
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9571
+#: cp/typeck.c:9631
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "回傳了對局部變數的 %q+D 的參照"
 
-#: cp/typeck.c:9575
+#: cp/typeck.c:9635
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.c:9581
+#: cp/typeck.c:9641
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:9585
+#: cp/typeck.c:9645
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:9740
+#: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.c:9742 cp/typeck.c:9765
+#: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.c:9764
+#: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "太多值在中回傳敘述"
 
-#: cp/typeck.c:9803
+#: cp/typeck.c:9863
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "解構函式回傳值"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9811
+#: cp/typeck.c:9871
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能從建構式的異常處理中回傳"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9814
+#: cp/typeck.c:9874
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "建構式回傳值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9849 cp/typeck.c:9895
+#: cp/typeck.c:9909 cp/typeck.c:9955
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<brace-enclosed initializer list>"
 
-#: cp/typeck.c:9876
+#: cp/typeck.c:9936
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "不一致類型 %qT 和 %qT deduced 用於 lambda 傳回類型"
 
-#: cp/typeck.c:9879
+#: cp/typeck.c:9939
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/typeck.c:9914
+#: cp/typeck.c:9974
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:9943
+#: cp/typeck.c:10003
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> 不能回傳 NULL，除非它被宣告為 %<throw()%> (或 -fcheck-new 起作用)"
 
-#: cp/typeck.c:10579
+#: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "使用暫時的做為 lvalue"
@@ -58512,110 +58581,110 @@ msgstr "標量初始化帶大括號"
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.c:1696 cp/typeck2.c:1726
+#: cp/typeck2.c:1700 cp/typeck2.c:1730
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.c:1704
+#: cp/typeck2.c:1708
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1711
+#: cp/typeck2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1797
+#: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: cp/typeck2.c:1870
+#: cp/typeck2.c:1874
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.c:1881
+#: cp/typeck2.c:1885
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.c:2075
+#: cp/typeck2.c:2079
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.c:2119
+#: cp/typeck2.c:2123
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.c:2121
+#: cp/typeck2.c:2125
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.c:2148
+#: cp/typeck2.c:2152
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.c:2157
+#: cp/typeck2.c:2161
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.c:2179
+#: cp/typeck2.c:2183
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.c:2237
+#: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2248
+#: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2256
+#: cp/typeck2.c:2260
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2297
+#: cp/typeck2.c:2301
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.c:2319
+#: cp/typeck2.c:2323
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from %<()%>"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/typeck2.c:2339
+#: cp/typeck2.c:2343
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.c:2580
+#: cp/typeck2.c:2584
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.c:2583
+#: cp/typeck2.c:2587
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -58847,10 +58916,10 @@ msgstr "%C 處的任何參照都不能多於 %d 維"
 msgid "Array reference at %C cannot have more than %d dimensions"
 msgstr "%C 處的任何參照都不能多於 %d 維"
 
-#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3423
-#: fortran/check.c:5896 fortran/check.c:5934 fortran/check.c:5976
-#: fortran/check.c:6003 fortran/check.c:6260 fortran/match.c:1874
-#: fortran/match.c:3267 fortran/match.c:3609 fortran/match.c:3805
+#: fortran/array.c:241 fortran/array.c:696 fortran/check.c:3427
+#: fortran/check.c:5918 fortran/check.c:5956 fortran/check.c:5998
+#: fortran/check.c:6025 fortran/check.c:6288 fortran/match.c:1874
+#: fortran/match.c:3270 fortran/match.c:3612 fortran/match.c:3808
 #: fortran/simplify.c:2957 fortran/simplify.c:2987 fortran/simplify.c:6253
 #: fortran/simplify.c:8236
 #, fuzzy, gcc-internal-format
@@ -59022,7 +59091,7 @@ msgstr "Fortran 2003:[...] 樣式陣列建構子於 %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003:陣列建構子包含型態規格於 %C"
 
-#: fortran/array.c:1255 fortran/match.c:4241
+#: fortran/array.c:1255 fortran/match.c:4244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
@@ -59142,7 +59211,7 @@ msgstr "non-parameter %qs 無法參數包裝"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "『我』於 %L 和『J』於 %L 無法兩者是 BOZ 實字常數"
 
-#: fortran/check.c:123 fortran/resolve.c:10854
+#: fortran/check.c:123 fortran/resolve.c:10856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無效的 exponent-letter『q』在中 real-literal-constant 於 %C"
@@ -59186,7 +59255,7 @@ msgstr "預期的 coarray 變數做為『%s』引數到 %s intrinsic 於 %L"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
 msgstr "『a1』引數的『%s』intrinsic 於 %L 必須是整數，真實或字元"
 
-#: fortran/check.c:590 fortran/check.c:3378
+#: fortran/check.c:590 fortran/check.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
@@ -59204,7 +59273,7 @@ msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為實數型
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為 INTEGER 或 PROCEDURE"
 
-#: fortran/check.c:651 fortran/check.c:7463
+#: fortran/check.c:651 fortran/check.c:7494
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -59337,173 +59406,173 @@ msgstr "Unequal 字元長度 (%ld/%ld) 在中 %s 於 %L"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "「%s」和「%s」引數(屬於「%s」內建函式)在 %L 處類型必須相同"
 
-#: fortran/check.c:1416 fortran/check.c:3687
+#: fortran/check.c:1416 fortran/check.c:3694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
 msgstr "擴充：%L 處類型種別不同"
 
-#: fortran/check.c:1452
+#: fortran/check.c:1439
+#, fuzzy, gcc-internal-format
+#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr "%L 的 NULL 指標不能做為內建函式「%s」的引數"
+
+#: fortran/check.c:1461
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是一個 POINTER"
 
-#: fortran/check.c:1461 fortran/check.c:1497 fortran/check.c:4368
+#: fortran/check.c:1470 fortran/check.c:1505 fortran/check.c:4381
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:1479
+#: fortran/check.c:1487
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是指標或目標變數或函式"
 
-#: fortran/check.c:1488
+#: fortran/check.c:1496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER or a TARGET"
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是一個 POINTER 或 TARGET"
 
-#: fortran/check.c:1513
+#: fortran/check.c:1521
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
 msgstr "%L 處由向量下標選擇的部分陣列不應是指標的目的"
 
-#: fortran/check.c:1524
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
-msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "%L 的 NULL 指標不能做為內建函式「%s」的引數"
-
-#: fortran/check.c:1567
+#: fortran/check.c:1568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
 msgstr "原子引數於 %L 到內建函式 %s 應該是整數的 ATOMIC_INT_KIND 或邏輯的的 ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1575
+#: fortran/check.c:1576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
 msgstr "原子引數於 %L 的 %s 內建函式應該是 coarray 或 coindexed"
 
-#: fortran/check.c:1582
+#: fortran/check.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須具有與「%s」一樣的類型和種別"
 
-#: fortran/check.c:1600 fortran/check.c:1813
+#: fortran/check.c:1601 fortran/check.c:1814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "STAT= argument to %s at %L"
 msgstr "給予函式 %s 的參數太多，於 %L"
 
-#: fortran/check.c:1619 fortran/check.c:1753 fortran/check.c:1850
+#: fortran/check.c:1620 fortran/check.c:1754 fortran/check.c:1851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
 msgstr "原子引數的 %s 內建函式於 %L 應該是 definable"
 
-#: fortran/check.c:1633 fortran/check.c:1833
+#: fortran/check.c:1634 fortran/check.c:1834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
 msgstr "原子引數於 %L 到內建函式 %s 應該是整數的 ATOMIC_INT_KIND 或邏輯的的 ATOMIC_LOGICAL_KIND"
 
-#: fortran/check.c:1653
+#: fortran/check.c:1654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
 msgstr "值引數的 %s 內建函式於 %L 應該是 definable"
 
-#: fortran/check.c:1672 fortran/check.c:1686 fortran/check.c:1721
+#: fortran/check.c:1673 fortran/check.c:1687 fortran/check.c:1722
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 可能無法是程序"
 
-#: fortran/check.c:1706
+#: fortran/check.c:1707
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 並非有效尺寸索引"
 
-#: fortran/check.c:1760 fortran/check.c:1857
+#: fortran/check.c:1761 fortran/check.c:1858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
 msgstr "原子引數的 %s 內建函式於 %L 應該是 definable"
 
-#: fortran/check.c:1775
+#: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/check.c:1785
+#: fortran/check.c:1786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
 msgstr "原子引數的 %s 內建函式於 %L 應該是 definable"
 
-#: fortran/check.c:1798
+#: fortran/check.c:1799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
 msgstr "原子引數的 %s 內建函式於 %L 應該是 definable"
 
-#: fortran/check.c:1877
+#: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
 msgstr "延伸：負引數 N 於 %L"
 
-#: fortran/check.c:2099 fortran/check.c:2589
+#: fortran/check.c:2100 fortran/check.c:2590
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be present if 'x' is COMPLEX"
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
 msgstr "當「x」是 COMPLEX 時「%s」引數(屬於「%s」內建函式，在 %L 處)不能存在"
 
-#: fortran/check.c:2108 fortran/check.c:2598
+#: fortran/check.c:2109 fortran/check.c:2599
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須有型態的還是真實或整數"
 
-#: fortran/check.c:2118 fortran/check.c:2124
+#: fortran/check.c:2119 fortran/check.c:2125
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
 msgstr ""
 
-#: fortran/check.c:2146
+#: fortran/check.c:2147
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
 msgstr ""
 
-#: fortran/check.c:2154
+#: fortran/check.c:2155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:2177
+#: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/check.c:2193
+#: fortran/check.c:2194
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/check.c:2201
+#: fortran/check.c:2202
 #, fuzzy, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
 msgstr "Coarrays 已停用於 %C, 使用 -fcoarray=以啟用"
 
-#: fortran/check.c:2216
+#: fortran/check.c:2217
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2235
+#: fortran/check.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:2242
+#: fortran/check.c:2243
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
 msgstr ""
 
-#: fortran/check.c:2256
+#: fortran/check.c:2257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "OPERATOR argument at %L must be a PURE function"
@@ -59512,714 +59581,714 @@ msgstr "%s 的參數(位於 %L)長度必須為 1"
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
-#: fortran/check.c:2266
+#: fortran/check.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
 msgstr "內建函式『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/check.c:2283
+#: fortran/check.c:2284
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
 msgstr ""
 
-#: fortran/check.c:2293
+#: fortran/check.c:2294
 #, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L has type %s but the function passed as OPERATOR at %L returns %s"
 msgstr ""
 
-#: fortran/check.c:2302
+#: fortran/check.c:2303
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
 msgstr ""
 
-#: fortran/check.c:2313
+#: fortran/check.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
 msgstr ""
 
-#: fortran/check.c:2321
+#: fortran/check.c:2322
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2328
+#: fortran/check.c:2329
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2335
+#: fortran/check.c:2336
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
 msgstr ""
 
-#: fortran/check.c:2343
+#: fortran/check.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
 msgstr ""
 
-#: fortran/check.c:2373
+#: fortran/check.c:2374
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2380
+#: fortran/check.c:2381
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
 msgstr ""
 
-#: fortran/check.c:2398
+#: fortran/check.c:2399
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:2477 fortran/check.c:3107 fortran/check.c:3190
-#: fortran/check.c:3409 fortran/check.c:3454 fortran/check.c:4934
-#: fortran/check.c:5068 fortran/check.c:5123 fortran/check.c:6246
-#: fortran/check.c:6375
+#: fortran/check.c:2478 fortran/check.c:3108 fortran/check.c:3191
+#: fortran/check.c:3413 fortran/check.c:3461 fortran/check.c:4947
+#: fortran/check.c:5084 fortran/check.c:5139 fortran/check.c:6274
+#: fortran/check.c:6403
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Fortran 2003:『%s』intrinsic 與 KIND 引數於 %L"
 
-#: fortran/check.c:2524 fortran/check.c:2793 fortran/check.c:2853
+#: fortran/check.c:2525 fortran/check.c:2794 fortran/check.c:2854
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有無效的形狀在中尺寸 %d (%ld/%ld)"
 
-#: fortran/check.c:2539 fortran/check.c:2808 fortran/check.c:2868
+#: fortran/check.c:2540 fortran/check.c:2809 fortran/check.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
 msgstr "『%s』引數的 intrinsic『%s』於 %L 的必須有分級 %d 或是純量"
 
-#: fortran/check.c:2651 fortran/check.c:3781 fortran/check.c:3789
+#: fortran/check.c:2652 fortran/check.c:3788 fortran/check.c:3796
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be numeric or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為數字或 LOGICAL 型"
 
-#: fortran/check.c:2665
+#: fortran/check.c:2666
 #, fuzzy, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
 msgstr "不同的形狀用於引數『%s』和『%s』於 %L 用於 intrinsic『dotproduct』(_P)"
 
-#: fortran/check.c:2685 fortran/check.c:2693
+#: fortran/check.c:2686 fortran/check.c:2694
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是預設真實"
 
-#: fortran/check.c:2829
+#: fortran/check.c:2830
 #, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
 msgstr ""
 
-#: fortran/check.c:2887
+#: fortran/check.c:2888
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是 %s"
 
-#: fortran/check.c:2919
+#: fortran/check.c:2920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
 msgstr "GNU 延伸：non-default 整數 kind 引數到 %s intrinsic 於 %L"
 
-#: fortran/check.c:2980
+#: fortran/check.c:2981
 #, fuzzy, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
 msgstr "Fortran 2008:複雜引數『%s』引數的『%s』intrinsic 於 %L"
 
-#: fortran/check.c:3062
+#: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "不同的 kind 型態參數在中指標指派於 %L"
 
-#: fortran/check.c:3158
+#: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of %s at %L must be of length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/check.c:3197
+#: fortran/check.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須具有與「%s」一樣的種別"
 
-#: fortran/check.c:3231
+#: fortran/check.c:3232
 #, gcc-internal-format
 msgid "%qs intrinsic subprogram at %L has been deprecated.  Use INT intrinsic subprogram."
 msgstr ""
 
-#: fortran/check.c:3283
+#: fortran/check.c:3284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SIZE at %L must be positive"
 msgstr "大小於 %L 必須是正值"
 
-#: fortran/check.c:3295
+#: fortran/check.c:3296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
 msgstr "絕對值的 Shift 於 %L 必須是少於或等於大小於 %L"
 
-#: fortran/check.c:3354
+#: fortran/check.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STATUS at %L shall be an INTENT(OUT) variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/check.c:3363
+#: fortran/check.c:3364
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L shall be an INTENT(OUT) variable"
 msgstr "『%s』於 %C 並非變數"
 
-#: fortran/check.c:3385
+#: fortran/check.c:3389
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是一個常數"
 
-#: fortran/check.c:3596
+#: fortran/check.c:3603
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Intrinsic %qs at %L must have at least two arguments"
 msgstr "內建函式「%s」 於 %L 處必須有至少兩個引數"
 
-#: fortran/check.c:3644
+#: fortran/check.c:3651
 #, fuzzy, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
 msgstr "缺少引數到『%s』於 %C"
 
-#: fortran/check.c:3659
+#: fortran/check.c:3666
 #, fuzzy, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
 msgstr "引數『%s』和『%s』用於 intrinsic %s"
 
-#: fortran/check.c:3664
+#: fortran/check.c:3671
 #, fuzzy, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
 msgstr "引數『%s』和『%s』用於 intrinsic %s"
 
-#: fortran/check.c:3693
+#: fortran/check.c:3700
 #, fuzzy, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
 msgstr "『a%d』引數的『%s』intrinsic 於 %L 必須是 %s(%d)"
 
-#: fortran/check.c:3724
+#: fortran/check.c:3731
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
 msgstr "Fortran 2003:『%s』intrinsic 與字元引數於 %L"
 
-#: fortran/check.c:3731
+#: fortran/check.c:3738
 #, fuzzy, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
 msgstr "『a1』引數的『%s』intrinsic 於 %L 必須是整數，真實或字元"
 
-#: fortran/check.c:3798
+#: fortran/check.c:3805
 #, fuzzy, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
 msgstr "引數類型的『%s』intrinsic 於 %L 必須匹配 (%s/%s)"
 
-#: fortran/check.c:3812
+#: fortran/check.c:3819
 #, fuzzy, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
 msgstr "不同的形狀於尺寸 1 用於引數『%s』和『%s』於 %L 用於 intrinsic matmul"
 
-#: fortran/check.c:3831
+#: fortran/check.c:3838
 #, fuzzy, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
 msgstr "不同的形狀於尺寸 2 用於引數『%s』和尺寸 1 用於引數『%s』於 %L 用於 intrinsic matmul"
 
-#: fortran/check.c:3840
+#: fortran/check.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)的秩必須為 1 或 2"
 
-#: fortran/check.c:4003
+#: fortran/check.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be conformable with '%s' argument"
 msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須與「%s」引數相容"
 
-#: fortran/check.c:4121 fortran/check.c:7383 fortran/check.c:7398
+#: fortran/check.c:4128 fortran/check.c:7414 fortran/check.c:7429
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是整數"
 
-#: fortran/check.c:4198
+#: fortran/check.c:4211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:4209
+#: fortran/check.c:4222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:4216
+#: fortran/check.c:4229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
 msgstr "到引數在中 MOVE_ALLOC 於 %L 必須是 polymorphic 如果從是 polymorphic"
 
-#: fortran/check.c:4227
+#: fortran/check.c:4240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
 msgstr "『%s』和『%s』引數的『%s』intrinsic 於 %L 必須有同級 %d/%d"
 
-#: fortran/check.c:4236
+#: fortran/check.c:4249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
 msgstr "『%s』和『%s』引數的『%s』intrinsic 於 %L 必須有同級 %d/%d"
 
-#: fortran/check.c:4276
+#: fortran/check.c:4289
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
 msgstr ""
 
-#: fortran/check.c:4303
+#: fortran/check.c:4316
 #, fuzzy, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
 msgstr "引數『S』的最近的於 %L 不應該是零"
 
-#: fortran/check.c:4353
+#: fortran/check.c:4366
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是指標，ALLOCATABLE 或程序指標"
 
-#: fortran/check.c:4361
+#: fortran/check.c:4374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Fortran 2003:空值 intrinsic 與 allocatable 鑄型於 %L"
 
-#: fortran/check.c:4440 fortran/check.c:6322
+#: fortran/check.c:4453 fortran/check.c:6350
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須提供至少做為許多元件做為有些.TRUE。值在中『%s』(%ld/%d)"
 
-#: fortran/check.c:4498
+#: fortran/check.c:4511
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是一個啞元變數"
 
-#: fortran/check.c:4506
+#: fortran/check.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an OPTIONAL dummy variable"
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
 msgstr "「%s」引數(屬於「%s」內建函式，位於 %L)必須是一個 OPTIONAL 啞變數"
 
-#: fortran/check.c:4525
+#: fortran/check.c:4538
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須不是子物件的『%s』"
 
-#: fortran/check.c:4576
+#: fortran/check.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "引數的分級 intrinsic 於 %L 必須是資料物件"
 
-#: fortran/check.c:4683
+#: fortran/check.c:4696
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "「reshape」內建函式的「shape」引數在 %L 處必須是大小為常數的陣列"
 
-#: fortran/check.c:4693
+#: fortran/check.c:4706
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 是空的"
 
-#: fortran/check.c:4700
+#: fortran/check.c:4713
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "「reshape」內建函式的「shape」引數在 %L 處有多於 %d 個的元素"
 
-#: fortran/check.c:4717
+#: fortran/check.c:4730
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有負元件 (%d)"
 
-#: fortran/check.c:4749
+#: fortran/check.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "複雜引數的記錄檔於 %L 無法零"
 
-#: fortran/check.c:4787
+#: fortran/check.c:4800
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有錯誤的元件號碼的 (%d/%d)"
 
-#: fortran/check.c:4805
+#: fortran/check.c:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有 out-of-range 尺寸 (%d)"
 
-#: fortran/check.c:4814
+#: fortran/check.c:4827
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有無效的排列的維度 (尺寸『%d』重製)"
 
-#: fortran/check.c:4850
+#: fortran/check.c:4863
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "而無需填補，有些不足元件在中 intrinsic 重設形狀來源於 %L 到匹配形狀"
 
-#: fortran/check.c:4867 fortran/check.c:4886
+#: fortran/check.c:4880 fortran/check.c:4899
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是 %s"
 
-#: fortran/check.c:4877 fortran/check.c:4896
+#: fortran/check.c:4890 fortran/check.c:4909
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是的 extensible 型態"
 
-#: fortran/check.c:4995
+#: fortran/check.c:5008
 #, fuzzy, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "Fortran 2008:SELECTED_REAL_KIND 與 neither『P』nor『R』引數於 %L"
 
-#: fortran/check.c:5026
+#: fortran/check.c:5039
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Fortran 2008:『%s』intrinsic 與基數引數於 %L"
 
-#: fortran/check.c:5061
+#: fortran/check.c:5077
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "「shape」內建函式的「source」引數在 %L 處不能是假定大小的陣列"
 
-#: fortran/check.c:5138 fortran/check.c:7443
+#: fortran/check.c:5157 fortran/check.c:7474
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 可能無法是程序"
 
-#: fortran/check.c:5151 fortran/check.c:5290 fortran/check.c:7435
+#: fortran/check.c:5170 fortran/check.c:5309 fortran/check.c:7466
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:5162 fortran/check.c:5302
+#: fortran/check.c:5181 fortran/check.c:5321
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "「shape」內建函式的「source」引數在 %L 處不能是假定大小的陣列"
 
-#: fortran/check.c:5232
+#: fortran/check.c:5251
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:5281
+#: fortran/check.c:5300
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是可交流的資料個體"
 
-#: fortran/check.c:5320
+#: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5334
+#: fortran/check.c:5353
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:5358
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:5370
+#: fortran/check.c:5389
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5377
+#: fortran/check.c:5396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5384
+#: fortran/check.c:5403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5391
+#: fortran/check.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:5397
+#: fortran/check.c:5416
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:5416
+#: fortran/check.c:5435
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:5426
+#: fortran/check.c:5445
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:5431
+#: fortran/check.c:5450
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:5447
+#: fortran/check.c:5466
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:5459
+#: fortran/check.c:5478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5466
+#: fortran/check.c:5485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5472
+#: fortran/check.c:5491
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:5486
+#: fortran/check.c:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:5498
+#: fortran/check.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/check.c:5505
+#: fortran/check.c:5524
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:5511
+#: fortran/check.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "缺少引數「%s」，在呼叫「%s」時，位於 %L"
 
-#: fortran/check.c:5525
+#: fortran/check.c:5544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:5531
+#: fortran/check.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5542
+#: fortran/check.c:5561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%C 處的元件必須有 POINTER 屬性"
 
-#: fortran/check.c:5550
+#: fortran/check.c:5569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "引數『S』的最近的於 %L 不應該是零"
 
-#: fortran/check.c:5559
+#: fortran/check.c:5578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:5566
+#: fortran/check.c:5585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "缺少引數「%s」，在呼叫「%s」時，位於 %L"
 
-#: fortran/check.c:5577
+#: fortran/check.c:5596
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:5582
+#: fortran/check.c:5601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: fortran/check.c:5610
+#: fortran/check.c:5629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "GNU 延伸：非雙倍精度真實引數到 %s intrinsic 於 %L"
 
-#: fortran/check.c:5623
+#: fortran/check.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)秩必須小於 %d"
 
-#: fortran/check.c:5642
+#: fortran/check.c:5664
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 並非有效尺寸索引"
 
-#: fortran/check.c:5905
+#: fortran/check.c:5927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "%s 引數到 IMAGE_INDEX 必須是分級一個陣列於 %L"
 
-#: fortran/check.c:5916
+#: fortran/check.c:5938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "陣列元素數量的子引數到 IMAGE_INDEX 於 %L 應該是 %d (corank) 無法 %d"
 
-#: fortran/check.c:5949
+#: fortran/check.c:5971
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5962
+#: fortran/check.c:5984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "鑄型引數到空值必要項於 %L"
 
-#: fortran/check.c:5986
+#: fortran/check.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "原子引數於 %L 的 %s 內建函式應該是 coarray 或 coindexed"
 
-#: fortran/check.c:6012
+#: fortran/check.c:6034
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM 引數而無需陣列引數不允許用於 THIS_IMAGE intrinsic 於 %L"
 
-#: fortran/check.c:6019
+#: fortran/check.c:6041
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:6030
+#: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "%C 處參數清單中有非預期的無用字元"
 
-#: fortran/check.c:6048
+#: fortran/check.c:6070
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:6106
+#: fortran/check.c:6128
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
 msgstr ""
 
-#: fortran/check.c:6155
+#: fortran/check.c:6180
 #, fuzzy, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "『鑄型』引數的『轉送』intrinsic 於 %L 必須不是 %s"
 
-#: fortran/check.c:6171
+#: fortran/check.c:6199
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
 msgstr "『鑄型』引數的『轉送』intrinsic 於 %L 必須不是 %s"
 
-#: fortran/check.c:6179
+#: fortran/check.c:6207
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "『鑄型』引數的『轉送』intrinsic 於 %L 必須不是 %s"
 
-#: fortran/check.c:6214
+#: fortran/check.c:6242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Intrinsic 轉送於 %L 有部分未定義的結果：來源大小 %ld<結果大小 %ld"
 
-#: fortran/check.c:6336
+#: fortran/check.c:6364
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須有同級做為『%s』或是純量"
 
-#: fortran/check.c:6349
+#: fortran/check.c:6377
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "『%s』和『%s』引數的『%s』intrinsic 於 %L 必須有相等的形狀。"
 
-#: fortran/check.c:6612 fortran/check.c:6644
+#: fortran/check.c:6643 fortran/check.c:6675
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "大小的『%s』引數的『%s』intrinsic 於 %L 太小 (%i/%i)"
 
-#: fortran/check.c:6652
+#: fortran/check.c:6683
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "給予函式 %s 的參數太多，於 %L"
 
-#: fortran/check.c:6670
+#: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:6682
+#: fortran/check.c:6713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: fortran/check.c:6722
+#: fortran/check.c:6753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:6741
+#: fortran/check.c:6772
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6751
+#: fortran/check.c:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:6768
+#: fortran/check.c:6799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:6985
+#: fortran/check.c:7016
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是的 kind 無法 wider 比預設 kind (%d)"
 
-#: fortran/check.c:7167
+#: fortran/check.c:7198
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
 msgstr "原子引數於 %L 的 %s 內建函式應該是 coarray 或 coindexed"
 
-#: fortran/check.c:7356 fortran/check.c:7367
+#: fortran/check.c:7387 fortran/check.c:7398
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為 INTEGER 或 LOGICAL"
 
-#: fortran/check.c:7427
+#: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
 
-#: fortran/class.c:628
+#: fortran/class.c:648
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
 msgstr "假設的大小 polymorphic 物件或成分，像是該於 %C, 尚未被實作"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:739 fortran/decl.c:3885 fortran/decl.c:10547
+#: fortran/class.c:759 fortran/decl.c:3890 fortran/decl.c:10559
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "最大值延伸等級達到的與型態『%s』於 %L"
 
-#: fortran/class.c:2911 fortran/class.c:2985
+#: fortran/class.c:2947 fortran/class.c:3021
 #, fuzzy, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
 msgstr "『%s』的『%s』是私人的於 %L"
@@ -60422,1799 +60491,1799 @@ msgstr "%C 處錯誤地指定 INTENT"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003:已推遲型態參數於 %C"
 
-#: fortran/decl.c:1147 fortran/resolve.c:12361
+#: fortran/decl.c:1152 fortran/resolve.c:12371
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1173
+#: fortran/decl.c:1178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Obsolescent 特徵：舊式字元長度於 %C"
 
-#: fortran/decl.c:1204
+#: fortran/decl.c:1209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "%C 處指定字元長度時語法錯誤"
 
-#: fortran/decl.c:1356 fortran/decl.c:1363 fortran/decl.c:1427
+#: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "程序「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/decl.c:1371
+#: fortran/decl.c:1376
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "程序「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/decl.c:1383
+#: fortran/decl.c:1388
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "名稱『%s』於 %C 已經定義為通用介面於 %L"
 
-#: fortran/decl.c:1399
+#: fortran/decl.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "程序「%s」在 %C 處具有顯式介面，而且必須在 %L 處不具有已宣告的屬性"
 
-#: fortran/decl.c:1415
+#: fortran/decl.c:1420
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1498
+#: fortran/decl.c:1503
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "程序『%s』於 %L 必須有繫結©屬性為 C 可交流的"
 
-#: fortran/decl.c:1525
+#: fortran/decl.c:1530
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "變數『%s』於 %L 是虛引數到繫結©程序『%s』但是不是 C 可交流的因為衍生類型『%s』不是 C 可交流的"
 
-#: fortran/decl.c:1532
+#: fortran/decl.c:1537
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "變數『%s』於 %L 是虛引數到繫結©程序『%s』但是不是 C 可交流的因為它是 polymorphic"
 
-#: fortran/decl.c:1539
+#: fortran/decl.c:1544
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "變數『%s』於 %L 是參數到繫結©程序『%s』但是可能無法是 C 可交流的"
 
-#: fortran/decl.c:1554
+#: fortran/decl.c:1559
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "字元引數『%s』於 %L 必須是長度 1 因為程序『%s』是繫結©"
 
-#: fortran/decl.c:1567
+#: fortran/decl.c:1572
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1580
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1584
+#: fortran/decl.c:1589
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "變數『%s』於 %L 無法同時有可選的和值屬性因為程序『%s』是繫結©"
 
-#: fortran/decl.c:1591
+#: fortran/decl.c:1596
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1602
+#: fortran/decl.c:1607
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Assumed-shape 陣列『%s』於 %L 無法引數到程序『%s』於 %L 因為程序是繫結©"
 
-#: fortran/decl.c:1670
+#: fortran/decl.c:1675
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "符號「%s」在 %L 處已經有了基本類型 %s"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1734
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "變數『%s』在中共同區塊『%s』於 %C 必須被宣告與 C 可交流的 kind 自從共同區塊『%s』是繫結©"
 
-#: fortran/decl.c:1769
+#: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "引數必須是常數"
 
-#: fortran/decl.c:1784
+#: fortran/decl.c:1789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "字元運算式於 %L 正在被截斷 (%d/%d)"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "字元元件的陣列建構子於 %L 必須有相同長度 (%d/%d)"
 
-#: fortran/decl.c:1891
+#: fortran/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "PARAMETER「%s」在 %C 處不允許有初始值設定"
 
-#: fortran/decl.c:1901
+#: fortran/decl.c:1906
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "%L 處 PARAMETER 缺少初始值設定"
 
-#: fortran/decl.c:1911
+#: fortran/decl.c:1916
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "變數『%s』於 %C 與初始設定式已經出現在中資料敘述"
 
-#: fortran/decl.c:1954
+#: fortran/decl.c:1959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "無法初始化 implied-shape 陣列於 %L 與純量"
 
-#: fortran/decl.c:2023
+#: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "無法初始化 implied-shape 陣列於 %L 與純量"
 
-#: fortran/decl.c:2034
+#: fortran/decl.c:2039
 #, gcc-internal-format
 msgid "gfc_array_size failed"
 msgstr ""
 
-#: fortran/decl.c:2064
+#: fortran/decl.c:2069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Non-constant 下限在中 implied-shape 宣告於 %L"
 
-#: fortran/decl.c:2150 fortran/decl.c:2157
+#: fortran/decl.c:2155 fortran/decl.c:2162
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C 處的元件必須有 POINTER 屬性"
 
-#: fortran/decl.c:2166
+#: fortran/decl.c:2171
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 
-#: fortran/decl.c:2175
+#: fortran/decl.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "陣列成分的結構於 %C 必須有明確的或已推遲形狀"
 
-#: fortran/decl.c:2199 fortran/symbol.c:2258
+#: fortran/decl.c:2204 fortran/symbol.c:2263
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "元件「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/decl.c:2247
+#: fortran/decl.c:2252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "指標陣列成分的結構於 %C 必須有已推遲形狀"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allocatable 成分的結構於 %C 必須有已推遲形狀"
 
-#: fortran/decl.c:2265
+#: fortran/decl.c:2270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "陣列成分的結構於 %C 必須有明確的形狀"
 
-#: fortran/decl.c:2282
+#: fortran/decl.c:2287
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "帶有省略號的參數清單無法與空參數名清單宣告匹配"
 
-#: fortran/decl.c:2339
+#: fortran/decl.c:2344
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "%C 處的 NULL() 初始化有歧義"
 
-#: fortran/decl.c:2356
+#: fortran/decl.c:2361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "%C 處的 NULL() 初始化有歧義"
 
-#: fortran/decl.c:2373
+#: fortran/decl.c:2378
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C 處對指標的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:2394
+#: fortran/decl.c:2399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "在中指標初始化於 %C 時發生錯誤"
 
-#: fortran/decl.c:2401
+#: fortran/decl.c:2406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2008:non-NULL 指標初始化於 %C"
 
-#: fortran/decl.c:2424
+#: fortran/decl.c:2429
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2478
+#: fortran/decl.c:2483
 #, fuzzy, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "值未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:2480
+#: fortran/decl.c:2485
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2488
+#: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "列舉量不能有屬性 %C"
 
-#: fortran/decl.c:2498
+#: fortran/decl.c:2503
 #, fuzzy, gcc-internal-format
 msgid "Invalid character %qc in variable name at %C"
 msgstr "無效字元在中名稱於 %C"
 
-#: fortran/decl.c:2540
+#: fortran/decl.c:2545
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
 msgstr "Non-PARAMETER 符號『%s』於 %L 無法 implied-shape"
 
-#: fortran/decl.c:2550
+#: fortran/decl.c:2555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008:Implied-shape 陣列於 %L"
 
-#: fortran/decl.c:2607
+#: fortran/decl.c:2612
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2701
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2707
+#: fortran/decl.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/decl.c:2732 fortran/decl.c:8788
+#: fortran/decl.c:2737 fortran/decl.c:8800
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "重製陣列 spec 用於 Cray 點於 %C"
 
-#: fortran/decl.c:2740
+#: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "無法轉換為指標類型"
 
-#: fortran/decl.c:2803
+#: fortran/decl.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: fortran/decl.c:2811
+#: fortran/decl.c:2816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: fortran/decl.c:2824
+#: fortran/decl.c:2829
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "在中指標初始化於 %C 時發生錯誤"
 
-#: fortran/decl.c:2844 fortran/decl.c:7004
+#: fortran/decl.c:2849 fortran/decl.c:7016
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C 的初始化不是為指標變數準備的"
 
-#: fortran/decl.c:2867
+#: fortran/decl.c:2872
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "在 %C 處的指標初始化需要「=>」，而不是「=」"
 
-#: fortran/decl.c:2876 fortran/decl.c:10721
+#: fortran/decl.c:2881 fortran/decl.c:10733
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C 處需要一個初始化運算式"
 
-#: fortran/decl.c:2883
+#: fortran/decl.c:2888
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C 處對變數的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:2900
+#: fortran/decl.c:2905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "初始化的 allocatable 成分於 %C 未被允許"
 
-#: fortran/decl.c:2909
+#: fortran/decl.c:2914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
 msgstr "初始化的 allocatable 成分於 %C 未被允許"
 
-#: fortran/decl.c:2923
+#: fortran/decl.c:2928
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2931
+#: fortran/decl.c:2936
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2939
+#: fortran/decl.c:2944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "指標成分『%s』的『%s』於 %L 是型態該未被宣告"
 
-#: fortran/decl.c:2948
+#: fortran/decl.c:2953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "BOZ literal constant at %L cannot appear as an initializer"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
 msgstr ""
 
-#: fortran/decl.c:3028 fortran/decl.c:3064
+#: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "舊式的型態宣告 %s*%d 在 %C 處不被支援"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nonstandard 類型宣告 %s*%d 於 %C"
 
-#: fortran/decl.c:3129 fortran/decl.c:3206
+#: fortran/decl.c:3134 fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "缺少右括號於 %C"
 
-#: fortran/decl.c:3142 fortran/decl.c:3277
+#: fortran/decl.c:3147 fortran/decl.c:3282
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C 處需要初始化運算式"
 
-#: fortran/decl.c:3150 fortran/decl.c:3283
+#: fortran/decl.c:3155 fortran/decl.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C 處需要標量初始化運算式"
 
-#: fortran/decl.c:3180 fortran/decl.c:3906
+#: fortran/decl.c:3185 fortran/decl.c:3911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Kind %d 不支援用於型態 %s 於 %C"
 
-#: fortran/decl.c:3193
+#: fortran/decl.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C kind 型態參數是用於型態 %s 但是型態於 %L 是 %s"
 
-#: fortran/decl.c:3204
+#: fortran/decl.c:3209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "缺少右括號或逗號於 %C"
 
-#: fortran/decl.c:3309
+#: fortran/decl.c:3314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Kind %d 未被支援用於字元於 %C"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3446
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:3540
+#: fortran/decl.c:3545
 #, gcc-internal-format
 msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:3553
+#: fortran/decl.c:3558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:3666
+#: fortran/decl.c:3671
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3690
+#: fortran/decl.c:3695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Kind 型態參數用於實體於 %L 不同從 kind 型態參數的 typespec"
 
-#: fortran/decl.c:3714
+#: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "第一個參數的 %<operator new%> 無法有預設引數"
 
-#: fortran/decl.c:3746
+#: fortran/decl.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "運算式於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/decl.c:3774
+#: fortran/decl.c:3779
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3781
+#: fortran/decl.c:3786
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: fortran/decl.c:3796
+#: fortran/decl.c:3801
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3805
+#: fortran/decl.c:3810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: fortran/decl.c:4041
+#: fortran/decl.c:4046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "擴充：%C 處的 BYTE 類型"
 
-#: fortran/decl.c:4053
+#: fortran/decl.c:4058
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C 使用到的 BYTE 類型在目標平臺上不可"
 
-#: fortran/decl.c:4114
+#: fortran/decl.c:4120
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4123
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:4139 fortran/decl.c:4173 fortran/decl.c:4206
-#: fortran/decl.c:4499
+#: fortran/decl.c:4145 fortran/decl.c:4179 fortran/decl.c:4212
+#: fortran/decl.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008:型態與 intrinsic-type-spec 於 %C"
 
-#: fortran/decl.c:4151 fortran/decl.c:4179 fortran/decl.c:4212
-#: fortran/decl.c:4238 fortran/decl.c:4524 fortran/decl.c:4539
+#: fortran/decl.c:4157 fortran/decl.c:4185 fortran/decl.c:4218
+#: fortran/decl.c:4244 fortran/decl.c:4536 fortran/decl.c:4551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed type-spec at %C"
 msgstr "無效的 type-spec 於 %C"
 
-#: fortran/decl.c:4202
+#: fortran/decl.c:4208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "延伸：雙倍複雜於 %C"
 
-#: fortran/decl.c:4254 fortran/decl.c:4390 fortran/decl.c:4402
-#: fortran/decl.c:4416 fortran/decl.c:4898 fortran/decl.c:4906
+#: fortran/decl.c:4260 fortran/decl.c:4402 fortran/decl.c:4414
+#: fortran/decl.c:4428 fortran/decl.c:4910 fortran/decl.c:4918
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "類型名「%s」(於 %C 處)有歧義"
 
-#: fortran/decl.c:4349
+#: fortran/decl.c:4361
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003:類別敘述於 %C"
 
-#: fortran/decl.c:4431
+#: fortran/decl.c:4443
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "型態名稱『%s』於 %C 衝突與在之前宣告的實體於 %L, 該項有同名"
 
-#: fortran/decl.c:4574
+#: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C 處 IMPLICIT NONE 敘述重複"
 
-#: fortran/decl.c:4583
+#: fortran/decl.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "缺少字元範圍在中隱含的於 %C"
 
-#: fortran/decl.c:4688
+#: fortran/decl.c:4700
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C 處 IMPLICIT 敘述中的字母必須按序排列"
 
-#: fortran/decl.c:4741
+#: fortran/decl.c:4753
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:4751
+#: fortran/decl.c:4763
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:4857
+#: fortran/decl.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:4864
+#: fortran/decl.c:4876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:4869
+#: fortran/decl.c:4881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:4883
+#: fortran/decl.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/decl.c:4912
+#: fortran/decl.c:4924
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "無法匯入『%s』從主機範圍單位於 %C - 不存在。"
 
-#: fortran/decl.c:4919
+#: fortran/decl.c:4931
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "『%s』已經匯入的從主機範圍單位於 %C。"
 
-#: fortran/decl.c:4960
+#: fortran/decl.c:4972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "語法時發生錯誤匯入敘述於 %C"
 
-#: fortran/decl.c:5300
+#: fortran/decl.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "缺少codimension 規格於 %C"
 
-#: fortran/decl.c:5302
+#: fortran/decl.c:5314
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C 處沒有指定維數"
 
-#: fortran/decl.c:5397
+#: fortran/decl.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重複的 %s 屬性，位於 %L"
 
-#: fortran/decl.c:5414
+#: fortran/decl.c:5426
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5433
+#: fortran/decl.c:5445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5435
+#: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5445
+#: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5447
+#: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5455
+#: fortran/decl.c:5467
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5462
+#: fortran/decl.c:5474
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5472
+#: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5474
+#: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5482
+#: fortran/decl.c:5494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "成分在中型態於 %C 必須前繼含有"
 
-#: fortran/decl.c:5489
+#: fortran/decl.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 
-#: fortran/decl.c:5498
+#: fortran/decl.c:5510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5500
+#: fortran/decl.c:5512
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a STRUCTURE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5518
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5528
+#: fortran/decl.c:5540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s 屬性於 %L 未被允許外側的規格部分的模組"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5551
+#: fortran/decl.c:5563
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003:非同步屬性於 %C"
 
-#: fortran/decl.c:5562
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008:CONTIGUOUS 屬性於 %C"
 
-#: fortran/decl.c:5617 fortran/decl.c:9090
+#: fortran/decl.c:5629 fortran/decl.c:9102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "保護的於 %C 只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:5623
+#: fortran/decl.c:5635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003:保護的屬性於 %C"
 
-#: fortran/decl.c:5657
+#: fortran/decl.c:5669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003:值屬性於 %C"
 
-#: fortran/decl.c:5664
+#: fortran/decl.c:5676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003:易變的屬性於 %C"
 
-#: fortran/decl.c:5671
+#: fortran/decl.c:5683
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5712
+#: fortran/decl.c:5724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "多重識別碼提供的與單一名稱=說明符於 %C"
 
-#: fortran/decl.c:5810
+#: fortran/decl.c:5822
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "隱含地宣告的繫結©函式『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/decl.c:5832
+#: fortran/decl.c:5844
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 可能無法是 C 可交流的 kind 雖然共同區塊『%s』是繫結©"
 
-#: fortran/decl.c:5841
+#: fortran/decl.c:5853
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "類型宣告『%s』於 %L 不是 C 可交流的但是它是繫結©"
 
-#: fortran/decl.c:5845
+#: fortran/decl.c:5857
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "變數『%s』於 %L 可能無法是 C 可交流的 kind 但是它是繫結©"
 
-#: fortran/decl.c:5857
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 無法宣告的與繫結©自從它並非全域"
 
-#: fortran/decl.c:5871
+#: fortran/decl.c:5883
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/decl.c:5879
+#: fortran/decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/decl.c:5891
+#: fortran/decl.c:5903
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法陣列"
 
-#: fortran/decl.c:5899
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法字元串"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5910
+#: fortran/decl.c:5922
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "符號『%s』於 %L 被標記私人的但是已被給定的繫結標貼『%s』"
 
-#: fortran/decl.c:5984
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "需要還是實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:6029
+#: fortran/decl.c:6041
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "缺少實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:6036
+#: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "缺少數字"
 
-#: fortran/decl.c:6065
+#: fortran/decl.c:6077
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/decl.c:6151
+#: fortran/decl.c:6163
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "衍生類型於 %C 未被在之前定義的和因而無法出現在中衍生類型定義"
 
-#: fortran/decl.c:6193
+#: fortran/decl.c:6205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:6202
+#: fortran/decl.c:6214
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:6274
+#: fortran/decl.c:6286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:6279
+#: fortran/decl.c:6291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
 msgstr "模組程序於 %C 必須是在中通用模組介面"
 
-#: fortran/decl.c:6330
+#: fortran/decl.c:6342
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:6342
+#: fortran/decl.c:6354
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必須不出現兩者於 %C"
 
-#: fortran/decl.c:6388
+#: fortran/decl.c:6400
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6395
+#: fortran/decl.c:6407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6402
+#: fortran/decl.c:6414
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6463
+#: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A type parameter list is required at %C"
 msgstr "左parenthesis 必要項之後『*』"
 
-#: fortran/decl.c:6477 fortran/primary.c:1859
+#: fortran/decl.c:6489 fortran/primary.c:1859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C 處需要替代的回傳標籤"
 
-#: fortran/decl.c:6483 fortran/decl.c:6491
+#: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "參數名稱省略"
 
-#: fortran/decl.c:6531
+#: fortran/decl.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "名稱「%s」(位於 %C)是一個程序的名稱"
 
-#: fortran/decl.c:6544
+#: fortran/decl.c:6556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C 處陣列宣告需要另外一維"
 
-#: fortran/decl.c:6547
+#: fortran/decl.c:6559
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C 處參數清單中有非預期的無用字元"
 
-#: fortran/decl.c:6565
+#: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "重製名稱『%s』在中關聯於 %C"
 
-#: fortran/decl.c:6568
+#: fortran/decl.c:6580
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符號「%s」在 %C 處的參數清單中重複出現"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6652
+#: fortran/decl.c:6664
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C 處 RESULT 變數不能與函式同名"
 
-#: fortran/decl.c:6729
+#: fortran/decl.c:6741
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:6739 fortran/decl.c:7876
+#: fortran/decl.c:6751 fortran/decl.c:7888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008:繫結©屬性於 %L 可能無法被指定的用於內部程序"
 
-#: fortran/decl.c:6943
+#: fortran/decl.c:6955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "繫結©屬性於 %C 需求介面與繫結©"
 
-#: fortran/decl.c:6950
+#: fortran/decl.c:6962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "繫結©程序與名稱可能無法有指標屬性於 %C"
 
-#: fortran/decl.c:6956
+#: fortran/decl.c:6968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "虛設程序於 %C 可能無法有繫結©屬性與名稱"
 
-#: fortran/decl.c:6979
+#: fortran/decl.c:6991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "程序『%s』於 %L 已經有基本型式的 %s"
 
-#: fortran/decl.c:7025 fortran/decl.c:7213 fortran/decl.c:11205
+#: fortran/decl.c:7037 fortran/decl.c:7225 fortran/decl.c:11217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "語法時發生錯誤程序敘述於 %C"
 
-#: fortran/decl.c:7074 fortran/decl.c:11105
+#: fortran/decl.c:7086 fortran/decl.c:11117
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "預期『::』之後 binding-attributes 於 %C"
 
-#: fortran/decl.c:7081
+#: fortran/decl.c:7093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/decl.c:7085
+#: fortran/decl.c:7097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003:程序指標成分於 %C"
 
-#: fortran/decl.c:7157
+#: fortran/decl.c:7169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "語法時發生錯誤程序指標成分於 %C"
 
-#: fortran/decl.c:7175
+#: fortran/decl.c:7187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "程序於 %C 必須是在中通用介面"
 
-#: fortran/decl.c:7184 fortran/decl.c:9845
+#: fortran/decl.c:7196 fortran/decl.c:9857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:7254
+#: fortran/decl.c:7266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003:程序敘述於 %C"
 
-#: fortran/decl.c:7326
+#: fortran/decl.c:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "預期的形式引數清單在中函式定義於 %C"
 
-#: fortran/decl.c:7356 fortran/decl.c:7634 fortran/decl.c:7843
+#: fortran/decl.c:7368 fortran/decl.c:7646 fortran/decl.c:7855
 #: fortran/symbol.c:1903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "繫結©屬性於 %L 只能使用用於變數或共同區塊"
 
-#: fortran/decl.c:7385 fortran/decl.c:7900
+#: fortran/decl.c:7397 fortran/decl.c:7912
 #, gcc-internal-format
 msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
 msgstr ""
 
-#: fortran/decl.c:7528
+#: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:7537
+#: fortran/decl.c:7549
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C 處的 ENTRY 敘述不能出現在 PROGRAM 中"
 
-#: fortran/decl.c:7540
+#: fortran/decl.c:7552
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:7543
+#: fortran/decl.c:7555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:7546
+#: fortran/decl.c:7558
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C 處的 ENTRY 敘述不能出現在 BLOCK DATA 中"
 
-#: fortran/decl.c:7550 fortran/decl.c:7595
+#: fortran/decl.c:7562 fortran/decl.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/decl.c:7554
+#: fortran/decl.c:7566
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:7558
+#: fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DERIVED TYPE 區塊中"
 
-#: fortran/decl.c:7562
+#: fortran/decl.c:7574
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 IF-THEN 區塊中"
 
-#: fortran/decl.c:7567
+#: fortran/decl.c:7579
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DO 中"
 
-#: fortran/decl.c:7571
+#: fortran/decl.c:7583
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:7575
+#: fortran/decl.c:7587
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 FORALL 區塊中"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7591
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 WHERE 區塊中"
 
-#: fortran/decl.c:7583
+#: fortran/decl.c:7595
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C 處的 ENTRY 敘述不能出現在巢狀的子程式中"
 
-#: fortran/decl.c:7587
+#: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:7608
+#: fortran/decl.c:7620
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/decl.c:7659 fortran/decl.c:7883
+#: fortran/decl.c:7671 fortran/decl.c:7895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "缺少必要項 parentheses 之前繫結©於 %C"
 
-#: fortran/decl.c:7753
+#: fortran/decl.c:7765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/decl.c:7909
+#: fortran/decl.c:7921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
 msgstr "交替回傳無法出現在中運算子介面於 %L"
 
-#: fortran/decl.c:7972 fortran/decl.c:7979
+#: fortran/decl.c:7984 fortran/decl.c:7991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無效的 C 名稱在中名稱=說明符於 %C"
 
-#: fortran/decl.c:8019
+#: fortran/decl.c:8031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "語法時發生錯誤名稱=說明符用於繫結標貼於 %C"
 
-#: fortran/decl.c:8035
+#: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/decl.c:8043
+#: fortran/decl.c:8055
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:8062
+#: fortran/decl.c:8074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "缺少關閉同位用於繫結標貼於 %C"
 
-#: fortran/decl.c:8068
+#: fortran/decl.c:8080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:8074
+#: fortran/decl.c:8086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "用於虛設程序 %s，沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "名稱不允許於繫結©用於摘要介面於 %C"
 
-#: fortran/decl.c:8349
+#: fortran/decl.c:8361
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Fortran 2008:結束敘述以代替 %s 敘述於 %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:8367
+#: fortran/decl.c:8379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 敘述在 %L 處"
 
-#: fortran/decl.c:8378
+#: fortran/decl.c:8390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 敘述，於 %C"
 
-#: fortran/decl.c:8398
+#: fortran/decl.c:8410
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要塊名「%s」在「%s」運算式中，於 %C"
 
-#: fortran/decl.c:8415
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/decl.c:8429 fortran/decl.c:8437
+#: fortran/decl.c:8441 fortran/decl.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "需要標籤「%s」，為 %s 敘述，於 %C"
 
-#: fortran/decl.c:8536
+#: fortran/decl.c:8548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中尺寸敘述"
 
-#: fortran/decl.c:8544
+#: fortran/decl.c:8556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "維度指定的用於 %s 於 %L 之後它的 initialisation"
 
-#: fortran/decl.c:8552
+#: fortran/decl.c:8564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中 CODIMENSION 敘述"
 
-#: fortran/decl.c:8561
+#: fortran/decl.c:8573
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L 處陣列指定必須延遲"
 
-#: fortran/decl.c:8576
+#: fortran/decl.c:8588
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DIMENSION attribute at %C"
 msgstr "重製指標屬性於 %C"
 
-#: fortran/decl.c:8668
+#: fortran/decl.c:8680
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C 處變數清單中有非預期的無用字元"
 
-#: fortran/decl.c:8705
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "在 %C 處需要「(」"
 
-#: fortran/decl.c:8719 fortran/decl.c:8759
+#: fortran/decl.c:8731 fortran/decl.c:8771
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在 %C 處需要變數名"
 
-#: fortran/decl.c:8735
+#: fortran/decl.c:8747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: fortran/decl.c:8739
+#: fortran/decl.c:8751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray 指標於 %C 有 %d 位元組的精確度；記憶體位址需求 %d 位元組"
 
-#: fortran/decl.c:8745
+#: fortran/decl.c:8757
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:8784
+#: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "無法轉換為指標類型"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8820
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在 %C 處需要「)」"
 
-#: fortran/decl.c:8820
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "在 %C 處需要「,」或敘述尾"
 
-#: fortran/decl.c:8846
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "含義未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:8878
+#: fortran/decl.c:8890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "可選的未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:8897
+#: fortran/decl.c:8909
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
 msgstr "Cray 指標宣告於 %C 需求 -fcray-pointer 旗標"
 
-#: fortran/decl.c:8936
+#: fortran/decl.c:8948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008:CONTIGUOUS 敘述於 %C"
 
-#: fortran/decl.c:9034
+#: fortran/decl.c:9046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "存取規格的 %s 運算子於 %C 已指定的"
 
-#: fortran/decl.c:9050
+#: fortran/decl.c:9062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "存取規格的.%s。運算子於 %C 已指定的"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003:保護的敘述於 %C"
 
-#: fortran/decl.c:9132
+#: fortran/decl.c:9144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/decl.c:9159 fortran/decl.c:9184
+#: fortran/decl.c:9171 fortran/decl.c:9196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "私人的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:9205 fortran/decl.c:9225
+#: fortran/decl.c:9217 fortran/decl.c:9237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "公用的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:9247
+#: fortran/decl.c:9259
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "預期的變數名稱於 %C 在中參數敘述"
 
-#: fortran/decl.c:9254
+#: fortran/decl.c:9266
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 敘述中需要 = 符號"
 
-#: fortran/decl.c:9260
+#: fortran/decl.c:9272
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 敘述中需要運算式"
 
-#: fortran/decl.c:9280
+#: fortran/decl.c:9292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "初始化已經初始化的變數於 %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:9305
+#: fortran/decl.c:9317
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:9321
+#: fortran/decl.c:9333
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C 處 PARAMETER 敘述中有非預期的字元"
 
-#: fortran/decl.c:9340 fortran/decl.c:9396
+#: fortran/decl.c:9352 fortran/decl.c:9408
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:9375
+#: fortran/decl.c:9387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/decl.c:9382
+#: fortran/decl.c:9394
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:9431
+#: fortran/decl.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/decl.c:9438
+#: fortran/decl.c:9450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:9457
+#: fortran/decl.c:9469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket 儲存敘述於 %C 追隨前一個儲存敘述"
 
-#: fortran/decl.c:9468
+#: fortran/decl.c:9480
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:9516
+#: fortran/decl.c:9528
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:9533
+#: fortran/decl.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "值未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:9537
+#: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003:值敘述於 %C"
 
-#: fortran/decl.c:9575
+#: fortran/decl.c:9587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "語法時發生錯誤值敘述於 %C"
 
-#: fortran/decl.c:9587
+#: fortran/decl.c:9599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003:易變的敘述於 %C"
 
-#: fortran/decl.c:9614
+#: fortran/decl.c:9626
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易變的用於 coarray 變數『%s』於 %C, 該項是 use-/ host-associated"
 
-#: fortran/decl.c:9639
+#: fortran/decl.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:9651
+#: fortran/decl.c:9663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003:非同步敘述於 %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "語法時發生錯誤非同步敘述於 %C"
 
-#: fortran/decl.c:9720
+#: fortran/decl.c:9732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:9820
+#: fortran/decl.c:9832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "模組程序於 %C 必須是在中通用模組介面"
 
-#: fortran/decl.c:9878
+#: fortran/decl.c:9890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsic 程序於 %L 無法模組程序"
 
-#: fortran/decl.c:9927
+#: fortran/decl.c:9939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "模稜兩可的符號在中類型定義於 %C"
 
-#: fortran/decl.c:9936
+#: fortran/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/decl.c:9942
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "『%s』在中延伸運算式於 %C 並非衍生類型"
 
-#: fortran/decl.c:9949
+#: fortran/decl.c:9961
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "『%s』無法進階於 %C 因為它是繫結©"
 
-#: fortran/decl.c:9956
+#: fortran/decl.c:9968
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "『%s』無法進階於 %C 因為它是序列型態"
 
-#: fortran/decl.c:9979
+#: fortran/decl.c:9991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "衍生類型於 %C 只能是私人的在中規格部分的模組"
 
-#: fortran/decl.c:9991
+#: fortran/decl.c:10003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "衍生類型於 %C 只能是公用的在中規格部分的模組"
 
-#: fortran/decl.c:10012
+#: fortran/decl.c:10024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "摘要型態『%s』使用的於 %L"
 
-#: fortran/decl.c:10058
+#: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "重複的建構標籤「%s」出現在 %C 處"
 
-#: fortran/decl.c:10064
+#: fortran/decl.c:10076
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:10111
+#: fortran/decl.c:10123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:10144
+#: fortran/decl.c:10156
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:10179
+#: fortran/decl.c:10191
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:10193
+#: fortran/decl.c:10205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:10211
+#: fortran/decl.c:10223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:10218
+#: fortran/decl.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:10381
+#: fortran/decl.c:10393
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定義中需要 ::"
 
-#: fortran/decl.c:10394
+#: fortran/decl.c:10406
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mangled derived type definition at %C"
 msgstr "Fortran 2003: 含有區塊在中衍生類型定義於 %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10435
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:10434
+#: fortran/decl.c:10446
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "衍生類型名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/decl.c:10437
+#: fortran/decl.c:10449
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type"
 msgstr "衍生類型名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/decl.c:10452
+#: fortran/decl.c:10464
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be a derived type at %C"
 msgstr "啞元「%s」(位於 %L)不能是 OPTIONAL"
 
-#: fortran/decl.c:10461
+#: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:10524
+#: fortran/decl.c:10536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray 點於 %C 無法假設的形狀陣列"
 
-#: fortran/decl.c:10627
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003:ENUM 和列舉值於 %C"
 
-#: fortran/decl.c:10659
+#: fortran/decl.c:10671
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C 處：列舉量超過 C 整數類型"
 
-#: fortran/decl.c:10738
+#: fortran/decl.c:10750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "列舉值 %L 無法初始化的與整數運算式"
 
-#: fortran/decl.c:10786
+#: fortran/decl.c:10798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM 定義敘述預期的之前 %C"
 
-#: fortran/decl.c:10822
+#: fortran/decl.c:10834
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C 處 ENUMERATOR 定義中語法錯誤"
 
-#: fortran/decl.c:10869 fortran/decl.c:10884
+#: fortran/decl.c:10881 fortran/decl.c:10896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重製 access-specifier 於 %C"
 
-#: fortran/decl.c:10904
+#: fortran/decl.c:10916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的 NOPASS 於 %C"
 
-#: fortran/decl.c:10924
+#: fortran/decl.c:10936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的回合於 %C"
 
-#: fortran/decl.c:10951
+#: fortran/decl.c:10963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "重製指標屬性於 %C"
 
-#: fortran/decl.c:10969
+#: fortran/decl.c:10981
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "重製 NON_OVERRIDABLE 於 %C"
 
-#: fortran/decl.c:10985
+#: fortran/decl.c:10997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "重製已推遲於 %C"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "預期 access-specifier 於 %C"
 
-#: fortran/decl.c:11000
+#: fortran/decl.c:11012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "預期的繫結屬性於 %C"
 
-#: fortran/decl.c:11008
+#: fortran/decl.c:11020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
 msgstr "NON_OVERRIDABLE 和已推遲無法兩者出現於 %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "指標屬性被必要項用於程序指標成分於 %C"
 
-#: fortran/decl.c:11063
+#: fortran/decl.c:11075
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:11069
+#: fortran/decl.c:11081
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "『)』預期的於 %C"
 
-#: fortran/decl.c:11089
+#: fortran/decl.c:11101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "介面必須被指定的用於已推遲繫結於 %C"
 
-#: fortran/decl.c:11094
+#: fortran/decl.c:11106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "程序 (介面) 於 %C 應該被宣告已推遲"
 
-#: fortran/decl.c:11117
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "預期的繫結名稱於 %C"
 
-#: fortran/decl.c:11121
+#: fortran/decl.c:11133
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:11133
+#: fortran/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "『=>目標』無效用於已推遲繫結於 %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11151
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "『::』所需的在中程序繫結與明確的目標於 %C"
 
-#: fortran/decl.c:11149
+#: fortran/decl.c:11161
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "預期的繫結目標之後『=>』於 %C"
 
-#: fortran/decl.c:11166
+#: fortran/decl.c:11178
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "型態『%s』包含已推遲繫結於 %C 不是摘要"
 
-#: fortran/decl.c:11177
+#: fortran/decl.c:11189
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "已經有程序與繫結名稱『%s』用於衍生類型『%s』於 %C"
 
-#: fortran/decl.c:11228
+#: fortran/decl.c:11240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "通用於 %C 必須是內部衍生類型含有"
 
-#: fortran/decl.c:11248
+#: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "預期『::』於 %C"
 
-#: fortran/decl.c:11260
+#: fortran/decl.c:11272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "預期的通用名稱或運算子描述元於 %C"
 
-#: fortran/decl.c:11281
+#: fortran/decl.c:11293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:11292
+#: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "預期『=>』於 %C"
 
-#: fortran/decl.c:11328
+#: fortran/decl.c:11340
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "那裡『s 已經 non-generic 程序與繫結名稱 』%s『 用於衍生類型 』%s' 於 %C"
 
-#: fortran/decl.c:11336
+#: fortran/decl.c:11348
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "繫結於 %C 必須有相同存取做為已經定義的繫結『%s』"
 
-#: fortran/decl.c:11384
+#: fortran/decl.c:11396
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "預期的特定的繫結名稱於 %C"
 
-#: fortran/decl.c:11394
+#: fortran/decl.c:11406
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "『%s』已經定義為特定的繫結用於通用『%s』於 %C"
 
-#: fortran/decl.c:11412
+#: fortran/decl.c:11424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "垃圾之後通用繫結於 %C"
 
-#: fortran/decl.c:11447
+#: fortran/decl.c:11459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "最後的宣告於 %C 必須是內部衍生類型含有區段"
 
-#: fortran/decl.c:11458
+#: fortran/decl.c:11470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "衍生類型宣告與最後的於 %C 必須是在中規格部分的模組"
 
-#: fortran/decl.c:11480
+#: fortran/decl.c:11492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "清空最後的於 %C"
 
-#: fortran/decl.c:11487
+#: fortran/decl.c:11499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "預期的模組程序名稱於 %C"
 
-#: fortran/decl.c:11497
+#: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:11503
+#: fortran/decl.c:11515
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明程序名稱「%s」於 %C"
 
-#: fortran/decl.c:11516
+#: fortran/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "『%s』於 %C 已經定義為最後的程序！"
 
-#: fortran/decl.c:11586
+#: fortran/decl.c:11598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "不明屬性在中！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:11632
+#: fortran/decl.c:11644
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "語法時發生錯誤！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:11652
+#: fortran/decl.c:11664
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11666
+#: fortran/decl.c:11678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "%C 處 FORALL 迭代語法錯誤"
 
-#: fortran/decl.c:11730
+#: fortran/decl.c:11742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ IVDEP directive at %C"
 msgstr "%C 處 FORALL 迭代語法錯誤"
 
-#: fortran/decl.c:11747
+#: fortran/decl.c:11759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ VECTOR directive at %C"
 msgstr "%C 處 FORALL 迭代語法錯誤"
 
-#: fortran/decl.c:11764
+#: fortran/decl.c:11776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
@@ -62344,12 +62413,12 @@ msgstr "索引在中尺寸 %d 是超出邊界於 %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/expr.c:1787 fortran/primary.c:2379
+#: fortran/expr.c:1787 fortran/primary.c:2264 fortran/primary.c:2400
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN part_ref at %C"
 msgstr "Fortran 2003:值屬性於 %C"
 
-#: fortran/expr.c:1805 fortran/primary.c:2394
+#: fortran/expr.c:1805 fortran/primary.c:2259 fortran/primary.c:2415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid KIND parameter of %s at %L"
 msgid "KIND part_ref at %C"
@@ -62425,7 +62494,7 @@ msgstr "transformational intrinsic『%s』於 %L 未被允許在中初始化運
 msgid "Evaluation of nonstandard initialization expression at %L"
 msgstr "延伸：求值的 nonstandard 初始化運算式於 %L"
 
-#: fortran/expr.c:2909 fortran/resolve.c:2718
+#: fortran/expr.c:2909 fortran/resolve.c:2720
 #, fuzzy, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
 msgstr "函式『%s』在中初始化運算式於 %L 必須是內建函式"
@@ -62701,7 +62770,7 @@ msgstr "介面不匹配在中程序指標指派於 %L:%s"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2599
+#: fortran/expr.c:4116 fortran/expr.c:4131 fortran/resolve.c:2601
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "NOPASS 或明確的介面必要項於 %C"
@@ -62759,167 +62828,167 @@ msgstr "Fortran 2008:分級重新映射目標不是分級 1 於 %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:4263 fortran/expr.c:4342
+#: fortran/expr.c:4260 fortran/expr.c:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "資料目標於 %L 不應該有 coindex"
 
-#: fortran/expr.c:4266
+#: fortran/expr.c:4263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.c:4287
+#: fortran/expr.c:4284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.c:4297
+#: fortran/expr.c:4294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "指標指派目標是 neither 目標 nor 指標於 %L"
 
-#: fortran/expr.c:4312
+#: fortran/expr.c:4309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "不當的目標在中指標指派在中 PURE 程序於 %L"
 
-#: fortran/expr.c:4321
+#: fortran/expr.c:4318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "指標指派與向量註標於 rhs 於 %L"
 
-#: fortran/expr.c:4329
+#: fortran/expr.c:4326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "指標指派目標有保護的屬性於 %L"
 
-#: fortran/expr.c:4353
+#: fortran/expr.c:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:4392
+#: fortran/expr.c:4391
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.c:4468 fortran/resolve.c:1459
+#: fortran/expr.c:4467 fortran/resolve.c:1459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "指標初始化目標於 %L 必須不是 ALLOCATABLE "
 
-#: fortran/expr.c:4474
+#: fortran/expr.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.c:4489 fortran/resolve.c:1465
+#: fortran/expr.c:4488 fortran/resolve.c:1465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "指標初始化目標於 %L 必須有儲存屬性"
 
-#: fortran/expr.c:4501
+#: fortran/expr.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "程序指標初始化目標於 %L 可能無法是程序指標"
 
-#: fortran/expr.c:4507
+#: fortran/expr.c:4506
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:4514
+#: fortran/expr.c:4513
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:4982
+#: fortran/expr.c:4981
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.c:6067
+#: fortran/expr.c:6066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008:指標函式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6075
+#: fortran/expr.c:6074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 運算式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6083
+#: fortran/expr.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6092
+#: fortran/expr.c:6091
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "『%s』在中變數定義語境 (%s) 於 %L 並非變數"
 
-#: fortran/expr.c:6103
+#: fortran/expr.c:6102
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:6112
+#: fortran/expr.c:6111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6125
+#: fortran/expr.c:6124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6138
+#: fortran/expr.c:6137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6173
+#: fortran/expr.c:6172
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:6183
+#: fortran/expr.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6196
+#: fortran/expr.c:6195
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:6204
+#: fortran/expr.c:6203
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:6216
+#: fortran/expr.c:6215
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "變數『%s』無法出現在中變數定義語境 (%s) 於 %L 在中 PURE 程序"
 
-#: fortran/expr.c:6275
+#: fortran/expr.c:6274
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到 vector-indexed 目標無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:6280
+#: fortran/expr.c:6279
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:6292
+#: fortran/expr.c:6291
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associate-name『%s』無法出現在中變數定義語境 (%s) 於 %L 因為它的目標於 %L 無法，還是"
 
-#: fortran/expr.c:6334
+#: fortran/expr.c:6333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
@@ -62946,7 +63015,7 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.c:870 fortran/trans-array.c:1276
-#: fortran/trans-array.c:6606 fortran/trans-array.c:8153
+#: fortran/trans-array.c:6606 fortran/trans-array.c:8155
 #: fortran/trans-intrinsic.c:8338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
@@ -63142,12 +63211,12 @@ msgstr "第一個引數的定義的指派於 %L 必須是含義 (出) 或含義
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:987 fortran/resolve.c:17067
+#: fortran/interface.c:987 fortran/resolve.c:17081
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:994 fortran/resolve.c:17085
+#: fortran/interface.c:994 fortran/resolve.c:17099
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -63220,591 +63289,591 @@ msgstr "有歧義的介面「%s」和「%s」在 %s 中，位於 %L"
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
 msgstr "雖然無法引用，『%s』有模稜兩可的介面於 %L"
 
-#: fortran/interface.c:2003
+#: fortran/interface.c:2006
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
 msgstr "『%s』於 %L 並非模組程序"
 
-#: fortran/interface.c:2208
+#: fortran/interface.c:2211
 #, fuzzy, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.c:2211
+#: fortran/interface.c:2214
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (純量和 rank-%d)"
 
-#: fortran/interface.c:2214
+#: fortran/interface.c:2217
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和純量)"
 
-#: fortran/interface.c:2217
+#: fortran/interface.c:2220
 #, fuzzy, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和 rank-%d)"
 
-#: fortran/interface.c:2225
+#: fortran/interface.c:2228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (純量和 rank-%d)"
 
-#: fortran/interface.c:2229
+#: fortran/interface.c:2232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和純量)"
 
-#: fortran/interface.c:2233
+#: fortran/interface.c:2236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
 msgstr "分級不匹配在中引數『%s』於 %L (rank-%d 和 rank-%d)"
 
-#: fortran/interface.c:2338
+#: fortran/interface.c:2341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure argument at %L"
 msgstr "無效的程序引數於 %L"
 
-#: fortran/interface.c:2346 fortran/interface.c:2373
+#: fortran/interface.c:2349 fortran/interface.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/interface.c:2384
+#: fortran/interface.c:2387
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
 msgstr "實際引數到 contiguous 指標虛設『%s』於 %L 必須是僅需 contigous"
 
-#: fortran/interface.c:2407
+#: fortran/interface.c:2410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
 msgstr "含義 (%s) 實際引數於 %L 也許 interfere 與實際引數於 %L。"
 
-#: fortran/interface.c:2417
+#: fortran/interface.c:2420
 #, fuzzy, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
 msgstr "型態不匹配在中引數『%s』於 %L; 傳遞 %s 到 %s"
 
-#: fortran/interface.c:2427
+#: fortran/interface.c:2430
 #, fuzzy, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/interface.c:2443
+#: fortran/interface.c:2446
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/interface.c:2453
+#: fortran/interface.c:2456
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
 msgstr "實際引數到『%s』於 %L 必須有相同宣告的型態"
 
-#: fortran/interface.c:2468
+#: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
 msgstr ""
 
-#: fortran/interface.c:2479
+#: fortran/interface.c:2482
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/interface.c:2498
+#: fortran/interface.c:2501
 #, fuzzy, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
 msgstr "Corank 不匹配在中引數『%s』於 %L (%d 和 %d)"
 
-#: fortran/interface.c:2516
+#: fortran/interface.c:2519
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
 msgstr "實際引數到『%s』於 %L 必須是僅需 contiguous"
 
-#: fortran/interface.c:2531
+#: fortran/interface.c:2534
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2546
+#: fortran/interface.c:2549
 #, fuzzy, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
 msgstr "實際引數到 non-INTENT (INOUT) 虛設『%s』於 %L, 該項是 LOCK_TYPE 或有 LOCK_TYPE 成分"
 
-#: fortran/interface.c:2565
+#: fortran/interface.c:2568
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
 msgstr "虛引數『%s』必須是指標或 assumed-shape 陣列而無需 CONTIGUOUS 屬性 - 做為實際引數於 %L 不是僅需 contiguous 和兩者是非同步或易變的"
 
-#: fortran/interface.c:2578
+#: fortran/interface.c:2581
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
 msgstr "傳遞 coarray 於 %L 到 allocatable、noncoarray，含義 (出) 虛引數『%s』"
 
-#: fortran/interface.c:2585
+#: fortran/interface.c:2588
 #, fuzzy, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
 msgstr "傳遞 coarray 於 %L 到 allocatable，noncoarray 虛引數『%s』，該項無效如果配額狀態被已修改"
 
-#: fortran/interface.c:2659
+#: fortran/interface.c:2662
 #, fuzzy, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
 msgstr "Polymorphic 純量傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2670
+#: fortran/interface.c:2673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2675
+#: fortran/interface.c:2678
 #, fuzzy, gcc-internal-format
 msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
 msgstr "元件的 assumed-shaped 或指標陣列傳遞到陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2688
+#: fortran/interface.c:2691
 #, fuzzy, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "延伸：純量 non-default-kind，non-C_CHAR-kind 字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:2696
+#: fortran/interface.c:2699
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
 msgstr "Fortran 2003:純量字元實際引數與陣列虛引數『%s』於 %L"
 
-#: fortran/interface.c:3047
+#: fortran/interface.c:3050
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:3070
+#: fortran/interface.c:3073
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:3074
+#: fortran/interface.c:3077
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
 msgstr "關鍵字引數『%s』於 %L 不是在中程序"
 
-#: fortran/interface.c:3083
+#: fortran/interface.c:3086
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
 msgstr "關鍵字引數『%s』於 %L 已經關聯的與另外的實際引數"
 
-#: fortran/interface.c:3093
+#: fortran/interface.c:3096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "More actual than formal arguments in procedure call at %L"
 msgstr "更多實際的比形式引數在中程序呼叫於 %L"
 
-#: fortran/interface.c:3107
+#: fortran/interface.c:3110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:3119
+#: fortran/interface.c:3122
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
 msgstr "未預期的交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:3148
+#: fortran/interface.c:3151
 #, fuzzy, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/interface.c:3151
+#: fortran/interface.c:3154
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
 msgstr "Fortran 2008:空指標於 %L 到 non-pointer 虛設『%s』"
 
-#: fortran/interface.c:3175
+#: fortran/interface.c:3178
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
 msgstr ""
 
-#: fortran/interface.c:3197
+#: fortran/interface.c:3200
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和指標或 allocatable 虛引數『%s』於 %L"
 
-#: fortran/interface.c:3204
+#: fortran/interface.c:3207
 #, fuzzy, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
 msgstr "字元長度不匹配 (%ld/%ld) 介於實際引數和 assumed-shape 虛引數『%s』於 %L"
 
-#: fortran/interface.c:3218
+#: fortran/interface.c:3221
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
 msgstr "實際引數於 %L 到 allocatable 或指標虛引數『%s』必須有已推遲長度型態參數如果和只有如果虛設有一個"
 
-#: fortran/interface.c:3235
+#: fortran/interface.c:3238
 #, fuzzy, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
 msgstr "字元長度的實際引數短於的虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.c:3243 fortran/interface.c:3248
+#: fortran/interface.c:3246 fortran/interface.c:3251
 #, fuzzy, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
 msgstr "實際引數含有太少元件用於虛引數『%s』(%lu/%lu) 於 %L"
 
-#: fortran/interface.c:3268
+#: fortran/interface.c:3271
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
 msgstr "預期的程序指標用於引數『%s』於 %L"
 
-#: fortran/interface.c:3284
+#: fortran/interface.c:3287
 #, fuzzy, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
 msgstr "預期的程序用於引數『%s』於 %L"
 
-#: fortran/interface.c:3298
+#: fortran/interface.c:3301
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
 msgstr "實際引數用於『%s』無法 assumed-size 陣列於 %L"
 
-#: fortran/interface.c:3307
+#: fortran/interface.c:3310
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Actual argument for %qs must be a pointer at %L"
 msgstr "「%s」的引數在 %L 處必須是一個指標"
 
-#: fortran/interface.c:3317
+#: fortran/interface.c:3320
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
 msgstr "Fortran 2008:Non-pointer 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.c:3327
+#: fortran/interface.c:3330
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
 msgstr "Coindexed 實際引數於 %L 到指標虛設『%s』"
 
-#: fortran/interface.c:3340
+#: fortran/interface.c:3343
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 到 allocatable 虛設『%s』需求含義 (在中)"
 
-#: fortran/interface.c:3354
+#: fortran/interface.c:3357
 #, fuzzy, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
 msgstr "Coindexed 非同步或易變的實際引數於 %L 需求該虛設『%s』有 neither 非同步 nor 易變的"
 
-#: fortran/interface.c:3368
+#: fortran/interface.c:3371
 #, fuzzy, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
 msgstr "Coindexed 實際引數於 %L 與 allocatable ultimate 成分到虛設『%s』需求還是值或含義 (在中)"
 
-#: fortran/interface.c:3380
+#: fortran/interface.c:3383
 #, fuzzy, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
 msgstr "實際的類別陣列引數用於『%s』必須是全部陣列於 %L"
 
-#: fortran/interface.c:3390
+#: fortran/interface.c:3393
 #, fuzzy, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
 msgstr "實際引數用於『%s』必須是 ALLOCATABLE 於 %L"
 
-#: fortran/interface.c:3420
+#: fortran/interface.c:3423
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
 msgstr "Array-section 實際引數與向量註標於 %L 是不相容的與含義 (出)，含義 (INOUT)，易變的或非同步屬性的虛引數『%s』"
 
-#: fortran/interface.c:3439
+#: fortran/interface.c:3442
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Assumed-shape 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3456
+#: fortran/interface.c:3459
 #, fuzzy, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
 msgstr "Array-section 實際引數於 %L 是不相容的與 non-assumed-shape 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3476
+#: fortran/interface.c:3479
 #, fuzzy, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
 msgstr "Pointer-array 實際引數於 %L 需求 assumed-shape 或 pointer-array 虛引數『%s』由於易變的屬性"
 
-#: fortran/interface.c:3499
+#: fortran/interface.c:3502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return spec in subroutine call at %L"
 msgstr "缺少交替回傳 spec 在中副常式呼叫於 %L"
 
-#: fortran/interface.c:3507
+#: fortran/interface.c:3510
 #, fuzzy, gcc-internal-format
 #| msgid "Missing actual argument for argument '%s' at %L"
 msgid "Missing actual argument for argument %qs at %L"
 msgstr "參數「%s」在 %L 處缺少引數"
 
-#: fortran/interface.c:3633
+#: fortran/interface.c:3636
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
 msgstr ""
 
-#: fortran/interface.c:3662
+#: fortran/interface.c:3665
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3688
+#: fortran/interface.c:3691
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
 msgstr ""
 
-#: fortran/interface.c:3698
+#: fortran/interface.c:3701
 #, fuzzy, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
 msgstr "相同實際引數關聯的與含義 (%s) 引數『%s』和含義 (%s) 引數『%s』於 %L"
 
-#: fortran/interface.c:3728
+#: fortran/interface.c:3731
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
 msgstr ""
 
-#: fortran/interface.c:3748
+#: fortran/interface.c:3751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
 msgstr "程序引數於 %L 是本地到 PURE 程序和有指標屬性"
 
-#: fortran/interface.c:3760
+#: fortran/interface.c:3763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到含義 (%s) 引數"
 
-#: fortran/interface.c:3770
+#: fortran/interface.c:3773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
 msgstr "Coindexed 實際引數於 %L 在中 PURE 程序被傳遞到指標虛引數"
 
-#: fortran/interface.c:3781
+#: fortran/interface.c:3784
 #, fuzzy, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
 msgstr "Coindexed polymorphic 實際引數於 %L 被傳遞 polymorphic 虛引數『%s』"
 
-#: fortran/interface.c:3853
+#: fortran/interface.c:3826
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.c:3857 fortran/interface.c:3867
+#: fortran/interface.c:3830 fortran/interface.c:3840
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
 msgstr "程序『%s』called 於 %L 不是明確的宣告"
 
-#: fortran/interface.c:3863
+#: fortran/interface.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "Procedure %qs called with an implicit interface at %L"
 msgstr "呼叫程序「%s」帶隱含介面，位於 %L"
 
-#: fortran/interface.c:3876
+#: fortran/interface.c:3849
 #, fuzzy, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "指標物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.c:3884
+#: fortran/interface.c:3857
 #, fuzzy, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
 msgstr "allocatable 物件『%s』於 %L 必須有明確的函式介面或被宣告做為陣列"
 
-#: fortran/interface.c:3892
+#: fortran/interface.c:3865
 #, fuzzy, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
 msgstr "Allocatable 函式『%s』於 %L 必須有明確的函式介面"
 
-#: fortran/interface.c:3909
+#: fortran/interface.c:3882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Explicit interface required for polymorphic argument at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.c:3918
+#: fortran/interface.c:3891
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.c:3927
+#: fortran/interface.c:3900
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/interface.c:3942
+#: fortran/interface.c:3915
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.c:3957
+#: fortran/interface.c:3930
 #, fuzzy, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
 msgstr "實際引數的 LOCK_TYPE 或與 LOCK_TYPE 成分於 %L 需求明確的介面用於程序『%s』"
 
-#: fortran/interface.c:3967
+#: fortran/interface.c:3940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD argument to NULL required at %L"
 msgstr "鑄型引數到空值必要項於 %L"
 
-#: fortran/interface.c:3977
+#: fortran/interface.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
 msgstr "關鍵字引數需求明確的介面用於程序『%s』於 %L"
 
-#: fortran/interface.c:4023
+#: fortran/interface.c:3992
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
 msgstr "程序指標成分『%s』called 與隱含的介面於 %L"
 
-#: fortran/interface.c:4034
+#: fortran/interface.c:4003
 #, fuzzy, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/interface.c:4119
+#: fortran/interface.c:4088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
 msgstr "鑄型=必要項在中空值() 引數於 %L:模稜兩可介於特定的函式 %s 和 %s"
 
-#: fortran/interface.c:4189
+#: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
 msgid "Unable to find symbol %qs"
 msgstr "%q+D 別名到未定義的符號 %qE"
 
-#: fortran/interface.c:4562
+#: fortran/interface.c:4531
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
 msgstr "實體『%s』於 %C 已經呈現在中介面"
 
-#: fortran/interface.c:4679
+#: fortran/interface.c:4648
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
 msgstr ""
 
-#: fortran/interface.c:4773
+#: fortran/interface.c:4742
 #, fuzzy, gcc-internal-format
 msgid "Cannot overwrite GENERIC %qs at %L"
 msgstr "無法覆寫通用『%s』於 %L"
 
-#: fortran/interface.c:4785
+#: fortran/interface.c:4754
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
 msgstr "『%s』於 %L 強制變更程序繫結宣告 NON_OVERRIDABLE"
 
-#: fortran/interface.c:4793
+#: fortran/interface.c:4762
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
 msgstr "『%s』於 %L 必須不是已推遲做為它強制變更 non-DEFERRED 繫結"
 
-#: fortran/interface.c:4801
+#: fortran/interface.c:4770
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
 msgstr "『%s』於 %L 強制變更 PURE 程序且須也是 PURE"
 
-#: fortran/interface.c:4810
+#: fortran/interface.c:4779
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
 msgstr "『%s』於 %L 強制變更 ELEMENTAL 程序且須也是 ELEMENTAL"
 
-#: fortran/interface.c:4816
+#: fortran/interface.c:4785
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
 msgstr "『%s』於 %L 強制變更 non-ELEMENTAL 程序且須無法是 ELEMENTAL，還是"
 
-#: fortran/interface.c:4825
+#: fortran/interface.c:4794
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
 msgstr "『%s』於 %L 強制變更副常式且須也是副常式"
 
-#: fortran/interface.c:4836
+#: fortran/interface.c:4805
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
 msgstr "『%s』於 %L 強制變更函式且須也是函式"
 
-#: fortran/interface.c:4844
+#: fortran/interface.c:4813
 #, fuzzy, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.c:4855
+#: fortran/interface.c:4824
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
 msgstr "『%s』於 %L 強制變更公用的程序且須無法是私人的"
 
-#: fortran/interface.c:4885
+#: fortran/interface.c:4854
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
 msgstr "虛引數『%s』的『%s』於 %L 應該被具名的『%s』做為到匹配相應引數的 overridden 程序"
 
-#: fortran/interface.c:4896
+#: fortran/interface.c:4865
 #, fuzzy, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
 msgstr "引數不匹配用於強迫程序『%s』於 %L:%s"
 
-#: fortran/interface.c:4905
+#: fortran/interface.c:4874
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
 msgstr "『%s』於 %L 必須有相同形式引數數量做為 overridden 程序"
 
-#: fortran/interface.c:4914
+#: fortran/interface.c:4883
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
 msgstr "『%s』於 %L 強制變更 NOPASS 繫結且須也是 NOPASS"
 
-#: fortran/interface.c:4925
+#: fortran/interface.c:4894
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
 msgstr "『%s』於 %L 強制變更繫結與回合且須也是回合"
 
-#: fortran/interface.c:4932
+#: fortran/interface.c:4901
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是於相同位置做為 passed-object 虛引數的 overridden 程序"
 
-#: fortran/interface.c:4953
+#: fortran/interface.c:4922
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "DTIO dummy argument at %L must be of type %s"
 msgstr "%s 標記在 %L 處必須具有類型 %s"
 
-#: fortran/interface.c:4960
+#: fortran/interface.c:4929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be of INTEGER type"
 msgid "DTIO dummy argument at %L must be of KIND = %d"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/interface.c:4967
+#: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/interface.c:4971
+#: fortran/interface.c:4940
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
 msgstr ""
 
-#: fortran/interface.c:4975
+#: fortran/interface.c:4944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
 msgstr "Character-valued %s『%s』於 %L 必須不被假設長度"
 
-#: fortran/interface.c:4979
+#: fortran/interface.c:4948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "DTIO dummy argument at %L must have INTENT %s"
 msgstr "「%s」啞元引數在 %L 處不能是 INTENT(OUT)"
 
-#: fortran/interface.c:5037 fortran/interface.c:5083
+#: fortran/interface.c:5006 fortran/interface.c:5052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
 msgstr "DATA 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/interface.c:5049
+#: fortran/interface.c:5018
 #, fuzzy, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
 msgstr "ELEMENTAL 程序『%s』於 %L 必須有明確的介面"
 
-#: fortran/interface.c:5061
+#: fortran/interface.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
 msgstr "對「%s」的呼叫給出的參數太多，於 %L 處"
 
-#: fortran/interface.c:5068
+#: fortran/interface.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments in call to '%s' at %L"
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
@@ -63917,74 +63986,74 @@ msgstr "交替回傳無法允許的於 %L"
 msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
 msgstr "型態不匹配在中引數『%s』於 %L; 傳遞 %s 到 %s"
 
-#: fortran/intrinsic.c:4553
+#: fortran/intrinsic.c:4565
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4647
+#: fortran/intrinsic.c:4659
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
 msgstr ""
 
-#: fortran/intrinsic.c:4687
+#: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
 msgid "init_arglist(): too many arguments"
 msgstr "太多引數"
 
-#: fortran/intrinsic.c:4839
+#: fortran/intrinsic.c:4851
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
 msgstr ""
 
-#: fortran/intrinsic.c:4848
+#: fortran/intrinsic.c:4860
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
 msgstr "Intrinsic『%s』(是 %s) 被使用於 %L"
 
-#: fortran/intrinsic.c:4920
+#: fortran/intrinsic.c:4932
 #, fuzzy, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
 msgstr "Fortran 2003:函式『%s』做為初始化運算式於 %L"
 
-#: fortran/intrinsic.c:4938
+#: fortran/intrinsic.c:4950
 #, fuzzy, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
 msgstr "transformational intrinsic『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/intrinsic.c:5014
+#: fortran/intrinsic.c:5026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
 msgstr "Fortran 2003:Elemental 函式做為初始化運算式與 non-integer/non-character 引數於 %L"
 
-#: fortran/intrinsic.c:5095
+#: fortran/intrinsic.c:5107
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中做共時區塊於 %L 不是 PURE"
 
-#: fortran/intrinsic.c:5102
+#: fortran/intrinsic.c:5114
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
 msgstr "副常式呼叫到 intrinsic『%s』於 %L 不是 PURE"
 
-#: fortran/intrinsic.c:5204
+#: fortran/intrinsic.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Conversion from %s to %s at %L"
 msgstr "擴充：從 %s 到 %s，位於 %L"
 
-#: fortran/intrinsic.c:5225
+#: fortran/intrinsic.c:5237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "Nonstandard conversion from %s to %s at %L"
 msgstr "從 %s 轉換到 %s，位於 %L"
 
-#: fortran/intrinsic.c:5240 fortran/intrinsic.c:5257
+#: fortran/intrinsic.c:5252 fortran/intrinsic.c:5269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Possible change of value in conversion from %s to %s at %L"
 msgstr "可能的變更的值在中轉換從 %s 到 %s 於 %L"
 
 #. If HOLLERITH is involved, all bets are off.
-#: fortran/intrinsic.c:5245 fortran/intrinsic.c:5265
+#: fortran/intrinsic.c:5257 fortran/intrinsic.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to %s at %L"
 msgstr "從 %s 轉換到 %s，位於 %L"
@@ -63992,24 +64061,24 @@ msgstr "從 %s 轉換到 %s，位於 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permited for nonconstant
 #. strings.
-#: fortran/intrinsic.c:5331 fortran/resolve.c:10829
+#: fortran/intrinsic.c:5343 fortran/resolve.c:10831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
 msgstr "不能將 %s 轉換為 %s，於 %L"
 
-#: fortran/intrinsic.c:5336
+#: fortran/intrinsic.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %qs to %qs at %L"
 msgstr "不能將 %s 轉換為 %s，於 %L"
 
-#: fortran/intrinsic.c:5427
+#: fortran/intrinsic.c:5439
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
 msgstr "『%s』宣告的於 %L 也許會陰影 intrinsic 的同名。 以便呼叫 intrinsic，明確的 INTRINSIC 宣告也許會被必要項。"
 
-#: fortran/intrinsic.c:5433
+#: fortran/intrinsic.c:5445
 #, fuzzy, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
 msgstr "『%s』宣告的於 %L 也是名稱的 intrinsic。 它只能被 called 透過明確的介面或如果宣告的外部。"
@@ -64360,12 +64429,12 @@ msgstr "鑄型標籤於 %L 衝突與 typespec 於 %L"
 msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:非同步=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2247 fortran/io.c:3919
+#: fortran/io.c:2247 fortran/io.c:3921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:空白=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2275 fortran/io.c:3897
+#: fortran/io.c:2275 fortran/io.c:3899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:十進位=於 %C 不允許在中 Fortran 95"
@@ -64375,7 +64444,7 @@ msgstr "Fortran 2003:十進位=於 %C 不允許在中 Fortran 95"
 msgid "ENCODING= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:編碼=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2358 fortran/io.c:3964
+#: fortran/io.c:2358 fortran/io.c:3966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:四捨五入=於 %C 不允許在中 Fortran 95"
@@ -64420,7 +64489,7 @@ msgstr "關閉敘述於 %L 需要單元號碼"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "單元號碼在中關閉敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:2848 fortran/match.c:3096
+#: fortran/io.c:2848 fortran/match.c:3099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s 敘述不允許在中 PURE 程序於 %C"
@@ -64518,7 +64587,7 @@ msgstr "名稱表列『%s』在中讀取敘述於 %L 含有符號『%s』該項
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/io.c:3424 fortran/resolve.c:14962
+#: fortran/io.c:3424 fortran/resolve.c:14975
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -64587,7 +64656,7 @@ msgid "Expected expression in %s statement at %C"
 msgstr "需要 %s 敘述，於 %C 處"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3729 fortran/io.c:4413 fortran/gfortran.h:2992
+#: fortran/io.c:3729 fortran/io.c:4415 fortran/gfortran.h:3010
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 敘述在 %C 處語法錯誤"
@@ -64603,85 +64672,85 @@ msgstr "Fortran 2003:內部檔案於 %L 與名稱表列"
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
 msgstr "DATA 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/io.c:3942
+#: fortran/io.c:3944
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:填充=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:4011
+#: fortran/io.c:4013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %L not allowed in Fortran 95"
 msgstr "Fortran 2003:DELIM=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:4185
+#: fortran/io.c:4187
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C 處的 PRINT 名稱清單是一個擴充"
 
-#: fortran/io.c:4207
+#: fortran/io.c:4209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "Comma after * at %C not allowed without I/O list"
 msgstr "%C 處的 END 標記不允許出現在輸出敘述中"
 
-#: fortran/io.c:4380
+#: fortran/io.c:4382
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C 處 I/O 清單中需要逗號"
 
-#: fortran/io.c:4447
+#: fortran/io.c:4449
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "%C 處的 PRINT 敘述不允許出現在 PURE 程序中"
 
-#: fortran/io.c:4609
+#: fortran/io.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgid "NULL() near %L cannot appear in INQUIRE statement"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/io.c:4621 fortran/io.c:4683
+#: fortran/io.c:4623 fortran/io.c:4685
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/io.c:4649
+#: fortran/io.c:4651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH 標籤無效的在中查詢敘述於 %C"
 
-#: fortran/io.c:4659 fortran/trans-io.c:1332
+#: fortran/io.c:4661 fortran/trans-io.c:1332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "查詢敘述於 %L 無法包含兩者檔案和單位說明符"
 
-#: fortran/io.c:4666
+#: fortran/io.c:4668
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L 處的 INQUIRE 敘述需要 FILE 或 UNIT 限定符"
 
-#: fortran/io.c:4676
+#: fortran/io.c:4678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L cannot be %d"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:4691
+#: fortran/io.c:4693
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "查詢敘述於 %L 需要擱置=說明符與識別號=說明符"
 
-#: fortran/io.c:4867
+#: fortran/io.c:4869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:等待於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:4873
+#: fortran/io.c:4875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "等待敘述不允許在中 PURE 程序於 %C"
 
 #. Reject truncation.
-#: fortran/iresolve.c:69
+#: fortran/iresolve.c:70
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer overflow"
 msgid "identifier overflow: %d"
@@ -64937,506 +65006,506 @@ msgstr "垃圾之後關聯敘述於 %C"
 msgid "Derived type %qs at %L may not be ABSTRACT"
 msgstr "衍生類型『%s』於 %L 可能無法是摘要"
 
-#: fortran/match.c:2212 fortran/match.c:2281 fortran/match.c:2304
+#: fortran/match.c:2212 fortran/match.c:2284 fortran/match.c:2307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid type-spec at %C"
 msgstr "無效的 type-spec 於 %C"
 
-#: fortran/match.c:2399
+#: fortran/match.c:2402
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in FORALL iterator at %C"
 msgstr "%C 處 FORALL 迭代語法錯誤"
 
-#: fortran/match.c:2664
+#: fortran/match.c:2667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
 msgstr "Fortran 2008:做共時建構於 %C"
 
-#: fortran/match.c:2789
+#: fortran/match.c:2792
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
 msgstr "名稱『%s』在中 %s 敘述於 %C 為未知"
 
-#: fortran/match.c:2797
+#: fortran/match.c:2800
 #, fuzzy, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
 msgstr "名稱『%s』在中 %s 敘述於 %C 並非建構名稱"
 
-#: fortran/match.c:2809
+#: fortran/match.c:2812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves CRITICAL construct"
 msgstr "%s 敘述於 %C 樹葉重要建構"
 
 #. F2008, C821 & C845.
-#: fortran/match.c:2817
+#: fortran/match.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaves DO CONCURRENT construct"
 msgstr "%s 敘述於 %C 樹葉做共時建構"
 
-#: fortran/match.c:2829
+#: fortran/match.c:2832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C is not within a construct"
 msgstr "%s 敘述於 %C 不是在之內建構"
 
-#: fortran/match.c:2832
+#: fortran/match.c:2835
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
 msgstr "%s 敘述於 %C 不是在之內建構『%s』"
 
-#: fortran/match.c:2858
+#: fortran/match.c:2861
 #, fuzzy, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
 msgstr "週期敘述於 %C 不是適用的到 non-loop 建構『%s』"
 
-#: fortran/match.c:2863
+#: fortran/match.c:2866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
 msgstr "Fortran 2008:離開敘述不具任何 do-construct-name 於 %C"
 
-#: fortran/match.c:2869
+#: fortran/match.c:2872
 #, fuzzy, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
 msgstr "%s 敘述於 %C 不是適用的到建構『%s』"
 
-#: fortran/match.c:2877
+#: fortran/match.c:2880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
 msgstr "%s 敘述於 %C 離開 OpenMP 結構化訊息塊"
 
-#: fortran/match.c:2878
+#: fortran/match.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
 msgstr "%s 敘述於 %C 離開 OpenMP 結構化訊息塊"
 
-#: fortran/match.c:2915
+#: fortran/match.c:2918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
 msgstr "離開敘述於 %C 終止 !$OMP 做迴圈"
 
-#: fortran/match.c:2921
+#: fortran/match.c:2924
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
 msgstr "週期敘述於 %C 到 non-innermost 崩潰 !$OMP 做迴圈"
 
-#: fortran/match.c:2923
+#: fortran/match.c:2926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
 msgstr "週期敘述於 %C 到 non-innermost 崩潰 !$OMP 做迴圈"
 
-#: fortran/match.c:2952
+#: fortran/match.c:2955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
 msgstr "離開敘述於 %C 終止 !$OMP 做迴圈"
 
-#: fortran/match.c:2957
+#: fortran/match.c:2960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
 msgstr "週期敘述於 %C 到 non-innermost 崩潰 !$OMP 做迴圈"
 
-#: fortran/match.c:3045
+#: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
 msgstr "lvalue 必要項在中 asm 敘述"
 
-#: fortran/match.c:3063
+#: fortran/match.c:3066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/match.c:3069
+#: fortran/match.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
 msgstr ""
 
-#: fortran/match.c:3090
+#: fortran/match.c:3093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
 msgstr "影像控制敘述 %s 於 %C 在中 PURE 程序"
 
-#: fortran/match.c:3106
+#: fortran/match.c:3109
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in CRITICAL block"
 msgstr "影像控制敘述停止於 %C 在中重要區塊"
 
-#: fortran/match.c:3111
+#: fortran/match.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement STOP at %C in DO CONCURRENT block"
 msgstr "影像控制敘述停止於 %C 在中做共時區塊"
 
-#: fortran/match.c:3123
+#: fortran/match.c:3126
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
 msgstr ""
 
-#: fortran/match.c:3135
+#: fortran/match.c:3138
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/match.c:3142
+#: fortran/match.c:3145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be either INTEGER or CHARACTER type"
 msgstr "停止編碼於 %L 必須是還是整數或字元型式"
 
-#: fortran/match.c:3149
+#: fortran/match.c:3152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be scalar"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/match.c:3156
+#: fortran/match.c:3159
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default character KIND=%d"
 msgstr "停止編碼於 %L 必須是預設字元 KIND=%d"
 
-#: fortran/match.c:3163
+#: fortran/match.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "停止編碼於 %L 必須是預設整數 KIND=%d"
 
-#: fortran/match.c:3211
+#: fortran/match.c:3214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/match.c:3232
+#: fortran/match.c:3235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
 msgstr "Fortran 2008:錯誤停止敘述於 %C"
 
-#: fortran/match.c:3258
+#: fortran/match.c:3261
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
 msgstr "影像控制敘述 %s 於 %C 在中 PURE 程序"
 
-#: fortran/match.c:3273
+#: fortran/match.c:3276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
 msgstr "影像控制敘述 %s 於 %C 在中重要區塊"
 
-#: fortran/match.c:3280
+#: fortran/match.c:3283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
 msgstr "影像控制敘述 %s 於 %C 在中做共時區塊"
 
-#: fortran/match.c:3310 fortran/match.c:3652 fortran/match.c:3864
-#: fortran/match.c:4416 fortran/match.c:4787
+#: fortran/match.c:3313 fortran/match.c:3655 fortran/match.c:3867
+#: fortran/match.c:4419 fortran/match.c:4790
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
 msgstr "冗餘 STAT 標籤找到於 %L "
 
-#: fortran/match.c:3331 fortran/match.c:3673 fortran/match.c:3884
-#: fortran/match.c:4448 fortran/match.c:4812
+#: fortran/match.c:3334 fortran/match.c:3676 fortran/match.c:3887
+#: fortran/match.c:4451 fortran/match.c:4815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
 msgstr "冗餘 ERRMSG 標籤找到於 %L "
 
-#: fortran/match.c:3352
+#: fortran/match.c:3355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
 msgstr "冗餘 STAT 標籤找到於 %L "
 
-#: fortran/match.c:3418
+#: fortran/match.c:3421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/match.c:3428
+#: fortran/match.c:3431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/match.c:3440
+#: fortran/match.c:3443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
 msgstr "Fortran 2003:值敘述於 %C"
 
-#: fortran/match.c:3464
+#: fortran/match.c:3467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/match.c:3503
+#: fortran/match.c:3506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
 msgstr "Fortran 2003:類別敘述於 %C"
 
-#: fortran/match.c:3533
+#: fortran/match.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/match.c:3557
+#: fortran/match.c:3560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/match.c:3600
+#: fortran/match.c:3603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in PURE procedure"
 msgstr "影像控制敘述 %s 於 %C 在中 PURE 程序"
 
-#: fortran/match.c:3615
+#: fortran/match.c:3618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in CRITICAL block"
 msgstr "影像控制敘述 %s 於 %C 在中重要區塊"
 
-#: fortran/match.c:3622
+#: fortran/match.c:3625
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement %s at %C in DO CONCURRENT block"
 msgstr "影像控制敘述 %s 於 %C 在中做共時區塊"
 
-#: fortran/match.c:3694
+#: fortran/match.c:3697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
 msgstr "冗餘 ACQUIRED_LOCK 標籤找到於 %L "
 
-#: fortran/match.c:3759
+#: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
 msgstr "Fortran 2008:鎖定敘述於 %C"
 
-#: fortran/match.c:3769
+#: fortran/match.c:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
 msgstr "Fortran 2008:解除鎖定敘述於 %C"
 
-#: fortran/match.c:3794
+#: fortran/match.c:3797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in PURE procedure"
 msgstr "影像控制敘述同步於 %C 在中 PURE 程序"
 
-#: fortran/match.c:3800
+#: fortran/match.c:3803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/match.c:3812
+#: fortran/match.c:3815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in CRITICAL block"
 msgstr "影像控制敘述同步於 %C 在中重要區塊"
 
-#: fortran/match.c:3818
+#: fortran/match.c:3821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement SYNC at %C in DO CONCURRENT block"
 msgstr "影像控制敘述同步於 %C 在中做共時區塊"
 
-#: fortran/match.c:3998
+#: fortran/match.c:4001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
 msgstr "刪除的特徵：指派敘述於 %C"
 
-#: fortran/match.c:4042
+#: fortran/match.c:4045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
 msgstr "刪除的特徵：指派的前往敘述於 %C"
 
-#: fortran/match.c:4086 fortran/match.c:4137
+#: fortran/match.c:4089 fortran/match.c:4140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label list in GOTO at %C cannot be empty"
 msgstr "敘述標貼清單在中前往於 %C 不可為空"
 
-#: fortran/match.c:4147
+#: fortran/match.c:4150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
 msgstr "Obsolescent 特徵：計算的前往於 %C"
 
-#: fortran/match.c:4222
+#: fortran/match.c:4225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in type-spec at %L"
 msgstr "在中 type-spec 於 %L 時發生錯誤"
 
-#: fortran/match.c:4235
+#: fortran/match.c:4238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
 msgstr "Fortran 2003:typespec 在中配置於 %L"
 
-#: fortran/match.c:4258
+#: fortran/match.c:4261
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
 msgstr ""
 
-#: fortran/match.c:4288 fortran/match.c:4725
+#: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected constant at %C"
 msgstr "非預期的 %s 敘述於 %C 處"
 
-#: fortran/match.c:4298
+#: fortran/match.c:4301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad allocate-object at %C for a PURE procedure"
 msgstr "不當的 allocate-object 於 %C 用於 PURE 程序"
 
-#: fortran/match.c:4313
+#: fortran/match.c:4316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
 msgstr "不合法的 allocate-object 於 %C 用於 PURE 程序"
 
-#: fortran/match.c:4335
+#: fortran/match.c:4338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "配置的 coarray 於 %C 在中做共時區塊"
 
-#: fortran/match.c:4340
+#: fortran/match.c:4343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE of coarray at %C in CRITICAL block"
 msgstr "配置的 coarray 於 %C 在中重要區塊"
 
-#: fortran/match.c:4362
+#: fortran/match.c:4365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
 msgstr "Allocate-object 於 %L 並非 nonprocedure 指標或 allocatable 變數"
 
-#: fortran/match.c:4374
+#: fortran/match.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with typespec"
 msgstr "型態的實體於 %L 是型態不相容的與 typespec"
 
-#: fortran/match.c:4382
+#: fortran/match.c:4385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgstr "Kind 型態參數用於實體於 %L 不同從 kind 型態參數的 typespec"
 
-#: fortran/match.c:4399
+#: fortran/match.c:4402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shape specification for allocatable scalar at %C"
 msgstr "形狀規格用於 allocatable 純量於 %C"
 
-#: fortran/match.c:4426
+#: fortran/match.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT tag at %L cannot be a constant"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/match.c:4442
+#: fortran/match.c:4445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
 msgstr "Fortran 2003:ERRMSG 標籤於 %L"
 
-#: fortran/match.c:4465
+#: fortran/match.c:4468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
 msgstr "Fortran 2003:來源標籤於 %L"
 
-#: fortran/match.c:4471
+#: fortran/match.c:4474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
 msgstr "冗餘來源標籤找到於 %L "
 
-#: fortran/match.c:4478
+#: fortran/match.c:4481
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L conflicts with the typespec at %L"
 msgstr "來源標籤於 %L 衝突與 typespec 於 %L"
 
-#: fortran/match.c:4484
+#: fortran/match.c:4487
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
 msgstr "Fortran 2008:來源標籤於 %L 與超過單一配置物件"
 
-#: fortran/match.c:4502
+#: fortran/match.c:4505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
 msgstr "Fortran 2008:鑄型標籤於 %L"
 
-#: fortran/match.c:4508
+#: fortran/match.c:4511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
 msgstr "冗餘鑄型標籤找到於 %L "
 
-#: fortran/match.c:4515
+#: fortran/match.c:4518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with the typespec at %L"
 msgstr "鑄型標籤於 %L 衝突與 typespec 於 %L"
 
-#: fortran/match.c:4541
+#: fortran/match.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/match.c:4549
+#: fortran/match.c:4552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object 於 %L 與已推遲型態參數需求還是 type-spec 或來源標籤或鑄型標籤"
 
-#: fortran/match.c:4561
+#: fortran/match.c:4564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
 msgstr "Allocate-object 於 %L 與已推遲型態參數需求還是 type-spec 或來源標籤或鑄型標籤"
 
-#: fortran/match.c:4628
+#: fortran/match.c:4631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %C shall not be coindexed"
 msgstr "指標物件於 %C 不應該被 coindexed"
 
-#: fortran/match.c:4643
+#: fortran/match.c:4646
 #, gcc-internal-format, gfc-internal-format
 msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
 msgstr ""
 
-#: fortran/match.c:4737
+#: fortran/match.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal allocate-object at %C for a PURE procedure"
 msgstr "不合法的 allocate-object 於 %C 用於 PURE 程序"
 
-#: fortran/match.c:4747
+#: fortran/match.c:4750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
 msgstr "取消配置的 coarray 於 %C 在中做共時區塊"
 
-#: fortran/match.c:4754
+#: fortran/match.c:4757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DEALLOCATE of coarray at %C in CRITICAL block"
 msgstr "取消配置的 coarray 於 %C 在中重要區塊"
 
-#: fortran/match.c:4770
+#: fortran/match.c:4773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allocate-object 於 %C 並非 nonprocedure 指標或 allocatable 變數"
 
-#: fortran/match.c:4807
+#: fortran/match.c:4810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
 msgstr "Fortran 2003:ERRMSG 於 %L"
 
-#: fortran/match.c:4864
+#: fortran/match.c:4867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in CRITICAL block"
 msgstr "影像控制敘述回傳於 %C 在中重要區塊"
 
-#: fortran/match.c:4870
+#: fortran/match.c:4873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Image control statement RETURN at %C in DO CONCURRENT block"
 msgstr "影像控制敘述回傳於 %C 在中做共時區塊"
 
-#: fortran/match.c:4879
+#: fortran/match.c:4882
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
 msgstr "%C 處的替代 RETURN 敘述只允許出現在 SUBROUTINE 中"
 
-#: fortran/match.c:4910
+#: fortran/match.c:4913
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
 msgstr "延伸：回傳敘述在中主要程式於 %C"
 
-#: fortran/match.c:4938
+#: fortran/match.c:4941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected component reference at %C"
 msgstr "預期的成分參考於 %C"
 
-#: fortran/match.c:4947
+#: fortran/match.c:4950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after CALL at %C"
 msgstr "垃圾之後呼叫於 %C"
 
-#: fortran/match.c:4958
+#: fortran/match.c:4961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected type-bound procedure or procedure pointer component at %C"
 msgstr "預期 type-bound 程序或程序指標成分於 %C"
 
-#: fortran/match.c:5049
+#: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
 msgstr ""
 
-#: fortran/match.c:5189
+#: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in common block name at %C"
 msgstr "%C 處公共塊名語法錯誤"
@@ -65444,224 +65513,224 @@ msgstr "%C 處公共塊名語法錯誤"
 #. If we find an error, just print it and continue,
 #. cause it's just semantic, and we can see if there
 #. are more errors.
-#: fortran/match.c:5264
+#: fortran/match.c:5267
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
 msgstr "變數『%s』於 %L 在中共同區塊『%s』於 %C 必須被宣告與 C 可交流的 kind 自從共同區塊『%s』是繫結©"
 
-#: fortran/match.c:5273
+#: fortran/match.c:5276
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
 msgstr "變數『%s』在中共同區塊『%s』於 %C 無法繫結©自從它不是全域"
 
-#: fortran/match.c:5280
+#: fortran/match.c:5283
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
 msgstr "符號『%s』於 %C 已經在中共同區塊"
 
-#: fortran/match.c:5288
+#: fortran/match.c:5291
 #, fuzzy, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
 msgstr "初始化的符號『%s』於 %C 只能是共同在中區塊資料"
 
-#: fortran/match.c:5304
+#: fortran/match.c:5307
 #, fuzzy, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
 msgstr "陣列規格用於符號『%s』在中共同於 %C 必須是明確的"
 
-#: fortran/match.c:5314
+#: fortran/match.c:5317
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
 msgstr "符號『%s』在中共同於 %C 無法指標陣列"
 
-#: fortran/match.c:5360
+#: fortran/match.c:5363
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
 msgstr "符號『%s』，在中共同區塊『%s』於 %C 正在是間接等價到另外的共同區塊『%s』"
 
-#: fortran/match.c:5422
+#: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK DATA construct at %L"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/match.c:5506
+#: fortran/match.c:5509
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
 msgstr "名稱表列群組名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/match.c:5514
+#: fortran/match.c:5517
 #, fuzzy, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
 msgstr "名稱表列群組名稱『%s』於 %C 已經是使用關聯的和無法 respecified。"
 
-#: fortran/match.c:5540
+#: fortran/match.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %C 未被允許"
 
-#: fortran/match.c:5683
+#: fortran/match.c:5686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type component %C is not a permitted EQUIVALENCE member"
 msgstr "衍生類型成分 %C 並非允許的等價成員"
 
-#: fortran/match.c:5691
+#: fortran/match.c:5694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
 msgstr "陣列參照在中等價於 %C 無法陣列區段"
 
-#: fortran/match.c:5719
+#: fortran/match.c:5727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE at %C requires two or more objects"
 msgstr "等價於 %C 需求兩個以上物件"
 
-#: fortran/match.c:5733
+#: fortran/match.c:5741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
 msgstr "試圖到間接重疊共同區塊 %s 和 %s 由等價於 %C"
 
-#: fortran/match.c:5746
+#: fortran/match.c:5754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting a comma in EQUIVALENCE at %C"
 msgstr "預期逗號在中等價於 %C"
 
-#: fortran/match.c:5751
+#: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EQUIVALENCE statement at %C"
 msgstr "Fortran 2003:值敘述於 %C"
 
-#: fortran/match.c:5887
+#: fortran/match.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L is recursive"
 msgstr "%L 處的敘述函式是遞迴的"
 
-#: fortran/match.c:5893
+#: fortran/match.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L conflicts with function name"
 msgstr "敘述函式「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/match.c:5904
+#: fortran/match.c:5912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "Statement function at %L cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/match.c:5909
+#: fortran/match.c:5917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
 msgstr "%L 處的敘述函式是遞迴的"
 
-#: fortran/match.c:6034 fortran/match.c:6050
+#: fortran/match.c:6042 fortran/match.c:6058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be scalar"
 msgid "Expression in CASE selector at %L cannot be %s"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/match.c:6072
+#: fortran/match.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression in CASE at %C"
 msgstr "%C 處 CASE 中需要初始化運算式"
 
-#: fortran/match.c:6104
+#: fortran/match.c:6112
 #, fuzzy, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "預期的區塊名稱『%s』的選取建構於 %C"
 
-#: fortran/match.c:6393
+#: fortran/match.c:6401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SELECT TYPE at %C cannot appear in this scope"
 msgstr "%C 處的 ENTRY 敘述不能出現在巢狀的子程式中"
 
-#: fortran/match.c:6434
+#: fortran/match.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/match.c:6459
+#: fortran/match.c:6467
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "選擇器在中選取型態於 %C 並非具名的變數；使用 associate-name=>"
 
-#: fortran/match.c:6615
+#: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Fortran 2008:鎖定敘述於 %C"
 
-#: fortran/match.c:6643 fortran/match.c:6696
+#: fortran/match.c:6651 fortran/match.c:6705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "%C 處的 STAT 運算式必須是一個變數"
 
-#: fortran/match.c:6706
+#: fortran/match.c:6715
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/match.c:6742
+#: fortran/match.c:6751
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/match.c:6794
+#: fortran/match.c:6803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "語法時發生錯誤大小寫規格於 %C"
 
-#: fortran/match.c:6812
+#: fortran/match.c:6821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "未預期的型態是敘述於 %C"
 
-#: fortran/match.c:6844
+#: fortran/match.c:6853
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6855
+#: fortran/match.c:6864
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6866
+#: fortran/match.c:6875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "語法時發生錯誤型態是規格於 %C"
 
-#: fortran/match.c:6942
+#: fortran/match.c:6951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "語法時發生錯誤類別是規格於 %C"
 
-#: fortran/match.c:6962
+#: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/match.c:7008
+#: fortran/match.c:7017
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "%C 處的 STAT 運算式必須是一個變數"
 
-#: fortran/match.c:7017
+#: fortran/match.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.c:7044
+#: fortran/match.c:7053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "語法時發生錯誤大小寫規格於 %C"
 
-#: fortran/match.c:7166
+#: fortran/match.c:7175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "其他情況下敘述於 %C 無法夾於位置區塊"
 
-#: fortran/match.c:7204
+#: fortran/match.c:7213
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "標貼『%s』於 %C 不匹配位置標貼『%s』"
@@ -65703,12 +65772,12 @@ msgstr ""
 msgid "gfc_basic_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:199
+#: fortran/misc.c:205
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
 msgstr ""
 
-#: fortran/misc.c:281
+#: fortran/misc.c:287
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_code2string(): Bad code"
@@ -66403,8 +66472,8 @@ msgstr ""
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10651
-#: fortran/resolve.c:11942
+#: fortran/openmp.c:4110 fortran/openmp.c:4121 fortran/resolve.c:10653
+#: fortran/resolve.c:11952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
@@ -67820,179 +67889,179 @@ msgstr "%C 處變數清單中有非預期的無用字元"
 msgid "Expected structure component name at %C"
 msgstr "%C 處需要結構元件名"
 
-#: fortran/primary.c:2251 fortran/primary.c:2371
+#: fortran/primary.c:2253 fortran/primary.c:2387
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.c:2272 fortran/primary.c:2392
 #, gcc-internal-format, gfc-internal-format
 msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
 msgstr ""
 
-#: fortran/primary.c:2258 fortran/primary.c:2384
+#: fortran/primary.c:2279 fortran/primary.c:2405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/primary.c:2317
+#: fortran/primary.c:2338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected argument list at %C"
 msgstr "預期的引數清單於 %C"
 
-#: fortran/primary.c:2366
-#, gcc-internal-format, gfc-internal-format
-msgid "RE or IM part_ref at %C"
-msgstr ""
-
-#: fortran/primary.c:2400
+#: fortran/primary.c:2421
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
 msgstr "KIND 參數 %s 在 %L 處必須是初始化運算式"
 
-#: fortran/primary.c:2428
+#: fortran/primary.c:2449
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
 msgstr "程序指標成分『%s』需要一個引數清單於 %C"
 
-#: fortran/primary.c:2531
+#: fortran/primary.c:2552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
 msgstr "表單參考到參考類型 %qT"
 
-#: fortran/primary.c:2538
+#: fortran/primary.c:2559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed procedure-pointer component at %C"
 msgstr "Coindexed procedure-pointer 成分於 %C"
 
-#: fortran/primary.c:2574
+#: fortran/primary.c:2595
 #, fuzzy, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
 msgstr "%qE 屬性只有套用到變數"
 
-#: fortran/primary.c:2756
+#: fortran/primary.c:2777
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
 msgstr ""
 
-#: fortran/primary.c:2813
+#: fortran/primary.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "gfc_caf_attr(): Bad array reference"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/primary.c:2986
+#: fortran/primary.c:3007
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
 msgstr "Fortran 2003:結構建構子與缺少的選擇性引數於 %C"
 
-#: fortran/primary.c:2995
+#: fortran/primary.c:3016
 #, fuzzy, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
 msgstr "沒有初始設定式用於成分『%s』給定的在中結構建構子於 %C！"
 
-#: fortran/primary.c:3002
+#: fortran/primary.c:3023
 #, fuzzy, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
 msgstr "沒有初始設定式用於成分『%s』給定的在中結構建構子於 %C！"
 
-#: fortran/primary.c:3050
+#: fortran/primary.c:3071
 #, fuzzy, gcc-internal-format
 msgid "Cannot construct ABSTRACT type %qs at %L"
 msgstr "無法建構摘要型態『%s』於 %L"
 
-#: fortran/primary.c:3070
+#: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
 msgstr "Fortran 2003:結構建構子與具名引數於 %C"
 
-#: fortran/primary.c:3085
+#: fortran/primary.c:3106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
 msgstr "成分初始設定式而無需名稱之後成分名為 %s 的於 %L！"
 
-#: fortran/primary.c:3090
+#: fortran/primary.c:3111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
 msgstr "太多成分在中結構建構子於 %L！"
 
-#: fortran/primary.c:3148
+#: fortran/primary.c:3169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/primary.c:3166
+#: fortran/primary.c:3187
 #, fuzzy, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
 msgstr "成分『%s』被初始化的兩次在中結構建構子於 %L！"
 
-#: fortran/primary.c:3178
+#: fortran/primary.c:3199
 #, fuzzy, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
 msgstr "Coindexed 運算式到指標成分『%s』在中結構建構子於 %L！"
 
-#: fortran/primary.c:3232
+#: fortran/primary.c:3253
 #, fuzzy, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
 msgstr "成分『%s』於 %L 已設定由上層衍生類型建構子"
 
-#: fortran/primary.c:3388
+#: fortran/primary.c:3409
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
 msgstr ""
 
-#: fortran/primary.c:3447
+#: fortran/primary.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
 msgstr "『%s』於 %C 是名稱的遞迴函式和因而參考結果變數。使用明確的結果變數用於直接的遞迴 (12.5.2.1)"
 
-#: fortran/primary.c:3478 fortran/primary.c:3880
+#: fortran/primary.c:3499 fortran/primary.c:3901
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %C is not appropriate for an expression"
 msgstr "%C 處的符號不適用於運算式"
 
-#: fortran/primary.c:3583
+#: fortran/primary.c:3604
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected use of subroutine name '%s' at %C"
 msgid "Unexpected use of subroutine name %qs at %C"
 msgstr "對子處理序名「%s」非預期的使用，在 %C 處"
 
-#: fortran/primary.c:3615
+#: fortran/primary.c:3636
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs requires argument list at %C"
 msgstr "敘述函式「%s」在 %C 處缺少參數清單"
 
-#: fortran/primary.c:3618
+#: fortran/primary.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Function %qs requires an argument list at %C"
 msgstr "函式「%s」在 %C 需要參數清單"
 
-#: fortran/primary.c:3668
+#: fortran/primary.c:3689
 #, fuzzy, gcc-internal-format
 msgid "Missing argument to %qs at %C"
 msgstr "缺少引數到『%s』於 %C"
 
-#: fortran/primary.c:3681
+#: fortran/primary.c:3702
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
 msgstr ""
 
-#: fortran/primary.c:3836
+#: fortran/primary.c:3857
 #, fuzzy, gcc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Missing argument list in function %qs at %C"
 msgstr "函式「%s」在 %C 處缺少參數清單"
 
-#: fortran/primary.c:3950
+#: fortran/primary.c:3971
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %C"
 msgstr "名稱「%s」在 %C 處不能做為已定義的運算子"
 
-#: fortran/primary.c:3991
+#: fortran/primary.c:4012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Named constant at %C in an EQUIVALENCE"
 msgstr "具名的常數於 %C 在中等價"
 
-#: fortran/primary.c:4026
+#: fortran/primary.c:4047
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a variable"
 msgstr "『%s』於 %C 並非變數"
@@ -68321,502 +68390,502 @@ msgstr "『%s』於 %L 是模稜兩可的"
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "通用程序『%s』未被允許做為實際引數於 %L"
 
-#: fortran/resolve.c:1786
+#: fortran/resolve.c:1788
 #, fuzzy, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
 msgstr "型態指定的用於內建函式『%s』於 %L 被忽略"
 
-#: fortran/resolve.c:1799
+#: fortran/resolve.c:1801
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
 msgstr "Intrinsic 副常式『%s』於 %L 不應該有型態說明符"
 
-#: fortran/resolve.c:1810
+#: fortran/resolve.c:1812
 #, fuzzy, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
 msgstr "『%s』宣告的 INTRINSIC 於 %L 不存在"
 
-#: fortran/resolve.c:1823
+#: fortran/resolve.c:1825
 #, fuzzy, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
 msgstr "intrinsic『%s』宣告的 INTRINSIC 於 %L 不是可用在中目前的標準設定值但是 %s。 使用適當 -std=* 選項或啟用 -fall-intrinsics 以便使用它。"
 
-#: fortran/resolve.c:1859
+#: fortran/resolve.c:1861
 #, fuzzy, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.c:1917 fortran/resolve.c:10180 fortran/resolve.c:11871
+#: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
 
-#: fortran/resolve.c:1949
+#: fortran/resolve.c:1951
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs is used as an actual argument at %L"
 msgstr "Fortran 2008:內部程序『%s』被做為實際引數於 %L"
 
-#: fortran/resolve.c:1967
+#: fortran/resolve.c:1969
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L is not allowed as an actual argument"
 msgstr "敘述函式「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.c:1975
+#: fortran/resolve.c:1977
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
 msgstr "Intrinsic『%s』於 %L 未被允許做為實際引數"
 
-#: fortran/resolve.c:1982
+#: fortran/resolve.c:1984
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
 msgstr "Fortran 2008:內部程序『%s』被做為實際引數於 %L"
 
-#: fortran/resolve.c:1990
+#: fortran/resolve.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL non-INTRINSIC 程序「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.c:2017
+#: fortran/resolve.c:2019
 #, fuzzy, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
 msgstr "無法找到特定的 INTRINSIC 程序用於參考『%s』於 %L"
 
-#: fortran/resolve.c:2039
+#: fortran/resolve.c:2041
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %L is ambiguous"
 msgstr "符號「%s」(位於 %L)有歧義"
 
-#: fortran/resolve.c:2094
+#: fortran/resolve.c:2096
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not of numeric type"
 msgstr "By-value 引數於 %L 不是的數字類型"
 
-#: fortran/resolve.c:2101
+#: fortran/resolve.c:2103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L cannot be an array or an array section"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.c:2115
+#: fortran/resolve.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "By-value argument at %L is not allowed in this context"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: fortran/resolve.c:2127
+#: fortran/resolve.c:2129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passing internal procedure at %L by location not allowed"
 msgstr "傳遞內部程序於 %L 依位置不允許"
 
-#: fortran/resolve.c:2138
+#: fortran/resolve.c:2140
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
 msgstr "ELEMENTAL non-INTRINSIC 程序「%s」在 %L 處不允許做為實際引數"
 
-#: fortran/resolve.c:2147
+#: fortran/resolve.c:2149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed actual argument at %L with ultimate pointer component"
 msgstr "Coindexed 實際引數於 %L 與 ultimate 指標成分"
 
-#: fortran/resolve.c:2279
+#: fortran/resolve.c:2281
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
 msgstr "『%s』於 %L 是陣列和可選的；如果它缺少，它無法實際引數的 ELEMENTAL 程序除非有 non-optional 引數與同級 (12.4.1.5)"
 
-#: fortran/resolve.c:2316
+#: fortran/resolve.c:2318
 #, fuzzy, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
 msgstr "實際引數於 %L 用於含義 (%s) 虛設『%s』的 ELEMENTAL 副常式『%s』是純量，但是另外的實際引數是陣列"
 
-#: fortran/resolve.c:2590
+#: fortran/resolve.c:2592
 #, fuzzy, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
 msgstr "傳回類型不匹配的函式『%s』於 %L (%s/%s)"
 
-#: fortran/resolve.c:2617
+#: fortran/resolve.c:2619
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
 msgstr "介面不匹配在中虛設程序『%s』於 %L:%s"
 
-#: fortran/resolve.c:2722
+#: fortran/resolve.c:2724
 #, fuzzy, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
 msgstr "沒有任何特定的函式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:2742
+#: fortran/resolve.c:2744
 #, fuzzy, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
 msgstr "通用函式『%s』於 %L 不是一致的與特定的 intrinsic 介面"
 
-#: fortran/resolve.c:2780
+#: fortran/resolve.c:2782
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "函式『%s』於 %L 是 INTRINSIC 但是不是相容與 intrinsic"
 
-#: fortran/resolve.c:2835
+#: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "無法解析特定的函式『%s』於 %L"
 
-#: fortran/resolve.c:2931
+#: fortran/resolve.c:2933
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:2935 fortran/resolve.c:16999
+#: fortran/resolve.c:2937 fortran/resolve.c:17013
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:3059
+#: fortran/resolve.c:3061
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部 FORALL %s"
 
-#: fortran/resolve.c:3066
+#: fortran/resolve.c:3068
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部做共時 %s"
 
-#: fortran/resolve.c:3073
+#: fortran/resolve.c:3075
 #, fuzzy, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
 msgstr "參考到 non-PURE 函式『%s』於 %L 內部 FORALL %s"
 
-#: fortran/resolve.c:3140
+#: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
 msgid "Unexpected junk after %qs at %L"
 msgstr "未預期的垃圾之後 NOWAIT 子句於 %C"
 
-#: fortran/resolve.c:3151
+#: fortran/resolve.c:3153
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: fortran/resolve.c:3159 fortran/resolve.c:3651
+#: fortran/resolve.c:3161 fortran/resolve.c:3653
 #, fuzzy, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
 msgstr "摘要介面『%s』必須不被引用於 %L"
 
-#: fortran/resolve.c:3171
+#: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
 msgstr ""
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
-#: fortran/resolve.c:3214
+#: fortran/resolve.c:3216
 #, fuzzy, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
 msgstr "函式『%s』被宣告字元 (*) 和無法使用的於 %L 自從它並非虛引數"
 
-#: fortran/resolve.c:3248
+#: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
 msgid "resolve_function(): bad function type"
 msgstr "<unresolved overloaded function type>"
 
-#: fortran/resolve.c:3262
+#: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
 msgstr ""
 
-#: fortran/resolve.c:3278
+#: fortran/resolve.c:3280
 #, fuzzy, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
 msgstr "使用者自訂 non-ELEMENTAL 函式『%s』於 %L 不允許在中 WORKSHARE 建構"
 
-#: fortran/resolve.c:3340
+#: fortran/resolve.c:3342
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
 msgstr "條目『%s』於 %L 無法 called 遞迴，因為函式『%s』不是遞迴"
 
-#: fortran/resolve.c:3344
+#: fortran/resolve.c:3346
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "函式『%s』於 %L 無法 called 遞迴，因為它不是遞迴"
 
-#: fortran/resolve.c:3395
+#: fortran/resolve.c:3397
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中 FORALL 區塊於 %L 不是 PURE"
 
-#: fortran/resolve.c:3401
+#: fortran/resolve.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
 msgstr "副常式呼叫到『%s』在中做共時區塊於 %L 不是 PURE"
 
-#: fortran/resolve.c:3407
+#: fortran/resolve.c:3409
 #, fuzzy, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
 msgstr "副常式呼叫到『%s』於 %L 不是 PURE"
 
-#: fortran/resolve.c:3475
+#: fortran/resolve.c:3477
 #, fuzzy, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
 msgstr "沒有任何特定的副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:3484
+#: fortran/resolve.c:3486
 #, fuzzy, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
 msgstr "通用副常式『%s』於 %L 不是一致的與 intrinsic 副常式介面"
 
-#: fortran/resolve.c:3519
+#: fortran/resolve.c:3521
 #, fuzzy, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
 msgstr "副常式『%s』於 %L 是 INTRINSIC 但是不是相容與 intrinsic"
 
-#: fortran/resolve.c:3564
+#: fortran/resolve.c:3566
 #, fuzzy, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
 msgstr "無法解析特定的副常式『%s』於 %L"
 
-#: fortran/resolve.c:3622
+#: fortran/resolve.c:3624
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
 msgstr "『%s』於 %L 有型態，該項不是一致的與呼叫於 %L"
 
-#: fortran/resolve.c:3661
+#: fortran/resolve.c:3663
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
 msgstr "條目『%s』於 %L 無法 called 遞迴，因為副常式『%s』不是遞迴"
 
-#: fortran/resolve.c:3665
+#: fortran/resolve.c:3667
 #, fuzzy, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
 msgstr "副常式『%s』於 %L 無法 called 遞迴，因為它不是遞迴"
 
-#: fortran/resolve.c:3710
+#: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
 msgstr "<unresolved overloaded function type>"
 
-#: fortran/resolve.c:3748
+#: fortran/resolve.c:3750
 #, gcc-internal-format, gfc-internal-format
 msgid "Shapes for operands at %L and %L are not conformable"
 msgstr "%L 和 %L 處的運算元外形不相容"
 
-#: fortran/resolve.c:3800
+#: fortran/resolve.c:3802
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:3903
+#: fortran/resolve.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "Impure function %qs at %L might not be evaluated"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.c:3907
+#: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Impure function at %L might not be evaluated"
 msgstr "alwaysinline 函式也許無法是 inlinable(_I)"
 
-#: fortran/resolve.c:3983
+#: fortran/resolve.c:3985
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
 msgstr "By-value 引數於 %L 無法陣列或陣列區段"
 
-#: fortran/resolve.c:4004
+#: fortran/resolve.c:4006
 #, gcc-internal-format
 msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
 msgstr ""
 
-#: fortran/resolve.c:4287
+#: fortran/resolve.c:4289
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4457 fortran/resolve.c:4480
+#: fortran/resolve.c:4459 fortran/resolve.c:4482
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4575
+#: fortran/resolve.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4580
+#: fortran/resolve.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4590
+#: fortran/resolve.c:4592
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4595
+#: fortran/resolve.c:4597
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4615
+#: fortran/resolve.c:4617
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零間隔無效"
 
-#: fortran/resolve.c:4632
+#: fortran/resolve.c:4634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4640
+#: fortran/resolve.c:4642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4656
+#: fortran/resolve.c:4658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4665
+#: fortran/resolve.c:4667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4681
+#: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "陣列參照缺少下標"
 
-#: fortran/resolve.c:4704
+#: fortran/resolve.c:4706
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rightmost 上限的假設的大小陣列區段尚未指定於 %L"
 
-#: fortran/resolve.c:4714
+#: fortran/resolve.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L 處陣列參照中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4722
+#: fortran/resolve.c:4724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Coindex 分級不匹配在中陣列參照於 %L (%d/%d)"
 
-#: fortran/resolve.c:4738
+#: fortran/resolve.c:4740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Coindex 的 codimension %d 必須是純量於 %L"
 
-#: fortran/resolve.c:4766
+#: fortran/resolve.c:4768
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L 處陣列索引必須是標量"
 
-#: fortran/resolve.c:4772
+#: fortran/resolve.c:4774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "陣列索引於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.c:4778
+#: fortran/resolve.c:4780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "擴充：%L 處的 REAL 陣列索引"
 
-#: fortran/resolve.c:4817
+#: fortran/resolve.c:4819
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/resolve.c:4824
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/resolve.c:4873
+#: fortran/resolve.c:4875
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4884
+#: fortran/resolve.c:4886
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4896
+#: fortran/resolve.c:4898
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4939
+#: fortran/resolve.c:4941
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L 處陣列索引是一個秩為 %d 的陣列"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5039
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L 處的子字串起始索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:5044
+#: fortran/resolve.c:5046
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L 處的子字串起始索引必須是標量"
 
-#: fortran/resolve.c:5053
+#: fortran/resolve.c:5055
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L 處的子字串起始索引小於 1"
 
-#: fortran/resolve.c:5066
+#: fortran/resolve.c:5068
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L 處的子字串終止索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:5073
+#: fortran/resolve.c:5075
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L 處的子字串終止索引必須是標量"
 
-#: fortran/resolve.c:5083
+#: fortran/resolve.c:5085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "子字串結束索引於 %L 超出字串長度"
 
-#: fortran/resolve.c:5093
+#: fortran/resolve.c:5095
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "子字串結束索引於 %L 太大"
 
-#: fortran/resolve.c:5286
+#: fortran/resolve.c:5288
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/resolve.c:5300
+#: fortran/resolve.c:5302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有指標屬性於 %L"
 
-#: fortran/resolve.c:5310
+#: fortran/resolve.c:5312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有 ALLOCATABLE 屬性於 %L"
 
-#: fortran/resolve.c:5356
+#: fortran/resolve.c:5358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "兩個以上部分參考與非零值分級必須不被指定的於 %L"
 
-#: fortran/resolve.c:5448
+#: fortran/resolve.c:5450
 #, gcc-internal-format
 msgid "gfc_expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5530
+#: fortran/resolve.c:5532
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:5540
+#: fortran/resolve.c:5542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -68825,12 +68894,12 @@ msgstr "假定外形的陣列在 %L 處必須是啞引數"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5550
+#: fortran/resolve.c:5552
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5568
+#: fortran/resolve.c:5570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -68839,284 +68908,284 @@ msgstr "假定外形的陣列在 %L 處必須是啞引數"
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5578
+#: fortran/resolve.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5589
+#: fortran/resolve.c:5591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5598
+#: fortran/resolve.c:5600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5613
+#: fortran/resolve.c:5615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5793
+#: fortran/resolve.c:5795
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』，已用於規格運算式，被引用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5798
+#: fortran/resolve.c:5800
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』被使用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5868
+#: fortran/resolve.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphic 子物件的 coindexed 物件於 %L"
 
-#: fortran/resolve.c:5881
+#: fortran/resolve.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.c:6125 fortran/resolve.c:6277
+#: fortran/resolve.c:6127 fortran/resolve.c:6279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "在中 type-spec 於 %L 時發生錯誤"
 
-#: fortran/resolve.c:6241
+#: fortran/resolve.c:6243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.c:6248
+#: fortran/resolve.c:6250
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:6287
+#: fortran/resolve.c:6289
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:6296
+#: fortran/resolve.c:6298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6484
+#: fortran/resolve.c:6486
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.c:6518
+#: fortran/resolve.c:6520
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.c:6570
+#: fortran/resolve.c:6572
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.c:7105
+#: fortran/resolve.c:7107
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.c:7138
+#: fortran/resolve.c:7140
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.c:7148
+#: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.c:7152 fortran/resolve.c:7159
+#: fortran/resolve.c:7154 fortran/resolve.c:7161
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.c:7214
+#: fortran/resolve.c:7216
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.c:7237
+#: fortran/resolve.c:7239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.c:7254
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:7260
+#: fortran/resolve.c:7262
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:7321
+#: fortran/resolve.c:7323
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7326
+#: fortran/resolve.c:7328
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7333
+#: fortran/resolve.c:7335
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7341
+#: fortran/resolve.c:7343
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.c:7346
+#: fortran/resolve.c:7348
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.c:7359
+#: fortran/resolve.c:7361
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.c:7463 fortran/resolve.c:7760
+#: fortran/resolve.c:7465 fortran/resolve.c:7762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.c:7471 fortran/resolve.c:7724
+#: fortran/resolve.c:7473 fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:7581
+#: fortran/resolve.c:7583
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7614
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7773
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.c:7783
+#: fortran/resolve.c:7785
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.c:7797
+#: fortran/resolve.c:7799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7812
+#: fortran/resolve.c:7814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7825
+#: fortran/resolve.c:7827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.c:7843
+#: fortran/resolve.c:7845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.c:7924 fortran/resolve.c:7939
+#: fortran/resolve.c:7926 fortran/resolve.c:7941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7931
+#: fortran/resolve.c:7933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7956
+#: fortran/resolve.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7965 fortran/resolve.c:7994 fortran/resolve.c:8022
+#: fortran/resolve.c:7967 fortran/resolve.c:7996 fortran/resolve.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7971
+#: fortran/resolve.c:7973
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.c:7983
+#: fortran/resolve.c:7985
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.c:8041
+#: fortran/resolve.c:8043
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.c:8056
+#: fortran/resolve.c:8058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:8067
+#: fortran/resolve.c:8069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:8099
+#: fortran/resolve.c:8101
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:8122
+#: fortran/resolve.c:8124
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:8133
+#: fortran/resolve.c:8135
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.c:8149
+#: fortran/resolve.c:8151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:8172
+#: fortran/resolve.c:8174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:8202
+#: fortran/resolve.c:8204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.c:8208 fortran/resolve.c:8214
+#: fortran/resolve.c:8210 fortran/resolve.c:8216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -69125,285 +69194,285 @@ msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8442
+#: fortran/resolve.c:8444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:8493
+#: fortran/resolve.c:8495
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.c:8504
+#: fortran/resolve.c:8506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.c:8517
+#: fortran/resolve.c:8519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.c:8563
+#: fortran/resolve.c:8565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.c:8582
+#: fortran/resolve.c:8584
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8592
+#: fortran/resolve.c:8594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8610 fortran/resolve.c:8618
+#: fortran/resolve.c:8612 fortran/resolve.c:8620
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.c:8680 fortran/resolve.c:9327
+#: fortran/resolve.c:8682 fortran/resolve.c:9329
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.c:8706
+#: fortran/resolve.c:8708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.c:8718
+#: fortran/resolve.c:8720
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.c:8733
+#: fortran/resolve.c:8735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.c:8887
+#: fortran/resolve.c:8889
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/resolve.c:8896
+#: fortran/resolve.c:8898
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名稱「%s」在 %C 處不能做為已定義的運算子"
 
-#: fortran/resolve.c:8913
+#: fortran/resolve.c:8915
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:8929
+#: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.c:8936
+#: fortran/resolve.c:8938
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8941
+#: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8963
+#: fortran/resolve.c:8965
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:8974
+#: fortran/resolve.c:8976
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:9202
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:9237 fortran/resolve.c:9249
+#: fortran/resolve.c:9239 fortran/resolve.c:9251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:9278
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:9290
+#: fortran/resolve.c:9292
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:9302
+#: fortran/resolve.c:9304
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.c:9305
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.c:9315
+#: fortran/resolve.c:9317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.c:9562
+#: fortran/resolve.c:9564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:9690
+#: fortran/resolve.c:9692
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9699
+#: fortran/resolve.c:9701
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9702
+#: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:9712 fortran/resolve.c:9717
+#: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.c:9826
+#: fortran/resolve.c:9828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:9878
+#: fortran/resolve.c:9880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/resolve.c:9888
+#: fortran/resolve.c:9890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9901
+#: fortran/resolve.c:9903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9910
+#: fortran/resolve.c:9912
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.c:9917
+#: fortran/resolve.c:9919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9928
+#: fortran/resolve.c:9930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.c:9934
+#: fortran/resolve.c:9936
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.c:10006
+#: fortran/resolve.c:10008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:10016
+#: fortran/resolve.c:10018
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:10020
+#: fortran/resolve.c:10022
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:10023
+#: fortran/resolve.c:10025
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:10030 fortran/resolve.c:10152
+#: fortran/resolve.c:10032 fortran/resolve.c:10154
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:10042 fortran/resolve.c:10160
+#: fortran/resolve.c:10044 fortran/resolve.c:10162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:10054
+#: fortran/resolve.c:10056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.c:10067
+#: fortran/resolve.c:10069
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10130
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:10132 fortran/resolve.c:10142
+#: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.c:10187
+#: fortran/resolve.c:10189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.c:10197
+#: fortran/resolve.c:10199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:10214 fortran/resolve.c:10237
+#: fortran/resolve.c:10216 fortran/resolve.c:10239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.c:10218 fortran/resolve.c:10243
+#: fortran/resolve.c:10220 fortran/resolve.c:10245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -69411,192 +69480,192 @@ msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:10258
+#: fortran/resolve.c:10260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.c:10354 fortran/resolve.c:10441
+#: fortran/resolve.c:10356 fortran/resolve.c:10443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.c:10364 fortran/resolve.c:10451
+#: fortran/resolve.c:10366 fortran/resolve.c:10453
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.c:10395
+#: fortran/resolve.c:10397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:10404
+#: fortran/resolve.c:10406
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.c:10551
+#: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/resolve.c:10572
+#: fortran/resolve.c:10574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:10582
+#: fortran/resolve.c:10584
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.c:10659
+#: fortran/resolve.c:10661
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.c:10764
+#: fortran/resolve.c:10766
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10877
+#: fortran/resolve.c:10879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.c:10909
+#: fortran/resolve.c:10911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.c:10915
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.c:10927
+#: fortran/resolve.c:10929
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.c:10959
+#: fortran/resolve.c:10961
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10963
+#: fortran/resolve.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:10968
+#: fortran/resolve.c:10970
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10975
+#: fortran/resolve.c:10977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.c:10986
+#: fortran/resolve.c:10988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.c:11304
+#: fortran/resolve.c:11306
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:11546
+#: fortran/resolve.c:11548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/resolve.c:11558
+#: fortran/resolve.c:11560
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/resolve.c:11803
+#: fortran/resolve.c:11812
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.c:11806
+#: fortran/resolve.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.c:11817
+#: fortran/resolve.c:11827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.c:11879
+#: fortran/resolve.c:11889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.c:11925
+#: fortran/resolve.c:11935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.c:11929
+#: fortran/resolve.c:11939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.c:11990
+#: fortran/resolve.c:12000
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11995
+#: fortran/resolve.c:12005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.c:12079
+#: fortran/resolve.c:12089
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.c:12160
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.c:12270
+#: fortran/resolve.c:12280
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:12284
+#: fortran/resolve.c:12294
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -69604,971 +69673,971 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:12303
+#: fortran/resolve.c:12313
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.c:12388
+#: fortran/resolve.c:12398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.c:12620
+#: fortran/resolve.c:12630
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:12624
+#: fortran/resolve.c:12634
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:12632
+#: fortran/resolve.c:12642
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:12643
+#: fortran/resolve.c:12653
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.c:12658
+#: fortran/resolve.c:12668
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.c:12670
+#: fortran/resolve.c:12680
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.c:12702
+#: fortran/resolve.c:12712
 #, fuzzy, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.c:12724
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
 
-#: fortran/resolve.c:12755
+#: fortran/resolve.c:12765
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12791
+#: fortran/resolve.c:12801
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.c:12816
+#: fortran/resolve.c:12826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.c:12837
+#: fortran/resolve.c:12847
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.c:12844
+#: fortran/resolve.c:12854
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:12891
+#: fortran/resolve.c:12901
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12894
+#: fortran/resolve.c:12904
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12898
+#: fortran/resolve.c:12908
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12901
+#: fortran/resolve.c:12911
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12904
+#: fortran/resolve.c:12914
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12907
+#: fortran/resolve.c:12917
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12949
+#: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，於 %s:%d"
 
-#: fortran/resolve.c:12980
+#: fortran/resolve.c:12990
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.c:13002
+#: fortran/resolve.c:13013
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:13024
+#: fortran/resolve.c:13035
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.c:13042
+#: fortran/resolve.c:13053
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.c:13054
+#: fortran/resolve.c:13065
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:13063
+#: fortran/resolve.c:13074
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.c:13073
+#: fortran/resolve.c:13084
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.c:13092
+#: fortran/resolve.c:13103
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.c:13096
+#: fortran/resolve.c:13107
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.c:13100
+#: fortran/resolve.c:13111
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:13104
+#: fortran/resolve.c:13115
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.c:13117
+#: fortran/resolve.c:13128
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:13126
+#: fortran/resolve.c:13139
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.c:13132
+#: fortran/resolve.c:13145
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.c:13144
+#: fortran/resolve.c:13157
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:13201
+#: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13207
+#: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13213
+#: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13221
+#: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:13227
+#: fortran/resolve.c:13240
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.c:13270
+#: fortran/resolve.c:13283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13278
+#: fortran/resolve.c:13291
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13286
+#: fortran/resolve.c:13299
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:13295
+#: fortran/resolve.c:13308
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:13379
+#: fortran/resolve.c:13392
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.c:13388
+#: fortran/resolve.c:13401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.c:13397
+#: fortran/resolve.c:13410
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.c:13405
+#: fortran/resolve.c:13418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.c:13411
+#: fortran/resolve.c:13424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:13417
+#: fortran/resolve.c:13430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.c:13425
+#: fortran/resolve.c:13438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.c:13434
+#: fortran/resolve.c:13447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.c:13456
+#: fortran/resolve.c:13469
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.c:13493
+#: fortran/resolve.c:13506
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.c:13533
+#: fortran/resolve.c:13546
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:13569
+#: fortran/resolve.c:13582
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.c:13628
+#: fortran/resolve.c:13641
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.c:13640
+#: fortran/resolve.c:13653
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.c:13668
+#: fortran/resolve.c:13681
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.c:13724
+#: fortran/resolve.c:13737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.c:13935
+#: fortran/resolve.c:13948
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.c:13978
+#: fortran/resolve.c:13991
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:13992
+#: fortran/resolve.c:14005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:14006 fortran/resolve.c:14492
+#: fortran/resolve.c:14019 fortran/resolve.c:14505
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:14027
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:14023
+#: fortran/resolve.c:14036
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.c:14029
+#: fortran/resolve.c:14042
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:14035
+#: fortran/resolve.c:14048
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.c:14064
+#: fortran/resolve.c:14077
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.c:14074
+#: fortran/resolve.c:14087
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.c:14169
+#: fortran/resolve.c:14182
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14285
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.c:14281
+#: fortran/resolve.c:14294
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:14291
+#: fortran/resolve.c:14304
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:14316
+#: fortran/resolve.c:14329
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L 處 ICHAR 的參數長度必須為 1"
 
-#: fortran/resolve.c:14425
+#: fortran/resolve.c:14438
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:14439
+#: fortran/resolve.c:14452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:14455
+#: fortran/resolve.c:14468
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:14465
+#: fortran/resolve.c:14478
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.c:14474
+#: fortran/resolve.c:14487
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.c:14483
+#: fortran/resolve.c:14496
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:14525
+#: fortran/resolve.c:14538
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.c:14538
+#: fortran/resolve.c:14551
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14562
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.c:14582
+#: fortran/resolve.c:14595
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:14590
+#: fortran/resolve.c:14603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.c:14599
+#: fortran/resolve.c:14612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.c:14681
+#: fortran/resolve.c:14694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "衝突在中屬性的函式引數於 %C"
 
-#: fortran/resolve.c:14726
+#: fortran/resolve.c:14739
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.c:14739
+#: fortran/resolve.c:14752
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14816
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14836
+#: fortran/resolve.c:14849
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14928
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14934
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14927
+#: fortran/resolve.c:14940
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14935
+#: fortran/resolve.c:14948
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14952
+#: fortran/resolve.c:14965
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14974
+#: fortran/resolve.c:14987
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14998
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:15012
+#: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:15031
+#: fortran/resolve.c:15044
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.c:15047
+#: fortran/resolve.c:15060
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.c:15058
+#: fortran/resolve.c:15071
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.c:15066
+#: fortran/resolve.c:15079
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15130
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.c:15128
+#: fortran/resolve.c:15141
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:15135
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:15174
+#: fortran/resolve.c:15188
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:15238
+#: fortran/resolve.c:15252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.c:15241
+#: fortran/resolve.c:15255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.c:15337
+#: fortran/resolve.c:15351
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/resolve.c:15371
+#: fortran/resolve.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:15374
+#: fortran/resolve.c:15388
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:15384
+#: fortran/resolve.c:15398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:15391
+#: fortran/resolve.c:15405
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15418
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.c:15410
+#: fortran/resolve.c:15424
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.c:15420
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.c:15429
+#: fortran/resolve.c:15443
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.c:15442 fortran/resolve.c:15619
+#: fortran/resolve.c:15456 fortran/resolve.c:15633
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.c:15456
+#: fortran/resolve.c:15470
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15465
+#: fortran/resolve.c:15479
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:15474
+#: fortran/resolve.c:15488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:15482
+#: fortran/resolve.c:15496
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:15489
+#: fortran/resolve.c:15503
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:15509
+#: fortran/resolve.c:15523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:15523
+#: fortran/resolve.c:15537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:15530
+#: fortran/resolve.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.c:15556
+#: fortran/resolve.c:15570
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.c:15566
+#: fortran/resolve.c:15580
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/resolve.c:15645
+#: fortran/resolve.c:15659
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.c:15660
+#: fortran/resolve.c:15674
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:15673
+#: fortran/resolve.c:15687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:15691
+#: fortran/resolve.c:15705
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.c:15703
+#: fortran/resolve.c:15717
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15712
+#: fortran/resolve.c:15726
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15724
+#: fortran/resolve.c:15738
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15733
+#: fortran/resolve.c:15747
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:15745
+#: fortran/resolve.c:15759
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:15761
+#: fortran/resolve.c:15775
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.c:15769
+#: fortran/resolve.c:15783
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:15776
+#: fortran/resolve.c:15790
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.c:15788
+#: fortran/resolve.c:15802
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15797
+#: fortran/resolve.c:15811
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15813
+#: fortran/resolve.c:15827
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15819
+#: fortran/resolve.c:15833
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15844
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.c:15914
+#: fortran/resolve.c:15928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.c:15925
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:16030
+#: fortran/resolve.c:16044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/resolve.c:16038
+#: fortran/resolve.c:16052
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.c:16045
+#: fortran/resolve.c:16059
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.c:16052
+#: fortran/resolve.c:16066
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.c:16068
+#: fortran/resolve.c:16082
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.c:16075
+#: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.c:16123
+#: fortran/resolve.c:16137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.c:16136
+#: fortran/resolve.c:16150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.c:16235
+#: fortran/resolve.c:16249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16243
+#: fortran/resolve.c:16257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16251
+#: fortran/resolve.c:16265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.c:16541
+#: fortran/resolve.c:16555
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.c:16547
+#: fortran/resolve.c:16561
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.c:16631
+#: fortran/resolve.c:16645
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.c:16640
+#: fortran/resolve.c:16654
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.c:16648
+#: fortran/resolve.c:16662
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.c:16664
+#: fortran/resolve.c:16678
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.c:16767
+#: fortran/resolve.c:16781
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.c:16782
+#: fortran/resolve.c:16796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.c:16807
+#: fortran/resolve.c:16821
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.c:16816
+#: fortran/resolve.c:16830
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:16889
+#: fortran/resolve.c:16903
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.c:16900
+#: fortran/resolve.c:16914
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:16911
+#: fortran/resolve.c:16925
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.c:16942
+#: fortran/resolve.c:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C 處指定字元長度時語法錯誤"
 
-#: fortran/resolve.c:17009
+#: fortran/resolve.c:17023
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.c:17022
+#: fortran/resolve.c:17036
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:17042
+#: fortran/resolve.c:17056
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.c:17052
+#: fortran/resolve.c:17066
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.c:17060
+#: fortran/resolve.c:17074
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:17074
+#: fortran/resolve.c:17088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:17092
+#: fortran/resolve.c:17106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:17099
+#: fortran/resolve.c:17113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.c:17178
+#: fortran/resolve.c:17192
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -71273,159 +71342,159 @@ msgstr "『%s』於 %L 有屬性指定的外側它的介面內文"
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "符號『%s』於 %L 衝突與符號從模組『%s』，use-associated 於 %L"
 
-#: fortran/symbol.c:2008
+#: fortran/symbol.c:2008 fortran/symbol.c:2011
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符號「%s」在 %L 處已經有了基本類型 %s"
 
-#: fortran/symbol.c:2015
+#: fortran/symbol.c:2018
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "程序『%s』於 %L 可能無法有基本型式的 %s"
 
-#: fortran/symbol.c:2027
+#: fortran/symbol.c:2030
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "符號「%s」於 %L 處不能有類型"
 
-#: fortran/symbol.c:2270
+#: fortran/symbol.c:2275
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "成分『%s』於 %C 已經在中親代型態於 %L"
 
-#: fortran/symbol.c:2355
+#: fortran/symbol.c:2360
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "符號「%s」在 %C 處有歧義"
 
-#: fortran/symbol.c:2387
+#: fortran/symbol.c:2392
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "衍生類型『%s』於 %C 正在被使用之前它被定義"
 
-#: fortran/symbol.c:2536
+#: fortran/symbol.c:2541
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "元件「%s」在 %C 處是「%s」的 PRIVATE 元件"
 
-#: fortran/symbol.c:2557
+#: fortran/symbol.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.c:2561
+#: fortran/symbol.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.c:2725
+#: fortran/symbol.c:2730
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重複的敘述標籤 %d 出現在 %L 和 %L 處"
 
-#: fortran/symbol.c:2736
+#: fortran/symbol.c:2741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "標貼 %d 於 %C 已經引用做為分支目標"
 
-#: fortran/symbol.c:2746
+#: fortran/symbol.c:2751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "標貼 %d 於 %C 已經引用做為格式標貼"
 
-#: fortran/symbol.c:2753
+#: fortran/symbol.c:2758
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2794
+#: fortran/symbol.c:2799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "標貼 %d 於 %C 在之前使用的做為格式標貼"
 
-#: fortran/symbol.c:2803
+#: fortran/symbol.c:2808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "標貼 %d 於 %C 在之前使用的做為分支目標"
 
-#: fortran/symbol.c:2810
+#: fortran/symbol.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/symbol.c:2814
+#: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Fortran 2008:鎖定敘述於 %C"
 
-#: fortran/symbol.c:3150
+#: fortran/symbol.c:3155
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從模組『%s』"
 
-#: fortran/symbol.c:3153
+#: fortran/symbol.c:3158
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從目前的程式單元"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3396
+#: fortran/symbol.c:3401
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/symbol.c:4395
+#: fortran/symbol.c:4412
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4408
+#: fortran/symbol.c:4425
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "衍生類型『%s』宣告的於 %L 必須有繫結屬性為 C 可交流的"
 
-#: fortran/symbol.c:4426
+#: fortran/symbol.c:4443
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生類型『%s』與繫結©屬性於 %L 是空的，而也許會是不可存取由 C companion 處理器"
 
-#: fortran/symbol.c:4447
+#: fortran/symbol.c:4464
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "成分『%s』於 %L 無法有指標屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:4457
+#: fortran/symbol.c:4474
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "程序指標成分『%s』於 %L 無法成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:4468
+#: fortran/symbol.c:4485
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "成分『%s』於 %L 無法有 ALLOCATABLE 屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:4507
+#: fortran/symbol.c:4524
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的，甚至雖然衍生類型『%s』是繫結©"
 
-#: fortran/symbol.c:4517
+#: fortran/symbol.c:4534
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/symbol.c:4529
+#: fortran/symbol.c:4546
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "衍生類型『%s』於 %L 無法有序列屬性因為它是繫結©"
 
-#: fortran/symbol.c:5009 fortran/symbol.c:5014
+#: fortran/symbol.c:5026 fortran/symbol.c:5031
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "符號『%s』被使用之前它被型態於 %L"
@@ -71462,84 +71531,84 @@ msgstr "重疊 unequal 初始設定式在中等價於 %L"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/trans-array.c:8149
+#: fortran/trans-array.c:8151
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "建立陣列暫時的於 %L 用於引數『%s』"
 
-#: fortran/trans-array.c:11253
+#: fortran/trans-array.c:11255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "不當的運算式型態在的期間遍歷 (%d)"
 
-#: fortran/trans-common.c:401
+#: fortran/trans-common.c:404
 #, fuzzy, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
 msgstr "具名的共同區塊『%s』於 %L 應該是的相同大小做為其他情況下 (%lu vs %lu 位元組)"
 
-#: fortran/trans-common.c:787
+#: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "要求的位置不是一個整數常數"
 
-#: fortran/trans-common.c:815
+#: fortran/trans-common.c:818
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
 msgstr ""
 
-#: fortran/trans-common.c:885
+#: fortran/trans-common.c:888
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array reference at %L"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/trans-common.c:893
+#: fortran/trans-common.c:896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal reference type at %L as EQUIVALENCE object"
 msgstr "不合法的參考類型於 %L 做為等價物件"
 
-#: fortran/trans-common.c:933
+#: fortran/trans-common.c:936
 #, fuzzy, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
 msgstr "不一致等價規則牽連出『%s』於 %L 和『%s』於 %L"
 
 #. Aligning this field would misalign a previous field.
-#: fortran/trans-common.c:1122
+#: fortran/trans-common.c:1125
 #, fuzzy, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
 msgstr "等價設定用於變數『%s』宣告的於 %L 妨害對齊需求"
 
-#: fortran/trans-common.c:1187
+#: fortran/trans-common.c:1190
 #, fuzzy, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
 msgstr "等價用於『%s』不匹配定序的共同『%s』於 %L"
 
-#: fortran/trans-common.c:1202
+#: fortran/trans-common.c:1205
 #, fuzzy, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
 msgstr "等價設定用於『%s』造成無效的延伸到共同『%s』於 %L"
 
-#: fortran/trans-common.c:1218
+#: fortran/trans-common.c:1221
 #, fuzzy, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "填補的 %d 位元組必要項之前『%s』在中共同『%s』於 %L; 重新排序元件或使用 -fno-align-commons"
 
-#: fortran/trans-common.c:1224
+#: fortran/trans-common.c:1227
 #, fuzzy, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
 msgstr "填補的 %d 位元組必要項之前『%s』在中共同於 %L; 重新排序元件或使用 -fno-align-commons"
 
-#: fortran/trans-common.c:1245
+#: fortran/trans-common.c:1248
 #, fuzzy, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
 msgstr "共同『%s』於 %L 不存在"
 
-#: fortran/trans-common.c:1254
+#: fortran/trans-common.c:1257
 #, fuzzy, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "共同『%s』於 %L 需求 %d 位元組的填補；重新排序元件或使用 -fno-align-commons"
 
-#: fortran/trans-common.c:1259
+#: fortran/trans-common.c:1262
 #, fuzzy, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
 msgstr "共同於 %L 需求 %d 位元組的填補；重新排序元件或使用 -fno-align-commons"
@@ -71559,73 +71628,73 @@ msgstr "non-constant 初始化運算式於 %L"
 msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider using %<-frecursive%>, or increase the %<-fmax-stack-var-size=%> limit, or change the code to use an ALLOCATABLE array."
 msgstr ""
 
-#: fortran/trans-decl.c:1741
+#: fortran/trans-decl.c:1743
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
 msgstr "內建函式變數不是一個程序"
 
-#: fortran/trans-decl.c:4550 fortran/trans-decl.c:6913
+#: fortran/trans-decl.c:4555 fortran/trans-decl.c:6918
 #, fuzzy, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
 msgstr "傳回值的函式『%s』於 %L 無法設定"
 
-#: fortran/trans-decl.c:5038
+#: fortran/trans-decl.c:5043
 #, fuzzy, gcc-internal-format
 msgid "Deferred type parameter not yet supported"
 msgstr "已推遲型態參數尚未支援"
 
-#: fortran/trans-decl.c:5278
+#: fortran/trans-decl.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "backend decl for module variable %s already exists"
 msgid "backend decl for module variable %qs already exists"
 msgstr "模組變數 %s 的後端程式宣告已存在"
 
-#: fortran/trans-decl.c:5291
+#: fortran/trans-decl.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
 msgstr "未使用的變數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.c:5916
+#: fortran/trans-decl.c:5921
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
 msgstr "虛引數『%s』於 %L 被宣告含義 (出) 但是不是設定"
 
-#: fortran/trans-decl.c:5922
+#: fortran/trans-decl.c:5927
 #, fuzzy, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
 msgstr "衍生類型虛引數『%s』於 %L 被宣告含義 (出) 但是不是設定和沒有預設初始設定式"
 
-#: fortran/trans-decl.c:5933 fortran/trans-decl.c:6079
+#: fortran/trans-decl.c:5938 fortran/trans-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
 msgstr "未使用的虛引數『%s』於 %L"
 
-#: fortran/trans-decl.c:5949
+#: fortran/trans-decl.c:5954
 #, fuzzy, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
 msgstr "未使用的模組變數『%s』該項已被明確的匯入的於 %L"
 
-#: fortran/trans-decl.c:5968
+#: fortran/trans-decl.c:5973
 #, fuzzy, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
 msgstr "未使用的變數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.c:6017
+#: fortran/trans-decl.c:6022
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
 msgstr "未使用的參數『%s』宣告的於 %L"
 
-#: fortran/trans-decl.c:6021
+#: fortran/trans-decl.c:6026
 #, fuzzy, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
 msgstr "未使用的參數『%s』該項已被明確的匯入的於 %L"
 
-#: fortran/trans-decl.c:6051
+#: fortran/trans-decl.c:6056
 #, fuzzy, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
 msgstr "傳回值『%s』的函式『%s』宣告的於 %L 無法設定"
 
-#: fortran/trans-decl.c:6642
+#: fortran/trans-decl.c:6647
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
@@ -71640,27 +71709,27 @@ msgstr ""
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.c:1931
+#: fortran/trans-expr.c:1937
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.c:1940
+#: fortran/trans-expr.c:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "無限制的多型於 %C 尚未支援"
 
-#: fortran/trans-expr.c:3608
+#: fortran/trans-expr.c:3614
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "不明的內建作業"
 
-#: fortran/trans-expr.c:5107
+#: fortran/trans-expr.c:5113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "不明引數清單函式於 %L"
 
-#: fortran/trans-expr.c:9242
+#: fortran/trans-expr.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -71697,22 +71766,22 @@ msgstr "Fortran 2003:內部檔案於 %L 與名稱表列"
 msgid "Bad IO basetype (%d)"
 msgstr "錯誤的 IO 基礎類別型(%d)"
 
-#: fortran/trans-openmp.c:1274
+#: fortran/trans-openmp.c:1256
 #, fuzzy, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/trans-openmp.c:2508
+#: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
 msgid "optional class parameter"
 msgstr "無效的 PHI 引數"
 
-#: fortran/trans-openmp.c:2751
+#: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
 msgstr ""
 
-#: fortran/trans-openmp.c:5622
+#: fortran/trans-openmp.c:5588
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_omp_workshare(): Bad statement code"
 msgstr "gfc_trans_omp_workshare()：不當的敘述編碼"
@@ -71823,83 +71892,83 @@ msgstr "不匹配的引數"
 msgid "unable to open file"
 msgstr "開啟 %s 時失敗"
 
-#: lto/lto-common.c:1978
+#: lto/lto-common.c:1979
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "位元碼串流：無用資料於結束的符號區段"
 
-#: lto/lto-common.c:2005
+#: lto/lto-common.c:2006
 #, fuzzy, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "無法剖析十六進位數字"
 
-#: lto/lto-common.c:2037
+#: lto/lto-common.c:2038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "未預期的檔案名稱 %s 在中鏈結器解析度檔案。預期 %s"
 
-#: lto/lto-common.c:2046
+#: lto/lto-common.c:2047
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "無法剖析檔案偏移"
 
-#: lto/lto-common.c:2049
+#: lto/lto-common.c:2050
 #, fuzzy, gcc-internal-format
 msgid "unexpected offset"
 msgstr "未預期的偏移"
 
-#: lto/lto-common.c:2071
+#: lto/lto-common.c:2072
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "無效的列在中解析度檔案"
 
-#: lto/lto-common.c:2082
+#: lto/lto-common.c:2083
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "無效的解析度在中解析度檔案"
 
-#: lto/lto-common.c:2088
+#: lto/lto-common.c:2089
 #, fuzzy, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "解析度子識別號 "
 
-#: lto/lto-common.c:2205
+#: lto/lto-common.c:2206
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
 msgstr "位元碼串流產生的與 LTO 版本 %d.%d 以代替預期 %d.%d"
 
-#: lto/lto-common.c:2224
+#: lto/lto-common.c:2225
 #, fuzzy, gcc-internal-format
 msgid "cannot read %<LTO_section_decls%> from %s"
 msgstr "無法讀取 LTO decls 從 %s"
 
-#: lto/lto-common.c:2345
+#: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "無法開啟 %s"
 
-#: lto/lto-common.c:2366
+#: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "無法映射 %s"
 
-#: lto/lto-common.c:2377
+#: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "無法讀取 %s"
 
-#: lto/lto-common.c:2695
+#: lto/lto-common.c:2696
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "無法開啟符號解析度檔案：%m"
 
-#: lto/lto-common.c:2819
+#: lto/lto-common.c:2820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: lto/lto-common.c:2856
+#: lto/lto-common.c:2857
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "錯誤在的期間合併的轉譯單位"
@@ -73031,7 +73100,7 @@ msgstr "%qs 後缺少巨集名"
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1979 c-family/c.opt:1987 brig/lang.opt:44
-#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3244
+#: config/darwin.opt:30 common.opt:323 common.opt:326 common.opt:3248
 #, gcc-internal-format
 msgid "missing filename after %qs"
 msgstr "%qs 後缺少檔案名稱"
@@ -73236,22 +73305,42 @@ msgstr "不明 IRA 演算法 %qs"
 msgid "unknown TLS model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2966
+#: common.opt:2970
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:3004
+#: common.opt:3008
 #, fuzzy, gcc-internal-format
 msgid "unrecognized visibility value %qs"
 msgstr "無法辨識的可視性值 %qs"
 
-#: common.opt:3023
+#: common.opt:3027
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在 %qs 的初始化附近)"
 
+#, fuzzy
+#~| msgid "Warn about variables which are initialized to themselves"
+#~ msgid "Warn about code paths in which an uninitialized value is used."
+#~ msgstr "對初始化為自身的變數給出警告。"
+
+#, fuzzy
+#~| msgid "generation of Branch Likely instructions enabled, but not supported by architecture"
+#~ msgid "Use instructions for a future architecture."
+#~ msgstr "產生 Branch Likely 指令被啟用，但並不為架構所支援"
+
+#, fuzzy
+#~| msgid "%qE attribute can only be applied to Java class definitions"
+#~ msgid "three-way comparison operator can only be defaulted in a class definition"
+#~ msgstr "只能為 Java 類別定義套用 %qE 屬性"
+
+#, fuzzy
+#~| msgid "%qE attribute can only be applied to Java class definitions"
+#~ msgid "equality comparison operator can only be defaulted in a class definition"
+#~ msgstr "只能為 Java 類別定義套用 %qE 屬性"
+
 #~ msgid "Same as %s.  Use the latter option instead."
 #~ msgstr "等於 %s。請改用後者選項。"
 

commit 809d0065f1ddbaefbf1c2320649d24b83c90d7e7
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Tue Jul 28 00:17:01 2020 +0000

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index fa5830e15b6..79ea60c1313 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,22 @@
+2020-07-27  Aaron Sawdey  <acsawdey@linux.ibm.com>
+
+	Backported from master:
+	2020-06-23  Aaron Sawdey  <acsawdey@linux.ibm.com>
+
+	* config.gcc: Identify power10 as a 64-bit processor and as valid
+	for --with-cpu and --with-tune.
+
+2020-07-27  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2020-07-27  Martin Liska  <mliska@suse.cz>
+
+	PR lto/45375
+	* symbol-summary.h: Call vec_safe_reserve before grow is called
+	in order to grow to a reasonable size.
+	* vec.h (vec_safe_reserve): Add missing function for vl_ptr
+	type.
+
 2020-07-23  Sergei Trofimovich  <siarheit@google.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 244a45a8404..75ec474bf8f 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200727
+20200728
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index b0e1a540213..fa391848912 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,14 @@
+2020-07-27  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	Backported from master:
+	2020-07-14  Steven G. Kargl  <kargl@gcc.gnu.org>
+		    Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	PR fortran/95612
+	* expr.c (gfc_check_pointer_assigb): Output an error if
+	rvalue is a zero sized array or output an error if rvalue
+	doesn't have a symbol tree.
+
 2020-07-26  Mark Eggleston  <markeggleston@gcc.gnu.org>
 
 	Backported from master:
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index bed31e511e7..7a18efafb55 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,9 @@
+2020-07-27  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index a1a18d8f7b1..0ad755d0bac 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2020-07-27  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	Backported from master:
+	2020-07-14  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/95612
+	* gfortran.dg/pr95612.f90: New test.
+
 2020-07-26  Mark Eggleston  <markeggleston@gcc.gnu.org>
 
 	Backported from master:

commit 7d88f924ad8d773cceb08e123cb2831f20d40cb4
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Tue Jul 28 11:08:29 2020 +0200

    expander: Fix ICE in maybe_warn_rdwr_sizes [PR96335]
    
    The following testcase ICEs in maybe_warn_rdwr_sizes.  The problem is that
    the caller uses its fndecl and fntype variables to fill up rdwr_map, and
    the fntype in that case is a prototype with the access attribute and all
    the checks needed for that performed.  But the maybe_warn_rdwr_sizes
    function tries to rediscover fndecl/fntype itself and does it differently
    from how the caller did (for fndecl get_callee_fndecl and fntype from that
    FUNCTION_DECL, otherwise sets fntype to CALL_EXPR_FN's type).
    
    On the testcase, get_callee_fndecl does find a FUNCTION_DECL because
    it does STRIP_NOPS in between.
    
    Instead of trying to rediscover those, this patch just passes them down,
    like is done in several other functions.
    
    2020-07-28  Jakub Jelinek  <jakub@redhat.com>
    
            PR middle-end/96335
            * calls.c (maybe_warn_rdwr_sizes): Add FNDECL and FNTYPE arguments,
            instead of trying to rediscover them in the body.
            (initialize_argument_information): Adjust caller.
    
            * gcc.dg/pr96335.c: New test.
    
    (cherry picked from commit f9264b9008386ac3b5c795472c222fa524b127b0)

diff --git a/gcc/calls.c b/gcc/calls.c
index 8041388c1d2..e0831e9d4b9 100644
--- a/gcc/calls.c
+++ b/gcc/calls.c
@@ -1982,24 +1982,8 @@ append_attrname (const std::pair<int, attr_access> &access,
    in the function call EXP.  */
 
 static void
-maybe_warn_rdwr_sizes (rdwr_map *rwm, tree exp)
+maybe_warn_rdwr_sizes (rdwr_map *rwm, tree fndecl, tree fntype, tree exp)
 {
-  tree fndecl = NULL_TREE;
-  tree fntype = NULL_TREE;
-  if (tree fnaddr = CALL_EXPR_FN (exp))
-    {
-      if (TREE_CODE (fnaddr) == ADDR_EXPR)
-	{
-	  fndecl = TREE_OPERAND (fnaddr, 0);
-	  fntype = TREE_TYPE (fndecl);
-	}
-      else
-	fntype = TREE_TYPE (TREE_TYPE (fnaddr));
-    }
-
-  if (!fntype)
-    return;
-
   /* A string describing the attributes that the warnings issued by this
      function apply to.  Used to print one informational note per function
      call, rather than one per warning.  That reduces clutter.  */
@@ -2560,7 +2544,7 @@ initialize_argument_information (int num_actuals ATTRIBUTE_UNUSED,
   maybe_warn_nonstring_arg (fndecl, exp);
 
   /* Check read_only, write_only, and read_write arguments.  */
-  maybe_warn_rdwr_sizes (&rdwr_idx, exp);
+  maybe_warn_rdwr_sizes (&rdwr_idx, fndecl, fntype, exp);
 }
 
 /* Update ARGS_SIZE to contain the total size for the argument block.
diff --git a/gcc/testsuite/gcc.dg/pr96335.c b/gcc/testsuite/gcc.dg/pr96335.c
new file mode 100644
index 00000000000..ab243b3d129
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96335.c
@@ -0,0 +1,12 @@
+/* PR middle-end/96335 */
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+void bar (int, void *) __attribute__((__access__(__read_only__, 2)));
+
+void
+foo (void *x)
+{
+  void (*fn) () = bar;
+  fn (0, x);
+}

commit c0438ced53bcf57e4ebb1c38c226e41571aca892
Author: Martin Liska <mliska@suse.cz>
Date:   Mon Jul 27 12:30:24 2020 +0200

    expr: build string_constant only for a char type
    
    gcc/ChangeLog:
    
            PR tree-optimization/96058
            * expr.c (string_constant): Build string_constant only
            for a type that has same precision as char_type_node
            and is an integral type.
    
    (cherry picked from commit 7355a9408b990cdd20db91e2e1ba0b03e801d6a6)

diff --git a/gcc/expr.c b/gcc/expr.c
index a302e89e799..b2becc500db 100644
--- a/gcc/expr.c
+++ b/gcc/expr.c
@@ -11730,15 +11730,19 @@ string_constant (tree arg, tree *ptr_offset, tree *mem_size, tree *decl)
 	chartype = TREE_TYPE (chartype);
       /* Convert a char array to an empty STRING_CST having an array
 	 of the expected type.  */
-      if (!initsize)
-	  initsize = integer_zero_node;
+      if (INTEGRAL_TYPE_P (chartype)
+	  && TYPE_PRECISION (chartype) == TYPE_PRECISION (char_type_node))
+	{
+	  if (!initsize)
+	    initsize = integer_zero_node;
 
-      unsigned HOST_WIDE_INT size = tree_to_uhwi (initsize);
-      init = build_string_literal (size ? 1 : 0, "", chartype, size);
-      init = TREE_OPERAND (init, 0);
-      init = TREE_OPERAND (init, 0);
+	  unsigned HOST_WIDE_INT size = tree_to_uhwi (initsize);
+	  init = build_string_literal (size ? 1 : 0, "", chartype, size);
+	  init = TREE_OPERAND (init, 0);
+	  init = TREE_OPERAND (init, 0);
 
-      *ptr_offset = integer_zero_node;
+	  *ptr_offset = integer_zero_node;
+	}
     }
 
   if (decl)

commit 33fb1b3c73c9a33e9d6286bc281934bdfc4d7ae4
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Jul 29 00:16:54 2020 +0000

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 79ea60c1313..6a153ea0dca 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,23 @@
+2020-07-28  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2020-07-27  Martin Liska  <mliska@suse.cz>
+
+	PR tree-optimization/96058
+	* expr.c (string_constant): Build string_constant only
+	for a type that has same precision as char_type_node
+	and is an integral type.
+
+2020-07-28  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2020-07-28  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/96335
+	* calls.c (maybe_warn_rdwr_sizes): Add FNDECL and FNTYPE arguments,
+	instead of trying to rediscover them in the body.
+	(initialize_argument_information): Adjust caller.
+
 2020-07-27  Aaron Sawdey  <acsawdey@linux.ibm.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 75ec474bf8f..273bf0e001a 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200728
+20200729
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 0ad755d0bac..57c3820b31f 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2020-07-28  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2020-07-28  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/96335
+	* gcc.dg/pr96335.c: New test.
+
 2020-07-27  Mark Eggleston  <markeggleston@gcc.gnu.org>
 
 	Backported from master:

commit 412124203ec6dd7cb55798d01e29796c6383ecd8
Author: Iain Sandoe <iain@sandoe.co.uk>
Date:   Sun Jul 26 15:09:39 2020 +0100

    coroutines: co_returns are statements, not expressions.
    
    This corrects an error in the CO_RETURN_EXPR tree
    class.
    
    gcc/cp/ChangeLog:
    
            * cp-tree.def (CO_RETURN_EXPR): Correct the class
            to use tcc_statement.
    
    (cherry picked from commit 608832716e27ca356ee38d14ae30b3ab525884ea)

diff --git a/gcc/cp/cp-tree.def b/gcc/cp/cp-tree.def
index 1454802bf68..99851eb780f 100644
--- a/gcc/cp/cp-tree.def
+++ b/gcc/cp/cp-tree.def
@@ -594,9 +594,9 @@ DEFTREECODE (CO_YIELD_EXPR, "co_yield", tcc_expression, 2)
 /* The co_return expression is used to support coroutines.
 
    Op0 is the original expr, can be void (for use in diagnostics)
-   Op2 is the promise return_xxxx call for Op0. */
+   Op1 is the promise return_xxxx call for for the expression given. */
 
-DEFTREECODE (CO_RETURN_EXPR, "co_return", tcc_expression, 2)
+DEFTREECODE (CO_RETURN_EXPR, "co_return", tcc_statement, 2)
 
 /*
 Local variables:

commit f43a1b1d1718969423337190ddbbbc9037c67783
Author: Iain Sandoe <iain@sandoe.co.uk>
Date:   Sun Jul 19 18:39:21 2020 +0100

    coroutines: Correct frame capture of compiler temps [PR95591+4].
    
    When a full expression contains a co_await (or co_yield), this means
    that it might be suspended; which would destroy temporary variables
    (on a stack for example).  However the language guarantees that such
    temporaries are live until the end of the expression.
    
    In order to preserve this, we 'promote' temporaries where necessary
    so that they are saved in the coroutine frame (which allows them to
    remain live potentially until the frame is destroyed).  In addition,
    sub-expressions that produce control flow (such as TRUTH_AND/OR_IF
    or COND_EXPR) must be handled specifically to ensure that await
    expressions are properly expanded.
    
    This patch corrects two mistakes in which we were (a) failing to
    promote some temporaries and (b) we we failing to sequence DTORs for
    the captures properly. This manifests in a number of related (but not
    exact duplicate) PRs.
    
    The revised code collects the actions into one place and maps all the
    control flow into one form - a benefit of this is that co_returns are
    now expanded earlier (which provides an opportunity to address PR95517
    in some future patch).
    
    We replace a statement that contains await expression(s) with a bind
    scope that has a variable list describing the temporaries that have
    been 'promoted' and a statement list that contains a series of cleanup
    expressions for each of those.  Where we encounter nested conditional
    expressions, these are wrapped in a try-finally block with a guard var
    for each sub-expression variable that needs a DTOR.  The guards are all
    declared and initialized to false before the first conditional sub-
    expression.  The 'finally' block contains a series of if blocks (one
    per guard variable) enclosing the relevant DTOR.
    
    Variables listed in a bind scope in this manner are automatically moved
    to a coroutine frame version by existing code (so we re-use that rather
    than having a separate mechanism).
    
    gcc/cp/ChangeLog:
    
            PR c++/95591
            PR c++/95599
            PR c++/95823
            PR c++/95824
            PR c++/95895
            * coroutines.cc (struct coro_ret_data): Delete.
            (coro_maybe_expand_co_return): Delete.
            (co_return_expander): Delete.
            (expand_co_returns): Delete.
            (co_await_find_in_subtree): Remove unused name.
            (build_actor_fn): Remove unused parm, remove handling
            for co_return expansion.
            (register_await_info): Demote duplicate info message to a
            warning.
            (coro_make_frame_entry): Move closer to use site.
            (struct susp_frame_data): Add fields for final suspend label
            and a flag to indicate await expressions with initializers.
            (captures_temporary): Delete.
            (register_awaits): Remove unused code, update comments.
            (find_any_await): New.
            (tmp_target_expr_p): New.
            (struct interesting): New.
            (find_interesting_subtree): New.
            (struct var_nest_node): New.
            (flatten_await_stmt): New.
            (handle_nested_conditionals): New.
            (process_conditional): New.
            (replace_statement_captures): Rename to...
            (maybe_promote_temps): ... this.
            (maybe_promote_captured_temps): Delete.
            (analyze_expression_awaits): Check for await expressions with
            initializers.  Simplify handling for truth-and/or-if.
            (expand_one_truth_if): Simplify (map cases that need expansion
            to COND_EXPR).
            (await_statement_walker): Handle CO_RETURN_EXPR. Simplify the
            handling for truth-and/or-if expressions.
            (register_local_var_uses): Ensure that we create names in the
            implementation namespace.
            (morph_fn_to_coro): Add final suspend label to suspend frame
            callback data and remove it from the build_actor_fn call.
    
    gcc/testsuite/ChangeLog:
    
            PR c++/95591
            PR c++/95599
            PR c++/95823
            PR c++/95824
            PR c++/95895
            * g++.dg/coroutines/pr95591.C: New test.
            * g++.dg/coroutines/pr95599.C: New test.
            * g++.dg/coroutines/pr95823.C: New test.
            * g++.dg/coroutines/pr95824.C: New test.
    
    (cherry picked from commit 0f66b8486cea8668020e4bd48f261b760cb579be)

diff --git a/gcc/cp/coroutines.cc b/gcc/cp/coroutines.cc
index 451872b16de..548dcf078dd 100644
--- a/gcc/cp/coroutines.cc
+++ b/gcc/cp/coroutines.cc
@@ -1393,119 +1393,6 @@ replace_proxy (tree *here, int *do_subtree, void *d)
   return NULL_TREE;
 }
 
-/* Support for expansion of co_return statements.  */
-
-struct coro_ret_data
-{
-  tree promise_proxy;
-  tree real_promise;
-  tree fs_label;
-};
-
-/* If this is a coreturn statement (or one wrapped in a cleanup) then
-   return the list of statements to replace it.  */
-
-static tree
-coro_maybe_expand_co_return (tree co_ret_expr, coro_ret_data *data)
-{
-  /* Look inside <(void) (expr)> cleanup */
-  if (TREE_CODE (co_ret_expr) == CLEANUP_POINT_EXPR)
-    co_ret_expr = TREE_OPERAND (co_ret_expr, 0);
-
-  if (TREE_CODE (co_ret_expr) != CO_RETURN_EXPR)
-    return NULL_TREE;
-
-  location_t loc = EXPR_LOCATION (co_ret_expr);
-  tree expr = TREE_OPERAND (co_ret_expr, 0);
-  tree call = TREE_OPERAND (co_ret_expr, 1);
-  tree stmt_list = NULL;
-  if (expr && VOID_TYPE_P (TREE_TYPE (expr)))
-    {
-       /* [stmt.return.coroutine], 2.2 
-	  If expr is present and void, it is placed immediately before
-	  the call for return_void;  */
-      expr = maybe_cleanup_point_expr_void (expr);
-      append_to_statement_list (expr, &stmt_list);
-    }
-
-  /* Now replace the promise proxy with its real value.  */
-  proxy_replace p_data;
-  p_data.from = data->promise_proxy;
-  p_data.to = data->real_promise;
-  cp_walk_tree (&call, replace_proxy, &p_data, NULL);
-
-  /* The types of p.return_void and p.return_value are not explicitly stated
-     at least in n4835, it is expected that they will return void.  */
-  call = maybe_cleanup_point_expr_void (call);
-  append_to_statement_list (call, &stmt_list);
-  tree r = build1_loc (loc, GOTO_EXPR, void_type_node, data->fs_label);
-  append_to_statement_list (r, &stmt_list);
-  return stmt_list;
-}
-
-/* Callback that rewrites co_return as per [stmt.return.coroutine]
-   - for co_return;
-   { p.return_void (); goto final_suspend; }
-   - for co_return [void expr];
-   { expr; p.return_void(); goto final_suspend;}
-   - for co_return [non void expr];
-   { p.return_value(expr); goto final_suspend; }  */
-
-static tree
-co_return_expander (tree *stmt, int *do_subtree, void *d)
-{
-  coro_ret_data *data = (coro_ret_data *) d;
-
-  /* To avoid nesting statement lists, walk them and insert as needed.  */
-  if (TREE_CODE (*stmt) == STATEMENT_LIST)
-    {
-      tree_stmt_iterator i;
-      for (i = tsi_start (*stmt); !tsi_end_p (i); tsi_next (&i))
-	{
-	  tree *new_stmt = tsi_stmt_ptr (i);
-	  tree replace = coro_maybe_expand_co_return (*new_stmt, data);
-	  /* If we got something, it will be list and we want to splice
-	     it in.  */
-	  if (replace != NULL_TREE)
-	    {
-	      /* Splice it in ... */
-	      tsi_link_before (&i, replace, TSI_SAME_STMT);
-	      /* ... and delete what we expanded.  */
-	      tsi_delink (&i);
-	      /* Maybe, even likely, we replaced the last in the list.  */
-	      if (tsi_end_p (i))
-		break;
-	    }
-	  else /* Continue the walk.  */
-	    cp_walk_tree (new_stmt, co_return_expander, d, NULL);
-	}
-      *do_subtree = 0; /* Done subtrees.  */
-    }
-  else
-    {
-      /* We might have a single co_return statement, in which case, we do
-	 have to replace it with a list.  */
-      tree replace = coro_maybe_expand_co_return (*stmt, data);
-      if (replace != NULL_TREE)
-	{
-	  *stmt = replace;
-	  *do_subtree = 0; /* Done here.  */
-	}
-    }
-  return NULL_TREE;
-}
-
-/* Walk the original function body, rewriting co_returns.  */
-
-static tree
-expand_co_returns (tree *fnbody, tree promise_proxy, tree promise,
-		   tree fs_label)
-{
-  coro_ret_data data = {promise_proxy, promise, fs_label};
-  cp_walk_tree (fnbody, co_return_expander, &data, NULL);
-  return *fnbody;
-}
-
 /* Support for expansion of co_await statements.  */
 
 struct coro_aw_data
@@ -1530,7 +1417,7 @@ struct coro_aw_data
    awaits.  */
 
 static tree
-co_await_find_in_subtree (tree *stmt, int *do_subtree ATTRIBUTE_UNUSED, void *d)
+co_await_find_in_subtree (tree *stmt, int *, void *d)
 {
   tree **p = (tree **) d;
   if (TREE_CODE (*stmt) == CO_AWAIT_EXPR)
@@ -1895,7 +1782,9 @@ transform_await_wrapper (tree *stmt, int *do_subtree, void *d)
       && DECL_CONTEXT (*stmt) != xform->actor_fn)
     DECL_CONTEXT (*stmt) = xform->actor_fn;
 
-  if (TREE_CODE (*stmt) != CO_AWAIT_EXPR && TREE_CODE (*stmt) != CO_YIELD_EXPR)
+  /* We should have already lowered co_yields to their co_await.  */
+  gcc_checking_assert (TREE_CODE (*stmt) != CO_YIELD_EXPR);
+  if (TREE_CODE (*stmt) != CO_AWAIT_EXPR)
     return NULL_TREE;
 
   tree await_expr = *stmt;
@@ -2091,8 +1980,7 @@ static void
 build_actor_fn (location_t loc, tree coro_frame_type, tree actor, tree fnbody,
 		tree orig, hash_map<tree, param_info> *param_uses,
 		hash_map<tree, local_var_info> *local_var_uses,
-		vec<tree, va_gc> *param_dtor_list,
-		tree fs_label, tree resume_fn_field,
+		vec<tree, va_gc> *param_dtor_list, tree resume_fn_field,
 		unsigned body_count, tree frame_size)
 {
   verify_stmt_tree (fnbody);
@@ -2308,9 +2196,6 @@ build_actor_fn (location_t loc, tree coro_frame_type, tree actor, tree fnbody,
   await_xform_data xform
     = {actor, actor_frame, promise_proxy, ap, self_h_proxy, ash};
 
-  /* Expand co_returns in the saved function body  */
-  fnbody = expand_co_returns (&fnbody, promise_proxy, ap, fs_label);
-
   /* Transform the await expressions in the function body.  Only do each
      await tree once!  */
   hash_set<tree> pset;
@@ -2646,7 +2531,7 @@ register_await_info (tree await_expr, tree aw_type, tree aw_nam)
     = suspend_points->get_or_insert (await_expr, &seen);
   if (seen)
     {
-      error_at (EXPR_LOCATION (await_expr), "duplicate info for %qE",
+      warning_at (EXPR_LOCATION (await_expr), 0, "duplicate info for %qE",
 		await_expr);
       return false;
     }
@@ -2655,26 +2540,14 @@ register_await_info (tree await_expr, tree aw_type, tree aw_nam)
   return true;
 }
 
-/* Small helper for the repetitive task of adding a new field to the coro
-   frame type.  */
-
-static tree
-coro_make_frame_entry (tree *field_list, const char *name, tree fld_type,
-		       location_t loc)
-{
-  tree id = get_identifier (name);
-  tree decl = build_decl (loc, FIELD_DECL, id, fld_type);
-  DECL_CHAIN (decl) = *field_list;
-  *field_list = decl;
-  return id;
-}
-
 /* This data set is used when analyzing statements for await expressions.  */
+
 struct susp_frame_data
 {
   /* Function-wide.  */
   tree *field_list; /* The current coroutine frame field list.  */
   tree handle_type; /* The self-handle type for this coroutine.  */
+  tree fs_label;    /* The destination for co_returns.  */
   vec<tree, va_gc> *block_stack; /* Track block scopes.  */
   vec<tree, va_gc> *bind_stack;  /* Track current bind expr.  */
   unsigned await_number;	 /* Which await in the function.  */
@@ -2686,275 +2559,575 @@ struct susp_frame_data
   unsigned saw_awaits;		 /* Count of awaits in this statement  */
   bool captures_temporary;	 /* This expr captures temps by ref.  */
   bool needs_truth_if_exp;	 /* We must expand a truth_if expression.  */
+  bool has_awaiter_init;	 /* We must handle initializing an awaiter.  */
 };
 
-/* Walk the sub-tree looking for call expressions that both capture
-   references and have compiler-temporaries as parms.  */
+/* If this is an await expression, then count it (both uniquely within the
+   function and locally within a single statement).  */
+
+static tree
+register_awaits (tree *stmt, int *, void *d)
+{
+  tree aw_expr = *stmt;
+
+  /* We should have already lowered co_yields to their co_await.  */
+  gcc_checking_assert (TREE_CODE (aw_expr) != CO_YIELD_EXPR);
+
+  if (TREE_CODE (aw_expr) != CO_AWAIT_EXPR)
+    return NULL_TREE;
+
+  /* Count how many awaits the current expression contains.  */
+  susp_frame_data *data = (susp_frame_data *) d;
+  data->saw_awaits++;
+  /* Each await suspend context is unique, this is a function-wide value.  */
+  data->await_number++;
+
+  /* Awaitables should either be user-locals or promoted to coroutine frame
+     entries at this point, and their initializers should have been broken
+     out.  */
+  tree aw = TREE_OPERAND (aw_expr, 1);
+  gcc_checking_assert (!TREE_OPERAND (aw_expr, 2));
 
+  tree aw_field_type = TREE_TYPE (aw);
+  tree aw_field_nam = NULL_TREE;
+  register_await_info (aw_expr, aw_field_type, aw_field_nam);
+
+  /* Rewrite target expressions on the await_suspend () to remove extraneous
+     cleanups for the awaitables, which are now promoted to frame vars and
+     managed via that.  */
+  tree v = TREE_OPERAND (aw_expr, 3);
+  tree o = TREE_VEC_ELT (v, 1);
+  if (TREE_CODE (o) == TARGET_EXPR)
+    TREE_VEC_ELT (v, 1) = get_target_expr (TREE_OPERAND (o, 1));
+  return NULL_TREE;
+}
+
+/* There are cases where any await expression is relevant.  */
 static tree
-captures_temporary (tree *stmt, int *do_subtree, void *d)
+find_any_await (tree *stmt, int *dosub, void *d)
 {
-  /* Stop recursing if we see an await expression, the subtrees
-     of that will be handled when it is processed.  */
-  if (TREE_CODE (*stmt) == CO_AWAIT_EXPR || TREE_CODE (*stmt) == CO_YIELD_EXPR)
+  if (TREE_CODE (*stmt) == CO_AWAIT_EXPR)
     {
-      *do_subtree = 0;
-      return NULL_TREE;
+      *dosub = 0; /* We don't need to consider this any further.  */
+      tree **p = (tree **) d;
+      *p = stmt;
+      return *stmt;
     }
+  return NULL_TREE;
+}
 
-  /* We're only interested in calls.  */
-  if (TREE_CODE (*stmt) != CALL_EXPR)
-    return NULL_TREE;
+static bool
+tmp_target_expr_p (tree t)
+{
+  if (TREE_CODE (t) != TARGET_EXPR)
+    return false;
+  tree v = TREE_OPERAND (t, 0);
+  if (!DECL_ARTIFICIAL (v))
+    return false;
+  if (DECL_NAME (v))
+    return false;
+  return true;
+}
+
+/* Structure to record sub-expressions that need to be handled by the
+   statement flattener.  */
+
+struct coro_interesting_subtree
+{
+  tree* entry;
+  hash_set<tree> *temps_used;
+};
 
-  /* Does this call capture references?
-     Strip the ADDRESS_EXPR to get the fn decl and inspect it.  */
-  tree fn = TREE_OPERAND (CALL_EXPR_FN (*stmt), 0);
-  bool is_meth = TREE_CODE (TREE_TYPE (fn)) == METHOD_TYPE;
-  tree arg = TYPE_ARG_TYPES (TREE_TYPE (fn));
-  unsigned offset = 3;
-  for (unsigned anum = 0; arg != NULL; arg = TREE_CHAIN (arg), anum++)
+/* tree-walk callback that returns the first encountered sub-expression of
+   a kind that needs to be handled specifically by the statement flattener.  */
+
+static tree
+find_interesting_subtree (tree *expr_p, int *dosub, void *d)
+{
+  tree expr = *expr_p;
+  coro_interesting_subtree *p = (coro_interesting_subtree *)d;
+  if (TREE_CODE (expr) == CO_AWAIT_EXPR)
     {
-      tree parm_type = TREE_VALUE (arg);
-      if (anum == 0 && is_meth && INDIRECT_TYPE_P (parm_type))
+      *dosub = 0; /* We don't need to consider this any further.  */
+      if (TREE_OPERAND (expr, 2))
 	{
-	  /* Account for 'this' when the fn is a method.  Unless it
-	     belongs to a CTOR or DTOR.  */
-	  if (DECL_CONSTRUCTOR_P (fn) || DECL_DESTRUCTOR_P (fn))
-	    continue;
+	  p->entry = expr_p;
+	  return expr;
 	}
-      else if (!TYPE_REF_P (parm_type))
-	/* If it's not a reference, we don't care.  */
-	continue;
+    }
+  else if (tmp_target_expr_p (expr)
+	   && !p->temps_used->contains (expr))
+    {
+      p->entry = expr_p;
+      return expr;
+    }
 
-      /* Fetch the value presented to the fn.  */
-      tree parm = TREE_OPERAND (*stmt, anum + offset);
+  return NULL_TREE;
+}
 
-      while (TREE_CODE (parm) == NOP_EXPR)
-	parm = TREE_OPERAND (parm, 0);
+/* Node for a doubly-linked list of promoted variables and their
+   initializers.  When the initializer is a conditional expression
+   the 'then' and 'else' clauses are represented by a linked list
+   attached to then_cl and else_cl respectively.  */
 
-      /* We only care if we're taking the addr of a temporary.  */
-      if (TREE_CODE (parm) != ADDR_EXPR)
-	continue;
+struct var_nest_node
+{
+  var_nest_node () = default;
+  var_nest_node (tree v, tree i, var_nest_node *p, var_nest_node *n)
+    : var(v), init(i), prev(p), next(n)
+    {
+      if (p)
+	p->next = this;
+      if (n)
+	n->prev = this;
+    }
+  tree var;
+  tree init;
+  var_nest_node *prev;
+  var_nest_node *next;
+  var_nest_node *then_cl;
+  var_nest_node *else_cl;
+};
 
-      parm = TREE_OPERAND (parm, 0);
+/* This is called for single statements from the co-await statement walker.
+   It checks to see if the statement contains any initializers for awaitables
+   and if any of these capture items by reference.  */
 
-      /* In case of component_ref, we need to capture the object of base
-	 class as if it is temporary object.  There are two possibilities:
-	 (*base).field and base->field.  */
-      while (TREE_CODE (parm) == COMPONENT_REF)
+static void
+flatten_await_stmt (var_nest_node *n, hash_set<tree> *promoted,
+		    hash_set<tree> *temps_used, tree *replace_in)
+{
+  bool init_expr = false;
+  switch (TREE_CODE (n->init))
+    {
+      default: break;
+      /* Compound expressions must be flattened specifically.  */
+      case COMPOUND_EXPR:
 	{
-	  parm = TREE_OPERAND (parm, 0);
-	  if (TREE_CODE (parm) == INDIRECT_REF)
-	    parm = TREE_OPERAND (parm, 0);
-	  STRIP_NOPS (parm);
+	  tree first = TREE_OPERAND (n->init, 0);
+	  n->init = TREE_OPERAND (n->init, 1);
+	  var_nest_node *ins
+	    = new var_nest_node(NULL_TREE, first, n->prev, n);
+	  /* The compiler (but not the user) can generate temporaries with
+	     uses in the second arm of a compound expr.  */
+	  flatten_await_stmt (ins, promoted, temps_used, &n->init);
+	  flatten_await_stmt (n, promoted, temps_used, NULL);
+	  /* The two arms have been processed separately.  */
+	  return;
 	}
+	break;
+      /* Handle conditional expressions.  */
+      case INIT_EXPR:
+	init_expr = true;
+	/* FALLTHROUGH */
+      case MODIFY_EXPR:
+	{
+	  tree old_expr = TREE_OPERAND (n->init, 1);
+	  if (TREE_CODE (old_expr) == COMPOUND_EXPR)
+	    {
+	      tree first = TREE_OPERAND (old_expr, 0);
+	      TREE_OPERAND (n->init, 1) = TREE_OPERAND (old_expr, 1);
+	      var_nest_node *ins
+		= new var_nest_node(NULL_TREE, first, n->prev, n);
+	      flatten_await_stmt (ins, promoted, temps_used,
+				  &TREE_OPERAND (n->init, 1));
+	      flatten_await_stmt (n, promoted, temps_used, NULL);
+	      return;
+	    }
+	  if (TREE_CODE (old_expr) != COND_EXPR)
+	    break;
+	  /* Reconstruct x = t ? y : z;
+	     as (void) t ? x = y : x = z;  */
+	  tree var = TREE_OPERAND (n->init, 0);
+	  tree var_type = TREE_TYPE (var);
+	  tree cond = COND_EXPR_COND (old_expr);
+	  /* We are allowed a void type throw in one or both of the cond
+	     expr arms.  */
+	  tree then_cl = COND_EXPR_THEN (old_expr);
+	  if (!VOID_TYPE_P (TREE_TYPE (then_cl)))
+	    {
+	      gcc_checking_assert (TREE_CODE (then_cl) != STATEMENT_LIST);
+	      then_cl
+		= build2 (init_expr ? INIT_EXPR : MODIFY_EXPR, var_type,
+			  var, then_cl);
+	    }
+	  tree else_cl = COND_EXPR_ELSE (old_expr);
+	  if (!VOID_TYPE_P (TREE_TYPE (else_cl)))
+	    {
+	      gcc_checking_assert (TREE_CODE (then_cl) != STATEMENT_LIST);
+	      else_cl
+		= build2 (init_expr ? INIT_EXPR : MODIFY_EXPR, var_type,
+			  var, else_cl);
+	    }
+	  n->init = build3 (COND_EXPR, var_type, cond, then_cl, else_cl);
+	}
+	/* FALLTHROUGH */
+      case COND_EXPR:
+	{
+	  tree *found;
+	  tree cond = COND_EXPR_COND (n->init);
+	  /* If the condition contains an await expression, then we need to
+	     set that first and use a separate var.  */
+	  if (cp_walk_tree (&cond, find_any_await, &found, NULL))
+	    {
+	      tree cond_type = TREE_TYPE (cond);
+	      tree cond_var  = build_lang_decl (VAR_DECL, NULL_TREE, cond_type);
+	      DECL_ARTIFICIAL (cond_var) = true;
+	      layout_decl (cond_var, 0);
+	      gcc_checking_assert (!TYPE_NEEDS_CONSTRUCTING (cond_type));
+	      cond = build2 (INIT_EXPR, cond_type, cond_var, cond);
+	      var_nest_node *ins
+		= new var_nest_node (cond_var, cond, n->prev, n);
+	      COND_EXPR_COND (n->init) = cond_var;
+	      flatten_await_stmt (ins, promoted, temps_used, NULL);
+	    }
 
-      /* This isn't a temporary.  */
-      if ((VAR_P (parm)
-	   && (!DECL_ARTIFICIAL (parm) || DECL_HAS_VALUE_EXPR_P (parm)))
-	  || TREE_CODE (parm) == PARM_DECL
-	  || TREE_CODE (parm) == NON_LVALUE_EXPR)
-	continue;
-
-      if (TREE_CODE (parm) == TARGET_EXPR)
+	  n->then_cl
+	    = new var_nest_node (n->var, COND_EXPR_THEN (n->init), NULL, NULL);
+	  n->else_cl
+	    = new var_nest_node (n->var, COND_EXPR_ELSE (n->init), NULL, NULL);
+	  flatten_await_stmt (n->then_cl, promoted, temps_used, NULL);
+	  /* Point to the start of the flattened code.  */
+	  while (n->then_cl->prev)
+	    n->then_cl = n->then_cl->prev;
+	  flatten_await_stmt (n->else_cl, promoted, temps_used, NULL);
+	  while (n->else_cl->prev)
+	    n->else_cl = n->else_cl->prev;
+	  return;
+	}
+	break;
+    }
+  coro_interesting_subtree v = { NULL, temps_used };
+  tree t = cp_walk_tree (&n->init, find_interesting_subtree, (void *)&v, NULL);
+  if (!t)
+    return;
+  switch (TREE_CODE (t))
+    {
+      default: break;
+      case CO_AWAIT_EXPR:
 	{
-	  /* We're taking the address of a temporary and using it as a ref.  */
-	  tree tvar = TREE_OPERAND (parm, 0);
-	  gcc_checking_assert (DECL_ARTIFICIAL (tvar));
-
-	  susp_frame_data *data = (susp_frame_data *) d;
-	  data->captures_temporary = true;
-	  /* Record this one so we don't duplicate, and on the first
-	     occurrence note the target expr to be replaced.  */
-	  if (!data->captured_temps.add (tvar))
-	    vec_safe_push (data->to_replace, parm);
-	  /* Now see if the initializer contains any more cases.  */
-	  hash_set<tree> visited;
-	  tree res = cp_walk_tree (&TREE_OPERAND (parm, 1),
-				   captures_temporary, d, &visited);
-	  if (res)
-	    return res;
-	  /* Otherwise, we're done with sub-trees for this.  */
+	  /* Await expressions with initializers have a compiler-temporary
+	     as the awaitable.  'promote' this.  */
+	  tree var = TREE_OPERAND (t, 1);
+	  bool already_present = promoted->add (var);
+	  gcc_checking_assert (!already_present);
+	  tree init = TREE_OPERAND (t, 2);
+	  switch (TREE_CODE (init))
+	    {
+	      default: break;
+	      case INIT_EXPR:
+	      case MODIFY_EXPR:
+		{
+		  tree inner = TREE_OPERAND (init, 1);
+		  /* We can have non-lvalue-expressions here, but when we see
+		     a target expression, mark it as already used.  */
+		  if (TREE_CODE (inner) == TARGET_EXPR)
+		    {
+		      temps_used->add (inner);
+		      gcc_checking_assert
+			(TREE_CODE (TREE_OPERAND (inner, 1)) != COND_EXPR);
+		    }
+		}
+		break;
+	      case CALL_EXPR:
+		/* If this is a call and not a CTOR, then we didn't expect it.  */
+		gcc_checking_assert
+		  (DECL_CONSTRUCTOR_P (TREE_OPERAND (CALL_EXPR_FN (init), 0)));
+		break;
+	    }
+	  var_nest_node *ins = new var_nest_node (var, init, n->prev, n);
+	  TREE_OPERAND (t, 2) = NULL_TREE;
+	  flatten_await_stmt (ins, promoted, temps_used, NULL);
+	  flatten_await_stmt (n, promoted, temps_used, NULL);
+	  return;
 	}
-      else if (TREE_CODE (parm) == CO_AWAIT_EXPR)
+	break;
+      case TARGET_EXPR:
 	{
-	  /* CO_AWAIT expressions behave in a similar manner to target
-	     expressions when the await_resume call is contained in one.  */
-	  tree awr = TREE_OPERAND (parm, 3); /* call vector.  */
-	  awr = TREE_VEC_ELT (awr, 2); /* resume call.  */
-	  if (TREE_CODE (awr) == TARGET_EXPR)
+	  /* We have a temporary; promote it.  */
+	  tree init = t;
+	  temps_used->add (init);
+	  tree var_type = TREE_TYPE (init);
+	  char *buf = xasprintf ("D.%d", DECL_UID (TREE_OPERAND (init, 0)));
+	  tree var = build_lang_decl (VAR_DECL, get_identifier (buf), var_type);
+	  DECL_ARTIFICIAL (var) = true;
+	  free (buf);
+	  bool already_present = promoted->add (var);
+	  gcc_checking_assert (!already_present);
+	  tree inner = TREE_OPERAND (init, 1);
+	  gcc_checking_assert (TREE_CODE (inner) != COND_EXPR);
+	  if (TYPE_NEEDS_CONSTRUCTING (var_type))
 	    {
-	      tree tvar = TREE_OPERAND (awr, 0);
-	      gcc_checking_assert (DECL_ARTIFICIAL (tvar));
-
-	      susp_frame_data *data = (susp_frame_data *) d;
-	      data->captures_temporary = true;
-	      /* Use this as a place-holder.  */
-	      if (!data->captured_temps.add (tvar))
-		vec_safe_push (data->to_replace, parm);
+	      releasing_vec p_in (make_tree_vector_single (init));
+	      init = build_special_member_call (var, complete_ctor_identifier,
+						&p_in, var_type, LOOKUP_NORMAL,
+						tf_warning_or_error);
 	    }
-	/* We will walk the sub-trees of this co_await separately.  */
+	  else
+	    init = build2 (INIT_EXPR, var_type, var, init);
+	  var_nest_node *ins
+	    = new var_nest_node (var, init, n->prev, n);
+	  /* We have to replace the target expr... */
+	  proxy_replace pr = {TREE_OPERAND (t, 0), var};
+	  *v.entry = var;
+	  /* ... and any uses of its var.  */
+	  cp_walk_tree (&n->init, replace_proxy, &pr, NULL);
+	  /* Compiler-generated temporaries can also have uses in following
+	     arms of compound expressions, which will be listed in 'replace_in'
+	     if present.  */
+	  if (replace_in)
+	    cp_walk_tree (replace_in, replace_proxy, &pr, NULL);
+	  flatten_await_stmt (ins, promoted, temps_used, NULL);
+	  flatten_await_stmt (n, promoted, temps_used, NULL);
+	  return;
 	}
-      else
-	gcc_unreachable ();
+	break;
     }
-  /* As far as it's necessary, we've walked the subtrees of the call
-     expr.  */
-  *do_subtree = 0;
-  return NULL_TREE;
 }
 
-/* If this is an await, then register it and decide on what coro
-   frame storage is needed.
-   If this is a co_yield (which embeds an await), drop the yield
-   and record the await (the yield was kept for diagnostics only).  */
+/* Helper for 'process_conditional' that handles recursion into nested
+   conditionals.  */
 
-static tree
-register_awaits (tree *stmt, int *do_subtree ATTRIBUTE_UNUSED, void *d)
+static void
+handle_nested_conditionals (var_nest_node *n, vec<tree>& list,
+			    hash_map<tree, tree>& map)
 {
-  susp_frame_data *data = (susp_frame_data *) d;
+  do
+    {
+      if (n->var && DECL_NAME (n->var))
+	{
+	  list.safe_push (n->var);
+	  if (TYPE_HAS_NONTRIVIAL_DESTRUCTOR (TREE_TYPE (n->var)))
+	    {
+	      bool existed;
+	      tree& flag = map.get_or_insert (n->var, &existed);
+	      if (!existed)
+		{
+		  /* We didn't see this var before and it needs a DTOR, so
+		     build a guard variable for it.  */
+		  char *nam
+		    = xasprintf ("%s_guard",
+				 IDENTIFIER_POINTER (DECL_NAME (n->var)));
+		  flag = build_lang_decl (VAR_DECL, get_identifier (nam),
+					  boolean_type_node);
+		  free (nam);
+		  DECL_ARTIFICIAL (flag) = true;
+		}
+
+	      /* The initializer for this variable is replaced by a compound
+		 expression that performs the init and then records that the
+		 variable is live (and the DTOR should be run at the scope
+		 exit.  */
+	      tree set_flag = build2 (INIT_EXPR, boolean_type_node,
+				      flag, boolean_true_node);
+	      n->init
+		= build2 (COMPOUND_EXPR, boolean_type_node, n->init, set_flag);
+	}
+	}
+      if (TREE_CODE (n->init) == COND_EXPR)
+	{
+	  tree new_then = push_stmt_list ();
+	  handle_nested_conditionals (n->then_cl, list, map);
+	  new_then = pop_stmt_list (new_then);
+	  tree new_else = push_stmt_list ();
+	  handle_nested_conditionals (n->else_cl, list, map);
+	  new_else = pop_stmt_list (new_else);
+	  tree new_if
+	    = build4 (IF_STMT, void_type_node, COND_EXPR_COND (n->init),
+		      new_then, new_else, NULL_TREE);
+	  add_stmt (new_if);
+	}
+      else
+	finish_expr_stmt (n->init);
+      n = n->next;
+    } while (n);
+}
 
-  if (TREE_CODE (*stmt) != CO_AWAIT_EXPR && TREE_CODE (*stmt) != CO_YIELD_EXPR)
-    return NULL_TREE;
+/* helper for 'maybe_promote_temps'.
 
-  tree aw_expr = *stmt;
-  location_t aw_loc = EXPR_LOCATION (aw_expr); /* location of the co_xxxx.  */
-  /* co_yield is syntactic sugar, re-write it to co_await.  */
-  if (TREE_CODE (aw_expr) == CO_YIELD_EXPR)
+   When we have a conditional expression which might embed await expressions
+   and/or promoted variables, we need to handle it appropriately.
+
+   The linked lists for the 'then' and 'else' clauses in a conditional node
+   identify the promoted variables (but these cannot be wrapped in a regular
+   cleanup).
+
+   So recurse through the lists and build up a composite list of captured vars.
+   Declare these and any guard variables needed to decide if a DTOR should be
+   run.  Then embed the conditional into a try-finally expression that handles
+   running each DTOR conditionally on its guard variable.  */
+
+static void
+process_conditional (var_nest_node *n, tree& vlist)
+{
+  tree init = n->init;
+  hash_map<tree, tree> var_flags;
+  vec<tree> var_list = vNULL;
+  tree new_then = push_stmt_list ();
+  handle_nested_conditionals (n->then_cl, var_list, var_flags);
+  new_then = pop_stmt_list (new_then);
+  tree new_else = push_stmt_list ();
+  handle_nested_conditionals (n->else_cl, var_list, var_flags);
+  new_else = pop_stmt_list (new_else);
+  /* Declare the vars.  There are two loops so that the boolean flags are
+     grouped in the frame.  */
+  for (unsigned i = 0; i < var_list.length(); i++)
     {
-      aw_expr = TREE_OPERAND (aw_expr, 1);
-      *stmt = aw_expr;
+      tree var = var_list[i];
+      DECL_CHAIN (var) = vlist;
+      vlist = var;
+      add_decl_expr (var);
     }
-
-  /* If the awaitable is a parm or a local variable, then we already have
-     a frame copy, so don't make a new one.  */
-  tree aw = TREE_OPERAND (aw_expr, 1);
-  tree o = TREE_OPERAND (aw_expr, 2); /* Initializer for the frame var.  */
-  /* If we have an initializer, then the var is a temp and we need to make
-     it in the frame.  */
-  tree aw_field_type = TREE_TYPE (aw);
-  tree aw_field_nam = NULL_TREE;
-  if (o)
+  /* Define the guard flags for variables that need a DTOR.  */
+  for (unsigned i = 0; i < var_list.length(); i++)
+    {
+      tree *flag = var_flags.get (var_list[i]);
+      if (flag)
+	{
+	  DECL_INITIAL (*flag) = boolean_false_node;
+	  DECL_CHAIN (*flag) = vlist;
+	  vlist = *flag;
+	  add_decl_expr (*flag);
+	}
+    }
+  tree new_if
+    = build4 (IF_STMT, void_type_node, COND_EXPR_COND (init),
+	      new_then, new_else, NULL_TREE);
+  /* Build a set of conditional DTORs.  */
+  tree final_actions = push_stmt_list ();
+  while (!var_list.is_empty())
     {
-      /* The required field has the same type as the proxy stored in the
-	 await expr.  */
-      char *nam = xasprintf ("__aw_s.%d", data->await_number);
-      aw_field_nam = coro_make_frame_entry (data->field_list, nam,
-					    aw_field_type, aw_loc);
-      free (nam);
-
-      /* If the init is a target expression, then we need to remake it to
-	 strip off any extra cleanups added.  */
-      if (o && TREE_CODE (o) == TARGET_EXPR)
-	TREE_OPERAND (aw_expr, 2) = get_target_expr (TREE_OPERAND (o, 1));
+      tree var = var_list.pop ();
+      tree *flag = var_flags.get (var);
+      if (!flag)
+	continue;
+      tree var_type = TREE_TYPE (var);
+      tree cleanup
+	= build_special_member_call (var, complete_dtor_identifier,
+				     NULL, var_type, LOOKUP_NORMAL,
+				     tf_warning_or_error);
+      tree cond_cleanup = begin_if_stmt ();
+      finish_if_stmt_cond (*flag, cond_cleanup);
+      finish_expr_stmt (cleanup);
+      finish_then_clause (cond_cleanup);
+      finish_if_stmt (cond_cleanup);
     }
+  final_actions = pop_stmt_list (final_actions);
+  tree try_finally
+    = build2 (TRY_FINALLY_EXPR, void_type_node, new_if, final_actions);
+  add_stmt (try_finally);
+}
 
-  tree v = TREE_OPERAND (aw_expr, 3);
-  o = TREE_VEC_ELT (v, 1);
-  if (TREE_CODE (o) == TARGET_EXPR)
-    TREE_VEC_ELT (v, 1) = get_target_expr (TREE_OPERAND (o, 1));
+/* Given *STMT, that contains at least one await expression.
 
-  register_await_info (aw_expr, aw_field_type, aw_field_nam);
+   The full expression represented in the original source code will contain
+   suspension points, but it is still required that the lifetime of temporary
+   values extends to the end of the expression.
 
-  /* Count how many awaits the current expression contains.  */
-  data->saw_awaits++;
-  /* Each await suspend context is unique, this is a function-wide value.  */
-  data->await_number++;
-
-  /* We now need to know if to take special action on lifetime extension
-     of temporaries captured by reference.  This can only happen if such
-     a case appears in the initializer for the awaitable.  The callback
-     records captured temporaries including subtrees of initializers.  */
-  hash_set<tree> visited;
-  tree res = cp_walk_tree (&TREE_OPERAND (aw_expr, 2), captures_temporary, d,
-			   &visited);
-  return res;
-}
+   We already have a mechanism to 'promote' user-authored local variables
+   to a coroutine frame counterpart (which allows explicit management of the
+   lifetime across suspensions).  The transform here re-writes STMT into
+   a bind expression, promotes temporary values into local variables in that
+   and flattens the statement into a series of cleanups.
 
-/* The gimplifier correctly extends the lifetime of temporaries captured
-   by reference (per. [class.temporary] (6.9) "A temporary object bound
-   to a reference parameter in a function call persists until the completion
-   of the full-expression containing the call").  However, that is not
-   sufficient to work across a suspension - and we need to promote such
-   temporaries to be regular vars that will then get a coro frame slot.
-   We don't want to incur the effort of checking for this unless we have
-   an await expression in the current full expression.  */
-
-/* This takes the statement which contains one or more temporaries that have
-   been 'captured' by reference in the initializer(s) of co_await(s).
-   The statement is replaced by a bind expression that has actual variables
-   to replace the temporaries.  These variables will be added to the coro-
-   frame in the same manner as user-authored ones.  */
+   Conditional expressions are re-written to regular 'if' statements.
+   The cleanups for variables initialized inside a conditional (including
+   nested cases) are wrapped in a try-finally clause, with guard variables
+   to determine which DTORs need to be run.  */
 
-static void
-replace_statement_captures (tree *stmt, void *d)
+static tree
+maybe_promote_temps (tree *stmt, void *d)
 {
   susp_frame_data *awpts = (susp_frame_data *) d;
+
   location_t sloc = EXPR_LOCATION (*stmt);
-  tree aw_bind
-    = build3_loc (sloc, BIND_EXPR, void_type_node, NULL, NULL, NULL);
-
-  /* Any cleanup point expression might no longer be necessary, since we
-     are removing one or more temporaries.  */
-  tree aw_statement_current = *stmt;
-  if (TREE_CODE (aw_statement_current) == CLEANUP_POINT_EXPR)
-    aw_statement_current = TREE_OPERAND (aw_statement_current, 0);
-
-  /* Collected the scope vars we need move the temps to regular. */
-  tree aw_bind_body = push_stmt_list ();
-  tree varlist = NULL_TREE;
-  int vnum = -1;
-  while (!awpts->to_replace->is_empty ())
+  tree expr = *stmt;
+  /* Strip off uninteresting wrappers.  */
+  if (TREE_CODE (expr) == CLEANUP_POINT_EXPR)
+    expr = TREE_OPERAND (expr, 0);
+  if (TREE_CODE (expr) == EXPR_STMT)
+    expr = EXPR_STMT_EXPR (expr);
+  if (TREE_CODE (expr) == CONVERT_EXPR
+      && VOID_TYPE_P (TREE_TYPE (expr)))
+    expr = TREE_OPERAND (expr, 0);
+  STRIP_NOPS (expr);
+
+  /* We walk the statement trees, flattening it into an ordered list of
+     variables with initializers and fragments corresponding to compound
+     expressions, truth or/and if and ternary conditionals.  Conditional
+     expressions carry a nested list of fragments for the then and else
+     clauses.  We anchor to the 'bottom' of the fragment list; we will write
+     a cleanup nest with one shell for each variable initialized.  */
+  var_nest_node *root = new var_nest_node (NULL_TREE, expr, NULL, NULL);
+  /* Check to see we didn't promote one twice.  */
+  hash_set<tree> promoted_vars;
+  hash_set<tree> used_temps;
+  flatten_await_stmt (root, &promoted_vars, &used_temps, NULL);
+
+  gcc_checking_assert (root->next == NULL);
+  tree vlist = NULL_TREE;
+  var_nest_node *t = root;
+  gcc_checking_assert (!t->var);
+  /* We build the bind scope expression from the bottom-up.
+     EXPR_LIST holds the inner expression nest at the current cleanup
+     level (becoming the final expression list when we've exhausted the
+     number of sub-expression fragments).  */
+  tree expr_list = NULL_TREE;
+  do
     {
-      tree to_replace = awpts->to_replace->pop ();
-      tree orig_temp;
-      if (TREE_CODE (to_replace) == CO_AWAIT_EXPR)
+      tree new_list = push_stmt_list ();
+      /* When we have a promoted variable, then add that to the bind scope
+	 and initialize it.  When there's no promoted variable, we just need
+	 to run the initializer.
+	 If the initializer is a conditional expression, we need to collect
+	 and declare any promoted variables nested within it.  DTORs for such
+	 variables must be run conditionally too.  */
+      if (t->var && DECL_NAME (t->var))
 	{
-	  orig_temp = TREE_OPERAND (to_replace, 3);
-	  orig_temp = TREE_VEC_ELT (orig_temp, 2);
-	  orig_temp = TREE_OPERAND (orig_temp, 0);
+	  tree var = t->var;
+	  DECL_CHAIN (var) = vlist;
+	  vlist = var;
+	  add_decl_expr (var);
+	  if (TREE_CODE (t->init) == COND_EXPR)
+	    process_conditional (t, vlist);
+	  else
+	    finish_expr_stmt (t->init);
+	  tree var_type = TREE_TYPE (var);
+	  if (TYPE_HAS_NONTRIVIAL_DESTRUCTOR (var_type))
+	    {
+	      tree cleanup
+		= build_special_member_call (var, complete_dtor_identifier,
+					     NULL, var_type, LOOKUP_NORMAL,
+					     tf_warning_or_error);
+	      tree cl = build_stmt (sloc, CLEANUP_STMT, expr_list, cleanup, var);
+	      add_stmt (cl); /* push this onto the level above.  */
+	    }
+	  else if (expr_list)
+	    add_stmt (expr_list);
+	  else
+	    gcc_unreachable ();
 	}
       else
-	orig_temp = TREE_OPERAND (to_replace, 0);
-
-      tree var_type = TREE_TYPE (orig_temp);
-      gcc_checking_assert (same_type_p (TREE_TYPE (to_replace), var_type));
-      /* Build a variable to hold the captured value, this will be included
-	 in the frame along with any user-authored locals.  */
-      char *nam = xasprintf ("aw_%d.tmp.%d", awpts->await_number, ++vnum);
-      tree newvar = build_lang_decl (VAR_DECL, get_identifier (nam), var_type);
-      free (nam);
-      /* If we have better location than the whole expression use that, else
-	 fall back to the expression loc.  */
-      DECL_CONTEXT (newvar) = DECL_CONTEXT (orig_temp);
-      if (DECL_SOURCE_LOCATION (orig_temp))
-	sloc = DECL_SOURCE_LOCATION (orig_temp);
-     else
-	sloc = EXPR_LOCATION (*stmt);
-      DECL_SOURCE_LOCATION (newvar) = sloc;
-      DECL_CHAIN (newvar) = varlist;
-      varlist = newvar; /* Chain it onto the list for the bind expr.  */
-      /* Declare and initialize it in the new bind scope.  */
-      add_decl_expr (newvar);
-      tree new_s = build2_loc (sloc, INIT_EXPR, var_type, newvar, to_replace);
-      new_s = coro_build_cvt_void_expr_stmt (new_s, sloc);
-      add_stmt (new_s);
-
-     /* Replace all instances of that temp in the original expr.  */
-      proxy_replace pr = {to_replace, newvar};
-       cp_walk_tree (&aw_statement_current, replace_proxy, &pr, NULL);
-    }
-
-  /* What's left should be the original statement with any co_await captured
-     temporaries broken out.  Other temporaries might remain so see if we
-     need to wrap the revised statement in a cleanup.  */
-  aw_statement_current = maybe_cleanup_point_expr_void (aw_statement_current);
-  add_stmt (aw_statement_current);
-
-  BIND_EXPR_BODY (aw_bind) = pop_stmt_list (aw_bind_body);
-  awpts->captured_temps.empty ();
-
-  BIND_EXPR_VARS (aw_bind) = nreverse (varlist);
+	{
+	  if (TREE_CODE (t->init) == COND_EXPR)
+	    process_conditional (t, vlist);
+	  else
+	    finish_expr_stmt (t->init);
+	  if (expr_list)
+	    add_stmt (expr_list);
+	}
+      expr_list = pop_stmt_list (new_list);
+      var_nest_node *old = t;
+      t = t->prev;
+      delete old;
+    } while (t);
+
+  /* Now produce the bind expression containing the 'promoted' temporaries
+     as its variable list, and the cleanup nest as the statement.  */
+  tree await_bind = build3_loc (sloc, BIND_EXPR, void_type_node,
+				NULL, NULL, NULL);
+  BIND_EXPR_BODY (await_bind) = expr_list;
+  BIND_EXPR_VARS (await_bind) = nreverse (vlist);
   tree b_block = make_node (BLOCK);
   if (!awpts->block_stack->is_empty ())
     {
@@ -2966,37 +3139,12 @@ replace_statement_captures (tree *stmt, void *d)
 	BLOCK_SUBBLOCKS (s_block) = b_block;
 	}
     }
-  BIND_EXPR_BLOCK (aw_bind) = b_block;
-  TREE_SIDE_EFFECTS (aw_bind) = TREE_SIDE_EFFECTS (BIND_EXPR_BODY (aw_bind));
-  *stmt = aw_bind;
-}
-
-/* This is called for single statements from the co-await statement walker.
-   It checks to see if the statement contains any co-awaits and, if so,
-   whether any of these 'capture' a temporary by reference.  */
-
-static tree
-maybe_promote_captured_temps (tree *stmt, void *d)
-{
-  susp_frame_data *awpts = (susp_frame_data *) d;
+  BLOCK_VARS (b_block) = BIND_EXPR_VARS (await_bind) ;
+  BIND_EXPR_BLOCK (await_bind) = b_block;
+  TREE_SIDE_EFFECTS (await_bind) = TREE_SIDE_EFFECTS (BIND_EXPR_BODY (await_bind));
+  *stmt = await_bind;
   hash_set<tree> visited;
-  awpts->saw_awaits = 0;
-
-  /* When register_awaits sees an await, it walks the initializer for
-     that await looking for temporaries captured by reference and notes
-     them in awpts->captured_temps.  */
-
-  if (tree res = cp_walk_tree (stmt, register_awaits, d, &visited))
-    return res; /* We saw some reason to abort the tree walk.  */
-
-  /* We only need to take any action here if the statement contained any
-     awaits and any of those had temporaries captured by reference in their
-     initializers. */
-
-  if (awpts->saw_awaits > 0 && !awpts->captured_temps.is_empty ())
-    replace_statement_captures (stmt, d);
-
-  return NULL_TREE;
+  return cp_walk_tree (stmt, register_awaits, d, &visited);
 }
 
 /* Lightweight callback to determine two key factors:
@@ -3005,6 +3153,7 @@ maybe_promote_captured_temps (tree *stmt, void *d)
       TRUTH_{AND,OR}IF_EXPRs since, in most cases, they will need expansion
       so that the await expressions are not processed in the case of the
       short-circuit arm.
+
    CO_YIELD expressions are re-written to their underlying co_await.  */
 
 static tree
@@ -3021,6 +3170,9 @@ analyze_expression_awaits (tree *stmt, int *do_subtree, void *d)
 	/* FALLTHROUGH */
       case CO_AWAIT_EXPR:
 	awpts->saw_awaits++;
+	/* A non-null initializer for the awaiter means we need to expand.  */
+	if (TREE_OPERAND (*stmt, 2))
+	  awpts->has_awaiter_init = true;
 	break;
       case TRUTH_ANDIF_EXPR:
       case TRUTH_ORIF_EXPR:
@@ -3054,15 +3206,13 @@ analyze_expression_awaits (tree *stmt, int *do_subtree, void *d)
 
 /* Given *EXPR
    If EXPR contains a TRUTH_{AND,OR}IF_EXPR, TAOIE with an await expr on
-   the conditional branch expand this to:
+   the conditionally executed branch, change this in a ternary operator.
 
    bool not_expr = TAOIE == TRUTH_ORIF_EXPR ? NOT : NOP;
-   A) bool t = always exec expr
-      if (not_expr (t))
-   B)   t = conditionally exec expr
-   c) EXPR' = EXPR with  TAOIE replaced by t.
+   not_expr (always-exec expr) ? conditionally-exec expr : not_expr;
 
-   Then repeat this for A, B and C.  */
+   Apply this recursively to the condition and the conditionally-exec
+   branch.  */
 
 struct truth_if_transform {
   tree *orig_stmt;
@@ -3088,47 +3238,26 @@ expand_one_truth_if (tree *expr, int *do_subtree, void *d)
 	    break;
 
 	  location_t sloc = EXPR_LOCATION (*expr);
-	  tree type = TREE_TYPE (xform->scratch_var);
-	  gcc_checking_assert (TREE_CODE (type) == BOOLEAN_TYPE);
-	  tree new_list = push_stmt_list ();
-	  /* Init our scratch with the unconditionally-evaluated expr.  */
-	  tree new_s = build2_loc (sloc, INIT_EXPR, boolean_type_node,
-				   xform->scratch_var,
-				   TREE_OPERAND (*expr, 0));
-	  finish_expr_stmt (new_s);
-	  tree *pre = tsi_stmt_ptr (tsi_last (new_list));
-	  tree if_cond = xform->scratch_var;
+	  /* Transform truth expression into a cond expression with
+	     * the always-executed arm as the condition.
+	     * the conditionally-executed arm as the then clause.
+	     * the 'else' clause is fixed: 'true' for ||,'false' for &&.  */
+	  tree cond = TREE_OPERAND (*expr, 0);
+	  tree test1 = TREE_OPERAND (*expr, 1);
+	  tree fixed = needs_not ? boolean_true_node : boolean_false_node;
 	  if (needs_not)
-	    if_cond = build1 (TRUTH_NOT_EXPR, boolean_type_node, if_cond);
-	  tree if_stmt = begin_if_stmt ();
-	  finish_if_stmt_cond (if_cond, if_stmt);
-	  /* If we take the if branch, then overwrite scratch with the cond
-	     executed branch.  */
-	  new_s = build2 (INIT_EXPR, boolean_type_node,
-			  xform->scratch_var, TREE_OPERAND (*expr, 1));
-	  finish_expr_stmt (new_s);
-	  finish_then_clause (if_stmt);
-	  finish_if_stmt (if_stmt);
-	  *expr = xform->scratch_var; /* now contains the result.  */
-	  /* So now we've got a statement list expanding one TAOIe.  */
-	  add_stmt (*xform->orig_stmt);
-	  tree *post = tsi_stmt_ptr (tsi_last (new_list));
-	  *xform->orig_stmt = pop_stmt_list (new_list);
-	  /* Now recurse into the pre, if and post parts.  */
-	  truth_if_transform sub_data = {pre, xform->scratch_var,
-					 xform->truth_aoif_to_expand};
-	  if (tree res = cp_walk_tree (pre, expand_one_truth_if, &sub_data,
-				       NULL))
-	    return res;
-	  sub_data.orig_stmt = &THEN_CLAUSE (if_stmt);
-	  if (tree res = cp_walk_tree (&THEN_CLAUSE (if_stmt),
-				       expand_one_truth_if, &sub_data, NULL))
+	    cond = build1 (TRUTH_NOT_EXPR, boolean_type_node, cond);
+	  tree cond_expr
+	    = build3_loc (sloc, COND_EXPR, boolean_type_node,
+			  cond, test1, fixed);
+	  *expr = cond_expr;
+	  if (tree res = cp_walk_tree (&COND_EXPR_COND (*expr),
+				       expand_one_truth_if, d, NULL))
 	    return res;
-	  sub_data.orig_stmt = post;
-	  if (tree res = cp_walk_tree (post, expand_one_truth_if, &sub_data,
-				       NULL))
+	  if (tree res = cp_walk_tree (&COND_EXPR_THEN (*expr),
+				       expand_one_truth_if, d, NULL))
 	    return res;
-	  /* We've done the sub-trees here.  */
+	  /* We've manually processed necessary sub-trees here.  */
 	  *do_subtree = 0;
 	}
 	break;
@@ -3143,7 +3272,6 @@ static tree
 add_var_to_bind (tree& bind, tree var_type,
 		 const char *nam_root, unsigned nam_vers)
 {
-
   tree b_vars = BIND_EXPR_VARS (bind);
   /* Build a variable to hold the condition, this will be included in the
      frame as a local var.  */
@@ -3209,14 +3337,20 @@ await_statement_walker (tree *stmt, int *do_subtree, void *d)
     }
 
   /* We have something to be handled as a single statement.  */
+  bool has_cleanup_wrapper = TREE_CODE (*stmt) == CLEANUP_POINT_EXPR;
   hash_set<tree> visited;
   awpts->saw_awaits = 0;
   hash_set<tree> truth_aoif_to_expand;
   awpts->truth_aoif_to_expand = &truth_aoif_to_expand;
   awpts->needs_truth_if_exp = false;
-
-  if (STATEMENT_CLASS_P (*stmt))
-    switch (TREE_CODE (*stmt))
+  awpts->has_awaiter_init = false;
+  tree expr = *stmt;
+  if (has_cleanup_wrapper)
+    expr = TREE_OPERAND (expr, 0);
+  STRIP_NOPS (expr);
+
+  if (STATEMENT_CLASS_P (expr))
+    switch (TREE_CODE (expr))
       {
 	/* Unless it's a special case, just walk the subtrees as usual.  */
 	default: return NULL_TREE;
@@ -3256,13 +3390,6 @@ await_statement_walker (tree *stmt, int *do_subtree, void *d)
 	    tree new_s = build2_loc (sloc, MODIFY_EXPR, boolean_type_node,
 				     newvar, cond_inner);
 	    finish_expr_stmt (new_s);
-	    if (awpts->needs_truth_if_exp)
-	      {
-		tree *sp = tsi_stmt_ptr (tsi_last (insert_list));
-		truth_if_transform xf = {sp, newvar, &truth_aoif_to_expand};
-		if ((res = cp_walk_tree (sp, expand_one_truth_if, &xf, NULL)))
-		  return res;
-	      }
 	    IF_COND (if_stmt) = newvar;
 	    add_stmt (if_stmt);
 	    *stmt = pop_stmt_list (insert_list);
@@ -3328,7 +3455,6 @@ await_statement_walker (tree *stmt, int *do_subtree, void *d)
 				d, NULL);
 	    *do_subtree = 0; /* Done subtrees.  */
 	    return res;
-
 	  }
 	  break;
 	case SWITCH_STMT:
@@ -3372,8 +3498,57 @@ await_statement_walker (tree *stmt, int *do_subtree, void *d)
 	    return res;
 	  }
 	  break;
+	case CO_RETURN_EXPR:
+	  {
+	    /* Expand the co_return as per [stmt.return.coroutine]
+	       - for co_return;
+		{ p.return_void (); goto final_suspend; }
+	       - for co_return [void expr];
+		{ expr; p.return_void(); goto final_suspend;}
+	       - for co_return [non void expr];
+		{ p.return_value(expr); goto final_suspend; }  */
+	    if ((res = cp_walk_tree (stmt, analyze_expression_awaits,
+		 d, &visited)))
+	      return res;
+	    location_t loc = EXPR_LOCATION (expr);
+	    tree call = TREE_OPERAND (expr, 1);
+	    expr = TREE_OPERAND (expr, 0);
+	    tree ret_list = push_stmt_list ();
+	    /* [stmt.return.coroutine], 2.2
+	       If expr is present and void, it is placed immediately before
+	       the call for return_void;  */
+	    tree *maybe_await_stmt = NULL;
+	    if (expr && VOID_TYPE_P (TREE_TYPE (expr)))
+	      {
+		finish_expr_stmt (expr);
+		/* If the return argument was a void expression, then any
+		   awaits must be contained in that.  */
+		maybe_await_stmt = tsi_stmt_ptr (tsi_last (ret_list));
+	      }
+	    /* Insert p.return_{void,value(expr)}.  */
+	    finish_expr_stmt (call);
+	    /* Absent a return of a void expression, any awaits must be in
+	       the parameter to return_value().  */
+	    if (!maybe_await_stmt)
+	      maybe_await_stmt = tsi_stmt_ptr (tsi_last (ret_list));
+	    expr = build1_loc (loc, GOTO_EXPR, void_type_node, awpts->fs_label);
+	    finish_expr_stmt (expr);
+	    *stmt = pop_stmt_list (ret_list);
+	    /* Once this is complete, we will have processed subtrees.  */
+	    *do_subtree = 0;
+	    if (awpts->saw_awaits)
+	      {
+		gcc_checking_assert (maybe_await_stmt);
+		res = cp_walk_tree (maybe_await_stmt, await_statement_walker,
+				    d, NULL);
+		if (res)
+		  return res;
+	      }
+	    return NULL_TREE; /* Done.  */
+	  }
+	break;
       }
-  else if (EXPR_P (*stmt))
+  else if (EXPR_P (expr))
     {
       if ((res = cp_walk_tree (stmt, analyze_expression_awaits, d, &visited)))
 	return res;
@@ -3381,31 +3556,19 @@ await_statement_walker (tree *stmt, int *do_subtree, void *d)
       if (!awpts->saw_awaits)
 	return NULL_TREE; /* Nothing special to do here.  */
 
-      /* Unless we need to expand any truth-and/or-if expressions, then the
-	 remaining action is to check for temporaries to await expressions
-	 captured by refence.  */
-      if (!awpts->needs_truth_if_exp)
-	return maybe_promote_captured_temps (stmt, d);
-
-      gcc_checking_assert (!awpts->bind_stack->is_empty());
-      tree& bind_expr = awpts->bind_stack->last ();
-      /* Build a variable to hold the condition, this will be
-      included in the frame as a local var.  */
-      tree newvar = add_var_to_bind (bind_expr, boolean_type_node,
-				     "taoi", awpts->cond_number++);
-      tree insert_list = push_stmt_list ();
-      add_decl_expr (newvar);
-      add_stmt (*stmt);
-      tree *sp = tsi_stmt_ptr (tsi_last (insert_list));
-      *stmt = pop_stmt_list (insert_list);
-
-      truth_if_transform xf = {sp, newvar, &truth_aoif_to_expand};
-      if ((res = cp_walk_tree (sp, expand_one_truth_if, &xf, NULL)))
-	return res;
-      /* Process the expanded trees.  */
-      return cp_walk_tree (stmt, await_statement_walker, d, NULL);
+      if (awpts->needs_truth_if_exp)
+	{
+	  /* If a truth-and/or-if expression has an await expression in the
+	     conditionally-taken branch, then it must be rewritten into a
+	     regular conditional.  */
+	  truth_if_transform xf = {stmt, NULL_TREE, &truth_aoif_to_expand};
+	  if ((res = cp_walk_tree (stmt, expand_one_truth_if, &xf, NULL)))
+	    return res;
+	}
+      /* Process this statement, which contains at least one await expression
+	 to 'promote' temporary values to a coroutine frame slot.  */
+      return maybe_promote_temps (stmt, d);
     }
- 
   /* Continue recursion, if needed.  */
   return res;
 }
@@ -3421,6 +3584,9 @@ struct param_frame_data
   bool param_seen;
 };
 
+/* A tree-walk callback that records the use of parameters (to allow for
+   optimizations where handling unused parameters may be omitted).  */
+
 static tree
 register_param_uses (tree *stmt, int *do_subtree ATTRIBUTE_UNUSED, void *d)
 {
@@ -3456,7 +3622,21 @@ register_param_uses (tree *stmt, int *do_subtree ATTRIBUTE_UNUSED, void *d)
   return NULL_TREE;
 }
 
-/* For figuring out what local variable usage we have.  */
+/* Small helper for the repetitive task of adding a new field to the coro
+   frame type.  */
+
+static tree
+coro_make_frame_entry (tree *field_list, const char *name, tree fld_type,
+		       location_t loc)
+{
+  tree id = get_identifier (name);
+  tree decl = build_decl (loc, FIELD_DECL, id, fld_type);
+  DECL_CHAIN (decl) = *field_list;
+  *field_list = decl;
+  return id;
+}
+
+/* For recording local variable usage.  */
 
 struct local_vars_frame_data
 {
@@ -3468,6 +3648,10 @@ struct local_vars_frame_data
   bool local_var_seen;
 };
 
+/* A tree-walk callback that processes one bind expression noting local
+   variables, and making a coroutine frame slot available for those that
+   need it, so that they can be 'promoted' across suspension points.  */
+
 static tree
 register_local_var_uses (tree *stmt, int *do_subtree, void *d)
 {
@@ -3524,11 +3708,11 @@ register_local_var_uses (tree *stmt, int *do_subtree, void *d)
 	  tree lvname = DECL_NAME (lvar);
 	  char *buf;
 	  if (lvname != NULL_TREE)
-	    buf = xasprintf ("__lv.%u.%u.%s", lvd->bind_indx, lvd->nest_depth,
-			     IDENTIFIER_POINTER (lvname));
+	    buf = xasprintf ("__%s.%u.%u", IDENTIFIER_POINTER (lvname),
+			     lvd->nest_depth, lvd->bind_indx);
 	  else
-	    buf = xasprintf ("__lv.%u.%u.D%u", lvd->bind_indx, lvd->nest_depth,
-			     DECL_UID (lvar));
+	    buf = xasprintf ("_D%u.%u.%u", DECL_UID (lvar), lvd->nest_depth,
+			     lvd->bind_indx);
 	  /* TODO: Figure out if we should build a local type that has any
 	     excess alignment or size from the original decl.  */
 	  local_var.field_id
@@ -3632,7 +3816,7 @@ coro_rewrite_function_body (location_t fn_start, tree fnbody,
 					 fn_start, NULL, /*musthave=*/true);
       /* Create and initialize the initial-await-resume-called variable per
 	 [dcl.fct.def.coroutine] / 5.3.  */
-      tree i_a_r_c = build_lang_decl (VAR_DECL, get_identifier ("__i_a_r_c"),
+      tree i_a_r_c = build_lang_decl (VAR_DECL, get_identifier ("i_a_r_c"),
 				      boolean_type_node);
       DECL_ARTIFICIAL (i_a_r_c) = true;
       DECL_CHAIN (i_a_r_c) = var_list;
@@ -3761,9 +3945,7 @@ coro_rewrite_function_body (location_t fn_start, tree fnbody,
   short __resume_at;
   handle_type self_handle;
   (maybe) parameter copies.
-  coro1::suspend_never_prt __is;
-  coro1::suspend_always_prt __fs;
-  (maybe) local variables saved
+  (maybe) local variables saved (including awaitables)
   (maybe) trailing space.
  };  */
 
@@ -3976,8 +4158,8 @@ morph_fn_to_coro (tree orig, tree *resumer, tree *destroyer)
      to promote any temporaries that are captured by reference (to regular
      vars) they will get added to the coro frame along with other locals.  */
   susp_frame_data body_aw_points
-    = {&field_list, handle_type, NULL, NULL, 0, 0,
-       hash_set<tree> (), NULL, NULL, 0, false, false};
+    = {&field_list, handle_type, fs_label, NULL, NULL, 0, 0,
+       hash_set<tree> (), NULL, NULL, 0, false, false, false};
   body_aw_points.block_stack = make_tree_vector ();
   body_aw_points.bind_stack = make_tree_vector ();
   body_aw_points.to_replace = make_tree_vector ();
@@ -4565,7 +4747,7 @@ morph_fn_to_coro (tree orig, tree *resumer, tree *destroyer)
 
   /* Build the actor...  */
   build_actor_fn (fn_start, coro_frame_type, actor, fnbody, orig, param_uses,
-		  &local_var_uses, param_dtor_list, fs_label, resume_fn_field,
+		  &local_var_uses, param_dtor_list, resume_fn_field,
 		  body_aw_points.await_number, frame_size);
 
   /* Destroyer ... */
diff --git a/gcc/testsuite/g++.dg/coroutines/pr95591.C b/gcc/testsuite/g++.dg/coroutines/pr95591.C
new file mode 100644
index 00000000000..664b1d39619
--- /dev/null
+++ b/gcc/testsuite/g++.dg/coroutines/pr95591.C
@@ -0,0 +1,26 @@
+#if __has_include (<coroutine>)
+#include <coroutine>
+using namespace std;
+#elif defined (__clang__) && __has_include (<experimental/coroutine>)
+#include <experimental/coroutine>
+namespace std { using namespace experimental; }
+#endif
+
+struct generator {
+    struct promise_type {
+        generator get_return_object();
+        void return_void();
+        void unhandled_exception();
+        suspend_always initial_suspend();
+        suspend_always final_suspend();
+
+        template<typename Arg>
+        suspend_always yield_value(Arg&&) {
+            return {};
+        }
+    };
+};
+
+generator x() {
+    co_yield "foo";
+}
diff --git a/gcc/testsuite/g++.dg/coroutines/pr95599.C b/gcc/testsuite/g++.dg/coroutines/pr95599.C
new file mode 100644
index 00000000000..9376359d378
--- /dev/null
+++ b/gcc/testsuite/g++.dg/coroutines/pr95599.C
@@ -0,0 +1,69 @@
+//  { dg-do run }
+
+// The simplest co_await we can do.
+
+#include "coro.h"
+
+// boiler-plate for tests of codegen
+#include "coro1-ret-int-yield-int.h"
+
+int counter = 0;
+int a, b, c, d;
+int e, f, g;
+
+struct suspend_always_order {
+  suspend_always_order (int *v) { 
+    PRINT ("susp-always-order-ctor-value"); *v = counter++;
+  }
+  suspend_always_order () { PRINT ("susp-always-order-ctor"); }
+  constexpr bool await_ready() const noexcept { return false; }
+  void await_suspend(coro1::handle_type) const noexcept { PRINT ("susp-always-order-susp");}
+  void await_resume() const noexcept { PRINT ("susp-always-order-resume");}
+  ~suspend_always_order() { PRINT ("susp-always-order-dtor"); }
+};
+
+coro1
+my_coro ()
+{
+  (a = counter++, b = counter++, co_await suspend_always_order(&c), d = counter++);
+  co_await (e = counter++, suspend_always_order (&f));
+  co_return (g = counter++, 10);
+}
+
+int main ()
+{
+  auto f_coro = my_coro ();
+
+  if (f_coro.handle.done())
+    {
+      PRINT ("main: we should not be 'done' [1]");
+      abort ();
+    }
+  PRINT ("main: resuming [1] initial suspend");
+  f_coro.handle.resume();
+  PRINT ("main: resuming [2] co_await");
+  f_coro.handle.resume();
+  PRINT ("main: resuming [3] co_await");
+  f_coro.handle.resume();
+
+  /* we should now have returned with the co_return */
+  if (!f_coro.handle.done())
+    {
+      PRINT ("main: we should be 'done' ");
+      abort ();
+    }
+  int y = f_coro.handle.promise().get_value();
+  if (y != 10)
+    {
+      PRINTF ("main: y is wrong : %d, should be 10\n", y);
+      abort ();
+    }
+  if (a != 0 || b != 1 || c != 2 || d != 3
+      || e != 4 || f != 5 || g != 6 )
+    {
+      PRINTF ("something happened in the wrong order %d, %d, %d, %d, %d, %d, %d\n", a, b, c, d, e, f, g);
+      abort ();
+    }
+  puts ("main: done");
+  return 0;
+}
diff --git a/gcc/testsuite/g++.dg/coroutines/pr95823.C b/gcc/testsuite/g++.dg/coroutines/pr95823.C
new file mode 100644
index 00000000000..14d4680206d
--- /dev/null
+++ b/gcc/testsuite/g++.dg/coroutines/pr95823.C
@@ -0,0 +1,30 @@
+#include <coroutine>
+#include <memory>
+
+struct task {
+  struct promise_type {
+    auto initial_suspend() noexcept { return std::suspend_always{}; }
+    auto final_suspend() noexcept { return std::suspend_always{}; }
+    void return_void() {}
+    task get_return_object() { return task{}; }
+    void unhandled_exception() noexcept {}
+  };
+
+  ~task() noexcept {}
+
+  bool await_ready() const noexcept { return false; }
+  void await_suspend(std::coroutine_handle<>) noexcept {}
+  void await_resume() noexcept {}
+};
+
+struct Id
+{
+    std::unique_ptr<int> value;
+};
+
+task g(int);
+
+task f() {
+    std::unique_ptr<Id> id;
+    co_await g(*id->value);
+}
diff --git a/gcc/testsuite/g++.dg/coroutines/pr95824.C b/gcc/testsuite/g++.dg/coroutines/pr95824.C
new file mode 100644
index 00000000000..d44d7015090
--- /dev/null
+++ b/gcc/testsuite/g++.dg/coroutines/pr95824.C
@@ -0,0 +1,37 @@
+#include <coroutine>
+
+struct task {
+  struct promise_type {
+    auto initial_suspend() noexcept { return std::suspend_always{}; }
+    auto final_suspend() noexcept { return std::suspend_always{}; }
+    void return_void() {}
+    task get_return_object() { return task{}; }
+    void unhandled_exception() noexcept {}
+  };
+
+  ~task() noexcept {}
+
+  bool await_ready() const noexcept { return false; }
+  void await_suspend(std::coroutine_handle<>) noexcept {}
+  void await_resume() noexcept {}
+};
+
+struct base
+{
+    virtual ~base() = default;
+};
+
+class exception : public virtual base
+{};
+
+struct factory
+{
+    virtual ~factory() = default;
+    virtual int makeId() const;
+};
+
+task g(int);
+
+task f(factory& factory) {
+    co_await g(factory.makeId());
+}

commit 2ced237ad122091d4c050f2234349cb90e127e54
Author: Julian Brown <julian@codesourcery.com>
Date:   Thu Jul 2 14:18:20 2020 -0700

    openacc: Remove unnecessary detach finalization
    
    The call to gomp_detach_pointer in gomp_unmap_vars_internal does not
    need to force finalization, and doing so may mask mismatched pointer
    attachments/detachments. This patch removes the forcing.
    
    2020-07-16  Julian Brown  <julian@codesourcery.com>
                Thomas Schwinge  <thomas@codesourcery.com>
    
    libgomp/
            * target.c (gomp_unmap_vars_internal): Remove unnecessary forcing of
            finalization for detach operation.
            * testsuite/libgomp.oacc-c-c++-common/structured-detach-underflow.c:
            New test.
    
    Co-Authored-By: Thomas Schwinge <thomas@codesourcery.com>
    (cherry picked from commit 25bce75c77ec5617c78173d837d3b664c0f20968)

diff --git a/libgomp/target.c b/libgomp/target.c
index d6b3572c8d8..00c75fbd885 100644
--- a/libgomp/target.c
+++ b/libgomp/target.c
@@ -1437,7 +1437,7 @@ gomp_unmap_vars_internal (struct target_mem_desc *tgt, bool do_copyfrom,
       if (k != NULL && tgt->list[i].do_detach)
 	gomp_detach_pointer (devicep, aq, k, tgt->list[i].key->host_start
 					     + tgt->list[i].offset,
-			     k->refcount == 1, NULL);
+			     false, NULL);
     }
 
   for (i = 0; i < tgt->list_count; i++)
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-detach-underflow.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-detach-underflow.c
new file mode 100644
index 00000000000..fc1f59e2185
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-detach-underflow.c
@@ -0,0 +1,28 @@
+/* { dg-skip-if "" { *-*-* } { "*" } { "-DACC_MEM_SHARED=0" } } */
+
+#include <stdio.h>
+
+int main ()
+{
+  struct {
+    int *arr;
+  } mystr;
+  int localarr[16];
+  mystr.arr = localarr;
+
+  #pragma acc enter data copyin(mystr, localarr[0:16])
+
+  #pragma acc data attach(mystr.arr)
+  {
+    #pragma acc exit data detach(mystr.arr)
+    fprintf (stderr, "CheCKpOInT1\n");
+    /* { dg-output ".*CheCKpOInT1(\n|\r\n|\r)" } */
+  }
+  /* { dg-shouldfail "" }
+     { dg-output "(\n|\r\n|\r)libgomp: attach count underflow(\n|\r\n|\r)$" } */
+  fprintf (stderr, "CheCKpOInT2\n");
+
+  #pragma acc exit data copyout(mystr, localarr[0:16])
+
+  return 0;
+}

commit d9a77a17333ab93b023b13c41758adb3dc72ad1c
Author: Julian Brown <julian@codesourcery.com>
Date:   Thu Jun 18 05:11:08 2020 -0700

    openacc: Deep copy attach/detach should not affect reference counts
    
    Attach and detach operations are not supposed to affect structural or
    dynamic reference counts for OpenACC. Previously they did so, which led to
    subtle problems in some circumstances. We can avoid reference-counting
    attach/detach operations by extending and slightly repurposing the
    do_detach field in target_var_desc. It is now called is_attach to better
    reflect its new role.
    
    2020-07-27  Julian Brown  <julian@codesourcery.com>
                Thomas Schwinge  <thomas@codesourcery.com>
    
    libgomp/
            * libgomp.h (struct target_var_desc): Rename do_detach field to
            is_attach.
            * oacc-mem.c (goacc_exit_datum_1): Add assert.  Don't set finalize for
            GOMP_MAP_FORCE_DETACH. Update checking to use is_attach field.
            (goacc_enter_data_internal): Don't affect reference counts
            for attach mappings.
            (goacc_exit_data_internal): Don't affect reference counts for detach
            mappings.
            * target.c (gomp_map_vars_existing): Don't affect reference counts for
            attach mappings.
            (gomp_map_vars_internal): Set renamed is_attach flag unconditionally to
            mark attach mappings.
            (gomp_unmap_vars_internal): Use is_attach flag to prevent affecting
            reference count for attach mappings.
            * testsuite/libgomp.oacc-c-c++-common/mdc-refcount-1.c: New test.
            * testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c: New test.
            * testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c: New test.
            * testsuite/libgomp.oacc-fortran/deep-copy-6-no_finalize.F90: Mark
            test as shouldfail.
            * testsuite/libgomp.oacc-fortran/deep-copy-6.f90: Adjust to fail
            gracefully in no-finalize mode.
    
    Co-Authored-By: Thomas Schwinge <thomas@codesourcery.com>
    (cherry picked from commit bc4ed079dc09a62168699227a794ac52a5b6f6a4)

diff --git a/libgomp/libgomp.h b/libgomp/libgomp.h
index 2cd9853236a..02b2580e6c6 100644
--- a/libgomp/libgomp.h
+++ b/libgomp/libgomp.h
@@ -948,8 +948,8 @@ struct target_var_desc {
   bool copy_from;
   /* True if data always should be copied from device to host at the end.  */
   bool always_copy_from;
-  /* True if variable should be detached at end of region.  */
-  bool do_detach;
+  /* True if this is for OpenACC 'attach'.  */
+  bool is_attach;
   /* Relative offset against key host_start.  */
   uintptr_t offset;
   /* Actual length.  */
diff --git a/libgomp/oacc-mem.c b/libgomp/oacc-mem.c
index 855cad84391..65757ab2ffc 100644
--- a/libgomp/oacc-mem.c
+++ b/libgomp/oacc-mem.c
@@ -667,6 +667,9 @@ static void
 goacc_exit_datum_1 (struct gomp_device_descr *acc_dev, void *h, size_t s,
 		    unsigned short kind, splay_tree_key n, goacc_aq aq)
 {
+  assert (kind != GOMP_MAP_DETACH
+	  && kind != GOMP_MAP_FORCE_DETACH);
+
   if ((uintptr_t) h < n->host_start || (uintptr_t) h + s > n->host_end)
     {
       size_t host_size = n->host_end - n->host_start;
@@ -676,8 +679,7 @@ goacc_exit_datum_1 (struct gomp_device_descr *acc_dev, void *h, size_t s,
     }
 
   bool finalize = (kind == GOMP_MAP_FORCE_FROM
-		   || kind == GOMP_MAP_DELETE
-		   || kind == GOMP_MAP_FORCE_DETACH);
+		   || kind == GOMP_MAP_DELETE);
 
   assert (n->refcount != REFCOUNT_LINK);
   if (n->refcount != REFCOUNT_INFINITY
@@ -725,7 +727,8 @@ goacc_exit_datum_1 (struct gomp_device_descr *acc_dev, void *h, size_t s,
 	     zero.  Otherwise (e.g. for a 'GOMP_MAP_STRUCT' mapping with
 	     multiple members), fall back to skipping the test.  */
 	  for (size_t l_i = 0; l_i < n->tgt->list_count; ++l_i)
-	    if (n->tgt->list[l_i].key)
+	    if (n->tgt->list[l_i].key
+		&& !n->tgt->list[l_i].is_attach)
 	      ++num_mappings;
 	  bool is_tgt_unmapped = gomp_remove_var (acc_dev, n);
 	  assert (is_tgt_unmapped || num_mappings > 1);
@@ -1135,12 +1138,15 @@ goacc_enter_data_internal (struct gomp_device_descr *acc_dev, size_t mapnum,
 	  void *h = hostaddrs[i];
 	  size_t s = sizes[i];
 
-	  /* A standalone attach clause.  */
 	  if ((kinds[i] & 0xff) == GOMP_MAP_ATTACH)
-	    gomp_attach_pointer (acc_dev, aq, &acc_dev->mem_map, n,
-				 (uintptr_t) h, s, NULL);
-
-	  goacc_map_var_existing (acc_dev, h, s, n);
+	    {
+	      gomp_attach_pointer (acc_dev, aq, &acc_dev->mem_map, n,
+				   (uintptr_t) h, s, NULL);
+	      /* OpenACC 'attach'/'detach' doesn't affect structured/dynamic
+		 reference counts ('n->refcount', 'n->dynamic_refcount').  */
+	    }
+	  else
+	    goacc_map_var_existing (acc_dev, h, s, n);
 	}
       else if (n && groupnum > 1)
 	{
@@ -1168,7 +1174,9 @@ goacc_enter_data_internal (struct gomp_device_descr *acc_dev, size_t mapnum,
 		   list, and increment the refcounts for each item in that
 		   group.  */
 		for (size_t k = 0; k < groupnum; k++)
-		  if (j + k < tgt->list_count && tgt->list[j + k].key)
+		  if (j + k < tgt->list_count
+		      && tgt->list[j + k].key
+		      && !tgt->list[j + k].is_attach)
 		    {
 		      tgt->list[j + k].key->refcount++;
 		      tgt->list[j + k].key->dynamic_refcount++;
@@ -1202,7 +1210,7 @@ goacc_enter_data_internal (struct gomp_device_descr *acc_dev, size_t mapnum,
 	  for (size_t j = 0; j < tgt->list_count; j++)
 	    {
 	      n = tgt->list[j].key;
-	      if (n)
+	      if (n && !tgt->list[j].is_attach)
 		n->dynamic_refcount++;
 	    }
 	}
@@ -1268,14 +1276,10 @@ goacc_exit_data_internal (struct gomp_device_descr *acc_dev, size_t mapnum,
 	case GOMP_MAP_POINTER:
 	case GOMP_MAP_DELETE:
 	case GOMP_MAP_RELEASE:
-	case GOMP_MAP_DETACH:
-	case GOMP_MAP_FORCE_DETACH:
 	  {
 	    struct splay_tree_key_s cur_node;
 	    size_t size;
-	    if (kind == GOMP_MAP_POINTER
-		|| kind == GOMP_MAP_DETACH
-		|| kind == GOMP_MAP_FORCE_DETACH)
+	    if (kind == GOMP_MAP_POINTER)
 	      size = sizeof (void *);
 	    else
 	      size = sizes[i];
@@ -1298,6 +1302,12 @@ goacc_exit_data_internal (struct gomp_device_descr *acc_dev, size_t mapnum,
 	     'GOMP_MAP_STRUCT's anymore.  */
 	  break;
 
+	case GOMP_MAP_DETACH:
+	case GOMP_MAP_FORCE_DETACH:
+	  /* OpenACC 'attach'/'detach' doesn't affect structured/dynamic
+	     reference counts ('n->refcount', 'n->dynamic_refcount').  */
+	  break;
+
 	default:
 	  gomp_fatal (">>>> goacc_exit_data_internal UNHANDLED kind 0x%.2x",
 			  kind);
diff --git a/libgomp/target.c b/libgomp/target.c
index 00c75fbd885..3e292eb8c62 100644
--- a/libgomp/target.c
+++ b/libgomp/target.c
@@ -362,7 +362,7 @@ gomp_map_vars_existing (struct gomp_device_descr *devicep,
   tgt_var->key = oldn;
   tgt_var->copy_from = GOMP_MAP_COPY_FROM_P (kind);
   tgt_var->always_copy_from = GOMP_MAP_ALWAYS_FROM_P (kind);
-  tgt_var->do_detach = false;
+  tgt_var->is_attach = false;
   tgt_var->offset = newn->host_start - oldn->host_start;
   tgt_var->length = newn->host_end - newn->host_start;
 
@@ -1093,9 +1093,10 @@ gomp_map_vars_internal (struct gomp_device_descr *devicep,
 		      tgt->list[i].length = n->host_end - n->host_start;
 		      tgt->list[i].copy_from = false;
 		      tgt->list[i].always_copy_from = false;
-		      tgt->list[i].do_detach
-			= (pragma_kind != GOMP_MAP_VARS_ENTER_DATA);
-		      n->refcount++;
+		      tgt->list[i].is_attach = true;
+		      /* OpenACC 'attach'/'detach' doesn't affect
+			 structured/dynamic reference counts ('n->refcount',
+			 'n->dynamic_refcount').  */
 		    }
 		  else
 		    {
@@ -1151,7 +1152,7 @@ gomp_map_vars_internal (struct gomp_device_descr *devicep,
 		tgt->list[i].copy_from = GOMP_MAP_COPY_FROM_P (kind & typemask);
 		tgt->list[i].always_copy_from
 		  = GOMP_MAP_ALWAYS_FROM_P (kind & typemask);
-		tgt->list[i].do_detach = false;
+		tgt->list[i].is_attach = false;
 		tgt->list[i].offset = 0;
 		tgt->list[i].length = k->host_end - k->host_start;
 		k->refcount = 1;
@@ -1206,7 +1207,7 @@ gomp_map_vars_internal (struct gomp_device_descr *devicep,
 			  tgt->list[j].key = k;
 			  tgt->list[j].copy_from = false;
 			  tgt->list[j].always_copy_from = false;
-			  tgt->list[j].do_detach = false;
+			  tgt->list[j].is_attach = false;
 			  if (k->refcount != REFCOUNT_INFINITY)
 			    k->refcount++;
 			  gomp_map_pointer (tgt, aq,
@@ -1434,7 +1435,7 @@ gomp_unmap_vars_internal (struct target_mem_desc *tgt, bool do_copyfrom,
     {
       splay_tree_key k = tgt->list[i].key;
 
-      if (k != NULL && tgt->list[i].do_detach)
+      if (k != NULL && tgt->list[i].is_attach)
 	gomp_detach_pointer (devicep, aq, k, tgt->list[i].key->host_start
 					     + tgt->list[i].offset,
 			     false, NULL);
@@ -1446,6 +1447,11 @@ gomp_unmap_vars_internal (struct target_mem_desc *tgt, bool do_copyfrom,
       if (k == NULL)
 	continue;
 
+      /* OpenACC 'attach'/'detach' doesn't affect structured/dynamic reference
+	 counts ('n->refcount', 'n->dynamic_refcount').  */
+      if (tgt->list[i].is_attach)
+	continue;
+
       bool do_unmap = false;
       if (k->refcount > 1 && k->refcount != REFCOUNT_INFINITY)
 	k->refcount--;
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-1.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-1.c
new file mode 100644
index 00000000000..6170447e7d3
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-1.c
@@ -0,0 +1,60 @@
+/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
+
+#include <openacc.h>
+#include <assert.h>
+
+#define N 1024
+
+struct mystr {
+  int *data;
+};
+
+static void
+test (unsigned variant)
+{
+  int arr[N];
+  struct mystr s;
+
+  s.data = arr;
+
+  acc_copyin (&s, sizeof (s));
+  acc_create (s.data, N * sizeof (int));
+
+  for (int i = 0; i < 20; i++)
+    {
+      if ((variant + i) % 1)
+	{
+#pragma acc enter data attach(s.data)
+	}
+      else
+	acc_attach ((void **) &s.data);
+
+      if ((variant + i) % 2)
+	{
+#pragma acc exit data detach(s.data)
+	}
+      else
+	acc_detach ((void **) &s.data);
+    }
+
+  assert (acc_is_present (arr, N * sizeof (int)));
+  assert (acc_is_present (&s, sizeof (s)));
+
+  acc_delete (arr, N * sizeof (int));
+
+  assert (!acc_is_present (arr, N * sizeof (int)));
+
+  acc_copyout (&s, sizeof (s));
+
+  assert (!acc_is_present (&s, sizeof (s)));
+  assert (s.data == arr);
+}
+
+int
+main (int argc, char *argv[])
+{
+  for (unsigned variant = 0; variant < 4; ++variant)
+    test (variant);
+
+  return 0;
+}
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c
new file mode 100644
index 00000000000..2431a76a805
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c
@@ -0,0 +1,123 @@
+/* Verify that OpenACC 'attach'/'detach' doesn't interfere with reference
+   counting.  */
+
+#include <assert.h>
+#include <stdlib.h>
+#include <openacc.h>
+
+/* Need to shared this (and, in particular, implicit '&data_work' in
+   'attach'/'detach' clauses) between 'test' and 'test_'.  */
+static unsigned char *data_work;
+
+static void test_(unsigned variant,
+		  unsigned char *data,
+		  void *data_d)
+{
+  assert(acc_is_present(&data_work, sizeof data_work));
+  assert(data_work == data);
+
+  acc_update_self(&data_work, sizeof data_work);
+  assert(data_work == data);
+
+  if (variant & 1)
+    {
+#pragma acc enter data attach(data_work)
+    }
+  else
+    acc_attach((void **) &data_work);
+  acc_update_self(&data_work, sizeof data_work);
+  assert(data_work == data_d);
+
+  if (variant & 4)
+    {
+      if (variant & 2)
+	{ // attach some more
+	  data_work = data;
+	  acc_attach((void **) &data_work);
+#pragma acc enter data attach(data_work)
+	  acc_attach((void **) &data_work);
+#pragma acc enter data attach(data_work)
+#pragma acc enter data attach(data_work)
+#pragma acc enter data attach(data_work)
+	  acc_attach((void **) &data_work);
+	  acc_attach((void **) &data_work);
+#pragma acc enter data attach(data_work)
+	}
+      else
+	{}
+    }
+  else
+    { // detach
+      data_work = data;
+      if (variant & 2)
+	{
+#pragma acc exit data detach(data_work)
+	}
+      else
+	acc_detach((void **) &data_work);
+      acc_update_self(&data_work, sizeof data_work);
+      assert(data_work == data);
+
+      // now not attached anymore
+
+#if 0
+      if (TODO)
+	{
+	  acc_detach(&data_work); //TODO PR95203 "libgomp: attach count underflow"
+	  acc_update_self(&data_work, sizeof data_work);
+	  assert(data_work == data);
+	}
+#endif
+    }
+
+  assert(acc_is_present(&data_work, sizeof data_work));
+}
+
+static void test(unsigned variant)
+{
+  const int size = sizeof (void *);
+  unsigned char *data = (unsigned char *) malloc(size);
+  assert(data);
+  void *data_d = acc_create(data, size);
+  assert(data_d);
+  assert(acc_is_present(data, size));
+
+  data_work = data;
+
+  if (variant & 8)
+    {
+#pragma acc data copyin(data_work)
+      test_(variant, data, data_d);
+    }
+  else
+    {
+      acc_copyin(&data_work, sizeof data_work);
+      test_(variant, data, data_d);
+      acc_delete(&data_work, sizeof data_work);
+    }
+#if ACC_MEM_SHARED
+  assert(acc_is_present(&data_work, sizeof data_work));
+#else
+  assert(!acc_is_present(&data_work, sizeof data_work));
+#endif
+  data_work = NULL;
+
+  assert(acc_is_present(data, size));
+  acc_delete(data, size);
+  data_d = NULL;
+#if ACC_MEM_SHARED
+  assert(acc_is_present(data, size));
+#else
+  assert(!acc_is_present(data, size));
+#endif
+  free(data);
+  data = NULL;
+}
+
+int main()
+{
+  for (size_t i = 0; i < 16; ++i)
+    test(i);
+
+  return 0;
+}
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-3.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-3.c
new file mode 100644
index 00000000000..0f5e7becada
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/mdc-refcount-3.c
@@ -0,0 +1,86 @@
+/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
+
+/* Variant of 'deep-copy-7.c'.  */
+
+#include <stdlib.h>
+#include <assert.h>
+#include <openacc.h>
+
+struct dc
+{
+  int a;
+  int *b;
+};
+
+int
+main ()
+{
+  int n = 100, i, j, k;
+  struct dc v = { .a = 3 };
+
+  v.b = (int *) malloc (sizeof (int) * n);
+
+  for (k = 0; k < 16; k++)
+    {
+      /* Here, we do not explicitly copy the enclosing structure, but work
+	 with fields directly.  Make sure attachment counters and reference
+	 counters work properly in that case.  */
+#pragma acc enter data copyin(v.a, v.b[0:n]) // 1
+      assert (acc_is_present (&v.b, sizeof v.b));
+      assert (acc_is_present (v.b, sizeof (int) * n));
+#pragma acc enter data pcopyin(v.b[0:n]) // 2
+#pragma acc enter data pcopyin(v.b[0:n]) // 3
+
+#pragma acc parallel loop present(v.a, v.b)
+      for (i = 0; i < n; i++)
+	v.b[i] = k + v.a + i;
+
+      switch (k % 5)
+	{ // All optional.
+	case 0:
+	  break;
+	case 1:
+	  ; //TODO PR95901
+#pragma acc exit data detach(v.b) finalize
+	  break;
+	case 2:
+	  ; //TODO PR95901
+#pragma acc exit data detach(v.b)
+	  break;
+	case 3:
+	  acc_detach_finalize ((void **) &v.b);
+	  break;
+	case 4:
+	  acc_detach ((void **) &v.b);
+	  break;
+	}
+      assert (acc_is_present (&v.b, sizeof v.b));
+      assert (acc_is_present (v.b, sizeof (int) * n));
+      { // 3
+	acc_delete (&v.b, sizeof v.b);
+	assert (acc_is_present (&v.b, sizeof v.b));
+	acc_copyout (v.b, sizeof (int) * n);
+	assert (acc_is_present (v.b, sizeof (int) * n));
+      }
+      { // 2
+	acc_delete (&v.b, sizeof v.b);
+	assert (acc_is_present (&v.b, sizeof v.b));
+	acc_copyout (v.b, sizeof (int) * n);
+	assert (acc_is_present (v.b, sizeof (int) * n));
+      }
+      { // 1
+	acc_delete (&v.b, sizeof v.b);
+	assert (!acc_is_present (&v.b, sizeof v.b));
+	acc_copyout (v.b, sizeof (int) * n);
+	assert (!acc_is_present (v.b, sizeof (int) * n));
+      }
+#pragma acc exit data delete(v.a)
+
+      for (i = 0; i < n; i++)
+	assert (v.b[i] == k + v.a + i);
+
+      assert (!acc_is_present (&v, sizeof (v)));
+    }
+
+  return 0;
+}
diff --git a/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6-no_finalize.F90 b/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6-no_finalize.F90
index 038f04a3c37..1daff2dadf1 100644
--- a/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6-no_finalize.F90
+++ b/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6-no_finalize.F90
@@ -1,5 +1,12 @@
 ! { dg-do run }
 
-/* Nullify the 'finalize' clause.  */
+/* Nullify the 'finalize' clause.
+
+   That means, we do not detach properly, the host sees a device pointer, and
+   we fail as follows.
+   { dg-output "STOP 30(\n|\r\n|\r)+" { target { ! openacc_host_selected } } }
+   { dg-shouldfail "" { ! openacc_host_selected } }
+*/
 #define finalize
 #include "deep-copy-6.f90"
+
diff --git a/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6.f90 b/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6.f90
index 6aab6a4a763..94ddca3bce8 100644
--- a/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6.f90
+++ b/libgomp/testsuite/libgomp.oacc-fortran/deep-copy-6.f90
@@ -12,11 +12,14 @@ program dtype
   end type mytype
   integer i
 
-  type(mytype) :: var
+  type(mytype), target :: var
+  integer, pointer :: hostptr(:)
 
   allocate(var%a(1:n))
   allocate(var%b(1:n))
 
+  hostptr => var%a
+
 !$acc data copy(var)
 
   do i = 1, n
@@ -49,6 +52,9 @@ program dtype
 
 !$acc end data
 
+  ! See 'deep-copy-6-no_finalize.F90'.
+  if (.not. associated(hostptr, var%a)) stop 30
+
   do i = 1,4
     if (var%a(i) .ne. 0) stop 1
     if (var%b(i) .ne. 0) stop 2

commit bee0b7156a07afaa837ce0f31ba12a3eb5d1ee22
Author: Martin Liska <mliska@suse.cz>
Date:   Wed Jul 29 14:13:42 2020 +0200

    gcc-changelog: fix combining of arguments.
    
    contrib/ChangeLog:
    
    2020-07-29  Martin Liska  <mliska@suse.cz>
    
            * git-backport.py: fix how are ChangeLog paths combined.

diff --git a/contrib/git-backport.py b/contrib/git-backport.py
index 3a9413dcd27..2b8e4686719 100755
--- a/contrib/git-backport.py
+++ b/contrib/git-backport.py
@@ -46,7 +46,7 @@ if __name__ == '__main__':
         conflicts = out.strip().split('\n')
         changelogs = [c for c in conflicts if c.endswith('ChangeLog')]
         if changelogs:
-            cmd = 'git checkout --theirs %s' % '\n'.join(changelogs)
+            cmd = 'git checkout --theirs %s' % ' '.join(changelogs)
             subprocess.check_output(cmd, shell=True)
         # 2) remove all ChangeLog files from index
         cmd = 'git diff --name-only --diff-filter=M HEAD'

commit 3c4d2b867666464fad2dc5732940beaae48d8628
Author: Mark Eggleston <markeggleston@gcc.gnu.org>
Date:   Mon Jul 27 15:28:50 2020 +0100

    Fortran  : Don't warn for LOGICAL kind conversion PR96319
    
    LOGICAL values will always fit regardless of kind so there
    is no need for warnings.
    
    2020-07-29  Mark Eggleston  <markeggleston@gcc.gnu.org>
    
    gcc/fortran/
    
            PR fortran/96319
            * intrinsic.c (gfc_convert_type_warn):  Add check for
            LOGICAL type so that warnings are not output.
    
    2020-07-29  Mark Eggleston  <markeggleston@gcc.gnu.org>
    
    gcc/testsuite/
    
            PR fortran/96319
            * gfortran.dg/pr96319.f90: New test.
    
    (cherry picked from commit 6af8284719d151087a1c1e4da210cc5a9fa4a478)

diff --git a/gcc/fortran/intrinsic.c b/gcc/fortran/intrinsic.c
index 30f9f14572b..4271b2065f5 100644
--- a/gcc/fortran/intrinsic.c
+++ b/gcc/fortran/intrinsic.c
@@ -5245,8 +5245,10 @@ gfc_convert_type_warn (gfc_expr *expr, gfc_typespec *ts, int eflag, int wflag,
 	{
 	  /* Larger kinds can hold values of smaller kinds without problems.
 	     Hence, only warn if target kind is smaller than the source
-	     kind - or if -Wconversion-extra is specified.  */
-	  if (expr->expr_type != EXPR_CONSTANT)
+	     kind - or if -Wconversion-extra is specified.  LOGICAL values
+	     will always fit regardless of kind so ignore conversion.  */
+	  if (expr->expr_type != EXPR_CONSTANT
+	      && ts->type != BT_LOGICAL)
 	    {
 	      if (warn_conversion && from_ts.kind > ts->kind)
 		gfc_warning_now (OPT_Wconversion, "Possible change of value in "
diff --git a/gcc/testsuite/gfortran.dg/pr96319.f90 b/gcc/testsuite/gfortran.dg/pr96319.f90
new file mode 100644
index 00000000000..6d8d3b476eb
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr96319.f90
@@ -0,0 +1,12 @@
+! { dg-do compile }
+! { dg-options "-Wconversion -Wconversion-extra" }
+
+program test
+  LOGICAL(1) :: a
+  logical(4) :: t = .true.
+  logical(4) :: b
+  logical(1) :: f = .false.
+  a = t
+  b = f
+end program test
+

commit 5e66b6c0103c1d4f3bef661af41233886c7fe58a
Author: Tiziano Müller <tiziano.mueller@chem.uzh.ch>
Date:   Wed Jul 29 07:28:23 2020 -0700

    preprocessor: Teach traditional about has_include [PR95889]
    
    Traditional cpp (used by fortran) didn;t know about the new
    __has_include__ implementation.  Hey, since when did traditional cpp
    grow __has_include__? That wasn't in knr!
    
            libcpp/
            * init.c (builtin_array): Add xref comment.
            * traditional.c (fun_like_macro): Add HAS_INCLUDE codes.
            gcc/testsuite/
            * c-c++-common/cpp/has-include-1-traditional.c: New.

diff --git a/gcc/testsuite/c-c++-common/cpp/has-include-1-traditional.c b/gcc/testsuite/c-c++-common/cpp/has-include-1-traditional.c
new file mode 100644
index 00000000000..b0acdbece4d
--- /dev/null
+++ b/gcc/testsuite/c-c++-common/cpp/has-include-1-traditional.c
@@ -0,0 +1,38 @@
+/* { dg-do preprocess { target c } } */
+/* { dg-options "-traditional-cpp" } */
+
+#if __has_include ("stdlib.h")
+#else
+#error error 1
+#endif
+#if __has_include (<stdlib.h>)
+#else
+#error error 2
+#endif
+#if !__has_include ("stdlib.h")
+#error error 3
+#elif !__has_include (<stdlib.h>)
+#error error 4
+#endif
+#if __has_include ("stdlib.h") && __has_include (<stdlib.h>)
+#else
+#error error 5
+#endif
+#if !defined(__has_include)
+#error error 6
+#endif
+#ifndef __has_include
+#error error 7
+#endif
+#ifdef __has_include
+#else
+#error error 8
+#endif
+#define m1 __has_include("stdlib.h")
+#define m2 <stdlib.h>
+#if !m1
+#error error 9
+#endif
+#if !__has_include (m2)
+#error error 13
+#endif
diff --git a/libcpp/init.c b/libcpp/init.c
index a3cd8e28f62..f3b5e19cc2a 100644
--- a/libcpp/init.c
+++ b/libcpp/init.c
@@ -401,6 +401,9 @@ static const struct builtin_macro builtin_array[] =
   B("__LINE__",		 BT_SPECLINE,      true),
   B("__INCLUDE_LEVEL__", BT_INCLUDE_LEVEL, true),
   B("__COUNTER__",	 BT_COUNTER,       true),
+  /* Make sure to update the list of built-in
+     function-like macros in traditional.c:
+     fun_like_macro() when adding more following */
   B("__has_attribute",	 BT_HAS_ATTRIBUTE, true),
   B("__has_cpp_attribute", BT_HAS_ATTRIBUTE, true),
   B("__has_builtin",	 BT_HAS_BUILTIN,   true),
diff --git a/libcpp/traditional.c b/libcpp/traditional.c
index 039fcfe27f5..cb0e58feea1 100644
--- a/libcpp/traditional.c
+++ b/libcpp/traditional.c
@@ -326,7 +326,9 @@ fun_like_macro (cpp_hashnode *node)
 {
   if (cpp_builtin_macro_p (node))
     return (node->value.builtin == BT_HAS_ATTRIBUTE
-	    || node->value.builtin == BT_HAS_BUILTIN);
+	    || node->value.builtin == BT_HAS_BUILTIN
+	    || node->value.builtin == BT_HAS_INCLUDE
+	    || node->value.builtin == BT_HAS_INCLUDE_NEXT);
   return node->value.macro->fun_like;
 }
 

commit e6262c0d20b129030c55320ca8911aa7a85ac33d
Author: Joseph Myers <joseph@codesourcery.com>
Date:   Wed Jul 29 19:33:28 2020 +0000

    Update gcc ja.po, sv.po.
    
            * ja.po, sv.po: Update.

diff --git a/gcc/po/ja.po b/gcc/po/ja.po
index 11de13e75b1..ff7ec8526dd 100644
--- a/gcc/po/ja.po
+++ b/gcc/po/ja.po
@@ -1,5 +1,5 @@
 # Japanese messages for GNU gcc
-# Copyright (C) 1999, 2010, 2011, 2018 Free Software Foundation, Inc.
+# Copyright (C) 1999, 2010, 2011, 2018, 2020 Free Software Foundation, Inc.
 # This file is distributed under the same license as the gcc package.
 #
 # gcc では解釈される書式文字列が数種類あります
@@ -16,13 +16,14 @@
 #    IIDA Yosiaki <iida@secom.ne.jp>, 1999.
 # Yasuaki Taniguchi <yasuakit@gmail.com>, 2010, 2011
 # Takeshi Hamasaki <hmatrjp@users.sourceforge.jp>, 2018
+# Hiroshi Takekawa <sian@big.or.jp>, <sian.ht@gmail.com>, 2020
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 8.1.0\n"
+"Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2020-07-20 18:08+0000\n"
-"PO-Revision-Date: 2018-07-17 22:26+0900\n"
-"Last-Translator: Takeshi Hamasaki <hmatrjp@users.sourceforge.jp>\n"
+"PO-Revision-Date: 2020-07-29 19:20+0900\n"
+"Last-Translator: Hiroshi Takekawa <sian@big.or.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
 "Language: ja\n"
 "MIME-Version: 1.0\n"
@@ -54,10 +55,9 @@ msgid "[cannot find %s]"
 msgstr "[%s が見つかりません]"
 
 #: collect2.c:1569
-#, fuzzy, c-format
-#| msgid "collect2 version %s"
+#, c-format
 msgid "collect2 version %s\n"
-msgstr "collect2 バージョン %s"
+msgstr "collect2 バージョン %s\n"
 
 #: collect2.c:1674
 #, c-format
@@ -105,16 +105,14 @@ msgid "const/copy propagation disabled"
 msgstr ""
 
 #: diagnostic.c:158
-#, fuzzy, c-format
-#| msgid "%s: all warnings being treated as errors\n"
+#, c-format
 msgid "%s: all warnings being treated as errors"
-msgstr "%s: すべての警告はエラーとして取り扱われます\n"
+msgstr "%s: すべての警告はエラーとして取り扱われます"
 
 #: diagnostic.c:163
-#, fuzzy, c-format
-#| msgid "%s: some warnings being treated as errors\n"
+#, c-format
 msgid "%s: some warnings being treated as errors"
-msgstr "%s: いくつかの警告はエラーとして取り扱われます\n"
+msgstr "%s: いくつかの警告はエラーとして取り扱われます"
 
 #: diagnostic.c:386 input.c:225 input.c:1874 c-family/c-opts.c:1431
 #: fortran/cpp.c:577 fortran/error.c:1049 fortran/error.c:1069
@@ -132,24 +130,18 @@ msgid "compilation terminated due to -Wfatal-errors.\n"
 msgstr "-Wfatal-errors によりコンパイルを停止しました。\n"
 
 #: diagnostic.c:587
-#, fuzzy, c-format
-#| msgid ""
-#| "Please submit a full bug report,\n"
-#| "with preprocessed source if appropriate.\n"
-#| "See %s for instructions.\n"
+#, c-format
 msgid ""
 "Please submit a full bug report,\n"
 "with preprocessed source if appropriate.\n"
 msgstr ""
 "完全なバグ報告を送って下さい。\n"
 "適切ならば前処理後のソースをつけてください。\n"
-"%s を見れば方法が書いてあります。\n"
 
 #: diagnostic.c:593
-#, fuzzy, c-format
-#| msgid "Use fp double instructions"
+#, c-format
 msgid "See %s for instructions.\n"
-msgstr "倍精度浮動小数命令を有効にする"
+msgstr "報告は %s をご覧ください。\n"
 
 #: diagnostic.c:602
 #, c-format
@@ -158,13 +150,11 @@ msgstr "コンパイルを停止しました。\n"
 
 #: diagnostic.c:663
 msgid "In file included from"
-msgstr ""
+msgstr "次のファイルから読み込み: "
 
 #: diagnostic.c:664
-#, fuzzy
-#| msgid "          %s"
 msgid "                 from"
-msgstr "          %s"
+msgstr "         次から読み込み: "
 
 #: diagnostic.c:1135
 #, c-format
@@ -300,184 +290,122 @@ msgid "Options:\n"
 msgstr "オプション:\n"
 
 #: gcc.c:3546
-#, fuzzy
-#| msgid "  -pass-exit-codes         Exit with highest error code from a phase\n"
 msgid "  -pass-exit-codes         Exit with highest error code from a phase.\n"
-msgstr ""
-"  -pass-exit-codes         フェーズからのエラーコードの最大値を exit\n"
-"                               コードとして返す\n"
+msgstr "  -pass-exit-codes         フェーズからのエラーコードの最大値を exit コードとして返す\n"
 
 #: gcc.c:3547
-#, fuzzy
-#| msgid "  --help                   Display this information\n"
 msgid "  --help                   Display this information.\n"
 msgstr "  --help                   このヘルプ情報を表示する\n"
 
 #: gcc.c:3548
-#, fuzzy
-#| msgid "  --target-help            Display target specific command line options\n"
 msgid "  --target-help            Display target specific command line options.\n"
 msgstr "  --target-help            ターゲット固有のコマンドラインオプションを表示する\n"
 
 #: gcc.c:3549
-#, fuzzy
-#| msgid "  --help={target|optimizers|warnings|params|[^]{joined|separate|undocumented}}[,...]\n"
 msgid "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...].\n"
-msgstr "  --help={target|optimizers|warnings|params|[^]{joined|separate|undocumented}}[,...]\n"
+msgstr "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...].\n"
 
 #: gcc.c:3550
-#, fuzzy
-#| msgid "                           Display specific types of command line options\n"
 msgid "                           Display specific types of command line options.\n"
 msgstr "                           特定の種類のコマンドラインオプションを表示する\n"
 
 #: gcc.c:3552
-#, fuzzy
-#| msgid "  (Use '-v --help' to display command line options of sub-processes)\n"
 msgid "  (Use '-v --help' to display command line options of sub-processes).\n"
 msgstr "(`-v --help' を使うと、子プロセスのコマンドラインオプションを表示)\n"
 
 #: gcc.c:3553
-#, fuzzy
-#| msgid "  --version                Display compiler version information\n"
 msgid "  --version                Display compiler version information.\n"
 msgstr "  --version                コンパイラのバージョン情報を表示する\n"
 
 #: gcc.c:3554
-#, fuzzy
-#| msgid "  -dumpspecs               Display all of the built in spec strings\n"
 msgid "  -dumpspecs               Display all of the built in spec strings.\n"
 msgstr "  -dumpspecs               組み込み spec 文字列をすべて表示する\n"
 
 #: gcc.c:3555
-#, fuzzy
-#| msgid "  -dumpversion             Display the version of the compiler\n"
 msgid "  -dumpversion             Display the version of the compiler.\n"
 msgstr "  -dumpversion             コンパイラのバージョンを表示する\n"
 
 #: gcc.c:3556
-#, fuzzy
-#| msgid "  -dumpmachine             Display the compiler's target processor\n"
 msgid "  -dumpmachine             Display the compiler's target processor.\n"
 msgstr "  -dumpmachine             コンパイラのターゲットプロセッサを表示する\n"
 
 #: gcc.c:3557
-#, fuzzy
-#| msgid "  -print-search-dirs       Display the directories in the compiler's search path\n"
 msgid "  -print-search-dirs       Display the directories in the compiler's search path.\n"
 msgstr "  -print-search-dirs       コンパイラのサーチパスにあるディレクトリを表示する\n"
 
 #: gcc.c:3558
-#, fuzzy
-#| msgid "  -print-libgcc-file-name  Display the name of the compiler's companion library\n"
 msgid "  -print-libgcc-file-name  Display the name of the compiler's companion library.\n"
 msgstr "  -print-libgcc-file-name  コンパイラのコンパニオンライブラリ名を表示する\n"
 
 #: gcc.c:3559
-#, fuzzy
-#| msgid "  -print-file-name=<lib>   Display the full path to library <lib>\n"
 msgid "  -print-file-name=<lib>   Display the full path to library <lib>.\n"
 msgstr "  -print-file-name=<lib>   ライブラリ <lib> へのフルパスを表示する\n"
 
 #: gcc.c:3560
-#, fuzzy
-#| msgid "  -print-prog-name=<prog>  Display the full path to compiler component <prog>\n"
 msgid "  -print-prog-name=<prog>  Display the full path to compiler component <prog>.\n"
 msgstr "  -print-prog-name=<prog>  コンパイラの部品 <prog> へのフルパスを表示する\n"
 
 #: gcc.c:3561
-#, fuzzy
-#| msgid ""
-#| "  -print-multi-lib         Display the mapping between command line options and\n"
-#| "                           multiple library search directories\n"
 msgid ""
 "  -print-multiarch         Display the target's normalized GNU triplet, used as\n"
 "                           a component in the library path.\n"
 msgstr ""
-"  -print-multi-lib         コマンドラインオプションと複数のライブラリ探索し\n"
-"                               ディレクトリとの対応を表示する\n"
+"  -print-multiarch         ライブラリの検索に用いられる\n"
+"                           ターゲットの決められた GNU 3つ組を表示します。\n"
 
 #: gcc.c:3564
-#, fuzzy
-#| msgid "  -print-multi-directory   Display the root directory for versions of libgcc\n"
 msgid "  -print-multi-directory   Display the root directory for versions of libgcc.\n"
 msgstr "  -print-multi-directory   libgcc のバージョンディレクトリルートを表示する\n"
 
 #: gcc.c:3565
-#, fuzzy
-#| msgid ""
-#| "  -print-multi-lib         Display the mapping between command line options and\n"
-#| "                           multiple library search directories\n"
 msgid ""
 "  -print-multi-lib         Display the mapping between command line options and\n"
 "                           multiple library search directories.\n"
 msgstr ""
-"  -print-multi-lib         コマンドラインオプションと複数のライブラリ探索し\n"
-"                               ディレクトリとの対応を表示する\n"
+"  -print-multi-lib         コマンドラインオプションと\n"
+"                           マルチライブラリ探索ディレクトリとの対応を表示する\n"
 
 #: gcc.c:3568
-#, fuzzy
-#| msgid "  -print-multi-os-directory Display the relative path to OS libraries\n"
 msgid "  -print-multi-os-directory Display the relative path to OS libraries.\n"
-msgstr "  -print-multi-os-directory OSライブラリ関連のパスを表示する\n"
+msgstr "  -print-multi-os-directory OSライブラリへの相対パスを表示する\n"
 
 #: gcc.c:3569
-#, fuzzy
-#| msgid "  -print-sysroot           Display the target libraries directory\n"
 msgid "  -print-sysroot           Display the target libraries directory.\n"
 msgstr "  -print-sysroot           ターゲットライブラリのディレクトリを表示する\n"
 
 #: gcc.c:3570
-#, fuzzy
-#| msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers\n"
 msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers.\n"
-msgstr "  -print-sysroot-headers-suffix ヘッダを見つけるために使用する sysroot 接尾辞を表示する\n"
+msgstr "  -print-sysroot-headers-suffix ヘッダを見つけるために使用する sysroot 接頭辞を表示する\n"
 
 #: gcc.c:3571
-#, fuzzy
-#| msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler\n"
 msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler.\n"
 msgstr "  -Wa,<options>            カンマ区切りの <options> をアセンブラに渡す\n"
 
 #: gcc.c:3572
-#, fuzzy
-#| msgid "  -Wp,<options>            Pass comma-separated <options> on to the preprocessor\n"
 msgid "  -Wp,<options>            Pass comma-separated <options> on to the preprocessor.\n"
 msgstr "  -Wp,<options>            カンマ区切りの <options> をプリプロセッサに渡す\n"
 
 #: gcc.c:3573
-#, fuzzy
-#| msgid "  -Wl,<options>            Pass comma-separated <options> on to the linker\n"
 msgid "  -Wl,<options>            Pass comma-separated <options> on to the linker.\n"
 msgstr "  -Wl,<options>            カンマ区切りの <options> をリンカに渡す\n"
 
 #: gcc.c:3574
-#, fuzzy
-#| msgid "  -Xassembler <arg>        Pass <arg> on to the assembler\n"
 msgid "  -Xassembler <arg>        Pass <arg> on to the assembler.\n"
 msgstr "  -Xassembler <arg>        <arg> をアセンブラに渡す\n"
 
 #: gcc.c:3575
-#, fuzzy
-#| msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor\n"
 msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor.\n"
 msgstr "  -Xpreprocessor <arg>     <arg> をプリプロセッサに渡す\n"
 
 #: gcc.c:3576
-#, fuzzy
-#| msgid "  -Xlinker <arg>           Pass <arg> on to the linker\n"
 msgid "  -Xlinker <arg>           Pass <arg> on to the linker.\n"
 msgstr "  -Xlinker <arg>           <arg> をリンカに渡す\n"
 
 #: gcc.c:3577
-#, fuzzy
-#| msgid "  -save-temps              Do not delete intermediate files\n"
 msgid "  -save-temps              Do not delete intermediate files.\n"
 msgstr "  -save-temps              中間ファイルを削除しない\n"
 
 #: gcc.c:3578
-#, fuzzy
-#| msgid "  -save-temps=<arg>        Do not delete intermediate files\n"
 msgid "  -save-temps=<arg>        Do not delete intermediate files.\n"
 msgstr "  -save-temps=<arg>        中間ファイルを削除しない\n"
 
@@ -488,34 +416,22 @@ msgid ""
 msgstr ""
 
 #: gcc.c:3582
-#, fuzzy
-#| msgid "  -pipe                    Use pipes rather than intermediate files\n"
 msgid "  -pipe                    Use pipes rather than intermediate files.\n"
 msgstr "  -pipe                    中間ファイルではなくパイプを使う\n"
 
 #: gcc.c:3583
-#, fuzzy
-#| msgid "  -time                    Time the execution of each subprocess\n"
 msgid "  -time                    Time the execution of each subprocess.\n"
 msgstr "  -time                    子プロセスごとの実行時間を計測する\n"
 
 #: gcc.c:3584
-#, fuzzy
-#| msgid "  -specs=<file>            Override built-in specs with the contents of <file>\n"
 msgid "  -specs=<file>            Override built-in specs with the contents of <file>.\n"
 msgstr "  -specs=<file>            組み込み specs を <file> の内容で上書きする\n"
 
 #: gcc.c:3585
-#, fuzzy
-#| msgid "  -std=<standard>          Assume that the input sources are for <standard>\n"
 msgid "  -std=<standard>          Assume that the input sources are for <standard>.\n"
 msgstr "  -std=<standard>          入力ソースを <standard> に準拠すると見なす\n"
 
 #: gcc.c:3586
-#, fuzzy
-#| msgid ""
-#| "  --sysroot=<directory>    Use <directory> as the root directory for headers\n"
-#| "                           and libraries\n"
 msgid ""
 "  --sysroot=<directory>    Use <directory> as the root directory for headers\n"
 "                           and libraries.\n"
@@ -524,14 +440,10 @@ msgstr ""
 "                           <directory> を使用する\n"
 
 #: gcc.c:3589
-#, fuzzy
-#| msgid "  -B <directory>           Add <directory> to the compiler's search paths\n"
 msgid "  -B <directory>           Add <directory> to the compiler's search paths.\n"
 msgstr "  -B <directory>           <directory> をコンパイラの探索パスに追加する\n"
 
 #: gcc.c:3590
-#, fuzzy
-#| msgid "  -v                       Display the programs invoked by the compiler\n"
 msgid "  -v                       Display the programs invoked by the compiler.\n"
 msgstr "  -v                       コンパイラによって起動されるプログラムを表示する\n"
 
@@ -540,26 +452,18 @@ msgid "  -###                     Like -v but options quoted and commands not ex
 msgstr ""
 
 #: gcc.c:3592
-#, fuzzy
-#| msgid "  -E                       Preprocess only; do not compile, assemble or link\n"
 msgid "  -E                       Preprocess only; do not compile, assemble or link.\n"
 msgstr "  -E                       前処理のみ行う。コンパイル、アセンブル、リンクは行わない\n"
 
 #: gcc.c:3593
-#, fuzzy
-#| msgid "  -S                       Compile only; do not assemble or link\n"
 msgid "  -S                       Compile only; do not assemble or link.\n"
 msgstr "  -S                       コンパイルのみ行う。アセンブル、リンクは行わない\n"
 
 #: gcc.c:3594
-#, fuzzy
-#| msgid "  -c                       Compile and assemble, but do not link\n"
 msgid "  -c                       Compile and assemble, but do not link.\n"
 msgstr "  -c                       コンパイル、アセンブルを行う。リンクは行わない\n"
 
 #: gcc.c:3595
-#, fuzzy
-#| msgid "  -o <file>                Place the output into <file>\n"
 msgid "  -o <file>                Place the output into <file>.\n"
 msgstr "  -o <file>                <file> に出力する\n"
 
@@ -567,13 +471,11 @@ msgstr "  -o <file>                <file> に出力する\n"
 msgid ""
 "  -pie                     Create a dynamically linked position independent\n"
 "                           executable.\n"
-msgstr ""
+msgstr "  -pie                     動的リンク位置非依存(PIE)実行バイナリを生成する\n"
 
 #: gcc.c:3598
-#, fuzzy
-#| msgid "  --help                   Display this information\n"
 msgid "  -shared                  Create a shared library.\n"
-msgstr "  --help                   このヘルプ情報を表示する\n"
+msgstr "  -shared                  共有ライブラリを生成する\n"
 
 #: gcc.c:3599
 msgid ""
@@ -597,10 +499,9 @@ msgstr ""
 "には -W<letter> オプションを使わなければなりません。\n"
 
 #: gcc.c:6059
-#, fuzzy, c-format
-#| msgid "Processing spec %c%s%c, which is '%s'\n"
+#, c-format
 msgid "Processing spec (%s), which is '%s'\n"
-msgstr "spec %c%s%c を処理中, これは '%s' です\n"
+msgstr "spec (%s) を処理中, これは '%s' です\n"
 
 #: gcc.c:6809
 #, c-format
@@ -620,12 +521,12 @@ msgstr "スレッドモデル: %s\n"
 #: gcc.c:6825
 #, c-format
 msgid "Supported LTO compression algorithms: zlib"
-msgstr ""
+msgstr "サポートされている LTO 圧縮アルゴリズム: zlib"
 
 #: gcc.c:6827
 #, c-format
 msgid " zstd"
-msgstr ""
+msgstr " zstd"
 
 #: gcc.c:6829 gcov.c:1408 gcov.c:1476 gcov.c:2813
 #, c-format
@@ -645,12 +546,12 @@ msgstr "gcc ドライババージョン %s %s 実行 gcc バージョン %s\n"
 #: gcc.c:6916 gcc.c:7126
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
-msgstr ""
+msgstr "バグが再現できないのでハードウェアかOSの問題だと思われます。\n"
 
 #: gcc.c:7050
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
-msgstr ""
+msgstr "前処理したソースは %s にあります、バグレポートに添付してください。\n"
 
 #: gcc.c:7900
 #, c-format
@@ -743,16 +644,14 @@ msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
 #: gcov-tool.c:176 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
+#, c-format
 msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
+msgstr "    -o, --output <dir>                  <dir> に出力します\n"
 
 #: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
-#, fuzzy, c-format
-#| msgid "  -v, --version                   Print version number, then exit\n"
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
-msgstr "  -v, --version                   バージョン番号を表示して終了する\n"
+msgstr "    -v, --verbose                       冗長モード\n"
 
 #: gcov-tool.c:178
 #, c-format
@@ -805,28 +704,24 @@ msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profil
 msgstr ""
 
 #: gcov-tool.c:420
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -f, --function                      Print function level info\n"
-msgstr "  -h, --help                      このヘルプを表示して終了する\n"
+msgstr "    -f, --function                      関数レベルの情報を表示\n"
 
 #: gcov-tool.c:421
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -F, --fullname                      Print full filename\n"
-msgstr "  -h, --help                      このヘルプを表示して終了する\n"
+msgstr "    -F, --fullname                      ファイル名をフルパスで表示\n"
 
 #: gcov-tool.c:422
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "  -h, --help                      このヘルプを表示して終了する\n"
+msgstr "    -h, --hotonly                       hot なオブジェクト/関数のみ情報を表示\n"
 
 #: gcov-tool.c:423
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
-msgstr "  -h, --help                      このヘルプを表示して終了する\n"
+msgstr "    -o, --object                        オブジェクトレベルの情報を表示\n"
 
 #: gcov-tool.c:424
 #, c-format
@@ -839,12 +734,11 @@ msgid "Overlap subcomand usage:"
 msgstr ""
 
 #: gcov-tool.c:510
-#, fuzzy, c-format
-#| msgid "Usage: %s [OPTIONS]... CLASSNAMEmain [OUTFILE]\n"
+#, c-format
 msgid ""
 "Usage: %s [OPTION]... SUB_COMMAND [OPTION]...\n"
 "\n"
-msgstr "使用法: %s [OPTIONS]... CLASSNAMEmain [OUTFILE]\n"
+msgstr "使用法: %s [OPTION]... SUB_COMMAND [OPTION]...\n"
 
 #: gcov-tool.c:511
 #, c-format
@@ -854,16 +748,14 @@ msgid ""
 msgstr ""
 
 #: gcov-tool.c:512
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "  -h, --help                            Print this help, then exit\n"
-msgstr "  -h, --help                      このヘルプを表示して終了する\n"
+msgstr "  -h, --help                            このヘルプを表示して終了する\n"
 
 #: gcov-tool.c:513
-#, fuzzy, c-format
-#| msgid "  -v, --version                   Print version number, then exit\n"
+#, c-format
 msgid "  -v, --version                         Print version number, then exit\n"
-msgstr "  -v, --version                   バージョン番号を表示して終了する\n"
+msgstr "  -v, --version                         バージョン番号を表示して終了する\n"
 
 #: gcov-tool.c:517 gcov.c:915
 #, c-format
@@ -879,7 +771,7 @@ msgstr ""
 #: gcov-tool.c:528
 #, c-format
 msgid "Copyright %s 2020 Free Software Foundation, Inc.\n"
-msgstr ""
+msgstr "Copyright %s 2020 Free Software Foundation, Inc.\n"
 
 #: gcov-tool.c:531 gcov.c:929
 #, c-format
@@ -895,15 +787,12 @@ msgstr ""
 "\n"
 
 #: gcov.c:889
-#, fuzzy, c-format
-#| msgid ""
-#| "Usage: gcov [OPTION]... SOURCEFILE...\n"
-#| "\n"
+#, c-format
 msgid ""
 "Usage: gcov [OPTION...] SOURCE|OBJ...\n"
 "\n"
 msgstr ""
-"使用法: gcov [OPTION]... SOURCEFILE...\n"
+"使用法: gcov [OPTION...]... SOURCE|OBJ...\n"
 "\n"
 
 #: gcov.c:890
@@ -924,16 +813,13 @@ msgid "  -b, --branch-probabilities      Include branch probabilities in output\
 msgstr "  -b, --branch-probabilities      出力に分岐可能性情報を含める\n"
 
 #: gcov.c:893
-#, fuzzy, c-format
-#| msgid ""
-#| "  -c, --branch-counts             Given counts of branches taken\n"
-#| "                                    rather than percentages\n"
+#, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
 "                                    rather than percentages\n"
 msgstr ""
-"  -c, --branch-counts             分岐に関する百分率では無く行われた\n"
-"                                    回数を取得する\n"
+"  -c, --branch-counts             分岐に関するカウントを百分率ではなく\n"
+"                                    回数で出力する\n"
 
 #: gcov.c:895
 #, c-format
@@ -951,21 +837,19 @@ msgid "  -h, --help                      Print this help, then exit\n"
 msgstr "  -h, --help                      このヘルプを表示して終了する\n"
 
 #: gcov.c:898
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
+#, c-format
 msgid "  -i, --json-format               Output JSON intermediate format into .gcov.json.gz file\n"
-msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
+msgstr "  -i, --json-format               .gcov.json.gz ファイルに JSON 中間フォーマットで出力\n"
 
 #: gcov.c:899
 #, c-format
 msgid "  -j, --human-readable            Output human readable numbers\n"
-msgstr ""
+msgstr "  -j, --human-readable            人に読みやすい数字で出力する\n"
 
 #: gcov.c:900
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
+#, c-format
 msgid "  -k, --use-colors                Emit colored output\n"
-msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
+msgstr "  -k, --use-colors                色つきで出力する\n"
 
 #: gcov.c:901
 #, c-format
@@ -998,26 +882,23 @@ msgstr "  -p, --preserve-paths            すべてのパス名要素を保護
 
 #: gcov.c:907
 #, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
 msgid "  -q, --use-hotness-colors        Emit perf-like colored output for hot lines\n"
 msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
 
 #: gcov.c:908
 #, fuzzy, c-format
-#| msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgid "  -r, --relative-only             Only show data for relative sources\n"
 msgstr "  -a, --all-blocks                各基本ブロックに関する情報を表示する\n"
 
 #: gcov.c:909
 #, c-format
 msgid "  -s, --source-prefix DIR         Source prefix to elide\n"
-msgstr ""
+msgstr "  -s, --source-prefix DIR         省略するソースディレクトリの接頭辞\n"
 
 #: gcov.c:910
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
+#, c-format
 msgid "  -t, --stdout                    Output to stdout instead of a file\n"
-msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
+msgstr "  -t, --stdout                    ファイルではなく標準出力に出力する\n"
 
 #: gcov.c:911
 #, c-format
@@ -1030,16 +911,14 @@ msgid "  -v, --version                   Print version number, then exit\n"
 msgstr "  -v, --version                   バージョン番号を表示して終了する\n"
 
 #: gcov.c:913
-#, fuzzy, c-format
-#| msgid "  -v, --verbose           Print extra information while running\n"
+#, c-format
 msgid "  -w, --verbose                   Print verbose informations\n"
-msgstr "  -v, --verbose           実行時に追加の情報を表示する\n"
+msgstr "  -w, --verbose                   冗長な情報を出力\n"
 
 #: gcov.c:914
-#, fuzzy, c-format
-#| msgid "  -p, --preserve-paths            Preserve all pathname components\n"
+#, c-format
 msgid "  -x, --hash-filenames            Hash long pathnames\n"
-msgstr "  -p, --preserve-paths            すべてのパス名要素を保護する\n"
+msgstr "  -x, --hash-filenames            長いパス名をハッシュする\n"
 
 #: gcov.c:925
 #, c-format
@@ -1047,70 +926,59 @@ msgid "gcov %s%s\n"
 msgstr "gcov %s%s\n"
 
 #: gcov.c:1259
-#, fuzzy, c-format
-#| msgid "Treat the input file as already preprocessed"
+#, c-format
 msgid "'%s' file is already processed\n"
-msgstr "入力ファイルを前処理済として取り扱う"
+msgstr "入力ファイル '%s' を前処理済として取り扱う\n"
 
 #: gcov.c:1373
-#, fuzzy, c-format
-#| msgid "%s:creating '%s'\n"
+#, c-format
 msgid "Creating '%s'\n"
-msgstr "%s: '%s' を作成しています\n"
+msgstr "'%s' を作成しています\n"
 
 #: gcov.c:1376
-#, fuzzy, c-format
-#| msgid "%s:error writing output file '%s'\n"
+#, c-format
 msgid "Error writing output file '%s'\n"
-msgstr "%s: 出力ファイル '%s' を書き込み中にエラーが発生しました\n"
+msgstr "出力ファイル '%s' を書き込み中にエラーが発生しました\n"
 
 #: gcov.c:1381
-#, fuzzy, c-format
-#| msgid "%s:could not open output file '%s'\n"
+#, c-format
 msgid "Could not open output file '%s'\n"
-msgstr "%s: 出力ファイル '%s' を開けませんでした\n"
+msgstr "出力ファイル '%s' を開けませんでした\n"
 
 #: gcov.c:1386
-#, fuzzy, c-format
-#| msgid "[Leaving %s]\n"
+#, c-format
 msgid "Removing '%s'\n"
-msgstr "[%s を離れます]\n"
+msgstr "'%s' を削除します\n"
 
 #: gcov.c:1498
-#, fuzzy, c-format
-#| msgid "%s:could not open output file '%s'\n"
+#, c-format
 msgid "Cannot open JSON output file %s\n"
-msgstr "%s: 出力ファイル '%s' を開けませんでした\n"
+msgstr "出力 JSON ファイル %s を開けませんでした\n"
 
 #: gcov.c:1506
-#, fuzzy, c-format
-#| msgid "%s:error writing output file '%s'\n"
+#, c-format
 msgid "Error writing JSON output file %s\n"
-msgstr "%s: 出力ファイル '%s' を書き込み中にエラーが発生しました\n"
+msgstr "出力 JSON ファイル %s を書き込み中にエラーが発生しました\n"
 
 #: gcov.c:1673
-#, fuzzy, c-format
-#| msgid "%s:source file is newer than graph file '%s'\n"
+#, c-format
 msgid "%s:source file is newer than notes file '%s'\n"
-msgstr "%s: ソースファイルがグラフファイル '%s' より新しいです\n"
+msgstr "%s:ソースファイルがノートファイル '%s' より新しいです\n"
 
 #: gcov.c:1678
-#, fuzzy, c-format
-#| msgid "(the message is only displayed one per source file)\n"
+#, c-format
 msgid "(the message is displayed only once per source file)\n"
 msgstr "(このメッセージはソースファイルごとに一回のみ表示されます)\n"
 
 #: gcov.c:1698
-#, fuzzy, c-format
-#| msgid "%s:cannot open source file\n"
+#, c-format
 msgid "%s:cannot open notes file\n"
-msgstr "%s: ソースファイルを開けません\n"
+msgstr "%s: ノートファイルを開けません\n"
 
 #: gcov.c:1704
-#, fuzzy, c-format
-#| msgid "%s:not a gcov data file\n"
+#, c-format
 msgid "%s:not a gcov notes file\n"
-msgstr "%s: gcov データファイルではありません\n"
+msgstr "%s: gcov ノートファイルではありません\n"
 
 #: gcov.c:1717
 #, c-format
@@ -1243,10 +1111,9 @@ msgid "branch %2d taken %s%s"
 msgstr ""
 
 #: gcov.c:2808
-#, fuzzy, c-format
-#| msgid "instruction never executed"
+#, c-format
 msgid "branch %2d never executed"
-msgstr "命令は決して実行されません"
+msgstr "命令 %2d は決して実行されません"
 
 #: gcov.c:2811
 #, c-format
@@ -1264,10 +1131,9 @@ msgid "unconditional %2d never executed\n"
 msgstr ""
 
 #: gcov.c:3074
-#, fuzzy, c-format
-#| msgid "%s:cannot open source file\n"
+#, c-format
 msgid "Cannot open source file %s\n"
-msgstr "%s: ソースファイルを開けません\n"
+msgstr "ソースファイル %s を開けません\n"
 
 #: gcse.c:2596
 msgid "PRE disabled"
@@ -1352,7 +1218,6 @@ msgstr ""
 
 #: lra-constraints.c:3019
 #, fuzzy
-#| msgid "Enable unaligned load/store instruction"
 msgid "unable to generate reloads for impossible constraints:"
 msgstr "整列されていない load/store 命令を有効にする"
 
@@ -1362,10 +1227,8 @@ msgstr ""
 
 #. What to print when a switch has no documentation.
 #: opts.c:187
-#, fuzzy
-#| msgid "This switch lacks documentation"
 msgid "This option lacks documentation."
-msgstr "このスイッチには文書がありません"
+msgstr "このオプションに説明がありません"
 
 #: opts.c:188
 msgid "Uses of this option are diagnosed."
@@ -1393,7 +1256,6 @@ msgstr ""
 
 #: opts.c:1412
 #, fuzzy
-#| msgid "STAT variable"
 msgid "[available in "
 msgstr "STAT 変数"
 
@@ -1430,12 +1292,13 @@ msgid " All options with the desired characteristics have already been displayed
 msgstr ""
 
 #: opts.c:1588
-#, fuzzy, c-format
-#| msgid "unrecognized argument '%s' to -mcpu= option"
+#, c-format
 msgid ""
 "  Known valid arguments for %s option:\n"
 "   "
-msgstr "-mcpu= オプションへの認識出来ない引数 '%s' です"
+msgstr ""
+"  %s オプションの有効な引数は以下の通り:\n"
+"   "
 
 #: opts.c:1638
 msgid "The following options are target specific"
@@ -1454,10 +1317,8 @@ msgid "The following options are language-independent"
 msgstr "次のオプションは言語に依存しないものです"
 
 #: opts.c:1650
-#, fuzzy
-#| msgid "The following options control optimizations"
 msgid "The following options control parameters"
-msgstr "次のオプションは最適化を制御します"
+msgstr "次のオプションはパラメータを制御します"
 
 #: opts.c:1656
 msgid "The following options are specific to just the language "
@@ -1489,10 +1350,9 @@ msgid "during %s pass: %s\n"
 msgstr ""
 
 #: passes.c:1790
-#, fuzzy, c-format
-#| msgid "bad zip/jar file %s"
+#, c-format
 msgid "dump file: %s\n"
-msgstr "zip/jar ファイル %s は不正です"
+msgstr "ダンプファイル: %s\n"
 
 #: plugin.c:924
 msgid "Event"
@@ -1509,7 +1369,6 @@ msgstr "*** 警告 *** 有効になっているプラグインがあります。
 
 #: postreload-gcse.c:1354
 #, fuzzy
-#| msgid "Reschedule instructions after register allocation"
 msgid "using simple load CSE after register allocation"
 msgstr "レジスタ確保の後で命令を並べ直す"
 
@@ -1542,13 +1401,11 @@ msgstr "作成時と使用時で '%s' の設定が異なります"
 
 #: targhooks.c:2033
 #, fuzzy
-#| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "作成時と使用時で -fpic の設定が異なります"
 
 #: targhooks.c:2035
 #, fuzzy
-#| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "作成時と使用時で -fpie の設定が異なります"
 
@@ -1572,10 +1429,9 @@ msgid "%s%s%s %sversion %s (%s) compiled by CC, "
 msgstr "%s%s%s %sversion %s (%s) compiled by CC, "
 
 #: toplev.c:619
-#, fuzzy, c-format
-#| msgid "GMP version %s, MPFR version %s, MPC version %s\n"
+#, c-format
 msgid "GMP version %s, MPFR version %s, MPC version %s, isl version %s\n"
-msgstr "GMP version %s, MPFR version %s, MPC version %s\n"
+msgstr "GMP version %s, MPFR version %s, MPC version %s, isl version %s\n"
 
 #: toplev.c:621
 #, c-format
@@ -1607,7 +1463,6 @@ msgstr "inline に出来ると見なされていない関数です"
 
 #: cif-code.def:43
 #, fuzzy
-#| msgid "%qE is not initialized"
 msgid "caller is not optimized"
 msgstr "%qE は初期化されていません"
 
@@ -1624,10 +1479,8 @@ msgid "function not inlinable"
 msgstr "inline にできない関数です"
 
 #: cif-code.def:60
-#, fuzzy
-#| msgid "function body can be overwriten at linktime"
 msgid "function body can be overwritten at link time"
-msgstr "関数本体がリンク時に溢れるかもしれません"
+msgstr "関数本体がリンク時に上書き可能です"
 
 #: cif-code.def:64
 msgid "function not inline candidate"
@@ -1691,7 +1544,6 @@ msgstr ""
 
 #: cif-code.def:117
 #, fuzzy
-#| msgid "Enable exception handling"
 msgid "non-call exception handling mismatch"
 msgstr "例外処理を有効にする"
 
@@ -1708,20 +1560,16 @@ msgid "callee refers to comdat-local symbols"
 msgstr ""
 
 #: cif-code.def:133
-#, fuzzy
-#| msgid "multiple function type attributes specified"
 msgid "function attribute mismatch"
-msgstr "複数の関数型属性が指定されています"
+msgstr "関数属性が合いません"
 
 #: cif-code.def:138
 msgid "function has external linkage when the user requests only inlining static for live patching"
 msgstr ""
 
 #: cif-code.def:143
-#, fuzzy
-#| msgid "unrecoverable error"
 msgid "unreachable"
-msgstr "回復できないエラー"
+msgstr "到達不可能"
 
 #. The remainder are real diagnostic types.
 #: diagnostic.def:33
@@ -2051,7 +1899,6 @@ msgstr "<コマンドライン>"
 
 #: config/aarch64/aarch64.c:9995
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
@@ -2064,16 +1911,14 @@ msgstr "コード '%c' に対する無効な被演算子です"
 #: config/pru/pru.c:1700 config/pru/pru.c:1710 config/pru/pru.c:1741
 #: config/pru/pru.c:1752 config/pru/pru.c:1824
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
 #: config/aarch64/aarch64.c:10108 config/aarch64/aarch64.c:10119
 #: config/aarch64/aarch64.c:10271 config/aarch64/aarch64.c:10282
-#, fuzzy, c-format
-#| msgid "invalid vector permutation constant"
+#, c-format
 msgid "invalid vector constant"
-msgstr "無効なベクトル順列定数です"
+msgstr "無効なベクトル定数です"
 
 #: config/aarch64/aarch64.c:10131 config/aarch64/aarch64.c:10143
 #, c-format
@@ -2082,7 +1927,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:10157
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
@@ -2092,32 +1936,27 @@ msgid "missing operand"
 msgstr "被演算子がありません"
 
 #: config/aarch64/aarch64.c:10308
-#, fuzzy, c-format
-#| msgid "invalid insn:"
+#, c-format
 msgid "invalid constant"
-msgstr "無効な命令:"
+msgstr "無効な定数"
 
 #: config/aarch64/aarch64.c:10311
 #, fuzzy, c-format
-#| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "無効な %%d 被演算子です"
 
 #: config/aarch64/aarch64.c:10437 config/aarch64/aarch64.c:10442
 #, fuzzy, c-format
-#| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
 #: config/aarch64/aarch64.c:10462
 #, fuzzy, c-format
-#| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
 #: config/aarch64/aarch64.c:22752 config/arm/arm.c:33184
 #, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
@@ -2133,7 +1972,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:22793
 #, fuzzy
-#| msgid "invalid operands in binary operation"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二進演算内で無効な被演算子です"
 
@@ -2225,31 +2063,26 @@ msgstr "無効な %%xn コード"
 
 #: config/alpha/alpha.c:5462
 #, fuzzy, c-format
-#| msgid "invalid address"
 msgid "invalid operand address"
 msgstr "無効なアドレスです"
 
 #: config/arc/arc.c:4519
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "%%R コードに対する無効な被演算子"
 
 #: config/arc/arc.c:4527
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "%%R コードに対する無効な被演算子"
 
 #: config/arc/arc.c:4535
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "%%R コードに対する無効な被演算子"
 
 #: config/arc/arc.c:4543
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "%%R コードに対する無効な被演算子"
 
@@ -2285,7 +2118,6 @@ msgstr "%%V コードに対する無効な被演算子"
 
 #: config/arc/arc.c:4923
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
 msgstr "%%R コードに対する無効な被演算子"
 
@@ -2299,7 +2131,6 @@ msgstr "無効な被演算子出力コード"
 
 #: config/arc/arc.c:6489
 #, fuzzy, c-format
-#| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "被演算子として無効な UNSPEC です"
 
@@ -2326,7 +2157,6 @@ msgstr "条件シーケンスにある述語付き命令"
 #: config/arm/arm.c:23628 config/arm/arm.c:23641 config/arm/arm.c:23666
 #: config/nios2/nios2.c:3086
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
@@ -2362,19 +2192,16 @@ msgstr "アドレス被演算子は X、Y または Z レジスタに対する
 
 #: config/avr/avr.c:2813
 #, fuzzy
-#| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
 #: config/avr/avr.c:2863 config/avr/avr.c:2930
 #, fuzzy
-#| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "誤ったアドレスです。(reg+disp) ではありません:"
 
 #: config/avr/avr.c:2872
 #, fuzzy
-#| msgid "bad address, not a constant):"
 msgid "bad address, not a constant:"
 msgstr "誤ったアドレスです。定数ではありません):"
 
@@ -2425,28 +2252,20 @@ msgid "internal compiler error.  Incorrect shift:"
 msgstr "コンパイラ内部エラー。正しくないシフト:"
 
 #: config/avr/avr.c:8666
-#, fuzzy
-#| msgid "invalid types in fixed-point conversion"
 msgid "unsupported fixed-point conversion"
-msgstr "固定小数変換内で無効な型です"
+msgstr "サポートしていない固定小数点変換です"
 
 #: config/avr/avr.c:10023
-#, fuzzy
-#| msgid "STAT variable"
 msgid "variable"
-msgstr "STAT 変数"
+msgstr "変数"
 
 #: config/avr/avr.c:10028
-#, fuzzy
-#| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
-msgstr "仮引数 %q+D が再宣言されました"
+msgstr "関数パラメータ"
 
 #: config/avr/avr.c:10033
-#, fuzzy
-#| msgid "struct defined here"
 msgid "structure field"
-msgstr "構造体がここで定義されています"
+msgstr "構造体フィールド"
 
 #: config/avr/avr.c:10039
 #, fuzzy
@@ -2455,13 +2274,11 @@ msgstr "`%s' の宣言は関数の配列"
 
 #: config/avr/avr.c:10044
 #, fuzzy
-#| msgid "null pointer"
 msgid "pointer"
 msgstr "NULL ポインタ"
 
 #: config/avr/driver-avr.c:50
 #, fuzzy, c-format
-#| msgid "unknown spec function %qs"
 msgid ""
 "Running spec function '%s' with %d args\n"
 "\n"
@@ -2479,14 +2296,12 @@ msgstr "無効な const_double 被演算子"
 
 #: config/bpf/bpf.c:743
 #, fuzzy
-#| msgid "invalid addressing mode"
 msgid "invalid address in operand"
 msgstr "無効なアドレスモードです"
 
 #. Fallthrough.
 #: config/bpf/bpf.c:750
 #, fuzzy
-#| msgid "unexpected operand"
 msgid "unsupported operand"
 msgstr "予期しない演算子"
 
@@ -2719,19 +2534,16 @@ msgstr ""
 #: config/gcn/gcn.c:5630 config/gcn/gcn.c:5645 config/gcn/gcn.c:5664
 #: config/gcn/gcn.c:5740 config/gcn/gcn.c:5936 config/gcn/gcn.c:6051
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R code"
 msgid "invalid operand %%xn code"
 msgstr "%%R コードに対する無効な被演算子"
 
 #: config/gcn/gcn.c:6039
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand %%xn code invalid for QImode"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
 #: config/gcn/gcn.c:6121
 #, fuzzy, c-format
-#| msgid "invalid insn:"
 msgid "invalid fp constant"
 msgstr "無効な命令:"
 
@@ -2739,7 +2551,6 @@ msgstr "無効な命令:"
 #: config/h8300/h8300.c:1670 config/h8300/h8300.c:1679
 #: config/h8300/h8300.c:1687 config/h8300/h8300.c:1695
 #, fuzzy, c-format
-#| msgid "expected interface or pointer to interface"
 msgid "Expected register or constant integer."
 msgstr "インターフェースまたはインターフェースへのポインタが予期されます"
 
@@ -2750,43 +2561,36 @@ msgstr "被演算子として無効な UNSPEC です"
 
 #: config/i386/i386.c:12369
 #, fuzzy, c-format
-#| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "%<restrict%> の誤った使用法です"
 
 #: config/i386/i386.c:12374
 #, fuzzy, c-format
-#| msgid "invalid use of type"
 msgid "invalid use of asm flag output"
 msgstr "無効な型の使用法です"
 
 #: config/i386/i386.c:12605
 #, fuzzy, c-format
-#| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
 #: config/i386/i386.c:12640
 #, fuzzy, c-format
-#| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
 #: config/i386/i386.c:12709
 #, fuzzy, c-format
-#| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
 #: config/i386/i386.c:12714
 #, fuzzy, c-format
-#| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
 #: config/i386/i386.c:12769
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a condition code, invalid operand code 'I'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
@@ -2802,37 +2606,31 @@ msgstr "被演算子は条件コードではありません。無効な被演算
 
 #: config/i386/i386.c:12922
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
 #: config/i386/i386.c:12935
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
 #: config/i386/i386.c:12950
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
 #: config/i386/i386.c:12978
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
 #: config/i386/i386.c:12996
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
 #: config/i386/i386.c:13019
 #, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
@@ -2847,10 +2645,9 @@ msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
 #: config/i386/i386.c:13235
-#, fuzzy, c-format
-#| msgid "invalid vector permutation constant"
+#, c-format
 msgid "invalid vector immediate"
-msgstr "無効なベクトル順列定数です"
+msgstr "無効なベクトル直接表記"
 
 #: config/i386/i386.c:16163
 msgid "unknown insn mode"
@@ -2858,7 +2655,6 @@ msgstr "不明な命令モード"
 
 #: config/i386/djgpp.h:143
 #, fuzzy, c-format
-#| msgid "-f%s ignored for Unicos/Mk (not supported)"
 msgid "-f%s ignored (not supported for DJGPP)\n"
 msgstr "Unicos/Mk 用としては -f%s は無視されました (サポートされていません)"
 
@@ -3045,25 +2841,21 @@ msgstr "MMIX 内部: 定数ではありません:"
 
 #: config/msp430/msp430.c:3575
 #, fuzzy, c-format
-#| msgid "invalid reference prefix"
 msgid "invalid operand prefix"
 msgstr "無効な参照接頭辞です"
 
 #: config/msp430/msp430.c:3609
 #, fuzzy, c-format
-#| msgid "invalid use of %<restrict%>"
 msgid "invalid zero extract"
 msgstr "%<restrict%> の誤った使用法です"
 
 #: config/or1k/or1k.c:1116 config/or1k/or1k.c:1124
 #, fuzzy, c-format
-#| msgid "invalid %%d operand"
 msgid "invalid relocation"
 msgstr "無効な %%d 被演算子です"
 
 #: config/or1k/or1k.c:1218
 #, fuzzy, c-format
-#| msgid "invalid %%J value"
 msgid "invalid %%H value"
 msgstr "無効な %%J 値"
 
@@ -3074,55 +2866,46 @@ msgstr "無効な %%d 値です"
 
 #: config/or1k/or1k.c:1279
 #, fuzzy, c-format
-#| msgid "<unknown operator>"
 msgid "unknown operand letter: '%c'"
 msgstr "<不明な演算子>"
 
 #: config/pru/pru.c:1672 config/pru/pru.c:1683
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "I/O register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
 #: config/pru/pru.c:1689
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "non 32 bit register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
 #: config/pru/pru.c:1794
 #, fuzzy, c-format
-#| msgid "invalid types in fixed-point conversion"
 msgid "unsupported code '%c' for fixed-point:"
 msgstr "固定小数変換内で無効な型です"
 
 #: config/pru/pru.c:1808
 #, fuzzy, c-format
-#| msgid "-mhard-float not supported"
 msgid "double constants not supported"
 msgstr "-mhard-float はサポートされていません"
 
 #: config/pru/pru.c:1891
 #, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
 msgid "unsupported operand %s for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
 #: config/pru/pru.c:1901
 #, fuzzy, c-format
-#| msgid "unexpected side-effects in address"
 msgid "unexpected text address:"
 msgstr "アドレス内の予期しない副作用"
 
 #: config/pru/pru.c:1920
 #, fuzzy, c-format
-#| msgid "unsupported combination: %s"
 msgid "unsupported constant address:"
 msgstr "サポートされていない組み合わせです: %s"
 
 #: config/pru/pru.c:1981
 #, fuzzy, c-format
-#| msgid "invalid types in fixed-point conversion"
 msgid "unsupported memory expression:"
 msgstr "固定小数変換内で無効な型です"
 
@@ -3143,31 +2926,26 @@ msgstr "'%s' をシェル内で実行して制限値を上げてください\n"
 
 #: config/rs6000/rs6000.c:3696
 #, fuzzy
-#| msgid "-mvsx requires hardware floating point"
 msgid "%<-mvsx%> requires hardware floating point"
 msgstr "-mvsx はハードウェア浮動小数を要求します"
 
 #: config/rs6000/rs6000.c:3704
 #, fuzzy
-#| msgid "Disable preprocessing"
 msgid "%<-mvsx%> needs indexed addressing"
 msgstr "前処理を無効にする"
 
 #: config/rs6000/rs6000.c:3709
 #, fuzzy
-#| msgid "-mvsx and -mno-altivec are incompatible"
 msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
 msgstr "-mvsx と -mno-altivec は併用できません"
 
 #: config/rs6000/rs6000.c:3711
 #, fuzzy
-#| msgid "-mno-altivec disables vsx"
 msgid "%<-mno-altivec%> disables vsx"
 msgstr "-mno-altivec は vsx を無効にします"
 
 #: config/rs6000/rs6000.c:3845
 #, fuzzy
-#| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mquad-memory%> requires 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
@@ -3177,7 +2955,6 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:3860
 #, fuzzy
-#| msgid "Generate code in little endian mode"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
@@ -3187,13 +2964,12 @@ msgstr "誤った move です"
 
 #: config/rs6000/rs6000.c:12679
 msgid "Bad 128-bit move"
-msgstr ""
+msgstr "誤った 128 ビット move"
 
 #: config/rs6000/rs6000.c:12859
 #, fuzzy, c-format
-#| msgid "invalid %%J value"
 msgid "invalid %%A value"
-msgstr "無効な %%J 値"
+msgstr "無効な %%A 値"
 
 #: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
@@ -3202,9 +2978,8 @@ msgstr "無効な %%D 値です"
 
 #: config/rs6000/rs6000.c:12883
 #, fuzzy, c-format
-#| msgid "invalid %%H value"
 msgid "invalid %%e value"
-msgstr "無効な %%H 値"
+msgstr "無効な %%e 値"
 
 #: config/rs6000/rs6000.c:12904
 #, c-format
@@ -3253,9 +3028,8 @@ msgstr "無効な %%q 値です"
 
 #: config/rs6000/rs6000.c:13128
 #, fuzzy, c-format
-#| msgid "invalid %%J value"
 msgid "invalid %%t value"
-msgstr "無効な %%J 値"
+msgstr "無効な %%t 値"
 
 #: config/rs6000/rs6000.c:13145
 #, c-format
@@ -3273,10 +3047,9 @@ msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
 #: config/rs6000/rs6000.c:13221
-#, fuzzy, c-format
-#| msgid "invalid %%J value"
+#, c-format
 msgid "invalid %%V value"
-msgstr "無効な %%J 値"
+msgstr "無効な %%V 値"
 
 #: config/rs6000/rs6000.c:13238 config/xtensa/xtensa.c:2435
 #, c-format
@@ -3285,7 +3058,6 @@ msgstr "無効な %%x 値です"
 
 #: config/rs6000/rs6000.c:13295
 #, fuzzy, c-format
-#| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "無効な %%J 値"
 
@@ -3312,13 +3084,11 @@ msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました
 
 #: config/rs6000/rs6000.c:26116
 #, fuzzy
-#| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
 #: config/rs6000/rs6000.c:26185
 #, fuzzy
-#| msgid "Enable unaligned load/store instruction"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
@@ -3328,49 +3098,41 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:26740
 #, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
 #: config/rs6000/rs6000.c:26742
 #, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
-msgstr "%<__fpreg%> への無効な変換です"
+msgstr "無効なバージョン番号形式"
 
 #: config/rs6000/rs6000.c:26744
 #, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
 #: config/rs6000/rs6000.c:26746
 #, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "%<__fpreg%> への無効な変換です"
 
 #: config/rs6000/rs6000.c:26754
 #, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
 #: config/rs6000/rs6000.c:26757
 #, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
-msgstr "%<__fpreg%> への無効な変換です"
+msgstr "無効なバージョン番号形式"
 
 #: config/rs6000/rs6000.c:26760
 #, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
 #: config/rs6000/rs6000.c:26763
 #, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
 msgstr "%<__fpreg%> への無効な変換です"
 
@@ -3436,7 +3198,6 @@ msgstr "無効な定数です - 出力修飾子の使用を試みてください
 
 #: config/s390/s390.c:8142
 #, fuzzy, c-format
-#| msgid "invalid constant for output modifier '%c'"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
@@ -3452,13 +3213,11 @@ msgstr "出力修飾子 '%c' 用の無効な式です"
 
 #: config/s390/s390.c:11871
 #, fuzzy
-#| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
 #: config/s390/s390.c:16238
 #, fuzzy
-#| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "戻りでのポインタの先の符号が異なります"
 
@@ -3514,13 +3273,11 @@ msgstr "無効な %%B 被演算子です"
 #: config/sparc/sparc.c:9553 config/tilegx/tilegx.c:5090
 #: config/tilepro/tilepro.c:4499
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%C operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/sparc/sparc.c:9585 config/tilegx/tilegx.c:5123
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "無効な %%P 被演算子です"
 
@@ -3536,7 +3293,6 @@ msgstr "無効な %%s 被演算子です"
 
 #: config/sparc/sparc.c:9661
 #, fuzzy, c-format
-#| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
 msgstr "浮動小数定数は有効な即値被演算子ではありません"
 
@@ -3572,49 +3328,41 @@ msgstr "無効な %%d 被演算子です"
 
 #: config/tilegx/tilegx.c:5203
 #, fuzzy, c-format
-#| msgid "invalid %%L code"
 msgid "invalid %%H specifier"
 msgstr "無効な %%L コードです"
 
 #: config/tilegx/tilegx.c:5245 config/tilepro/tilepro.c:4513
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%h operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilegx/tilegx.c:5257 config/tilepro/tilepro.c:4577
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%I operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilegx/tilegx.c:5269 config/tilepro/tilepro.c:4589
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%i operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilegx/tilegx.c:5290 config/tilepro/tilepro.c:4610
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%j operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilegx/tilegx.c:5321
 #, fuzzy, c-format
-#| msgid "invalid %%c operand"
 msgid "invalid %%%c operand"
 msgstr "無効な %%c 被演算子です"
 
 #: config/tilegx/tilegx.c:5336 config/tilepro/tilepro.c:4724
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%N operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilegx/tilegx.c:5380
 #, fuzzy, c-format
-#| msgid "invalid operand for 'b' modifier"
 msgid "invalid operand for 'r' specifier"
 msgstr "'b' 修飾子に対する無効な被演算子"
 
@@ -3625,31 +3373,26 @@ msgstr ""
 
 #: config/tilepro/tilepro.c:4549
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%H operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilepro/tilepro.c:4649
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%L operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilepro/tilepro.c:4709
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%M operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilepro/tilepro.c:4752 config/tilepro/tilepro.c:4759
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%t operand"
 msgstr "無効な %%P 被演算子です"
 
 #: config/tilepro/tilepro.c:4779
 #, fuzzy, c-format
-#| msgid "invalid %%P operand"
 msgid "invalid %%r operand"
 msgstr "無効な %%P 被演算子です"
 
@@ -3682,31 +3425,26 @@ msgstr "不正な被演算子が検出されました"
 
 #: config/visium/visium.c:3362
 #, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand "
 msgstr "不正な被演算子が検出されました"
 
 #: config/visium/visium.c:3413
 #, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (1)"
 msgstr "不正な被演算子が検出されました"
 
 #: config/visium/visium.c:3420
 #, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (2)"
 msgstr "不正な被演算子が検出されました"
 
 #: config/visium/visium.c:3435
 #, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (3)"
 msgstr "不正な被演算子が検出されました"
 
 #: config/visium/visium.c:3443
 #, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (4)"
 msgstr "不正な被演算子が検出されました"
 
@@ -3734,7 +3472,7 @@ msgstr "アドレスオフセットが定数ではありません"
 
 #: c/c-objc-common.c:225
 msgid "aka"
-msgstr ""
+msgstr "aka"
 
 #: c/c-objc-common.c:332
 msgid "({anonymous})"
@@ -3902,19 +3640,15 @@ msgstr "%<<%> が予期されます"
 #: c/gimple-parser.c:2313 c/gimple-parser.c:2340 c/gimple-parser.c:2179
 #: c/gimple-parser.c:2216
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<__label__%>"
 msgid "expected label"
 msgstr "%<__label__%> が予期されます"
 
 #: cp/call.c:3868
-#, fuzzy
-#| msgid "candidate 1:"
 msgid "candidate:"
-msgstr "候補 1:"
+msgstr "候補:"
 
 #: cp/call.c:7220
 #, fuzzy
-#| msgid "Enable user-defined instructions"
 msgid "  after user-defined conversion:"
 msgstr "利用者定義命令を有効にする"
 
@@ -3966,10 +3700,9 @@ msgid "<unnamed>"
 msgstr "<名前なし>"
 
 #: cp/error.c:770
-#, fuzzy, c-format
-#| msgid "<unnamed>"
+#, c-format
 msgid "<unnamed %s>"
-msgstr "<名前なし>"
+msgstr "<名前なし %s>"
 
 #: cp/error.c:896
 msgid "<typeprefixerror>"
@@ -4002,16 +3735,12 @@ msgid "{anonymous}"
 msgstr "{無名}"
 
 #: cp/error.c:1217
-#, fuzzy
-#| msgid "(anonymous)"
 msgid "(anonymous namespace)"
-msgstr "(無名)"
+msgstr "(無名名前空間)"
 
 #: cp/error.c:1317
-#, fuzzy
-#| msgid "<template parameter error>"
 msgid "<template arguments error>"
-msgstr "<テンプレートパラメータエラー>"
+msgstr "<テンプレート引数エラー>"
 
 #: cp/error.c:1339
 msgid "<enumerator>"
@@ -4049,8 +3778,6 @@ msgid "<unparsed>"
 msgstr "<未構文解析>"
 
 #: cp/error.c:2842
-#, fuzzy
-#| msgid "<lambda"
 msgid "<lambda>"
 msgstr "<ラムダ"
 
@@ -4096,23 +3823,21 @@ msgstr "ラムダ関数内"
 
 #: cp/error.c:3498
 #, fuzzy, c-format
-#| msgid "%s: In instantiation of %qs:\n"
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: %qs のインスタンス内:\n"
 
 #: cp/error.c:3499
 #, fuzzy
-#| msgid "%s: In instantiation of %qs:\n"
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: %qs のインスタンス内:\n"
 
 #: cp/error.c:3524 cp/error.c:3678
 msgid "%r%s:%d:%d:%R   "
-msgstr ""
+msgstr "%r%s:%d:%d:%R   "
 
 #: cp/error.c:3527 cp/error.c:3681
 msgid "%r%s:%d:%R   "
-msgstr ""
+msgstr "%r%s:%d:%R   "
 
 #: cp/error.c:3535
 #, c-format
@@ -4126,7 +3851,6 @@ msgstr ""
 
 #: cp/error.c:3541
 #, fuzzy
-#| msgid "%s:%d:   recursively instantiated from %qs\n"
 msgid "recursively required from %q#D\n"
 msgstr "%s:%d:   %qs から再帰的に実体化されました\n"
 
@@ -4136,13 +3860,11 @@ msgstr ""
 
 #: cp/error.c:3549
 #, fuzzy
-#| msgid "%s:%d:   recursively instantiated from here"
 msgid "recursively required from here\n"
 msgstr "%s:%d:   ここから再帰的に実体化されました"
 
 #: cp/error.c:3550
 #, fuzzy
-#| msgid "called from here"
 msgid "required from here\n"
 msgstr "ここから呼び出されました"
 
@@ -4156,7 +3878,6 @@ msgstr ""
 
 #: cp/error.c:3662
 #, fuzzy
-#| msgid "%s:%d:%d:   instantiated from %qs\n"
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d:%d:   %qs から実体化されました\n"
 
@@ -4326,7 +4047,7 @@ msgstr ""
 
 #: fortran/error.c:880
 msgid "Fortran 2018:"
-msgstr ""
+msgstr "Fortran 2018:"
 
 #: fortran/error.c:882
 msgid "Fortran 2008 obsolescent feature:"
@@ -4334,7 +4055,7 @@ msgstr ""
 
 #: fortran/error.c:888
 msgid "GNU Extension:"
-msgstr ""
+msgstr "GNU 拡張:"
 
 #: fortran/error.c:890
 msgid "Legacy Extension:"
@@ -4346,7 +4067,6 @@ msgstr ""
 
 #: fortran/error.c:894
 #, fuzzy
-#| msgid "expected operator"
 msgid "Deleted feature:"
 msgstr "演算子が予期されます"
 
@@ -4406,11 +4126,11 @@ msgstr "予期しないファイル終端 (EOF) です"
 
 #: fortran/module.c:1358
 msgid "Name too long"
-msgstr ""
+msgstr "名前が長すぎます"
 
 #: fortran/module.c:1460 fortran/module.c:1563
 msgid "Bad name"
-msgstr ""
+msgstr "不正な名前です"
 
 #: fortran/module.c:1587
 #, fuzzy
@@ -4522,19 +4242,16 @@ msgstr ""
 
 #: fortran/resolve.c:2399
 #, fuzzy
-#| msgid "no arguments"
 msgid "allocatable argument"
 msgstr "引数がありません"
 
 #: fortran/resolve.c:2404
 #, fuzzy
-#| msgid "not enough arguments"
 msgid "asynchronous argument"
 msgstr "十分な引数がありません"
 
 #: fortran/resolve.c:2409
 #, fuzzy
-#| msgid "invalid PHI argument"
 msgid "optional argument"
 msgstr "無効な PHI 引数です"
 
@@ -4545,37 +4262,31 @@ msgstr "代入"
 
 #: fortran/resolve.c:2419
 #, fuzzy
-#| msgid "no arguments"
 msgid "target argument"
 msgstr "引数がありません"
 
 #: fortran/resolve.c:2424
 #, fuzzy
-#| msgid "invalid PHI argument"
 msgid "value argument"
 msgstr "無効な PHI 引数です"
 
 #: fortran/resolve.c:2429
 #, fuzzy
-#| msgid "no arguments"
 msgid "volatile argument"
 msgstr "引数がありません"
 
 #: fortran/resolve.c:2434
 #, fuzzy
-#| msgid "mismatched arguments"
 msgid "assumed-shape argument"
 msgstr "合っていない引数です"
 
 #: fortran/resolve.c:2439
 #, fuzzy
-#| msgid "mismatched arguments"
 msgid "assumed-rank argument"
 msgstr "合っていない引数です"
 
 #: fortran/resolve.c:2444
 #, fuzzy
-#| msgid "array assignment"
 msgid "coarray argument"
 msgstr "配列代入"
 
@@ -4585,7 +4296,6 @@ msgstr ""
 
 #: fortran/resolve.c:2454
 #, fuzzy
-#| msgid "no arguments"
 msgid "polymorphic argument"
 msgstr "引数がありません"
 
@@ -4597,7 +4307,6 @@ msgstr ""
 #. See also TS 29113, Note 6.1.
 #: fortran/resolve.c:2466
 #, fuzzy
-#| msgid "mismatched arguments"
 msgid "assumed-type argument"
 msgstr "合っていない引数です"
 
@@ -4673,7 +4382,6 @@ msgstr ""
 
 #: fortran/resolve.c:4267
 #, fuzzy, c-format
-#| msgid "<unknown operator>"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "<不明な演算子>"
 
@@ -4867,7 +4575,6 @@ msgstr "正しくない関数戻り値です"
 
 #: fortran/trans.c:659 fortran/trans.c:734
 #, fuzzy, c-format
-#| msgid "Memory allocation failed"
 msgid "Error allocating %lu bytes"
 msgstr "メモリ配置に失敗しました"
 
@@ -4893,7 +4600,6 @@ msgstr ""
 #. The remainder are real diagnostic types.
 #: fortran/gfc-diagnostic.def:33
 #, fuzzy
-#| msgid "Fatal Error:"
 msgid "Fatal Error"
 msgstr "致命的エラー:"
 
@@ -4901,25 +4607,21 @@ msgstr "致命的エラー:"
 #. when reporting fatal signal in the compiler.
 #: fortran/gfc-diagnostic.def:34 fortran/gfc-diagnostic.def:50
 #, fuzzy
-#| msgid "internal compiler error: "
 msgid "internal compiler error"
 msgstr "コンパイラ内部エラー: "
 
 #: fortran/gfc-diagnostic.def:35
 #, fuzzy
-#| msgid "Error:"
 msgid "Error"
 msgstr "エラー:"
 
 #: fortran/gfc-diagnostic.def:36
 #, fuzzy
-#| msgid "sorry, unimplemented: "
 msgid "sorry, unimplemented"
 msgstr "残念ですが未実装です: "
 
 #: fortran/gfc-diagnostic.def:37
 #, fuzzy
-#| msgid "Warning:"
 msgid "Warning"
 msgstr "警告: "
 
@@ -4929,13 +4631,11 @@ msgstr ""
 
 #: fortran/gfc-diagnostic.def:39
 #, fuzzy
-#| msgid "note: "
 msgid "note"
 msgstr "備考: "
 
 #: fortran/gfc-diagnostic.def:40
 #, fuzzy
-#| msgid "debug: "
 msgid "debug"
 msgstr "デバッグ: "
 
@@ -4947,7 +4647,6 @@ msgstr ""
 
 #: fortran/gfc-diagnostic.def:44
 #, fuzzy
-#| msgid "<type-error>"
 msgid "permerror"
 msgstr "<型エラー>"
 
@@ -4955,7 +4654,6 @@ msgstr "<型エラー>"
 #. due to -Werror and -Werror=warning.
 #: fortran/gfc-diagnostic.def:47
 #, fuzzy
-#| msgid "error: "
 msgid "error"
 msgstr "エラー: "
 
@@ -4964,10 +4662,8 @@ msgid "lseek failed while reading export data"
 msgstr ""
 
 #: go/go-backend.c:173
-#, fuzzy
-#| msgid "Memory allocation failed"
 msgid "memory allocation failed while reading export data"
-msgstr "メモリ配置に失敗しました"
+msgstr "export データを読み込み中にメモリ確保に失敗しました"
 
 #: go/go-backend.c:181
 msgid "read failed while reading export data"
@@ -4978,22 +4674,16 @@ msgid "short read while reading export data"
 msgstr ""
 
 #: gcc.c:762 gcc.c:766 gcc.c:821
-#, fuzzy
-#| msgid "-m%s not supported in this configuration"
 msgid "-gz is not supported in this configuration"
-msgstr "-m%s はこの設定ではサポートされていません"
+msgstr "-gz はこの構成ではサポートされていません"
 
 #: gcc.c:772 gcc.c:832
-#, fuzzy
-#| msgid "ifunc is not supported in this configuration"
 msgid "-gz=zlib is not supported in this configuration"
-msgstr "ifunc はこの設定ではサポートされていません"
+msgstr "-gz=zlib はこの構成ではサポートされていません"
 
 #: gcc.c:977
-#, fuzzy
-#| msgid "ifunc is not supported in this configuration"
 msgid "-fuse-linker-plugin is not supported in this configuration"
-msgstr "ifunc はこの設定ではサポートされていません"
+msgstr "-fuse-linker-plugin はこの構成ではサポートされていません"
 
 #: gcc.c:992
 msgid "cannot specify -static with -fsanitize=address"
@@ -5004,16 +4694,12 @@ msgid "cannot specify -static with -fsanitize=thread"
 msgstr ""
 
 #: gcc.c:1016
-#, fuzzy
-#| msgid "weakref is not supported in this configuration"
 msgid "-fvtable-verify=std is not supported in this configuration"
-msgstr "弱い参照はこの設定ではサポートされていません"
+msgstr "-fvtable-verify=std はこの構成ではサポートされていません"
 
 #: gcc.c:1018
-#, fuzzy
-#| msgid "alias definitions not supported in this configuration"
 msgid "-fvtable-verify=preinit is not supported in this configuration"
-msgstr "この設定では別名定義はサポートされていません"
+msgstr "-fvtable-verify=preinit はこの構成ではサポートされていません"
 
 #: gcc.c:1146 ada/gcc-interface/lang-specs.h:33
 msgid "-pg and -fomit-frame-pointer are incompatible"
@@ -5028,9 +4714,8 @@ msgid "-E or -x required when input is from standard input"
 msgstr "入力が標準入力からの場合は -E または -x が必要です"
 
 #: config/darwin.h:132 config/darwin.h:480
-#, fuzzy
 msgid "gsplit-dwarf is not supported on this platform"
-msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
+msgstr "gsplit-dwarf はこの構成ではサポートされていません"
 
 #: config/darwin.h:136 config/rs6000/darwin.h:123
 msgid " conflicting code gen style switches are used"
@@ -5041,10 +4726,8 @@ msgid "the y option is obsolete and ignored"
 msgstr ""
 
 #: config/darwin.h:143
-#, fuzzy
-#| msgid "-fpic is not supported"
 msgid "rdynamic is not supported"
-msgstr "-fpic はサポートされていません"
+msgstr "rdynamic はサポートされていません"
 
 #: config/darwin.h:300
 msgid "-current_version only allowed with -dynamiclib"
@@ -5097,10 +4780,8 @@ msgid "does not support multilib"
 msgstr "multilib はサポートしません"
 
 #: config/sol2.h:452
-#, fuzzy
-#| msgid "ifunc is not supported in this configuration"
 msgid "-pie is not supported in this configuration"
-msgstr "ifunc はこの設定ではサポートされていません"
+msgstr "-pie はこの構成ではサポートされていません"
 
 #: config/vxworks.h:139
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
@@ -5108,20 +4789,16 @@ msgstr "-Xbind-now と -Xbind-lazy は併用できません"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
 #: config/riscv/freebsd.h:44
-#, fuzzy
-#| msgid "consider using '-pg' instead of '-p' with gprof(1)"
 msgid "consider using `-pg' instead of `-p' with gprof (1)"
-msgstr "gprof(1) を使うときは '-p' の代わりに '-pg' を使用してください"
+msgstr "gprof(1) を使うときは `-p' の代わりに `-pg' を使用してください"
 
 #: config/arc/arc.h:68 config/mips/mips.h:1452
 msgid "may not use both -EB and -EL"
 msgstr "-EB と -EL の両方を使用することは出来ません"
 
 #: config/arm/arm.h:93
-#, fuzzy
-#| msgid "-msoft-float and -mhard_float may not be used together"
 msgid "-mfloat-abi=soft and -mfloat-abi=hard may not be used together"
-msgstr "-msoft-float と -mhard_float は併用できません"
+msgstr "-mfloat-abi=soft と -mfloat-abi=hard は併用できません"
 
 #: config/arm/arm.h:95 config/tilegx/tilegx.h:520 config/tilegx/tilegx.h:525
 msgid "-mbig-endian and -mlittle-endian may not be used together"
@@ -5129,7 +4806,6 @@ msgstr "-mbig-endian と -mlittle-endian は併用できません"
 
 #: config/avr/specs.h:71 config/pru/pru.h:58
 #, fuzzy
-#| msgid "-fpic is not supported"
 msgid "shared is not supported"
 msgstr "-fpic はサポートされていません"
 
@@ -5148,7 +4824,6 @@ msgstr "shared と mdll は併用できません"
 
 #: config/i386/darwin.h:134
 #, fuzzy
-#| msgid "%qD is not a template function"
 msgid "Darwin is not an mx32 platform"
 msgstr "%qD はテンプレート関数ではありません"
 
@@ -5157,10 +4832,8 @@ msgid "Darwin does not support -mfentry or associated options"
 msgstr ""
 
 #: config/i386/sol2.h:59
-#, fuzzy
-#| msgid "-f%s not supported: ignored"
 msgid "-mx32 is not supported on Solaris"
-msgstr "-f%s はサポートされていません: 無視されました"
+msgstr "-mx32 は Solaris ではサポートされていません"
 
 #: config/mcore/mcore.h:53
 msgid "the m210 does not have little endian support"
@@ -5176,7 +4849,6 @@ msgstr "-msingle-float と -msoft-float は併用できません"
 
 #: config/moxie/moxiebox.h:43
 #, fuzzy
-#| msgid "Assume target CPU is configured as little endian"
 msgid "this target is little-endian"
 msgstr "ターゲット CPU がリトルエンディアンとして設定されているとみなす"
 
@@ -5210,7 +4882,6 @@ msgstr "  プロファイリングサポートは書庫フォーマット内で
 
 #: config/rs6000/freebsd64.h:173
 #, fuzzy
-#| msgid "consider using '-pg' instead of '-p' with gprof(1)"
 msgid "consider using `-pg' instead of `-p' with gprof(1)"
 msgstr "gprof(1) を使うときは '-p' の代わりに '-pg' を使用してください"
 
@@ -5228,7 +4899,6 @@ msgstr "-mas100-syntax と -gdwarf は併用できません"
 
 #: config/rx/rx.h:81
 #, fuzzy
-#| msgid "rx200 cpu does not have FPU hardware"
 msgid "rx100 cpu does not have FPU hardware"
 msgstr "rx200 CPU にはハードウェア FPU がありません"
 
@@ -5242,7 +4912,6 @@ msgstr "SH2a はリトルエンディアンをサポートしていません"
 
 #: config/sparc/linux64.h:148
 #, fuzzy
-#| msgid "ifunc is not supported in this configuration"
 msgid "-fsanitize=address is not supported in this configuration"
 msgstr "ifunc はこの設定ではサポートされていません"
 
@@ -5266,13 +4935,11 @@ msgstr "Ada では -c または -S が必要です"
 
 #: ada/gcc-interface/lang-specs.h:53
 #, fuzzy
-#| msgid "-c or -S required for Ada"
 msgid "-c required for gnat2why"
 msgstr "Ada では -c または -S が必要です"
 
 #: ada/gcc-interface/lang-specs.h:66
 #, fuzzy
-#| msgid "-c or -S required for Ada"
 msgid "-c required for gnat2scil"
 msgstr "Ada では -c または -S が必要です"
 
@@ -5299,7 +4966,6 @@ msgstr ""
 
 #: fortran/lang.opt:198
 #, fuzzy, no-c-format
-#| msgid "Warn about possibly missing parentheses"
 msgid "Warn about possible aliasing of dummy arguments."
 msgstr "小括弧が無い可能性がある場合に警告する"
 
@@ -5315,7 +4981,6 @@ msgstr "文字定数の中でファイルの終端を検出しました"
 
 #: fortran/lang.opt:210
 #, fuzzy, no-c-format
-#| msgid "Warn about creation of array temporaries"
 msgid "Warn about creation of array temporaries."
 msgstr "一時配列の生成に関して警告する"
 
@@ -5335,7 +5000,6 @@ msgstr ""
 
 #: fortran/lang.opt:226
 #, fuzzy, no-c-format
-#| msgid "Warn about truncated source lines"
 msgid "Warn about truncated character expressions."
 msgstr "切り詰められたソース行に関して警告する"
 
@@ -5346,13 +5010,11 @@ msgstr ""
 
 #: fortran/lang.opt:238
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit declarations"
 msgid "Warn about most implicit conversions."
 msgstr "暗黙的宣言に関して警告する"
 
 #: fortran/lang.opt:242
 #, fuzzy, no-c-format
-#| msgid "Warn about possibly missing parentheses"
 msgid "Warn about possibly incorrect subscripts in do loops."
 msgstr "小括弧が無い可能性がある場合に警告する"
 
@@ -5363,13 +5025,11 @@ msgstr ""
 
 #: fortran/lang.opt:254
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit function declarations"
 msgid "Warn about function call elimination."
 msgstr "暗黙の関数宣言に関して警告する"
 
 #: fortran/lang.opt:258
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit declarations"
 msgid "Warn about calls with implicit interface."
 msgstr "暗黙的宣言に関して警告する"
 
@@ -5380,13 +5040,11 @@ msgstr ""
 
 #: fortran/lang.opt:266
 #, fuzzy, no-c-format
-#| msgid "Warn about compile-time integer division by zero"
 msgid "Warn about constant integer divisions with truncated results."
 msgstr "コンパイル時に整数の 0 による除算が行われたときに警告する"
 
 #: fortran/lang.opt:270
 #, fuzzy, no-c-format
-#| msgid "Warn about truncated source lines"
 msgid "Warn about truncated source lines."
 msgstr "切り詰められたソース行に関して警告する"
 
@@ -5397,7 +5055,6 @@ msgstr ""
 
 #: fortran/lang.opt:286
 #, fuzzy, no-c-format
-#| msgid "Warn about format strings that are not literals"
 msgid "Warn about USE statements that have no ONLY qualifier."
 msgstr "書式文字列が文字列リテラルでない場合に警告する"
 
@@ -5413,13 +5070,11 @@ msgstr ""
 
 #: fortran/lang.opt:306
 #, fuzzy, no-c-format
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a left-hand-side array variable is reallocated."
 msgstr "レジスタ変数が volatile と宣言されたときに警告する"
 
 #: fortran/lang.opt:310
 #, fuzzy, no-c-format
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a left-hand-side variable is reallocated."
 msgstr "レジスタ変数が volatile と宣言されたときに警告する"
 
@@ -5430,7 +5085,6 @@ msgstr ""
 
 #: fortran/lang.opt:322
 #, fuzzy, no-c-format
-#| msgid "Warn about suspicious declarations of \"main\""
 msgid "Warn about \"suspicious\" constructs."
 msgstr "疑わしい main の宣言に関して警告する"
 
@@ -5446,7 +5100,6 @@ msgstr ""
 
 #: fortran/lang.opt:334
 #, fuzzy, no-c-format
-#| msgid "Warn about overflow in arithmetic expressions"
 msgid "Warn about underflow of numerical constant expressions."
 msgstr "計算式内のオーバーフローに関して警告する"
 
@@ -5462,19 +5115,16 @@ msgstr ""
 
 #: fortran/lang.opt:354
 #, fuzzy, no-c-format
-#| msgid "Warn about zero-length formats"
 msgid "Warn about zero-trip DO loops."
 msgstr "長さが 0 の書式文字列に関して警告する"
 
 #: fortran/lang.opt:358
 #, fuzzy, no-c-format
-#| msgid "Enable preprocessing"
 msgid "Enable preprocessing."
 msgstr "前処理を有効にする"
 
 #: fortran/lang.opt:366
 #, fuzzy, no-c-format
-#| msgid "Disable preprocessing"
 msgid "Disable preprocessing."
 msgstr "前処理を無効にする"
 
@@ -5540,13 +5190,11 @@ msgstr ""
 
 #: fortran/lang.opt:441
 #, fuzzy, no-c-format
-#| msgid "Warn about unprototyped function declarations"
 msgid "Generate C prototypes from BIND(C) declarations."
 msgstr "プロトタイプが無い関数宣言に関して警告する"
 
 #: fortran/lang.opt:445
 #, fuzzy, no-c-format
-#| msgid "Warn about unprototyped function declarations"
 msgid "Generate C prototypes from non-BIND(C) external procedure definitions."
 msgstr "プロトタイプが無い関数宣言に関して警告する"
 
@@ -5562,13 +5210,11 @@ msgstr ""
 
 #: fortran/lang.opt:457
 #, fuzzy, no-c-format
-#| msgid "Enable Plan 9 language extensions"
 msgid "Enable all DEC language extensions."
 msgstr "Plan 9 言語拡張を有効にする"
 
 #: fortran/lang.opt:461
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of blank format items in format strings."
 msgstr "短い load 命令の使用を有効にする"
 
@@ -5639,7 +5285,6 @@ msgstr ""
 
 #: fortran/lang.opt:522
 #, fuzzy, no-c-format
-#| msgid "Display the compiler's version"
 msgid "Display the code tree after parsing."
 msgstr "`コンパイラのバージョンを表示する"
 
@@ -5650,7 +5295,6 @@ msgstr ""
 
 #: fortran/lang.opt:530
 #, fuzzy, no-c-format
-#| msgid "Display the compiler's version"
 msgid "Display the global symbol table after parsing."
 msgstr "`コンパイラのバージョンを表示する"
 
@@ -5666,13 +5310,11 @@ msgstr ""
 
 #: fortran/lang.opt:542
 #, fuzzy, no-c-format
-#| msgid "Use normal calling convention"
 msgid "Use f2c calling convention."
 msgstr "通常の呼び出し規約を使用する"
 
 #: fortran/lang.opt:546
 #, fuzzy, no-c-format
-#| msgid "Assume that the source file is fixed form"
 msgid "Assume that the source file is fixed form."
 msgstr "ソースファイルが固定形式であると見なす"
 
@@ -5718,7 +5360,6 @@ msgstr ""
 
 #: fortran/lang.opt:586
 #, fuzzy, no-c-format
-#| msgid "Assume that the source file is free form"
 msgid "Assume that the source file is free form."
 msgstr "ソースファイルが自由形式であると見なす"
 
@@ -5739,7 +5380,6 @@ msgstr ""
 
 #: fortran/lang.opt:602
 #, fuzzy, no-c-format
-#| msgid "Enable link-time optimization."
 msgid "Enable front end optimization."
 msgstr "リンク時最適化を有効にする"
 
@@ -5790,7 +5430,6 @@ msgstr ""
 
 #: fortran/lang.opt:660
 #, fuzzy, no-c-format
-#| msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgid "-fmax-array-constructor=<n>\tMaximum number of objects in an array constructor."
 msgstr "-fmax-errors=<number>\tエラー報告する最大数を <number> にする"
 
@@ -5876,13 +5515,11 @@ msgstr ""
 
 #: fortran/lang.opt:748
 #, fuzzy, no-c-format
-#| msgid "Use native format for unformatted files"
 msgid "Use a 4-byte record marker for unformatted files."
 msgstr "形式が定められていないファイルではネイティブの形式を使用する"
 
 #: fortran/lang.opt:752
 #, fuzzy, no-c-format
-#| msgid "Use native format for unformatted files"
 msgid "Use an 8-byte record marker for unformatted files."
 msgstr "形式が定められていないファイルではネイティブの形式を使用する"
 
@@ -5946,43 +5583,36 @@ msgstr ""
 
 #: fortran/lang.opt:851
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
 msgstr "ISO Fortran 2003 標準に準拠させる"
 
 #: fortran/lang.opt:855
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2008 standard."
 msgstr "ISO Fortran 2008 標準に準拠させる"
 
 #: fortran/lang.opt:859
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
 msgstr "ISO Fortran 2008 標準に準拠させる"
 
 #: fortran/lang.opt:863
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "ISO Fortran 2008 標準に準拠させる"
 
 #: fortran/lang.opt:867
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
 msgstr "ISO Fortran 95 標準に準拠させる"
 
 #: fortran/lang.opt:871
 #, fuzzy, no-c-format
-#| msgid "Conform to nothing in particular"
 msgid "Conform to nothing in particular."
 msgstr "特に何も準拠させない"
 
 #: fortran/lang.opt:875
 #, fuzzy, no-c-format
-#| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
 msgstr "古いコードをサポートするための拡張を受け付ける"
 
@@ -5992,116 +5622,97 @@ msgid "-A<question>=<answer>\tAssert the <answer> to <question>.  Putting '-' be
 msgstr ""
 
 #: c-family/c.opt:186
-#, fuzzy, no-c-format
-#| msgid "Do not discard comments"
+#, no-c-format
 msgid "Do not discard comments."
-msgstr "コメントを破棄しない"
+msgstr "コメントを破棄しない。"
 
 #: c-family/c.opt:190
-#, fuzzy, no-c-format
-#| msgid "Do not discard comments in macro expansions"
+#, no-c-format
 msgid "Do not discard comments in macro expansions."
-msgstr "マクロ展開内のコメントを破棄しない"
+msgstr "マクロ展開内のコメントを破棄しない。"
 
 #: c-family/c.opt:194
 #, fuzzy, no-c-format
-#| msgid "-D<macro>[=<val>]\tDefine a <macro> with <val> as its value.  If just <macro> is given, <val> is taken to be 1"
 msgid "-D<macro>[=<val>]\tDefine a <macro> with <val> as its value.  If just <macro> is given, <val> is taken to be 1."
 msgstr "-D<macro>[=<val>]\tマクロ <macro> を値 <val> として定義する。<macro> のみ与えられた場合、 <val> は 1 になる"
 
 #: c-family/c.opt:201
 #, fuzzy, no-c-format
-#| msgid "-F <dir>\tAdd <dir> to the end of the main framework include path"
 msgid "-F <dir>\tAdd <dir> to the end of the main framework include path."
 msgstr "-F <dir>\t主フレームワークインクルードパスの最後に <dir> を追加する"
 
 #: c-family/c.opt:205
 #, fuzzy, no-c-format
-#| msgid "Enable preprocessing"
 msgid "Enable parsing GIMPLE."
 msgstr "前処理を有効にする"
 
 #: c-family/c.opt:209
-#, fuzzy, no-c-format
-#| msgid "Print the name of header files as they are used"
+#, no-c-format
 msgid "Print the name of header files as they are used."
-msgstr "使用されるヘッダファイル名を表示する"
+msgstr "使用されるヘッダファイル名を表示する。"
 
 #: c-family/c.opt:213
-#, fuzzy, no-c-format
-#| msgid "-I <dir>\tAdd <dir> to the end of the main include path"
+#, no-c-format
 msgid "-I <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-I <dir>\t主インクルードパスの最後に <dir> を追加する"
 
 #: c-family/c.opt:217
-#, fuzzy, no-c-format
-#| msgid "Generate make dependencies"
+#, no-c-format
 msgid "Generate make dependencies."
 msgstr "make 依存関係を生成する"
 
 #: c-family/c.opt:221
-#, fuzzy, no-c-format
-#| msgid "Generate make dependencies and compile"
+#, no-c-format
 msgid "Generate make dependencies and compile."
 msgstr "make 依存関係を生成し、コンパイルする"
 
 #: c-family/c.opt:225
-#, fuzzy, no-c-format
-#| msgid "-MF <file>\tWrite dependency output to the given file"
+#, no-c-format
 msgid "-MF <file>\tWrite dependency output to the given file."
 msgstr "-MF <file>\t与えられたファイルに依存関係を出力する"
 
 #: c-family/c.opt:229
-#, fuzzy, no-c-format
-#| msgid "Treat missing header files as generated files"
+#, no-c-format
 msgid "Treat missing header files as generated files."
-msgstr "存在しないヘッダファイルを生成されたファイルとして取り扱う"
+msgstr "存在しないヘッダファイルを生成されたファイルとして取り扱う。"
 
 #: c-family/c.opt:233
-#, fuzzy, no-c-format
-#| msgid "Like -M but ignore system header files"
+#, no-c-format
 msgid "Like -M but ignore system header files."
-msgstr "-M と同様だがシステムヘッダファイルを無視する"
+msgstr "-M と同様だがシステムヘッダファイルを無視する。"
 
 #: c-family/c.opt:237
-#, fuzzy, no-c-format
-#| msgid "Like -MD but ignore system header files"
+#, no-c-format
 msgid "Like -MD but ignore system header files."
-msgstr "-MD と同様だがシステムヘッダファイルを無視する"
+msgstr "-MD と同様だがシステムヘッダファイルを無視する。"
 
 #: c-family/c.opt:241
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU as"
 msgid "Generate phony targets for all headers."
 msgstr "GNU as 用のコードを生成する"
 
 #: c-family/c.opt:245
 #, fuzzy, no-c-format
-#| msgid "-MT <target>\tAdd an unquoted target"
 msgid "-MQ <target>\tAdd a MAKE-quoted target."
 msgstr "-MT <target>\tターゲット (引用符を付けない) を追加する"
 
 #: c-family/c.opt:249
 #, fuzzy, no-c-format
-#| msgid "-MT <target>\tAdd an unquoted target"
 msgid "-MT <target>\tAdd an unquoted target."
 msgstr "-MT <target>\tターゲット (引用符を付けない) を追加する"
 
 #: c-family/c.opt:253
 #, fuzzy, no-c-format
-#| msgid "Do not generate #line directives"
 msgid "Do not generate #line directives."
 msgstr "#line 指示を生成しない"
 
 #: c-family/c.opt:257
-#, fuzzy, no-c-format
-#| msgid "-U<macro>\tUndefine <macro>"
+#, no-c-format
 msgid "-U<macro>\tUndefine <macro>."
 msgstr "-U<macro>\tマクロ <macro> を未定義状態にする"
 
 #: c-family/c.opt:261
 #, fuzzy, no-c-format
-#| msgid "Warn about things that will change when compiling with an ABI-compliant compiler"
 msgid "Warn about things that will change when compiling with an ABI-compliant compiler."
 msgstr "ABI に適合したコンパイラでコンパイルしたときに変更されることに関して警告する"
 
@@ -6121,8 +5732,7 @@ msgid "Warn on suspicious calls of standard functions computing absolute values.
 msgstr ""
 
 #: c-family/c.opt:280
-#, fuzzy, no-c-format
-#| msgid "Warn about suspicious uses of memory addresses"
+#, no-c-format
 msgid "Warn about suspicious uses of memory addresses."
 msgstr "メモリアドレスの疑わしい使用法について警告する"
 
@@ -6137,8 +5747,7 @@ msgid "-Waligned-new=[none|global|all]\tWarn even if 'new' uses a class member a
 msgstr ""
 
 #: c-family/c.opt:304 ada/gcc-interface/lang.opt:57
-#, fuzzy, no-c-format
-#| msgid "Enable most warning messages"
+#, no-c-format
 msgid "Enable most warning messages."
 msgstr "ほとんどの警告メッセージを有効にする"
 
@@ -6149,7 +5758,6 @@ msgstr ""
 
 #: c-family/c.opt:312
 #, fuzzy, no-c-format
-#| msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
 msgid "-Walloc-size-larger-than=<bytes>\tWarn for calls to allocation functions that attempt to allocate objects larger than the specified number of bytes."
 msgstr "-Wlarger-than=<number>\tオブジェクトが <number> バイト以上の場合に警告する"
 
@@ -6165,7 +5773,6 @@ msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
 #: c-family/c.opt:325
 #, fuzzy, no-c-format
-#| msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
 msgid "-Walloca-larger-than=<number>\tWarn on unbounded uses of alloca, and on bounded uses of alloca whose bound can be larger than <number> bytes."
 msgstr "-Wlarger-than=<number>\tオブジェクトが <number> バイト以上の場合に警告する"
 
@@ -6176,7 +5783,6 @@ msgstr ""
 
 #: c-family/c.opt:343
 #, fuzzy, no-c-format
-#| msgid "Warn about zero-length formats"
 msgid "Warn about accesses to interior zero-length array members."
 msgstr "長さが 0 の書式文字列に関して警告する"
 
@@ -6186,8 +5792,7 @@ msgid "Warn whenever an Objective-C assignment is being intercepted by the garba
 msgstr ""
 
 #: c-family/c.opt:351
-#, fuzzy, no-c-format
-#| msgid "Warn about casting functions to incompatible types"
+#, no-c-format
 msgid "Warn about casting functions to incompatible types."
 msgstr "互換性のない型への関数キャストに関して警告する"
 
@@ -6198,7 +5803,6 @@ msgstr ""
 
 #: c-family/c.opt:359
 #, fuzzy, no-c-format
-#| msgid "Warn about overflow in arithmetic expressions"
 msgid "Warn about certain operations on boolean expressions."
 msgstr "計算式内のオーバーフローに関して警告する"
 
@@ -6209,85 +5813,71 @@ msgstr ""
 
 #: c-family/c.opt:367
 #, fuzzy, no-c-format
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Warn when a built-in function is declared with the wrong signature."
 msgstr "インライン関数をインライン化できない場合に警告する"
 
 #: c-family/c.opt:371
 #, fuzzy, no-c-format
-#| msgid "Warn when a built-in preprocessor macro is undefined or redefined"
 msgid "Warn when a built-in preprocessor macro is undefined or redefined."
 msgstr "組み込み前処理マクロが未定義になるか再定義されたときに警告する"
 
 #: c-family/c.opt:375
 #, fuzzy, no-c-format
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in ISO C11, but present in ISO C2X."
 msgstr "伝統的な C には存在しない機能に関して警告する"
 
 #: c-family/c.opt:379
 #, fuzzy, no-c-format
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in ISO C90, but present in ISO C99."
 msgstr "伝統的な C には存在しない機能に関して警告する"
 
 #: c-family/c.opt:383
 #, fuzzy, no-c-format
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in ISO C99, but present in ISO C11."
 msgstr "伝統的な C には存在しない機能に関して警告する"
 
 #: c-family/c.opt:387
 #, fuzzy, no-c-format
-#| msgid "Warn about C constructs that are not in the common subset of C and C++"
 msgid "Warn about C constructs that are not in the common subset of C and C++."
 msgstr "C と C++ の共通部分集合では無い C 構文に関して警告する"
 
 #: c-family/c.opt:394
 #, fuzzy, no-c-format
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 200x"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011."
 msgstr "ISO C++ 1998 と ISO C++ 200x で意味が異なる C++ 構文に関して警告する"
 
 #: c-family/c.opt:398
 #, fuzzy, no-c-format
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 200x"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2011 and ISO C++ 2014."
 msgstr "ISO C++ 1998 と ISO C++ 200x で意味が異なる C++ 構文に関して警告する"
 
 #: c-family/c.opt:405
 #, fuzzy, no-c-format
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 200x"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2014 and ISO C++ 2017."
 msgstr "ISO C++ 1998 と ISO C++ 200x で意味が異なる C++ 構文に関して警告する"
 
 #: c-family/c.opt:412
 #, fuzzy, no-c-format
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 200x"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2017 and ISO C++ 2020."
 msgstr "ISO C++ 1998 と ISO C++ 200x で意味が異なる C++ 構文に関して警告する"
 
 #: c-family/c.opt:416
-#, fuzzy, no-c-format
-#| msgid "Warn about casting functions to incompatible types"
+#, no-c-format
 msgid "Warn about casts between incompatible function types."
 msgstr "互換性のない型への関数キャストに関して警告する"
 
 #: c-family/c.opt:420
 #, fuzzy, no-c-format
-#| msgid "Warn about pointer casts which increase alignment"
 msgid "Warn about casts which discard qualifiers."
 msgstr "ポインタのキャストによって整列が増加する場合に警告する"
 
 #: c-family/c.opt:424 c-family/c.opt:428
 #, fuzzy, no-c-format
-#| msgid "Warn about comparison of different enum types"
 msgid "Warn about catch handlers of non-reference type."
 msgstr "異なる列挙型の比較に関して警告する"
 
 #: c-family/c.opt:432
 #, fuzzy, no-c-format
-#| msgid "Warn about subscripts whose type is \"char\""
 msgid "Warn about subscripts whose type is \"char\"."
 msgstr "添え字の型が \"char\" である場合に警告する"
 
@@ -6300,31 +5890,26 @@ msgstr "添え字の型が \"char\" である場合に警告する"
 #: c-family/c.opt:1434 c-family/c.opt:1438 c-family/c.opt:1442
 #: config/i386/i386.opt:965
 #, fuzzy, no-c-format
-#| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 9.  This switch has no effect."
 msgstr "廃止されている。このスイッチは効果はない。"
 
 #: c-family/c.opt:440
 #, fuzzy, no-c-format
-#| msgid "Warn about variables that might be changed by \"longjmp\" or \"vfork\""
 msgid "Warn about variables that might be changed by \"longjmp\" or \"vfork\"."
 msgstr "\"longjmp\" または \"vfork\" によって変更されるかもしれない変数に関して警告する"
 
 #: c-family/c.opt:444
 #, fuzzy, no-c-format
-#| msgid "Warn about overflow in arithmetic expressions"
 msgid "Warn about uses of a comma operator within a subscripting expression."
 msgstr "計算式内のオーバーフローに関して警告する"
 
 #: c-family/c.opt:448
 #, fuzzy, no-c-format
-#| msgid "Warn about possibly nested block comments, and C++ comments spanning more than one physical line"
 msgid "Warn about possibly nested block comments, and C++ comments spanning more than one physical line."
 msgstr "ブロックコメントが入れ子になっている可能性または C++ コメントが物理的に一行以上にまたがっている可能性に関して警告する"
 
 #: c-family/c.opt:452
 #, fuzzy, no-c-format
-#| msgid "Synonym for -Wcomment"
 msgid "Synonym for -Wcomment."
 msgstr "-Wcomment の別名"
 
@@ -6335,19 +5920,16 @@ msgstr ""
 
 #: c-family/c.opt:460
 #, fuzzy, no-c-format
-#| msgid "Warn for implicit type conversions that may change a value"
 msgid "Warn for implicit type conversions that may change a value."
 msgstr "値が変更される場合がある暗黙的な型変換に関して警告する"
 
 #: c-family/c.opt:464
 #, fuzzy, no-c-format
-#| msgid "Warn for converting NULL from/to a non-pointer type"
 msgid "Warn for converting NULL from/to a non-pointer type."
 msgstr "非ポインタ型から NULL へ、または NULL から非ポインタ型への変換に関して警告する"
 
 #: c-family/c.opt:472
 #, fuzzy, no-c-format
-#| msgid "Warn when all constructors and destructors are private"
 msgid "Warn when all constructors and destructors are private."
 msgstr "すべてのコンストラクタとデストラクタが非公開の場合に警告する"
 
@@ -6363,19 +5945,16 @@ msgstr ""
 
 #: c-family/c.opt:484
 #, fuzzy, no-c-format
-#| msgid "Warn when a declaration is found after a statement"
 msgid "Warn when a declaration is found after a statement."
 msgstr "実行文より後に宣言が見つかったときに警告する"
 
 #: c-family/c.opt:488
 #, fuzzy, no-c-format
-#| msgid "dereferencing pointer to incomplete type"
 msgid "Warn when deleting a pointer to incomplete type."
 msgstr "不完全型のポインタへの間接参照"
 
 #: c-family/c.opt:492
 #, fuzzy, no-c-format
-#| msgid "Warn about non-virtual destructors"
 msgid "Warn about deleting polymorphic objects with non-virtual destructors."
 msgstr "非仮想デストラクタに関して警告する"
 
@@ -6391,7 +5970,6 @@ msgstr ""
 
 #: c-family/c.opt:510
 #, fuzzy, no-c-format
-#| msgid "Warn about possibly missing braces around initializers"
 msgid "Warn about positional initialization of structs requiring designated initializers."
 msgstr "初期化子のまわりに中括弧が無い可能性がある場合に警告する"
 
@@ -6402,19 +5980,16 @@ msgstr ""
 
 #: c-family/c.opt:518
 #, fuzzy, no-c-format
-#| msgid "Warn whenever type qualifiers are ignored."
 msgid "Warn if type qualifiers on pointers are discarded."
 msgstr "型修飾子が無視された場合はいつも警告する"
 
 #: c-family/c.opt:522
 #, fuzzy, no-c-format
-#| msgid "Warn about compile-time integer division by zero"
 msgid "Warn about compile-time integer division by zero."
 msgstr "コンパイル時に整数の 0 による除算が行われたときに警告する"
 
 #: c-family/c.opt:526
 #, fuzzy, no-c-format
-#| msgid "Warn about an empty body in an if or else statement"
 msgid "Warn about duplicated branches in if-else statements."
 msgstr "if または else 文の中身が空の場合に警告する"
 
@@ -6425,85 +6000,71 @@ msgstr ""
 
 #: c-family/c.opt:534
 #, fuzzy, no-c-format
-#| msgid "Warn about violations of Effective C++ style rules"
 msgid "Warn about violations of Effective C++ style rules."
 msgstr "Effective C++ 式の指針からはずれるものについて警告する"
 
 #: c-family/c.opt:538
 #, fuzzy, no-c-format
-#| msgid "Warn about an empty body in an if or else statement"
 msgid "Warn about an empty body in an if or else statement."
 msgstr "if または else 文の中身が空の場合に警告する"
 
 #: c-family/c.opt:542
 #, fuzzy, no-c-format
-#| msgid "Warn about stray tokens after #elif and #endif"
 msgid "Warn about stray tokens after #else and #endif."
 msgstr "#elif および #endif の後にあるはぐれたトークンに関して警告する"
 
 #: c-family/c.opt:546
 #, fuzzy, no-c-format
-#| msgid "Warn about comparison of different enum types"
 msgid "Warn about comparison of different enum types."
 msgstr "異なる列挙型の比較に関して警告する"
 
 #: c-family/c.opt:550
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit declarations"
 msgid "Warn about implicit conversion of enum types."
 msgstr "暗黙的宣言に関して警告する"
 
 #: c-family/c.opt:558
 #, fuzzy, no-c-format
-#| msgid "This switch is deprecated; use -Werror=implicit-function-declaration instead"
 msgid "This switch is deprecated; use -Werror=implicit-function-declaration instead."
 msgstr "このスイッチは廃止されました。代わりに -Werror=implicit-function-declaration を使用してください"
 
 #: c-family/c.opt:566
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit function declarations"
 msgid "Warn about semicolon after in-class function definition."
 msgstr "暗黙の関数宣言に関して警告する"
 
 #: c-family/c.opt:570
 #, fuzzy, no-c-format
-#| msgid "Warn for implicit type conversions that may change a value"
 msgid "Warn for implicit type conversions that cause loss of floating point precision."
 msgstr "値が変更される場合がある暗黙的な型変換に関して警告する"
 
 #: c-family/c.opt:574
 #, fuzzy, no-c-format
-#| msgid "Warn if testing floating point numbers for equality"
 msgid "Warn if testing floating point numbers for equality."
 msgstr "浮動小数点数の等価比較に関して警告する"
 
 #: c-family/c.opt:578 c-family/c.opt:624
 #, fuzzy, no-c-format
-#| msgid "Warn about printf/scanf/strftime/strfmon format string anomalies"
 msgid "Warn about printf/scanf/strftime/strfmon format string anomalies."
 msgstr "printf/scanf/strftime/strfmon 書式文字列異常に関して警告する"
 
 #: c-family/c.opt:582
 #, fuzzy, no-c-format
-#| msgid "Warn about format strings that contain NUL bytes"
 msgid "Warn about format strings that contain NUL bytes."
 msgstr "書式文字列に NUL バイトが含まれる場合に警告する"
 
 #: c-family/c.opt:586
 #, fuzzy, no-c-format
-#| msgid "Warn about format strings that are not literals"
 msgid "Warn about GCC format strings with strings unsuitable for diagnostics."
 msgstr "書式文字列が文字列リテラルでない場合に警告する"
 
 #: c-family/c.opt:590
 #, fuzzy, no-c-format
-#| msgid "Warn if passing too many arguments to a function for its format string"
 msgid "Warn if passing too many arguments to a function for its format string."
 msgstr "関数の書式文字列用に渡す引数が多すぎる場合に警告する"
 
 #: c-family/c.opt:594
 #, fuzzy, no-c-format
-#| msgid "Warn about format strings that are not literals"
 msgid "Warn about format strings that are not literals."
 msgstr "書式文字列が文字列リテラルでない場合に警告する"
 
@@ -6514,13 +6075,11 @@ msgstr ""
 
 #: c-family/c.opt:603
 #, fuzzy, no-c-format
-#| msgid "Warn about possible security problems with format functions"
 msgid "Warn about possible security problems with format functions."
 msgstr "セキュリティ問題になる可能性がある書式関数に関して警告する"
 
 #: c-family/c.opt:607
 #, fuzzy, no-c-format
-#| msgid "Warn about possible security problems with format functions"
 msgid "Warn about sign differences with format functions."
 msgstr "セキュリティ問題になる可能性がある書式関数に関して警告する"
 
@@ -6531,13 +6090,11 @@ msgstr ""
 
 #: c-family/c.opt:616
 #, fuzzy, no-c-format
-#| msgid "Warn about strftime formats yielding 2-digit years"
 msgid "Warn about strftime formats yielding 2-digit years."
 msgstr "strftime 書式が 2 桁の年の場合に警告する"
 
 #: c-family/c.opt:620
 #, fuzzy, no-c-format
-#| msgid "Warn about zero-length formats"
 msgid "Warn about zero-length formats."
 msgstr "長さが 0 の書式文字列に関して警告する"
 
@@ -6548,13 +6105,11 @@ msgstr ""
 
 #: c-family/c.opt:633
 #, fuzzy, no-c-format
-#| msgid "Warn about casting functions to incompatible types"
 msgid "Warn about calls to snprintf and similar functions that truncate output."
 msgstr "互換性のない型への関数キャストに関して警告する"
 
 #: c-family/c.opt:637
 #, fuzzy, no-c-format
-#| msgid "Warn when a Cell microcoded instruction is emitted"
 msgid "Warn when the field in a struct is not aligned."
 msgstr "Cell マイクロコード命令が発行されたときに警告する"
 
@@ -6565,13 +6120,11 @@ msgstr "型修飾子が無視された場合はいつも警告する"
 
 #: c-family/c.opt:645
 #, fuzzy, no-c-format
-#| msgid "Warn whenever type qualifiers are ignored."
 msgid "Warn whenever attributes are ignored."
 msgstr "型修飾子が無視された場合はいつも警告する"
 
 #: c-family/c.opt:649
 #, fuzzy, no-c-format
-#| msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgid "Warn when a base is inaccessible in derived due to ambiguity."
 msgstr "直接の基底 %qT は曖昧なため %qT 内でアクセスできません"
 
@@ -6587,7 +6140,6 @@ msgstr ""
 
 #: c-family/c.opt:661
 #, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
 msgid "Warn about variables which are initialized to themselves."
 msgstr "変数がそれ自身によって初期化されている場合に警告する"
 
@@ -6598,31 +6150,26 @@ msgstr ""
 
 #: c-family/c.opt:669
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit declarations"
 msgid "Warn about implicit declarations."
 msgstr "暗黙的宣言に関して警告する"
 
 #: c-family/c.opt:677
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit conversions from \"float\" to \"double\""
 msgid "Warn about implicit conversions from \"float\" to \"double\"."
 msgstr "\"float\" から \"double\" への暗黙的変換に関して警告する"
 
 #: c-family/c.opt:681
 #, fuzzy, no-c-format
-#| msgid "Warn if an undefined macro is used in an #if directive"
 msgid "Warn if \"defined\" is used outside #if."
 msgstr "#if 指示内で未定義マクロが使用された場合に警告する"
 
 #: c-family/c.opt:685
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit function declarations"
 msgid "Warn about implicit function declarations."
 msgstr "暗黙の関数宣言に関して警告する"
 
 #: c-family/c.opt:689
 #, fuzzy, no-c-format
-#| msgid "Warn when a declaration does not specify a type"
 msgid "Warn when a declaration does not specify a type."
 msgstr "宣言が型を指定していない場合に警告する"
 
@@ -6643,25 +6190,21 @@ msgstr ""
 
 #: c-family/c.opt:708
 #, fuzzy, no-c-format
-#| msgid "Warn when there is a cast to a pointer from an integer of a different size"
 msgid "Warn when there is a cast to a pointer from an integer of a different size."
 msgstr "サイズが異なる整数からポインタへのキャストに関して警告する"
 
 #: c-family/c.opt:712
 #, fuzzy, no-c-format
-#| msgid "Warn about invalid uses of the \"offsetof\" macro"
 msgid "Warn about invalid uses of the \"offsetof\" macro."
 msgstr "\"offsetof\" マクロの無効な使用方法に関して警告する"
 
 #: c-family/c.opt:716
 #, fuzzy, no-c-format
-#| msgid "Warn about PCH files that are found but not used"
 msgid "Warn about PCH files that are found but not used."
 msgstr "PCH ファイルが見つかったにもかかわらず使用されていない場合に警告する"
 
 #: c-family/c.opt:720
 #, fuzzy, no-c-format
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a jump misses a variable initialization."
 msgstr "レジスタ変数が volatile と宣言されたときに警告する"
 
@@ -6672,7 +6215,6 @@ msgstr ""
 
 #: c-family/c.opt:728
 #, fuzzy, no-c-format
-#| msgid "Warn when a logical operator is suspiciously always evaluating to true or false"
 msgid "Warn when a logical operator is suspiciously always evaluating to true or false."
 msgstr "論理演算子が常に true または false と評価されるように思われる場合に警告する"
 
@@ -6683,13 +6225,11 @@ msgstr ""
 
 #: c-family/c.opt:736
 #, fuzzy, no-c-format
-#| msgid "Do not warn about using \"long long\" when -pedantic"
 msgid "Do not warn about using \"long long\" when -pedantic."
 msgstr "-pedantic を使用しているときに\"long long\" が使用されても警告しない"
 
 #: c-family/c.opt:740
 #, fuzzy, no-c-format
-#| msgid "Warn about suspicious declarations of \"main\""
 msgid "Warn about suspicious declarations of \"main\"."
 msgstr "疑わしい main の宣言に関して警告する"
 
@@ -6705,7 +6245,6 @@ msgstr ""
 
 #: c-family/c.opt:756
 #, fuzzy, no-c-format
-#| msgid "Warn when the packed attribute has no effect on struct layout"
 msgid "Warn when the indentation of the code does not reflect the block structure."
 msgstr "packed 属性が構造体配置に影響しない場合に警告する"
 
@@ -6716,19 +6255,16 @@ msgstr ""
 
 #: c-family/c.opt:764
 #, fuzzy, no-c-format
-#| msgid "Warn about possibly missing braces around initializers"
 msgid "Warn about possibly missing braces around initializers."
 msgstr "初期化子のまわりに中括弧が無い可能性がある場合に警告する"
 
 #: c-family/c.opt:768
 #, fuzzy, no-c-format
-#| msgid "Warn about global functions without previous declarations"
 msgid "Warn about global functions without previous declarations."
 msgstr "前に宣言が無い大域関数に関して警告する"
 
 #: c-family/c.opt:772
 #, fuzzy, no-c-format
-#| msgid "Warn about missing fields in struct initializers"
 msgid "Warn about missing fields in struct initializers."
 msgstr "構造体の初期化子にフィールドが足りない場合に警告する"
 
@@ -6759,7 +6295,6 @@ msgstr ""
 
 #: c-family/c.opt:796
 #, fuzzy, no-c-format
-#| msgid "Warn about missing fields in struct initializers"
 msgid "Warn about missing sized deallocation functions."
 msgstr "構造体の初期化子にフィールドが足りない場合に警告する"
 
@@ -6800,7 +6335,6 @@ msgstr ""
 
 #: c-family/c.opt:832
 #, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for format attributes"
 msgid "Warn about functions which might be candidates for format attributes."
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
@@ -6811,25 +6345,21 @@ msgstr ""
 
 #: c-family/c.opt:841
 #, fuzzy, no-c-format
-#| msgid "Warn about enumerated switches, with no default, missing a case"
 msgid "Warn about enumerated switches, with no default, missing a case."
 msgstr "列挙定数を使用した switch 文で default 文が無いか特定の case が無い場合に警告する"
 
 #: c-family/c.opt:845
 #, fuzzy, no-c-format
-#| msgid "Warn about enumerated switches missing a \"default:\" statement"
 msgid "Warn about enumerated switches missing a \"default:\" statement."
 msgstr "列挙定数を使用した switch 文で \"default:\" 文が無い場合に警告する"
 
 #: c-family/c.opt:849
 #, fuzzy, no-c-format
-#| msgid "Warn about all enumerated switches missing a specific case"
 msgid "Warn about all enumerated switches missing a specific case."
 msgstr "列挙定数を使用した switch 文で特定の case が無い場合に警告する"
 
 #: c-family/c.opt:853
 #, fuzzy, no-c-format
-#| msgid "Warn about overflow in arithmetic expressions"
 msgid "Warn about switches with boolean controlling expression."
 msgstr "計算式内のオーバーフローに関して警告する"
 
@@ -6850,25 +6380,21 @@ msgstr ""
 
 #: c-family/c.opt:874
 #, fuzzy, no-c-format
-#| msgid "Warn about user-specified include directories that do not exist"
 msgid "Warn about user-specified include directories that do not exist."
 msgstr "利用者が指定したインクルードディレクトリが存在しない場合に警告する"
 
 #: c-family/c.opt:878
 #, fuzzy, no-c-format
-#| msgid "Warn about function parameters declared without a type specifier in K&R-style functions"
 msgid "Warn about function parameters declared without a type specifier in K&R-style functions."
 msgstr "K&R スタイルの関数内に型指定がない引数が宣言されている関数に関して警告する"
 
 #: c-family/c.opt:882
 #, fuzzy, no-c-format
-#| msgid "Warn about global functions without prototypes"
 msgid "Warn about global functions without prototypes."
 msgstr "プロトタイプ無しの大域関数に関して警告する"
 
 #: c-family/c.opt:889
 #, fuzzy, no-c-format
-#| msgid "Warn about use of multi-character character constants"
 msgid "Warn about use of multi-character character constants."
 msgstr "複数文字による文字定数が使用されている場合に警告する"
 
@@ -6879,7 +6405,6 @@ msgstr ""
 
 #: c-family/c.opt:897
 #, fuzzy, no-c-format
-#| msgid "Warn about \"extern\" declarations not at file scope"
 msgid "Warn about \"extern\" declarations not at file scope."
 msgstr "外部 (\"extern\") 宣言がファイルスコープでない場合に警告する"
 
@@ -6895,7 +6420,6 @@ msgstr ""
 
 #: c-family/c.opt:909
 #, fuzzy, no-c-format
-#| msgid "Warn when non-templatized friend functions are declared within a template"
 msgid "Warn when non-templatized friend functions are declared within a template."
 msgstr "テンプレート内でテンプレート化されていないフレンド関数が宣言された場合に警告する"
 
@@ -6911,37 +6435,31 @@ msgstr ""
 
 #: c-family/c.opt:921
 #, fuzzy, no-c-format
-#| msgid "Warn about non-virtual destructors"
 msgid "Warn about non-virtual destructors."
 msgstr "非仮想デストラクタに関して警告する"
 
 #: c-family/c.opt:925
 #, fuzzy, no-c-format
-#| msgid "Warn about NULL being passed to argument slots marked as requiring non-NULL"
 msgid "Warn about NULL being passed to argument slots marked as requiring non-NULL."
 msgstr "NULL で無いことが必要であるとマークされている引数の位置に NULL が渡された場合に警告する"
 
 #: c-family/c.opt:941
 #, fuzzy, no-c-format
-#| msgid "-Wnormalized=<id|nfc|nfkc>\tWarn about non-normalised Unicode strings"
 msgid "-Wnormalized=[none|id|nfc|nfkc]\tWarn about non-normalized Unicode strings."
 msgstr "-Wnormalized=<id|nfc|nfkc>\t正準化されていないユニコード文字列に関して警告する"
 
 #: c-family/c.opt:964
 #, fuzzy, no-c-format
-#| msgid "Warn if a C-style cast is used in a program"
 msgid "Warn if a C-style cast is used in a program."
 msgstr "C スタイルのキャストがプログラム内で使用された場合に警告する"
 
 #: c-family/c.opt:968
 #, fuzzy, no-c-format
-#| msgid "Warn for obsolescent usage in a declaration"
 msgid "Warn for obsolescent usage in a declaration."
 msgstr "廃止された宣言方法が使用された場合に警告する"
 
 #: c-family/c.opt:972
 #, fuzzy, no-c-format
-#| msgid "Warn if an old-style parameter definition is used"
 msgid "Warn if an old-style parameter definition is used."
 msgstr "古いスタイルの引数宣言が使用されたときに警告する"
 
@@ -6952,37 +6470,31 @@ msgstr ""
 
 #: c-family/c.opt:980
 #, fuzzy, no-c-format
-#| msgid "Warn if a string is longer than the maximum portable length specified by the standard"
 msgid "Warn if a string is longer than the maximum portable length specified by the standard."
 msgstr "標準によって指定されている移植性があるとされる最大文字列長を超える文字列がある場合に警告する"
 
 #: c-family/c.opt:984
 #, fuzzy, no-c-format
-#| msgid "Warn about overloaded virtual function names"
 msgid "Warn about overloaded virtual function names."
 msgstr "オーバーロードされた仮想関数名について警告する"
 
 #: c-family/c.opt:988
 #, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
 msgid "Warn about overriding initializers without side effects."
 msgstr "変数がそれ自身によって初期化されている場合に警告する"
 
 #: c-family/c.opt:992
 #, fuzzy, no-c-format
-#| msgid "Warn about variables which are initialized to themselves"
 msgid "Warn about overriding initializers with side effects."
 msgstr "変数がそれ自身によって初期化されている場合に警告する"
 
 #: c-family/c.opt:996
 #, fuzzy, no-c-format
-#| msgid "offset of packed bit-field %qD has changed in GCC 4.4"
 msgid "Warn about packed bit-fields whose offset changed in GCC 4.4."
 msgstr "packed ビットフィールド %qD のオフセットは GCC 4.4 で変更されています"
 
 #: c-family/c.opt:1000
 #, fuzzy, no-c-format
-#| msgid "Warn about possibly missing parentheses"
 msgid "Warn about possibly missing parentheses."
 msgstr "小括弧が無い可能性がある場合に警告する"
 
@@ -6993,37 +6505,31 @@ msgstr ""
 
 #: c-family/c.opt:1012
 #, fuzzy, no-c-format
-#| msgid "Warn when converting the type of pointers to member functions"
 msgid "Warn when converting the type of pointers to member functions."
 msgstr "ポインタからメンバ関数への型変換に関して警告する"
 
 #: c-family/c.opt:1016
 #, fuzzy, no-c-format
-#| msgid "Warn about function pointer arithmetic"
 msgid "Warn about function pointer arithmetic."
 msgstr "関数ポインタの計算に関して警告する"
 
 #: c-family/c.opt:1020
 #, fuzzy, no-c-format
-#| msgid "Warn when a pointer differs in signedness in an assignment"
 msgid "Warn when a pointer differs in signedness in an assignment."
 msgstr "オーバーロードが符号無しから符号付きに格上げとなる場合に警告する"
 
 #: c-family/c.opt:1024
 #, fuzzy, no-c-format
-#| msgid "Warn about use of multi-character character constants"
 msgid "Warn when a pointer is compared with a zero character constant."
 msgstr "複数文字による文字定数が使用されている場合に警告する"
 
 #: c-family/c.opt:1028
 #, fuzzy, no-c-format
-#| msgid "Warn when a pointer is cast to an integer of a different size"
 msgid "Warn when a pointer is cast to an integer of a different size."
 msgstr "ポインタからサイズが異なる整数型への変換に関して警告する"
 
 #: c-family/c.opt:1032
 #, fuzzy, no-c-format
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn about misuses of pragmas."
 msgstr "pragma の誤用に関して警告する"
 
@@ -7039,7 +6545,6 @@ msgstr ""
 
 #: c-family/c.opt:1044
 #, fuzzy, no-c-format
-#| msgid "Warn if inherited methods are unimplemented"
 msgid "Warn if inherited methods are unimplemented."
 msgstr "継承されたメソッドが実装されていない場合に警告する"
 
@@ -7050,7 +6555,6 @@ msgstr ""
 
 #: c-family/c.opt:1056
 #, fuzzy, no-c-format
-#| msgid "Warn about multiple declarations of the same object"
 msgid "Warn about multiple declarations of the same object."
 msgstr "同一オブジェクトの宣言が複数あれば警告する"
 
@@ -7061,13 +6565,11 @@ msgstr ""
 
 #: c-family/c.opt:1064
 #, fuzzy, no-c-format
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn about uses of register storage specifier."
 msgstr "pragma の誤用に関して警告する"
 
 #: c-family/c.opt:1068
 #, fuzzy, no-c-format
-#| msgid "Warn when the compiler reorders code"
 msgid "Warn when the compiler reorders code."
 msgstr "コンパイラがコードを並べ替えるときに警告する"
 
@@ -7083,13 +6585,11 @@ msgstr ""
 
 #: c-family/c.opt:1080
 #, fuzzy, no-c-format
-#| msgid "Warn if a selector has multiple methods"
 msgid "Warn if a selector has multiple methods."
 msgstr "セレクタが複数のメソッドを持っていれば警告する"
 
 #: c-family/c.opt:1084
 #, fuzzy, no-c-format
-#| msgid "Warn about possible violations of sequence point rules"
 msgid "Warn about possible violations of sequence point rules."
 msgstr "副作用完了点規則を破る可能性がある場合に警告する"
 
@@ -7105,19 +6605,16 @@ msgstr ""
 
 #: c-family/c.opt:1100
 #, fuzzy, no-c-format
-#| msgid "right shift count is negative"
 msgid "Warn if shift count is negative."
 msgstr "右シフト回数が負です"
 
 #: c-family/c.opt:1104
 #, fuzzy, no-c-format
-#| msgid "right shift count >= width of type"
 msgid "Warn if shift count >= width of type."
 msgstr "右シフト回数 >= 型の幅となっています"
 
 #: c-family/c.opt:1108
 #, fuzzy, no-c-format
-#| msgid "left shift count is negative"
 msgid "Warn if left shifting a negative value."
 msgstr "左シフト回数が負です"
 
@@ -7128,31 +6625,26 @@ msgstr ""
 
 #: c-family/c.opt:1116
 #, fuzzy, no-c-format
-#| msgid "Warn about signed-unsigned comparisons"
 msgid "Warn about signed-unsigned comparisons."
 msgstr "符号付き/符号無しの比較に関して警告する"
 
 #: c-family/c.opt:1124
 #, fuzzy, no-c-format
-#| msgid "Warn for implicit type conversions between signed and unsigned integers"
 msgid "Warn for implicit type conversions between signed and unsigned integers."
 msgstr "符号付き整数と符号無し整数間の暗黙的な型変換に関して警告する"
 
 #: c-family/c.opt:1128
 #, fuzzy, no-c-format
-#| msgid "Warn when overload promotes from unsigned to signed"
 msgid "Warn when overload promotes from unsigned to signed."
 msgstr "オーバーロードが符号無しから符号付きに格上げとなる場合に警告する"
 
 #: c-family/c.opt:1132
 #, fuzzy, no-c-format
-#| msgid "Warn about truncated source lines"
 msgid "Warn about uncasted NULL used as sentinel."
 msgstr "切り詰められたソース行に関して警告する"
 
 #: c-family/c.opt:1136
 #, fuzzy, no-c-format
-#| msgid "Warn about unprototyped function declarations"
 msgid "Warn about unprototyped function declarations."
 msgstr "プロトタイプが無い関数宣言に関して警告する"
 
@@ -7163,19 +6655,16 @@ msgstr ""
 
 #: c-family/c.opt:1152
 #, fuzzy, no-c-format
-#| msgid "Warn when __sync_fetch_and_nand and __sync_nand_and_fetch built-in functions are used"
 msgid "Warn when __sync_fetch_and_nand and __sync_nand_and_fetch built-in functions are used."
 msgstr "__sync_fetch_and_nand と __sync_nand_and_fetch 組み込み関数が使用された場合に警告する"
 
 #: c-family/c.opt:1156
 #, fuzzy, no-c-format
-#| msgid "Deprecated.  This switch has no effect"
 msgid "Deprecated.  This switch has no effect."
 msgstr "廃止されている。このスイッチは効果はない。"
 
 #: c-family/c.opt:1164
 #, fuzzy, no-c-format
-#| msgid "Warn when a logical operator is suspiciously always evaluating to true or false"
 msgid "Warn if a comparison always evaluates to true or false."
 msgstr "論理演算子が常に true または false と評価されるように思われる場合に警告する"
 
@@ -7186,7 +6675,6 @@ msgstr ""
 
 #: c-family/c.opt:1172
 #, fuzzy, no-c-format
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in traditional C."
 msgstr "伝統的な C には存在しない機能に関して警告する"
 
@@ -7197,61 +6685,51 @@ msgstr ""
 
 #: c-family/c.opt:1180
 #, fuzzy, no-c-format
-#| msgid "Warn if trigraphs are encountered that might affect the meaning of the program"
 msgid "Warn if trigraphs are encountered that might affect the meaning of the program."
 msgstr "トライグラフに遭遇し、プログラムないで意味を持つ場合に警告する"
 
 #: c-family/c.opt:1184
 #, fuzzy, no-c-format
-#| msgid "Warn about @selector()s without previously declared methods"
 msgid "Warn about @selector()s without previously declared methods."
 msgstr "前に宣言されたメソッドでない @selector() に関して警告する"
 
 #: c-family/c.opt:1188
 #, fuzzy, no-c-format
-#| msgid "Warn if an undefined macro is used in an #if directive"
 msgid "Warn if an undefined macro is used in an #if directive."
 msgstr "#if 指示内で未定義マクロが使用された場合に警告する"
 
 #: c-family/c.opt:1200
 #, fuzzy, no-c-format
-#| msgid "Warn about unrecognized pragmas"
 msgid "Warn about unrecognized pragmas."
 msgstr "認識できない pragma に関して警告する"
 
 #: c-family/c.opt:1204
 #, fuzzy, no-c-format
-#| msgid "Warn about unsuffixed float constants"
 msgid "Warn about unsuffixed float constants."
 msgstr "接尾辞がない浮動小数定数に関して警告する"
 
 #: c-family/c.opt:1212
 #, fuzzy, no-c-format
-#| msgid "Warn about macros defined in the main file that are not used"
 msgid "Warn when typedefs locally defined in a function are not used."
 msgstr "主ファイル内で定義されているが使用されていないマクロに関して警告する"
 
 #: c-family/c.opt:1216
 #, fuzzy, no-c-format
-#| msgid "Warn about macros defined in the main file that are not used"
 msgid "Warn about macros defined in the main file that are not used."
 msgstr "主ファイル内で定義されているが使用されていないマクロに関して警告する"
 
 #: c-family/c.opt:1220
 #, fuzzy, no-c-format
-#| msgid "Warn if a caller of a function, marked with attribute warn_unused_result, does not use its return value"
 msgid "Warn if a caller of a function, marked with attribute warn_unused_result, does not use its return value."
 msgstr "warn_unused_result 属性が設定されている呼び出し元関数で戻り値が使用されていない場合に警告する"
 
 #: c-family/c.opt:1228 c-family/c.opt:1232
 #, fuzzy, no-c-format
-#| msgid "Warn when a variable is unused"
 msgid "Warn when a const variable is unused."
 msgstr "変数が使用されていない場合に警告する"
 
 #: c-family/c.opt:1236
 #, fuzzy, no-c-format
-#| msgid "Do not warn about using variadic macros when -pedantic"
 msgid "Warn about using variadic macros."
 msgstr "-pedantic を使用しているときに variadic マクロを使用している場合でも警告しない"
 
@@ -7262,13 +6740,11 @@ msgstr ""
 
 #: c-family/c.opt:1244
 #, fuzzy, no-c-format
-#| msgid "Warn if a variable length array is used"
 msgid "Warn if a variable length array is used."
 msgstr "可変長配列が使用されたときに警告する"
 
 #: c-family/c.opt:1248
 #, fuzzy, no-c-format
-#| msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
 msgid "-Wvla-larger-than=<number>\tWarn on unbounded uses of variable-length arrays, and on bounded uses of variable-length arrays whose bound can be larger than <number> bytes. <number> bytes."
 msgstr "-Wlarger-than=<number>\tオブジェクトが <number> バイト以上の場合に警告する"
 
@@ -7279,13 +6755,11 @@ msgstr ""
 
 #: c-family/c.opt:1259
 #, fuzzy, no-c-format
-#| msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgid "Warn about deprecated uses of volatile qualifier."
 msgstr "廃止された 'vector long ...' AltiVec 型の使用について警告する"
 
 #: c-family/c.opt:1263
 #, fuzzy, no-c-format
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a register variable is declared volatile."
 msgstr "レジスタ変数が volatile と宣言されたときに警告する"
 
@@ -7306,13 +6780,11 @@ msgstr ""
 
 #: c-family/c.opt:1279
 #, fuzzy, no-c-format
-#| msgid "Warn when a label is unused"
 msgid "Warn when a literal '0' is used as null pointer."
 msgstr "ラベルが使用されていないときに警告する"
 
 #: c-family/c.opt:1283
 #, fuzzy, no-c-format
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn about useless casts."
 msgstr "pragma の誤用に関して警告する"
 
@@ -7333,7 +6805,6 @@ msgstr ""
 
 #: c-family/c.opt:1300
 #, fuzzy, no-c-format
-#| msgid "A synonym for -std=c89 (for C) or -std=c++98 (for C++)"
 msgid "A synonym for -std=c89 (for C) or -std=c++98 (for C++)."
 msgstr "-std=c89 (C 用) または -std=c++98 (C++ 用) の別名"
 
@@ -7370,19 +6841,16 @@ msgstr ""
 #: c-family/c.opt:1335 c-family/c.opt:1599 c-family/c.opt:1927
 #: c-family/c.opt:1931 c-family/c.opt:1947
 #, fuzzy, no-c-format
-#| msgid "No longer supported"
 msgid "No longer supported."
 msgstr "既にサポートされていません"
 
 #: c-family/c.opt:1339
 #, fuzzy, no-c-format
-#| msgid "Recognize the \"asm\" keyword"
 msgid "Recognize the \"asm\" keyword."
 msgstr "\"asm\" 予約語を認識する"
 
 #: c-family/c.opt:1347
 #, fuzzy, no-c-format
-#| msgid "Recognize built-in functions"
 msgid "Recognize built-in functions."
 msgstr "組み込み関数を認識する"
 
@@ -7398,19 +6866,16 @@ msgstr ""
 
 #: c-family/c.opt:1446
 #, fuzzy, no-c-format
-#| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 8.  This switch has no effect."
 msgstr "廃止されている。このスイッチは効果はない。"
 
 #: c-family/c.opt:1450
 #, fuzzy, no-c-format
-#| msgid "Enable PIC support for building libraries"
 msgid "Enable support for C++ concepts."
 msgstr "ライブラリ構築用に PIC サポートを有効にする"
 
 #: c-family/c.opt:1454
 #, fuzzy, no-c-format
-#| msgid "Warn about features not present in traditional C"
 msgid "Enable certain features present in the Concepts TS."
 msgstr "伝統的な C には存在しない機能に関して警告する"
 
@@ -7421,13 +6886,11 @@ msgstr ""
 
 #: c-family/c.opt:1462
 #, fuzzy, no-c-format
-#| msgid "Allow the arguments of the '?' operator to have different types"
 msgid "Allow the arguments of the '?' operator to have different types."
 msgstr "'?' 演算子の引数に異なる型を取ることを許可する"
 
 #: c-family/c.opt:1470
 #, fuzzy, no-c-format
-#| msgid "-fconst-string-class=<name>\tUse class <name> for constant strings"
 msgid "-fconst-string-class=<name>\tUse class <name> for constant strings."
 msgstr "-fconst-string-class=<name>\t文字列定数用にクラス <name> を使用する"
 
@@ -7458,13 +6921,11 @@ msgstr ""
 
 #: c-family/c.opt:1494
 #, fuzzy, no-c-format
-#| msgid "Enable traditional preprocessing"
 msgid "Emit debug annotations during preprocessing."
 msgstr "伝統的な前処理を有効にする"
 
 #: c-family/c.opt:1502
 #, fuzzy, no-c-format
-#| msgid "Warn when all constructors and destructors are private"
 msgid "Factor complex constructors and destructors to favor space over speed."
 msgstr "すべてのコンストラクタとデストラクタが非公開の場合に警告する"
 
@@ -7480,13 +6941,11 @@ msgstr "前処理指示のみ行う。"
 
 #: c-family/c.opt:1518
 #, fuzzy, no-c-format
-#| msgid "Permit '$' as an identifier character"
 msgid "Permit '$' as an identifier character."
 msgstr "'$' を識別子用の文字として許可する"
 
 #: c-family/c.opt:1522
 #, fuzzy, no-c-format
-#| msgid "Map one directory name to another in debug information"
 msgid "-fmacro-prefix-map=<old>=<new>\tMap one directory name to another in __FILE__, __BASE_FILE__, and __builtin_FILE()."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
@@ -7502,31 +6961,26 @@ msgstr ""
 
 #: c-family/c.opt:1537
 #, fuzzy, no-c-format
-#| msgid "Do not discard comments in macro expansions"
 msgid "Do not elide common elements in template comparisons."
 msgstr "マクロ展開内のコメントを破棄しない"
 
 #: c-family/c.opt:1541
 #, fuzzy, no-c-format
-#| msgid "Generate code to check exception specifications"
 msgid "Generate code to check exception specifications."
 msgstr "例外仕様を検査するためのコードを生成する"
 
 #: c-family/c.opt:1548
 #, fuzzy, no-c-format
-#| msgid "-fexec-charset=<cset>\tConvert all strings and character constants to character set <cset>"
 msgid "-fexec-charset=<cset>\tConvert all strings and character constants to character set <cset>."
 msgstr "-fexec-charset=<cset>\tすべての文字列と文字定数を文字集合 <cset> に変換する"
 
 #: c-family/c.opt:1552
 #, fuzzy, no-c-format
-#| msgid "Permit universal character names (\\u and \\U) in identifiers"
 msgid "Permit universal character names (\\u and \\U) in identifiers."
 msgstr "ユニバーサル文字名 (\\u and \\U) を識別子内で使用することを許可する"
 
 #: c-family/c.opt:1556
 #, fuzzy, no-c-format
-#| msgid "-finput-charset=<cset>\tSpecify the default character set for source files"
 msgid "-finput-charset=<cset>\tSpecify the default character set for source files."
 msgstr "-finput-charset=<cset>\tソースファイルのデフォルトの文字集合を指定する"
 
@@ -7537,49 +6991,41 @@ msgstr ""
 
 #: c-family/c.opt:1570
 #, fuzzy, no-c-format
-#| msgid "Do not assume that standard C libraries and \"main\" exist"
 msgid "Do not assume that standard C libraries and \"main\" exist."
 msgstr "標準 C ライブラリと \"main\" が存在すると見なさない"
 
 #: c-family/c.opt:1574
 #, fuzzy, no-c-format
-#| msgid "Recognize GNU-defined keywords"
 msgid "Recognize GNU-defined keywords."
 msgstr "GNU が定義した予約語を認識する"
 
 #: c-family/c.opt:1578
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU runtime environment"
 msgid "Generate code for GNU runtime environment."
 msgstr "GNU 実行環境用のコードを生成する"
 
 #: c-family/c.opt:1582
 #, fuzzy, no-c-format
-#| msgid "Use traditional GNU semantics for inline functions"
 msgid "Use traditional GNU semantics for inline functions."
 msgstr "インライン関数を伝統的な GNU の意味で使用する"
 
 #: c-family/c.opt:1595
 #, fuzzy, no-c-format
-#| msgid "Assume normal C execution environment"
 msgid "Assume normal C execution environment."
 msgstr "通常の C 実行環境を前提とする"
 
 #: c-family/c.opt:1603
 #, fuzzy, no-c-format
-#| msgid "Export functions even if they can be inlined"
 msgid "Export functions even if they can be inlined."
 msgstr "インラインにできる関数でもエクスポートする"
 
 #: c-family/c.opt:1607
 #, fuzzy, no-c-format
-#| msgid "Emit implicit instantiations of inline templates"
 msgid "Emit implicit instantiations of inline templates."
 msgstr "インラインテンプレートの暗黙的なインスタンス化を発行する"
 
 #: c-family/c.opt:1611
 #, fuzzy, no-c-format
-#| msgid "Emit implicit instantiations of templates"
 msgid "Emit implicit instantiations of templates."
 msgstr "テンプレートの暗黙的なインスタンス化を発行する"
 
@@ -7590,7 +7036,6 @@ msgstr ""
 
 #: c-family/c.opt:1622
 #, fuzzy, no-c-format
-#| msgid "Don't emit dllexported inline functions unless needed"
 msgid "Don't emit dllexported inline functions unless needed."
 msgstr "必要が無い限り dllexported インライン関数を発行しない"
 
@@ -7606,7 +7051,6 @@ msgstr ""
 
 #: c-family/c.opt:1637
 #, fuzzy, no-c-format
-#| msgid "Don't warn about uses of Microsoft extensions"
 msgid "Don't warn about uses of Microsoft extensions."
 msgstr "Microsoft 拡張の使用に関して警告しない"
 
@@ -7617,13 +7061,11 @@ msgstr ""
 
 #: c-family/c.opt:1660
 #, fuzzy, no-c-format
-#| msgid "Generate code for NeXT (Apple Mac OS X) runtime environment"
 msgid "Generate code for NeXT (Apple Mac OS X) runtime environment."
 msgstr "NeXT (Apple Mac OS X) 実行環境用のコードを生成する"
 
 #: c-family/c.opt:1664
 #, fuzzy, no-c-format
-#| msgid "Assume that receivers of Objective-C messages may be nil"
 msgid "Assume that receivers of Objective-C messages may be nil."
 msgstr "Objective-C メッセージの受信側が無い (nil) かもしれないと見なす"
 
@@ -7634,7 +7076,6 @@ msgstr ""
 
 #: c-family/c.opt:1672
 #, fuzzy, no-c-format
-#| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[private|protected|public|package]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tシンボル可視性のデフォルトを設定する"
 
@@ -7660,13 +7101,11 @@ msgstr ""
 
 #: c-family/c.opt:1717
 #, fuzzy, no-c-format
-#| msgid "Enable Objective-C exception and synchronization syntax"
 msgid "Enable Objective-C exception and synchronization syntax."
 msgstr "Objective-C 例外と同期構文を有効にする"
 
 #: c-family/c.opt:1721
 #, fuzzy, no-c-format
-#| msgid "Enable garbage collection (GC) in Objective-C/Objective-C++ programs"
 msgid "Enable garbage collection (GC) in Objective-C/Objective-C++ programs."
 msgstr "Objective-C/Objective-C++ プログラム内でガベージコレクション (GC) を有効にする"
 
@@ -7677,13 +7116,11 @@ msgstr ""
 
 #: c-family/c.opt:1730
 #, fuzzy, no-c-format
-#| msgid "Enable Objective-C setjmp exception handling runtime"
 msgid "Enable Objective-C setjmp exception handling runtime."
 msgstr "Objective-C setjmp 例外処理ランタイムを有効にする"
 
 #: c-family/c.opt:1734
 #, fuzzy, no-c-format
-#| msgid "Conform to the Objective-C 1.0 language as implemented in GCC 4.0"
 msgid "Conform to the Objective-C 1.0 language as implemented in GCC 4.0."
 msgstr "GCC 4.0 で実装されたように Objective-C 1.0 言語に準拠する"
 
@@ -7699,7 +7136,6 @@ msgstr ""
 
 #: c-family/c.opt:1746
 #, fuzzy, no-c-format
-#| msgid "Enable OpenMP (implies -frecursive in Fortran)"
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
 msgstr "OpenMP を有効にする (Fortran では暗黙的に -frecursive が指定される)"
 
@@ -7710,31 +7146,26 @@ msgstr ""
 
 #: c-family/c.opt:1754
 #, fuzzy, no-c-format
-#| msgid "Recognize C++ keywords like \"compl\" and \"xor\""
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
 msgstr "\"compl\" や \"xor\" などの C++ 予約語を認識する"
 
 #: c-family/c.opt:1765
 #, fuzzy, no-c-format
-#| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
 msgstr "前処理時でも PCH ファイルを探して使用する"
 
 #: c-family/c.opt:1769
 #, fuzzy, no-c-format
-#| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
 msgstr "規格準拠性エラーを警告に格下げする"
 
 #: c-family/c.opt:1773
 #, fuzzy, no-c-format
-#| msgid "Enable Plan 9 language extensions"
 msgid "Enable Plan 9 language extensions."
 msgstr "Plan 9 言語拡張を有効にする"
 
 #: c-family/c.opt:1777
 #, fuzzy, no-c-format
-#| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
 msgstr "入力ファイルを前処理済として取り扱う"
 
@@ -7760,43 +7191,36 @@ msgstr ""
 
 #: c-family/c.opt:1801
 #, fuzzy, no-c-format
-#| msgid "Deprecated.  This switch has no effect"
 msgid "Removed in GCC 10.  This switch has no effect."
 msgstr "廃止されている。このスイッチは効果はない。"
 
 #: c-family/c.opt:1805
 #, fuzzy, no-c-format
-#| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
 msgstr "実行時型記述子情報を生成する"
 
 #: c-family/c.opt:1809 ada/gcc-interface/lang.opt:81
 #, fuzzy, no-c-format
-#| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
 msgstr "列挙型として可能な限り最小幅の整数型を使用する"
 
 #: c-family/c.opt:1813
 #, fuzzy, no-c-format
-#| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
 msgstr "\"wchar_t\" の元となる型を強制的に \"unsigned short\" とする"
 
 #: c-family/c.opt:1817
 #, fuzzy, no-c-format
-#| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
 msgstr "\"signed\" または \"unsigned\" が与えられない場合、ビットフィールドを符号付きとする"
 
 #: c-family/c.opt:1821 ada/gcc-interface/lang.opt:85
 #, fuzzy, no-c-format
-#| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
 msgstr "\"char\" をデフォルトで符号付きにする"
 
 #: c-family/c.opt:1825
 #, fuzzy, no-c-format
-#| msgid "Enable decimal floating point hardware support"
 msgid "Enable C++14 sized deallocation support."
 msgstr "十進浮動小数点ハードウェアのサポートを有効にする"
 
@@ -7807,13 +7231,11 @@ msgstr ""
 
 #: c-family/c.opt:1848
 #, fuzzy, no-c-format
-#| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
 msgstr "コンパイル中に蓄積された統計情報を表示する"
 
 #: c-family/c.opt:1852
 #, fuzzy, no-c-format
-#| msgid "Assume that values of enumeration type are always within the minimum range of that type"
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
 msgstr "列挙型の値は常にその型の範囲内にあるとみなす"
 
@@ -7824,13 +7246,11 @@ msgstr ""
 
 #: c-family/c.opt:1881
 #, fuzzy, no-c-format
-#| msgid "-ftabstop=<number>\tDistance between tab stops for column reporting"
 msgid "-ftabstop=<number>\tDistance between tab stops for column reporting."
 msgstr "-ftabstop=<number>\t列を報告用する時のタブ位置までの距離を <number> にする"
 
 #: c-family/c.opt:1885
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -7846,37 +7266,31 @@ msgstr ""
 
 #: c-family/c.opt:1903
 #, fuzzy, no-c-format
-#| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
 msgstr "\"signed\" または \"unsigned\" が与えられていない場合、ビットフィールドを符号無しにする"
 
 #: c-family/c.opt:1907 ada/gcc-interface/lang.opt:89
 #, fuzzy, no-c-format
-#| msgid "Make \"char\" unsigned by default"
 msgid "Make \"char\" unsigned by default."
 msgstr "\"char\" をデフォルトで符号無しにする"
 
 #: c-family/c.opt:1911
 #, fuzzy, no-c-format
-#| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
 msgstr "デストラクタを登録するために __cxa_atexit を使用する"
 
 #: c-family/c.opt:1915
 #, fuzzy, no-c-format
-#| msgid "Use __cxa_get_exception_ptr in exception handling"
 msgid "Use __cxa_get_exception_ptr in exception handling."
 msgstr "例外処理内で __cxa_get_exception_ptr を使用する"
 
 #: c-family/c.opt:1919
 #, fuzzy, no-c-format
-#| msgid "Marks all inlined methods as having hidden visibility"
 msgid "Marks all inlined functions and methods as having hidden visibility."
 msgstr "すべてのインライン化されたメソッドが隠された可視性を持つとマークする"
 
 #: c-family/c.opt:1923
 #, fuzzy, no-c-format
-#| msgid "Changes visibility to match Microsoft Visual Studio by default"
 msgid "Changes visibility to match Microsoft Visual Studio by default."
 msgstr "デフォルトの可視性を Microsoft Visual Studio に適合するように変更する"
 
@@ -7887,13 +7301,11 @@ msgstr ""
 
 #: c-family/c.opt:1939
 #, fuzzy, no-c-format
-#| msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>"
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
 msgstr "-fwide-exec-charset=<cset>\tすべてのワイド文字列と文字定数を文字集合 <cset> に変換する"
 
 #: c-family/c.opt:1943
 #, fuzzy, no-c-format
-#| msgid "Generate a #line directive pointing at the current working directory"
 msgid "Generate a #line directive pointing at the current working directory."
 msgstr "現在の作業ディレクトリを指す #line 指示を生成する"
 
@@ -7904,25 +7316,21 @@ msgstr ""
 
 #: c-family/c.opt:1955
 #, fuzzy, no-c-format
-#| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
 msgstr "宣言を .decl ファイルにダンプする"
 
 #: c-family/c.opt:1959
 #, fuzzy, no-c-format
-#| msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs"
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
 msgstr "-femit-struct-debug-baseonly\t構造体用のデバッグ情報を積極的に削減する"
 
 #: c-family/c.opt:1963
 #, fuzzy, no-c-format
-#| msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs"
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
 msgstr "-femit-struct-debug-reduced\t構造体用のデバッグ情報を保守的に削減する"
 
 #: c-family/c.opt:1967
 #, fuzzy, no-c-format
-#| msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs"
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
 msgstr "-femit-struct-debug-detailed=<spec-list>\t構造体用のデバッグ情報の削減方法を詳細に指定する"
 
@@ -7933,25 +7341,21 @@ msgstr ""
 
 #: c-family/c.opt:1976
 #, fuzzy, no-c-format
-#| msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path"
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-idirafter <dir>\tシステムインクルードパスの最後に <dir> を追加する"
 
 #: c-family/c.opt:1980
 #, fuzzy, no-c-format
-#| msgid "-imacros <file>\tAccept definition of macros in <file>"
 msgid "-imacros <file>\tAccept definition of macros in <file>."
 msgstr "-imacros <file>\t<file>内にあるマクロ定義を受け付ける"
 
 #: c-family/c.opt:1984
 #, fuzzy, no-c-format
-#| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
 #: c-family/c.opt:1988
 #, fuzzy, no-c-format
-#| msgid "-include <file>\tInclude the contents of <file> before other files"
 msgid "-include <file>\tInclude the contents of <file> before other files."
 msgstr "-include <file>\t他のファイルの前に <file> の中身をインクルードする"
 
@@ -7962,55 +7366,46 @@ msgstr ""
 
 #: c-family/c.opt:1996
 #, fuzzy, no-c-format
-#| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
 msgstr "-isysroot <dir>\tシステムルートディレクトリを <dir> に設定する"
 
 #: c-family/c.opt:2000
 #, fuzzy, no-c-format
-#| msgid "-isystem <dir>\tAdd <dir> to the start of the system include path"
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
 msgstr "-isystem <dir>\tシステムインクルードパスの先頭に <dir> を追加する"
 
 #: c-family/c.opt:2004
 #, fuzzy, no-c-format
-#| msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path"
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
 msgstr "-idirafter <dir>\tシステムインクルードパスの最後に <dir> を追加する"
 
 #: c-family/c.opt:2008
 #, fuzzy, no-c-format
-#| msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path"
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
 msgstr "-iwithprefix <dir>\tシステムインクルードパスの最後に <dir> を追加する"
 
 #: c-family/c.opt:2012
 #, fuzzy, no-c-format
-#| msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path"
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
 msgstr "-iwithprefixbefore <dir>\t主インクルードパスの最後に <dir> を追加する"
 
 #: c-family/c.opt:2022
 #, fuzzy, no-c-format
-#| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
 msgstr "標準のシステムインクルードディレクトリを探査しない (-isystem で指定されたディレクトリは使用される)"
 
 #: c-family/c.opt:2026
 #, fuzzy, no-c-format
-#| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
 msgstr "C++ 用の標準システムインクルードディレクトリを探査しない"
 
 #: c-family/c.opt:2038
 #, fuzzy, no-c-format
-#| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
 msgstr "プラットフォーム固有機能の C ヘッダを生成する"
 
 #: c-family/c.opt:2042
 #, fuzzy, no-c-format
-#| msgid "Remap file names when including files"
 msgid "Remap file names when including files."
 msgstr "ファイルをインクルードするときにファイル名を再マップする"
 
@@ -8021,86 +7416,72 @@ msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2054
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
 msgstr "ISO 1998 C++ 標準に準拠させる"
 
 #: c-family/c.opt:2058
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++11."
 msgstr "-std=c99 によって廃止された"
 
 #: c-family/c.opt:2062
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++14."
 msgstr "-std=c99 によって廃止された"
 
 #: c-family/c.opt:2066
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
 msgstr "ISO 1998 C++ 標準に準拠させる"
 
 #: c-family/c.opt:2070
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c++17."
 msgstr "-std=c99 によって廃止された"
 
 #: c-family/c.opt:2074
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
 msgstr "ISO 1998 C++ 標準に準拠させる"
 
 #: c-family/c.opt:2078 c-family/c.opt:2082
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 201X C standard draft (experimental and incomplete support)"
 msgid "Conform to the ISO 2020 C++ draft standard (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に準拠させる (実験的かつ不完全なサポート)"
 
 #: c-family/c.opt:2086 c-family/c.opt:2216
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 2011 C standard."
 msgstr "ISO 1990 C 標準に準拠させる"
 
 #: c-family/c.opt:2090
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c11."
 msgstr "-std=c99 によって廃止された"
 
 #: c-family/c.opt:2094 c-family/c.opt:2098 c-family/c.opt:2220
 #: c-family/c.opt:2224
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "ISO 1990 C 標準 (1994年改正) に準拠させる"
 
 #: c-family/c.opt:2102
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 201X C standard draft (experimental and incomplete support)"
 msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に準拠させる (実験的かつ不完全なサポート)"
 
 #: c-family/c.opt:2106 c-family/c.opt:2110 c-family/c.opt:2200
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
 msgstr "ISO 1990 C 標準に準拠させる"
 
 #: c-family/c.opt:2114 c-family/c.opt:2208
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
 msgstr "ISO 1999 C 標準に準拠させる"
 
 #: c-family/c.opt:2118
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
 msgstr "-std=c99 によって廃止された"
 
@@ -8111,115 +7492,96 @@ msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2132
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2136
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++11."
 msgstr "-std=gnu99 によって廃止された"
 
 #: c-family/c.opt:2140
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++14."
 msgstr "-std=gnu99 によって廃止された"
 
 #: c-family/c.opt:2144
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2148
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu++17."
 msgstr "-std=gnu99 によって廃止された"
 
 #: c-family/c.opt:2152
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1998 C++ standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
 msgstr "ISO 1998 C++ 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2156 c-family/c.opt:2160
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 201X C standard draft with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 2020 C++ draft standard with GNU extensions (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に GNU 拡張付きで準拠させる (実験的かつ不完全なサポート)"
 
 #: c-family/c.opt:2164
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
 msgstr "ISO 1990 C 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2168
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu11."
 msgstr "-std=gnu99 によって廃止された"
 
 #: c-family/c.opt:2172 c-family/c.opt:2176
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
 msgstr "ISO 1990 C 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2180
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 201X C standard draft with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
 msgstr "ISO 201X C 標準ドラフト版に GNU 拡張付きで準拠させる (実験的かつ不完全なサポート)"
 
 #: c-family/c.opt:2184 c-family/c.opt:2188
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
 msgstr "ISO 1990 C 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2192
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
 msgstr "ISO 1999 C 標準に GNU 拡張付きで準拠させる"
 
 #: c-family/c.opt:2196
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
 msgstr "-std=gnu99 によって廃止された"
 
 #: c-family/c.opt:2204
 #, fuzzy, no-c-format
-#| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
 msgstr "ISO 1990 C 標準 (1994年改正) に準拠させる"
 
 #: c-family/c.opt:2212
 #, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
 msgstr "-std=iso9899:1999 によって廃止された"
 
 #: c-family/c.opt:2231
 #, fuzzy, no-c-format
-#| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
 msgstr "伝統的な前処理を有効にする"
 
 #: c-family/c.opt:2235
 #, fuzzy, no-c-format
-#| msgid "-trigraphs\tSupport ISO C trigraphs"
 msgid "-trigraphs\tSupport ISO C trigraphs."
 msgstr "-trigraphs\tISO C トライグラフをサポートする"
 
 #: c-family/c.opt:2239
 #, fuzzy, no-c-format
-#| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
 msgstr "システムおよび GCC 固有のマクロを事前定義しない"
 
@@ -8235,7 +7597,6 @@ msgstr ""
 
 #: ada/gcc-interface/lang.opt:65
 #, fuzzy, no-c-format
-#| msgid "Synonym for -Wcomment"
 msgid "Synonym of -gnatk8."
 msgstr "-Wcomment の別名"
 
@@ -8246,7 +7607,6 @@ msgstr ""
 
 #: ada/gcc-interface/lang.opt:77
 #, fuzzy, no-c-format
-#| msgid "Use the simulator runtime."
 msgid "Select the runtime."
 msgstr "シミュレータランタイムを使用する。"
 
@@ -8262,7 +7622,6 @@ msgstr ""
 
 #: ada/gcc-interface/lang.opt:101
 #, fuzzy, no-c-format
-#| msgid "-gnat<options>\tSpecify options to GNAT"
 msgid "-gnat<options>\tSpecify options to GNAT."
 msgstr "-gnat<options>\tGNAT へのオプションを指定する"
 
@@ -8278,13 +7637,11 @@ msgstr ""
 
 #: d/lang.opt:55
 #, fuzzy, no-c-format
-#| msgid "-o <file>\tPlace output into <file>"
 msgid "-Hf <file>\tWrite D interface to <file>."
 msgstr "-o <file>\t出力を <file> に配置する"
 
 #: d/lang.opt:123
 #, fuzzy, no-c-format
-#| msgid "Warn about pointer casts which increase alignment"
 msgid "Warn about casts that will produce a null result."
 msgstr "ポインタのキャストによって整列が増加する場合に警告する"
 
@@ -8295,13 +7652,11 @@ msgstr ""
 
 #: d/lang.opt:151
 #, fuzzy, no-c-format
-#| msgid "Generate H8S code"
 msgid "Generate JSON file."
 msgstr "H8S コードを生成する"
 
 #: d/lang.opt:155
 #, fuzzy, no-c-format
-#| msgid "-MF <file>\tWrite dependency output to the given file"
 msgid "-Xf <file>\tWrite JSON output to the given <file>."
 msgstr "-MF <file>\t与えられたファイルに依存関係を出力する"
 
@@ -8322,13 +7677,11 @@ msgstr ""
 
 #: d/lang.opt:174
 #, fuzzy, no-c-format
-#| msgid "Enable automatic template instantiation"
 msgid "Generate code for all template instantiations."
 msgstr "自動テンプレート実体化を有効にする"
 
 #: d/lang.opt:178
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU assembler (gas)"
 msgid "Generate code for assert contracts."
 msgstr "GNU アセンブラ (gas) 用のコードを生成する"
 
@@ -8339,7 +7692,6 @@ msgstr ""
 
 #: d/lang.opt:210
 #, fuzzy, no-c-format
-#| msgid "Generate code in big endian mode"
 msgid "Compile in debug code."
 msgstr "ビッグエンディアンモードでコードを生成する"
 
@@ -8350,7 +7702,6 @@ msgstr ""
 
 #: d/lang.opt:218
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate documentation."
 msgstr "ビット命令を生成する"
 
@@ -8361,7 +7712,6 @@ msgstr ""
 
 #: d/lang.opt:226
 #, fuzzy, no-c-format
-#| msgid "-o <file>\tPlace output into <file>"
 msgid "-fdoc-file=<file>\tWrite documentation to <file>."
 msgstr "-o <file>\t出力を <file> に配置する"
 
@@ -8372,13 +7722,11 @@ msgstr ""
 
 #: d/lang.opt:234
 #, fuzzy, no-c-format
-#| msgid "Do not assume that standard C libraries and \"main\" exist"
 msgid "Assume that standard D runtime libraries and \"D main\" exist."
 msgstr "標準 C ライブラリと \"main\" が存在すると見なさない"
 
 #: d/lang.opt:238
 #, fuzzy, no-c-format
-#| msgid "Display the compiler's version"
 msgid "Display the frontend AST after parsing and semantic passes."
 msgstr "`コンパイラのバージョンを表示する"
 
@@ -8389,7 +7737,6 @@ msgstr ""
 
 #: d/lang.opt:246
 #, fuzzy, no-c-format
-#| msgid "Generate code for a cpu32"
 msgid "Generate code for class invariant contracts."
 msgstr "cpu32 用のコードを生成する"
 
@@ -8405,7 +7752,6 @@ msgstr ""
 
 #: d/lang.opt:258
 #, fuzzy, no-c-format
-#| msgid "Generate code for the Boehm GC"
 msgid "Generate ModuleInfo struct for output module."
 msgstr "Boehm GC 用コードを生成する"
 
@@ -8416,25 +7762,21 @@ msgstr ""
 
 #: d/lang.opt:266
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate code for postcondition contracts."
 msgstr "ビット命令を生成する"
 
 #: d/lang.opt:270
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate code for precondition contracts."
 msgstr "ビット命令を生成する"
 
 #: d/lang.opt:274
 #, fuzzy, no-c-format
-#| msgid "Display the compiler's version"
 msgid "Compile release version."
 msgstr "`コンパイラのバージョンを表示する"
 
 #: d/lang.opt:282
 #, fuzzy, no-c-format
-#| msgid "Generate code for the Android platform."
 msgid "Generate code for switches without a default case."
 msgstr "Android プラットフォーム用コードを生成する。"
 
@@ -8480,13 +7822,11 @@ msgstr ""
 
 #: d/lang.opt:318
 #, fuzzy, no-c-format
-#| msgid "Use given thread-local storage dialect"
 msgid "List all variables going into thread local storage."
 msgstr "与えられたスレッド局所記憶域 (TLS) 形式を使用する"
 
 #: d/lang.opt:322
 #, fuzzy, no-c-format
-#| msgid "Compile with 32-bit integer mode"
 msgid "Compile in unittest code."
 msgstr "32 ビット整数モードでコンパイルする"
 
@@ -8497,7 +7837,6 @@ msgstr ""
 
 #: d/lang.opt:350
 #, fuzzy, no-c-format
-#| msgid "Do not assume that standard C libraries and \"main\" exist"
 msgid "Do not link the standard D library in the compilation."
 msgstr "標準 C ライブラリと \"main\" が存在すると見なさない"
 
@@ -8513,7 +7852,6 @@ msgstr ""
 
 #: go/lang.opt:42
 #, fuzzy, no-c-format
-#| msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgid "-fgo-c-header=<file>\tWrite Go struct definitions to file as C code."
 msgstr "-fdump-go-spec=filename\t全ての宣言を Go コードとしてファイルに書き込む"
 
@@ -8534,7 +7872,6 @@ msgstr ""
 
 #: go/lang.opt:58
 #, fuzzy, no-c-format
-#| msgid "-fgo-dump-<type>\tDump Go frontend internal information"
 msgid "-fgo-dump-<type>\tDump Go frontend internal information."
 msgstr "-fgo-dump-<type>\tGo フロントエンドの内部情報をダンプする"
 
@@ -8560,7 +7897,6 @@ msgstr ""
 
 #: go/lang.opt:78
 #, fuzzy, no-c-format
-#| msgid "Functions which return values must end with return statements"
 msgid "Functions which return values must end with return statements."
 msgstr "戻り値を返す関数は return 文で終了しなければならないこととする"
 
@@ -8576,7 +7912,6 @@ msgstr ""
 
 #: go/lang.opt:90
 #, fuzzy, no-c-format
-#| msgid "Enable linker optimizations"
 msgid "Emit optimization diagnostics."
 msgstr "リンカ最適化を有効にする"
 
@@ -8612,25 +7947,21 @@ msgstr ""
 
 #: analyzer/analyzer.opt:51
 #, fuzzy, no-c-format
-#| msgid "Warn about code which might break strict aliasing rules"
 msgid "Warn about code paths in which sensitive data is written to a file."
 msgstr "厳密な別名規約を壊す可能性があるコードに関して警告する"
 
 #: analyzer/analyzer.opt:55
 #, fuzzy, no-c-format
-#| msgid "Warn about code which might break strict aliasing rules"
 msgid "Warn about code paths in which a stdio FILE is not closed."
 msgstr "厳密な別名規約を壊す可能性があるコードに関して警告する"
 
 #: analyzer/analyzer.opt:59
 #, fuzzy, no-c-format
-#| msgid "Warn about code which might break strict aliasing rules"
 msgid "Warn about code paths in which a non-heap pointer is freed."
 msgstr "厳密な別名規約を壊す可能性があるコードに関して警告する"
 
 #: analyzer/analyzer.opt:63
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit declarations"
 msgid "Warn about code paths in which a heap-allocated pointer leaks."
 msgstr "暗黙的宣言に関して警告する"
 
@@ -8656,7 +7987,6 @@ msgstr ""
 
 #: analyzer/analyzer.opt:83
 #, fuzzy, no-c-format
-#| msgid "Warn about comparison of different enum types"
 msgid "Warn about code paths in which a NULL pointer is dereferenced."
 msgstr "異なる列挙型の比較に関して警告する"
 
@@ -8672,13 +8002,11 @@ msgstr ""
 
 #: analyzer/analyzer.opt:95
 #, fuzzy, no-c-format
-#| msgid "Warn about pointer casts which increase alignment"
 msgid "Warn about code paths in which a freed value is used."
 msgstr "ポインタのキャストによって整列が増加する場合に警告する"
 
 #: analyzer/analyzer.opt:99
 #, fuzzy, no-c-format
-#| msgid "Warn about macros defined in the main file that are not used"
 msgid "Warn about code paths in which a pointer to a stale stack frame is used."
 msgstr "主ファイル内で定義されているが使用されていないマクロに関して警告する"
 
@@ -8739,13 +8067,11 @@ msgstr ""
 
 #: analyzer/analyzer.opt:147
 #, fuzzy, no-c-format
-#| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
 #: analyzer/analyzer.opt:151
 #, fuzzy, no-c-format
-#| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "Dump various analyzer internals to stderr."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
@@ -8791,7 +8117,6 @@ msgstr ""
 
 #: config/vms/vms.opt:31
 #, fuzzy, no-c-format
-#| msgid "Set name of main routine for the debugger"
 msgid "Set name of main routine for the debugger."
 msgstr "デバッガ用のメインルーチン名を設定する"
 
@@ -8807,79 +8132,66 @@ msgstr ""
 
 #: config/mcore/mcore.opt:23
 #, fuzzy, no-c-format
-#| msgid "Generate code for the M*Core M210"
 msgid "Generate code for the M*Core M210."
 msgstr "M*Core M210 用のコードを生成する"
 
 #: config/mcore/mcore.opt:27
 #, fuzzy, no-c-format
-#| msgid "Generate code for the M*Core M340"
 msgid "Generate code for the M*Core M340."
 msgstr "M*Core M340 用のコードを生成する"
 
 #: config/mcore/mcore.opt:31
 #, fuzzy, no-c-format
-#| msgid "Force functions to be aligned to a 4 byte boundary"
 msgid "Force functions to be aligned to a 4 byte boundary."
 msgstr "関数を強制的に 4 バイト境界に整列する"
 
 #: config/mcore/mcore.opt:35 config/moxie/moxie.opt:23 config/csky/csky.opt:44
 #, fuzzy, no-c-format
-#| msgid "Generate big-endian code"
 msgid "Generate big-endian code."
 msgstr "ビッグエンディアンコードを生成する"
 
 #: config/mcore/mcore.opt:39
 #, fuzzy, no-c-format
-#| msgid "Emit call graph information"
 msgid "Emit call graph information."
 msgstr "呼び出しグラフ情報を送出する"
 
 #: config/mcore/mcore.opt:43
 #, fuzzy, no-c-format
-#| msgid "Use the divide instruction"
 msgid "Use the divide instruction."
 msgstr "除算命令を使用する"
 
 #: config/mcore/mcore.opt:47
 #, fuzzy, no-c-format
-#| msgid "Inline constants if it can be done in 2 insns or less"
 msgid "Inline constants if it can be done in 2 insns or less."
 msgstr "2 命令以下で行なえる不変処理をインラインにする"
 
 #: config/mcore/mcore.opt:51 config/moxie/moxie.opt:27 config/csky/csky.opt:51
 #, fuzzy, no-c-format
-#| msgid "Generate little-endian code"
 msgid "Generate little-endian code."
 msgstr "リトルエンディアンコードを生成する"
 
 #: config/mcore/mcore.opt:56 config/fr30/fr30.opt:27
 #, fuzzy, no-c-format
-#| msgid "Assume that run-time support has been provided, so omit -lsim from the linker command line"
 msgid "Assume that run-time support has been provided, so omit -lsim from the linker command line."
 msgstr "実行時サポートが提供されると見なし、リンカコマンドラインに -lsim を含めない"
 
 #: config/mcore/mcore.opt:60
 #, fuzzy, no-c-format
-#| msgid "Use arbitrary sized immediates in bit operations"
 msgid "Use arbitrary sized immediates in bit operations."
 msgstr "ビット操作で任意サイズの即値を使用する"
 
 #: config/mcore/mcore.opt:64
 #, fuzzy, no-c-format
-#| msgid "Prefer word accesses over byte accesses"
 msgid "Prefer word accesses over byte accesses."
 msgstr "バイトアクセスよりワードアクセスを選ぶ"
 
 #: config/mcore/mcore.opt:71
 #, fuzzy, no-c-format
-#| msgid "Set the maximum amount for a single stack increment operation"
 msgid "Set the maximum amount for a single stack increment operation."
 msgstr "単一のスタック増分操作の最大値を設定する"
 
 #: config/mcore/mcore.opt:75
 #, fuzzy, no-c-format
-#| msgid "Always treat bitfields as int-sized"
 msgid "Always treat bitfields as int-sized."
 msgstr "ビットフィールドを常に int のサイズとして取り扱う"
 
@@ -8890,25 +8202,21 @@ msgstr "Android プラットフォーム用コードを生成する。"
 
 #: config/mmix/mmix.opt:24
 #, fuzzy, no-c-format
-#| msgid "Return small aggregates in registers"
 msgid "For intrinsics library: pass all parameters in registers."
 msgstr "小さな集合体をレジスタで返す"
 
 #: config/mmix/mmix.opt:28
 #, fuzzy, no-c-format
-#| msgid "Use register stack for parameters and return value"
 msgid "Use register stack for parameters and return value."
 msgstr "引数と戻り値用にレジスタスタックを使用する"
 
 #: config/mmix/mmix.opt:32
 #, fuzzy, no-c-format
-#| msgid "Use call-clobbered registers for parameters and return value"
 msgid "Use call-clobbered registers for parameters and return value."
 msgstr "引数と戻り値用に呼び出しで破壊されるレジスタを使用する"
 
 #: config/mmix/mmix.opt:37
 #, fuzzy, no-c-format
-#| msgid "Use decimal floating point instructions"
 msgid "Use epsilon-respecting floating point compare instructions."
 msgstr "十進浮動小数点命令を使用する"
 
@@ -8929,7 +8237,6 @@ msgstr ""
 
 #: config/mmix/mmix.opt:53
 #, fuzzy, no-c-format
-#| msgid "Set start-address of the program"
 msgid "Do not provide a default start-address 0x100 of the program."
 msgstr "プログラムの開始アドレスを設定する"
 
@@ -8940,13 +8247,11 @@ msgstr ""
 
 #: config/mmix/mmix.opt:61
 #, fuzzy, no-c-format
-#| msgid "Use P-mnemonics for branches statically predicted as taken"
 msgid "Use P-mnemonics for branches statically predicted as taken."
 msgstr "統計的に使用されると予測される分岐に P-ニーモニックを使用する"
 
 #: config/mmix/mmix.opt:65
 #, fuzzy, no-c-format
-#| msgid "Don't use P-mnemonics for branches"
 msgid "Don't use P-mnemonics for branches."
 msgstr "分岐用にP-ニーモニックを使用しない"
 
@@ -8957,97 +8262,81 @@ msgstr ""
 
 #: config/mmix/mmix.opt:83
 #, fuzzy, no-c-format
-#| msgid "Do not use direct addressing mode for soft registers"
 msgid "Do not use addresses that allocate global registers."
 msgstr "ソフトレジスタ用に直接アドレスモードを使用しない"
 
 #: config/mmix/mmix.opt:87
 #, fuzzy, no-c-format
-#| msgid "Generate a single exit point for each function"
 msgid "Generate a single exit point for each function."
 msgstr "各関数で単一の終了点を生成する"
 
 #: config/mmix/mmix.opt:91
 #, fuzzy, no-c-format
-#| msgid "Do not generate a single exit point for each function"
 msgid "Do not generate a single exit point for each function."
 msgstr "各関数で単一の終了点を生成しない"
 
 #: config/mmix/mmix.opt:95
 #, fuzzy, no-c-format
-#| msgid "Set start-address of the program"
 msgid "Set start-address of the program."
 msgstr "プログラムの開始アドレスを設定する"
 
 #: config/mmix/mmix.opt:99
 #, fuzzy, no-c-format
-#| msgid "Set start-address of data"
 msgid "Set start-address of data."
 msgstr "データの開始アドレスを設定する"
 
 #: config/darwin.opt:34
 #, fuzzy, no-c-format
-#| msgid "Generate code for darwin loadable kernel extensions"
 msgid "Generate code for darwin loadable kernel extensions."
 msgstr "darwin ロード可能カーネル拡張用のコードを生成する"
 
 #: config/darwin.opt:38
 #, fuzzy, no-c-format
-#| msgid "-iframework <dir>\tAdd <dir> to the end of the system framework include path"
 msgid "-iframework <dir>\tAdd <dir> to the end of the system framework include path."
 msgstr "-iframework <dir>\t<dir> をシステムフレームワークインクルードパスの末尾に加える"
 
 #: config/darwin.opt:42
 #, fuzzy, no-c-format
-#| msgid "Generate compile-time CFString objects"
 msgid "Generate compile-time CFString objects."
 msgstr "コンパイル時 CFString オブジェクトを生成する"
 
 #: config/darwin.opt:46
 #, fuzzy, no-c-format
-#| msgid "Warn if constant CFString objects contain non-portable characters"
 msgid "Warn if constant CFString objects contain non-portable characters."
 msgstr "定数 CFString オブジェクトが移植性の無い文字を含む場合に警告する"
 
 #: config/darwin.opt:51
 #, fuzzy, no-c-format
-#| msgid "Generate AT&T-style stubs for Mach-O"
 msgid "Generate AT&T-style stubs for Mach-O."
 msgstr "Mach-O 用に AT&T スタイルのスタブを生成する"
 
 #: config/darwin.opt:55
 #, fuzzy, no-c-format
-#| msgid "Generate code suitable for executables (NOT shared libs)"
 msgid "Generate code suitable for executables (NOT shared libs)."
 msgstr "実行可能ファイル用 (共有ライブラリではなく) に適したコードを生成する"
 
 #: config/darwin.opt:59
 #, fuzzy, no-c-format
-#| msgid "Generate code suitable for fast turn around debugging"
 msgid "Generate code suitable for fast turn around debugging."
 msgstr "デバッグを高速に行うために適したコードを生成する"
 
 #: config/darwin.opt:63
 #, fuzzy, no-c-format
-#| msgid "Generate code for the kernel or loadable kernel extensions"
 msgid "Generate code for the kernel or loadable kernel extensions."
 msgstr "カーネル用、またはロード可能カーネル拡張用のコードを生成する"
 
 #: config/darwin.opt:71
 #, fuzzy, no-c-format
-#| msgid "The earliest MacOS X version on which this program will run"
 msgid "The earliest macOS version on which this program will run."
 msgstr "このプログラムを最初期の MacOS X バージョン上で実行されるものとする"
 
 #: config/darwin.opt:76
 #, fuzzy, no-c-format
-#| msgid "Set sizeof(bool) to 1"
 msgid "Set sizeof(bool) to 1."
 msgstr "sizeof(bool) を 1 に設定する"
 
 #: config/darwin.opt:80
 #, fuzzy, no-c-format
-#| msgid "Support code generation of movbe instruction."
 msgid "Force generation of external symbol indirection stubs."
 msgstr "movbe 命令のコード生成をサポートする。"
 
@@ -9068,7 +8357,6 @@ msgstr ""
 
 #: config/darwin.opt:102
 #, fuzzy, no-c-format
-#| msgid "Generate code for a cpu32"
 msgid "-arch <name>\tGenerate output for architecture <name>."
 msgstr "cpu32 用のコードを生成する"
 
@@ -9079,7 +8367,6 @@ msgstr ""
 
 #: config/darwin.opt:110
 #, fuzzy, no-c-format
-#| msgid "The earliest MacOS X version on which this program will run"
 msgid "The earliest macOS version on which this program will run (formatted for the assembler)."
 msgstr "このプログラムを最初期の MacOS X バージョン上で実行されるものとする"
 
@@ -9150,7 +8437,6 @@ msgstr ""
 
 #: config/darwin.opt:169 config/darwin.opt:189
 #, fuzzy, no-c-format
-#| msgid "Generate code for darwin loadable kernel extensions"
 msgid "Used for generating code for some older kernel revisions."
 msgstr "darwin ロード可能カーネル拡張用のコードを生成する"
 
@@ -9241,13 +8527,11 @@ msgstr ""
 
 #: config/darwin.opt:245 config/darwin.opt:260 config/darwin.opt:264
 #, fuzzy, no-c-format
-#| msgid "switch %qs is no longer supported"
 msgid "(Obsolete) LD_PREBIND is no longer supported."
 msgstr "%qs スイッチは既にサポートされていません"
 
 #: config/darwin.opt:249
 #, fuzzy, no-c-format
-#| msgid "Stores doubles in 32 bits.  This is the default."
 msgid "(Obsolete) This is the default."
 msgstr "double を 32 ビットで保存する (デフォルト)。"
 
@@ -9308,7 +8592,6 @@ msgstr ""
 
 #: config/darwin.opt:312
 #, fuzzy, no-c-format
-#| msgid "Synonym for -Wcomment"
 msgid "Synonym for \"image_base\"."
 msgstr "-Wcomment の別名"
 
@@ -9344,7 +8627,6 @@ msgstr ""
 
 #: config/darwin.opt:341
 #, fuzzy, no-c-format
-#| msgid "Stores doubles in 32 bits.  This is the default."
 msgid "(Obsolete)\tThis is the default."
 msgstr "double を 32 ビットで保存する (デフォルト)。"
 
@@ -9360,7 +8642,6 @@ msgstr ""
 
 #: config/darwin.opt:353
 #, fuzzy, no-c-format
-#| msgid "this is the first default label"
 msgid "This is the default."
 msgstr "これが最初の default ラベルです"
 
@@ -9412,25 +8693,21 @@ msgstr ""
 #: config/bfin/bfin.opt:40 config/msp430/msp430.opt:3 config/cr16/cr16.opt:23
 #: config/c6x/c6x.opt:38
 #, fuzzy, no-c-format
-#| msgid "Use simulator runtime"
 msgid "Use simulator runtime."
 msgstr "シミュレータランタイムを使用する"
 
 #: config/bfin/bfin.opt:44 config/arm/arm.opt:111
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target CPU"
 msgid "Specify the name of the target CPU."
 msgstr "ターゲット CPU の名前を指定する"
 
 #: config/bfin/bfin.opt:48
 #, fuzzy, no-c-format
-#| msgid "Omit frame pointer for leaf functions"
 msgid "Omit frame pointer for leaf functions."
 msgstr "末端の関数ではフレームポインタを省略する"
 
 #: config/bfin/bfin.opt:52
 #, fuzzy, no-c-format
-#| msgid "Program is entirely located in low 64k of memory"
 msgid "Program is entirely located in low 64k of memory."
 msgstr "プログラム全体をメモリの下位 64k に配置する"
 
@@ -9446,7 +8723,6 @@ msgstr ""
 
 #: config/bfin/bfin.opt:65
 #, fuzzy, no-c-format
-#| msgid "Enabled ID based shared library"
 msgid "Enabled ID based shared library."
 msgstr "ID に基づく共有ライブラリを有効にする"
 
@@ -9457,13 +8733,11 @@ msgstr ""
 
 #: config/bfin/bfin.opt:74 config/m68k/m68k.opt:175
 #, fuzzy, no-c-format
-#| msgid "ID of shared library to build"
 msgid "ID of shared library to build."
 msgstr "ビルドする共有ライブラリの ID"
 
 #: config/bfin/bfin.opt:78 config/m68k/m68k.opt:171
 #, fuzzy, no-c-format
-#| msgid "Enable separate data segment"
 msgid "Enable separate data segment."
 msgstr "分離データセグメントを有効にする"
 
@@ -9474,19 +8748,16 @@ msgstr ""
 
 #: config/bfin/bfin.opt:86
 #, fuzzy, no-c-format
-#| msgid "Link with the fast floating-point library"
 msgid "Link with the fast floating-point library."
 msgstr "高速な浮動小数ライブラリとリンクする"
 
 #: config/bfin/bfin.opt:90 config/arm/arm.opt:312 config/frv/frv.opt:130
 #, fuzzy, no-c-format
-#| msgid "Enable Function Descriptor PIC mode"
 msgid "Enable Function Descriptor PIC mode."
 msgstr "関数記述子 PIC モードを有効にする"
 
 #: config/bfin/bfin.opt:94 config/frv/frv.opt:162
 #, fuzzy, no-c-format
-#| msgid "Enable inlining of PLT in function calls"
 msgid "Enable inlining of PLT in function calls."
 msgstr "関数呼び出し内で PLT のインライン化を有効にする"
 
@@ -9497,25 +8768,21 @@ msgstr ""
 
 #: config/bfin/bfin.opt:102
 #, fuzzy, no-c-format
-#| msgid "Enable multicore support"
 msgid "Enable multicore support."
 msgstr "複数コアサポートを有効にする"
 
 #: config/bfin/bfin.opt:106
 #, fuzzy, no-c-format
-#| msgid "Build for Core A"
 msgid "Build for Core A."
 msgstr "Core A 用にビルドする"
 
 #: config/bfin/bfin.opt:110
 #, fuzzy, no-c-format
-#| msgid "Build for Core B"
 msgid "Build for Core B."
 msgstr "Core B 用にビルドする"
 
 #: config/bfin/bfin.opt:114
 #, fuzzy, no-c-format
-#| msgid "Build for SDRAM"
 msgid "Build for SDRAM."
 msgstr "SDRAM 用にビルドする"
 
@@ -9541,170 +8808,142 @@ msgstr ""
 
 #: config/m68k/ieee.opt:24 config/i386/i386.opt:364
 #, fuzzy, no-c-format
-#| msgid "Use IEEE math for fp comparisons"
 msgid "Use IEEE math for fp comparisons."
 msgstr "浮動小数点比較に IEEE 規格を使う"
 
 #: config/m68k/m68k.opt:30
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 520X"
 msgid "Generate code for a 520X."
 msgstr "520X 用のコードを生成する"
 
 #: config/m68k/m68k.opt:34
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 5206e"
 msgid "Generate code for a 5206e."
 msgstr "5206e 用のコードを生成する"
 
 #: config/m68k/m68k.opt:38
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 528x"
 msgid "Generate code for a 528x."
 msgstr "528x 用のコードを生成する"
 
 #: config/m68k/m68k.opt:42
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 5307"
 msgid "Generate code for a 5307."
 msgstr "5307 用のコードを生成する"
 
 #: config/m68k/m68k.opt:46
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 5407"
 msgid "Generate code for a 5407."
 msgstr "5407 用のコードを生成する"
 
 #: config/m68k/m68k.opt:50 config/m68k/m68k.opt:111
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68000"
 msgid "Generate code for a 68000."
 msgstr "68000 用のコードを生成する"
 
 #: config/m68k/m68k.opt:54
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68010"
 msgid "Generate code for a 68010."
 msgstr "68010 用のコードを生成する"
 
 #: config/m68k/m68k.opt:58 config/m68k/m68k.opt:115
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68020"
 msgid "Generate code for a 68020."
 msgstr "68020 用のコードを生成する"
 
 #: config/m68k/m68k.opt:62
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68040, without any new instructions"
 msgid "Generate code for a 68040, without any new instructions."
 msgstr "新命令無しの 68040 用コードを生成する"
 
 #: config/m68k/m68k.opt:66
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68060, without any new instructions"
 msgid "Generate code for a 68060, without any new instructions."
 msgstr "新命令無しの 68060 用コードを生成する"
 
 #: config/m68k/m68k.opt:70
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68030"
 msgid "Generate code for a 68030."
 msgstr "68030 用コードを生成する"
 
 #: config/m68k/m68k.opt:74
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68040"
 msgid "Generate code for a 68040."
 msgstr "68040 用コードを生成する"
 
 #: config/m68k/m68k.opt:78
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68060"
 msgid "Generate code for a 68060."
 msgstr "68060 用コードを生成する"
 
 #: config/m68k/m68k.opt:82
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68302"
 msgid "Generate code for a 68302."
 msgstr "68302 用コードを生成する"
 
 #: config/m68k/m68k.opt:86
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68332"
 msgid "Generate code for a 68332."
 msgstr "68332 用コードを生成する"
 
 #: config/m68k/m68k.opt:91
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 68851"
 msgid "Generate code for a 68851."
 msgstr "68851 用のコードを生成する"
 
 #: config/m68k/m68k.opt:95
 #, fuzzy, no-c-format
-#| msgid "Generate code that uses 68881 floating-point instructions"
 msgid "Generate code that uses 68881 floating-point instructions."
 msgstr "68881 浮動小数点命令を使用したコードを生成する"
 
 #: config/m68k/m68k.opt:99
 #, fuzzy, no-c-format
-#| msgid "Align variables on a 32-bit boundary"
 msgid "Align variables on a 32-bit boundary."
 msgstr "変数を 32 ビット境界に整列する"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
 #: config/nds32/nds32.opt:171 config/c6x/c6x.opt:67
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
 msgstr "ターゲットアーキテクチャの名前を指定する"
 
 #: config/m68k/m68k.opt:107
 #, fuzzy, no-c-format
-#| msgid "Use the bit-field instructions"
 msgid "Use the bit-field instructions."
 msgstr "ビットフィールド命令を使用する"
 
 #: config/m68k/m68k.opt:119
 #, fuzzy, no-c-format
-#| msgid "Generate code for a ColdFire v4e"
 msgid "Generate code for a ColdFire v4e."
 msgstr "ColdFire v4e 用の命令を生成する"
 
 #: config/m68k/m68k.opt:123
 #, fuzzy, no-c-format
-#| msgid "Specify the target CPU"
 msgid "Specify the target CPU."
 msgstr "ターゲット CPU を指定する"
 
 #: config/m68k/m68k.opt:127
 #, fuzzy, no-c-format
-#| msgid "Generate code for a cpu32"
 msgid "Generate code for a cpu32."
 msgstr "cpu32 用のコードを生成する"
 
 #: config/m68k/m68k.opt:131
 #, fuzzy, no-c-format
-#| msgid "Use hardware division instructions on ColdFire"
 msgid "Use hardware division instructions on ColdFire."
 msgstr "ColdFire のハードウェア除算命令を使用する"
 
 #: config/m68k/m68k.opt:135
 #, fuzzy, no-c-format
-#| msgid "Generate code for a Fido A"
 msgid "Generate code for a Fido A."
 msgstr "Fido A 用のコードを生成する"
 
 #: config/m68k/m68k.opt:139
 #, fuzzy, no-c-format
-#| msgid "Generate code which uses hardware floating point instructions"
 msgid "Generate code which uses hardware floating point instructions."
 msgstr "ハードウェア浮動小数点命令を使用するコードを生成する"
 
 #: config/m68k/m68k.opt:143
 #, fuzzy, no-c-format
-#| msgid "Enable ID based shared library"
 msgid "Enable ID based shared library."
 msgstr "ID に基づく共有ライブラリを有効にする"
 
@@ -9715,73 +8954,61 @@ msgstr ""
 
 #: config/m68k/m68k.opt:151
 #, fuzzy, no-c-format
-#| msgid "Do not use the bit-field instructions"
 msgid "Do not use the bit-field instructions."
 msgstr "ビットフィールド命令を使用しない"
 
 #: config/m68k/m68k.opt:155
 #, fuzzy, no-c-format
-#| msgid "Use normal calling convention"
 msgid "Use normal calling convention."
 msgstr "通常の呼び出し規約を使用する"
 
 #: config/m68k/m68k.opt:159
 #, fuzzy, no-c-format
-#| msgid "Consider type 'int' to be 32 bits wide"
 msgid "Consider type 'int' to be 32 bits wide."
 msgstr "'int' 型を 32 ビット幅とする"
 
 #: config/m68k/m68k.opt:163
 #, fuzzy, no-c-format
-#| msgid "Generate pc-relative code"
 msgid "Generate pc-relative code."
 msgstr "pc 関連コードを生成する"
 
 #: config/m68k/m68k.opt:167
 #, fuzzy, no-c-format
-#| msgid "Use different calling convention using 'rtd'"
 msgid "Use different calling convention using 'rtd'."
 msgstr "'rtd' を使用する異なる呼び出し規約を使用する"
 
 #: config/m68k/m68k.opt:179
 #, fuzzy, no-c-format
-#| msgid "Consider type 'int' to be 16 bits wide"
 msgid "Consider type 'int' to be 16 bits wide."
 msgstr "'int' 型を 16 ビット幅とする"
 
 #: config/m68k/m68k.opt:183
 #, fuzzy, no-c-format
-#| msgid "Generate code with library calls for floating point"
 msgid "Generate code with library calls for floating point."
 msgstr "浮動小数点用にライブラリ呼び出しを伴うコードを生成する"
 
 #: config/m68k/m68k.opt:187
 #, fuzzy, no-c-format
-#| msgid "Do not use unaligned memory references"
 msgid "Do not use unaligned memory references."
 msgstr "整列されていないメモリ参照を使用しない"
 
 #: config/m68k/m68k.opt:191
 #, fuzzy, no-c-format
-#| msgid "Tune for the specified target CPU or architecture"
 msgid "Tune for the specified target CPU or architecture."
 msgstr "指定されたターゲット CPU またはアーキテクチャ用に調整する"
 
 #: config/m68k/m68k.opt:195
 #, fuzzy, no-c-format
-#| msgid "Support more than 8192 GOT entries on ColdFire"
 msgid "Support more than 8192 GOT entries on ColdFire."
 msgstr "ColdFire 上で 8192 個を超える GOT エントリをサポートする"
 
 #: config/m68k/m68k.opt:199
 #, fuzzy, no-c-format
-#| msgid "Support TLS segment larger than 64K"
 msgid "Support TLS segment larger than 64K."
 msgstr "64K より大きな TLS セグメントをサポートする"
 
 #: config/riscv/riscv.opt:26
 #, fuzzy, no-c-format
-#| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
 msgstr "-mbranch-cost=COST\t分岐コストを大体 COST 命令分に設定する"
 
@@ -9792,13 +9019,11 @@ msgstr ""
 
 #: config/riscv/riscv.opt:34
 #, fuzzy, no-c-format
-#| msgid "Specify the __fp16 floating-point format"
 msgid "Specify integer and floating-point calling convention."
 msgstr "__fp16 浮動小数点形式を指定する"
 
 #: config/riscv/riscv.opt:38 config/i386/i386.opt:411
 #, fuzzy, no-c-format
-#| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
 msgstr "できるだけスタックをこの二の累乗に整列する"
 
@@ -9809,13 +9034,11 @@ msgstr ""
 
 #: config/riscv/riscv.opt:67
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point square root instruction"
 msgid "Use hardware floating-point divide and square root instructions."
 msgstr "ハードウェア浮動小数点二乗根命令を使用する"
 
 #: config/riscv/riscv.opt:71
 #, fuzzy, no-c-format
-#| msgid "Use hardware division instructions on ColdFire"
 msgid "Use hardware instructions for integer division."
 msgstr "ColdFire のハードウェア除算命令を使用する"
 
@@ -9826,7 +9049,6 @@ msgstr ""
 
 #: config/riscv/riscv.opt:80 config/mips/mips.opt:405
 #, fuzzy, no-c-format
-#| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR"
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
 msgstr "-mtune=PROCESSOR\tPROCESSOR 用に出力を最適化する"
 
@@ -9837,19 +9059,16 @@ msgstr ""
 
 #: config/riscv/riscv.opt:88
 #, fuzzy, no-c-format
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
 #: config/riscv/riscv.opt:92 config/aarch64/aarch64.opt:88
 #, fuzzy, no-c-format
-#| msgid "Select code model"
 msgid "Specify the code model."
 msgstr "コードモデルを選択する"
 
 #: config/riscv/riscv.opt:96
 #, fuzzy, no-c-format
-#| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
 msgstr "整列されていないメモリ参照を使用しない"
 
@@ -9877,7 +9096,6 @@ msgstr ""
 
 #: config/riscv/riscv.opt:137 config/i386/i386.opt:236
 #, fuzzy, no-c-format
-#| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
 msgstr "書き込み可能データ整列を調整しない"
 
@@ -9888,37 +9106,31 @@ msgstr ""
 
 #: config/m32c/m32c.opt:23
 #, fuzzy, no-c-format
-#| msgid "-msim\tUse simulator runtime"
 msgid "-msim\tUse simulator runtime."
 msgstr "-msim\tシミュレータランタイムを使用する"
 
 #: config/m32c/m32c.opt:27
 #, fuzzy, no-c-format
-#| msgid "-mcpu=r8c\tCompile code for R8C variants"
 msgid "-mcpu=r8c\tCompile code for R8C variants."
 msgstr "-mcpu=r8c\tR8C 類型用にコードをコンパイルする"
 
 #: config/m32c/m32c.opt:31
 #, fuzzy, no-c-format
-#| msgid "-mcpu=m16c\tCompile code for M16C variants"
 msgid "-mcpu=m16c\tCompile code for M16C variants."
 msgstr "-mcpu=m16c\tM16C 類型用にコードをコンパイルする"
 
 #: config/m32c/m32c.opt:35
 #, fuzzy, no-c-format
-#| msgid "-mcpu=m32cm\tCompile code for M32CM variants"
 msgid "-mcpu=m32cm\tCompile code for M32CM variants."
 msgstr "-mcpu=m32cm\tM32CM 類型用にコードをコンパイルする"
 
 #: config/m32c/m32c.opt:39
 #, fuzzy, no-c-format
-#| msgid "-mcpu=m32c\tCompile code for M32C variants"
 msgid "-mcpu=m32c\tCompile code for M32C variants."
 msgstr "-mcpu=m32c\tM32C 類型用にコードをコンパイルする"
 
 #: config/m32c/m32c.opt:43
 #, fuzzy, no-c-format
-#| msgid "-memregs=\tNumber of memreg bytes (default: 16, range: 0..16)"
 msgid "-memregs=\tNumber of memreg bytes (default: 16, range: 0..16)."
 msgstr "-memregs=\tmemreg のバイト数 (デフォルト: 16、範囲: 0..16)"
 
@@ -10020,13 +9232,11 @@ msgstr ""
 #: config/aarch64/aarch64.opt:68 config/arm/arm.opt:99
 #: config/microblaze/microblaze.opt:60
 #, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as big endian"
 msgid "Assume target CPU is configured as big endian."
 msgstr "ターゲット CPU がビックエンディアンとして設定されているとみなす"
 
 #: config/aarch64/aarch64.opt:72 config/i386/i386.opt:1016
 #, fuzzy, no-c-format
-#| msgid "Generate code which uses hardware floating point instructions"
 msgid "Generate code which uses only the general registers."
 msgstr "ハードウェア浮動小数点命令を使用するコードを生成する"
 
@@ -10043,7 +9253,6 @@ msgstr ""
 #: config/aarch64/aarch64.opt:84 config/arm/arm.opt:164
 #: config/microblaze/microblaze.opt:64
 #, fuzzy, no-c-format
-#| msgid "Assume target CPU is configured as little endian"
 msgid "Assume target CPU is configured as little endian."
 msgstr "ターゲット CPU がリトルエンディアンとして設定されているとみなす"
 
@@ -10054,7 +9263,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.opt:96 config/i386/i386.opt:395
 #, fuzzy, no-c-format
-#| msgid "Omit the frame pointer in leaf functions"
 msgid "Omit the frame pointer in leaf functions."
 msgstr "末端の関数ではフレームポインタを省略する"
 
@@ -10065,31 +9273,26 @@ msgstr ""
 
 #: config/aarch64/aarch64.opt:104
 #, fuzzy, no-c-format
-#| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specifies bit size of immediate TLS offsets.  Valid values are 12, 24, 32, 48."
 msgstr "即値 TLS オフセットのビットサイズを指定する"
 
 #: config/aarch64/aarch64.opt:123
 #, fuzzy, no-c-format
-#| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "Use features of architecture ARCH."
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
 #: config/aarch64/aarch64.opt:127
 #, fuzzy, no-c-format
-#| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "Use features of and optimize for CPU."
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
 #: config/aarch64/aarch64.opt:131
 #, fuzzy, no-c-format
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize for CPU."
 msgstr "速度よりもサイズを重視した最適化を行う"
 
 #: config/aarch64/aarch64.opt:135
 #, fuzzy, no-c-format
-#| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "Generate code that conforms to the specified ABI."
 msgstr "-mabi=ABI\t与えられた ABI に準拠したコードを生成する"
 
@@ -10166,7 +9369,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.opt:235 config/rs6000/rs6000.opt:543
 #, fuzzy, no-c-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -10182,7 +9384,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.opt:260
 #, fuzzy, no-c-format
-#| msgid "Generate a call to abort if a noreturn function returns"
 msgid "Generate local calls to out-of-line atomic operations."
 msgstr "noreturn 関数が return するとき abort の呼び出しを生成する"
 
@@ -10203,176 +9404,147 @@ msgstr ""
 
 #: config/linux.opt:24
 #, fuzzy, no-c-format
-#| msgid "Use Bionic C library"
 msgid "Use Bionic C library."
 msgstr "Bionic C ライブラリを使用する"
 
 #: config/linux.opt:28
 #, fuzzy, no-c-format
-#| msgid "Use GNU C library"
 msgid "Use GNU C library."
 msgstr "GNU C ライブラリを使用する"
 
 #: config/linux.opt:32
 #, fuzzy, no-c-format
-#| msgid "Use uClibc C library"
 msgid "Use uClibc C library."
 msgstr "uClibc C ライブラリを使用する"
 
 #: config/linux.opt:36
 #, fuzzy, no-c-format
-#| msgid "Use uClibc C library"
 msgid "Use musl C library."
 msgstr "uClibc C ライブラリを使用する"
 
 #: config/ia64/ilp32.opt:3
 #, fuzzy, no-c-format
-#| msgid "Generate ILP32 code"
 msgid "Generate ILP32 code."
 msgstr "ILP32 コードを生成する"
 
 #: config/ia64/ilp32.opt:7
 #, fuzzy, no-c-format
-#| msgid "Generate LP64 code"
 msgid "Generate LP64 code."
 msgstr "LP64 コードを生成する"
 
 #: config/ia64/ia64.opt:28
 #, fuzzy, no-c-format
-#| msgid "Generate big endian code"
 msgid "Generate big endian code."
 msgstr "ビッグエンディアンコードを生成する"
 
 #: config/ia64/ia64.opt:32
 #, fuzzy, no-c-format
-#| msgid "Generate little endian code"
 msgid "Generate little endian code."
 msgstr "リトルエンディアンコードを生成する"
 
 #: config/ia64/ia64.opt:36
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU as"
 msgid "Generate code for GNU as."
 msgstr "GNU as 用のコードを生成する"
 
 #: config/ia64/ia64.opt:40
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU ld"
 msgid "Generate code for GNU ld."
 msgstr "GNU ld 用のコードを生成する"
 
 #: config/ia64/ia64.opt:44
 #, fuzzy, no-c-format
-#| msgid "Emit stop bits before and after volatile extended asms"
 msgid "Emit stop bits before and after volatile extended asms."
 msgstr "拡張アセンブリ volatile の前後に stop ビットを送出する"
 
 #: config/ia64/ia64.opt:48
 #, fuzzy, no-c-format
-#| msgid "Use in/loc/out register names"
 msgid "Use in/loc/out register names."
 msgstr "in/loc/out レジスタ名を使用する"
 
 #: config/ia64/ia64.opt:55
 #, fuzzy, no-c-format
-#| msgid "Enable use of sdata/scommon/sbss"
 msgid "Enable use of sdata/scommon/sbss."
 msgstr "sdata/scommon/sbss の使用を有効にする"
 
 #: config/ia64/ia64.opt:59
 #, fuzzy, no-c-format
-#| msgid "Generate code without GP reg"
 msgid "Generate code without GP reg."
 msgstr "GP レジスタ不使用のコードを生成する"
 
 #: config/ia64/ia64.opt:63
 #, fuzzy, no-c-format
-#| msgid "gp is constant (but save/restore gp on indirect calls)"
 msgid "gp is constant (but save/restore gp on indirect calls)."
 msgstr "gp を定数とする（ただし、間接呼び出しでは gp を save/restore する）"
 
 #: config/ia64/ia64.opt:67
 #, fuzzy, no-c-format
-#| msgid "Generate self-relocatable code"
 msgid "Generate self-relocatable code."
 msgstr "自己再配置可能コードを生成する"
 
 #: config/ia64/ia64.opt:71
 #, fuzzy, no-c-format
-#| msgid "Generate inline floating point division, optimize for latency"
 msgid "Generate inline floating point division, optimize for latency."
 msgstr "インラインの浮動小数点除算を生成し、レイテンシを最適化する"
 
 #: config/ia64/ia64.opt:75
 #, fuzzy, no-c-format
-#| msgid "Generate inline floating point division, optimize for throughput"
 msgid "Generate inline floating point division, optimize for throughput."
 msgstr "インラインの浮動小数点除算を生成し、スループットを最適化する"
 
 #: config/ia64/ia64.opt:82
 #, fuzzy, no-c-format
-#| msgid "Generate inline integer division, optimize for latency"
 msgid "Generate inline integer division, optimize for latency."
 msgstr "インラインの整数除算を生成し、レイテンシを最適化する"
 
 #: config/ia64/ia64.opt:86
 #, fuzzy, no-c-format
-#| msgid "Generate inline integer division, optimize for throughput"
 msgid "Generate inline integer division, optimize for throughput."
 msgstr "インラインの整数除算を生成し、スループットを最適化する"
 
 #: config/ia64/ia64.opt:90
 #, fuzzy, no-c-format
-#| msgid "Do not inline integer division"
 msgid "Do not inline integer division."
 msgstr "整数除算をインライン化しない"
 
 #: config/ia64/ia64.opt:94
 #, fuzzy, no-c-format
-#| msgid "Generate inline square root, optimize for latency"
 msgid "Generate inline square root, optimize for latency."
 msgstr "インライン二乗根を生成し、レイテンシを最適化する"
 
 #: config/ia64/ia64.opt:98
 #, fuzzy, no-c-format
-#| msgid "Generate inline square root, optimize for throughput"
 msgid "Generate inline square root, optimize for throughput."
 msgstr "インライン二乗根を生成し、スループットを最適化する"
 
 #: config/ia64/ia64.opt:102
 #, fuzzy, no-c-format
-#| msgid "Do not inline square root"
 msgid "Do not inline square root."
 msgstr "二乗根をインライン化しない"
 
 #: config/ia64/ia64.opt:106
 #, fuzzy, no-c-format
-#| msgid "Enable Dwarf 2 line debug info via GNU as"
 msgid "Enable DWARF line debug info via GNU as."
 msgstr "GNU as を通じた Dwarf2 の行デバッグを有効にする"
 
 #: config/ia64/ia64.opt:110
 #, fuzzy, no-c-format
-#| msgid "Enable earlier placing stop bits for better scheduling"
 msgid "Enable earlier placing stop bits for better scheduling."
 msgstr "より良いスケジューリング用に事前にストップビットを配置する"
 
 #: config/ia64/ia64.opt:114 config/pa/pa.opt:66 config/sh/sh.opt:227
 #, fuzzy, no-c-format
-#| msgid "Specify range of registers to make fixed"
 msgid "Specify range of registers to make fixed."
 msgstr "固定するレジスタの範囲を指定する"
 
 #: config/ia64/ia64.opt:118 config/alpha/alpha.opt:130
 #, fuzzy, no-c-format
-#| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
 msgstr "即値 TLS オフセットのビットサイズを指定する"
 
 #: config/ia64/ia64.opt:122 config/i386/i386.opt:509 config/s390/s390.opt:197
 #: config/sparc/sparc.opt:146 config/visium/visium.opt:49
 #, fuzzy, no-c-format
-#| msgid "Schedule code for given CPU"
 msgid "Schedule code for given CPU."
 msgstr "与えられた CPU 用のコードをスケジュールする"
 
@@ -10383,49 +9555,41 @@ msgstr ""
 
 #: config/ia64/ia64.opt:136
 #, fuzzy, no-c-format
-#| msgid "Use data speculation before reload"
 msgid "Use data speculation before reload."
 msgstr "reload 前にデータ投機を使用する"
 
 #: config/ia64/ia64.opt:140
 #, fuzzy, no-c-format
-#| msgid "Use data speculation after reload"
 msgid "Use data speculation after reload."
 msgstr "reload 後にデータ投機を使用する"
 
 #: config/ia64/ia64.opt:144
 #, fuzzy, no-c-format
-#| msgid "Use control speculation"
 msgid "Use control speculation."
 msgstr "制御投機を使用する"
 
 #: config/ia64/ia64.opt:148
 #, fuzzy, no-c-format
-#| msgid "Use in block data speculation before reload"
 msgid "Use in block data speculation before reload."
 msgstr "reload 前にブロック内データ投機を使用する"
 
 #: config/ia64/ia64.opt:152
 #, fuzzy, no-c-format
-#| msgid "Use in block data speculation after reload"
 msgid "Use in block data speculation after reload."
 msgstr "reload 後にブロック内データ投機を使用する"
 
 #: config/ia64/ia64.opt:156
 #, fuzzy, no-c-format
-#| msgid "Use in block control speculation"
 msgid "Use in block control speculation."
 msgstr "ブロック内制御投機を使用する"
 
 #: config/ia64/ia64.opt:160
 #, fuzzy, no-c-format
-#| msgid "Use simple data speculation check"
 msgid "Use simple data speculation check."
 msgstr "単純データ投機検査を使用する"
 
 #: config/ia64/ia64.opt:164
 #, fuzzy, no-c-format
-#| msgid "Use simple data speculation check for control speculation"
 msgid "Use simple data speculation check for control speculation."
 msgstr "制御投機用の単純データ投機検査を使用する"
 
@@ -10436,7 +9600,6 @@ msgstr ""
 
 #: config/ia64/ia64.opt:178
 #, fuzzy, no-c-format
-#| msgid "Place a stop bit after every cycle when scheduling"
 msgid "Place a stop bit after every cycle when scheduling."
 msgstr "スケジューリング時の各サイクル後にストップビットを配置する"
 
@@ -10457,7 +9620,6 @@ msgstr ""
 
 #: config/ia64/ia64.opt:194
 #, fuzzy, no-c-format
-#| msgid "Don't generate checks for control speculation in selective scheduling"
 msgid "Don't generate checks for control speculation in selective scheduling."
 msgstr "選択的スケジューリング内では制御投機用の検査を生成しない"
 
@@ -10473,25 +9635,21 @@ msgstr ""
 
 #: config/epiphany/epiphany.opt:32
 #, fuzzy, no-c-format
-#| msgid "Relax branches"
 msgid "Set branch cost."
 msgstr "分岐を緩和する"
 
 #: config/epiphany/epiphany.opt:36
 #, fuzzy, no-c-format
-#| msgid "Enable all optional instructions"
 msgid "Enable conditional move instruction usage."
 msgstr "すべてのオプションの命令を有効にする"
 
 #: config/epiphany/epiphany.opt:40
 #, fuzzy, no-c-format
-#| msgid "The number of insns executed before prefetch is completed"
 msgid "Set number of nops to emit before each insn pattern."
 msgstr "プリフェッチが完了する前に実行される命令数"
 
 #: config/epiphany/epiphany.opt:52
 #, fuzzy, no-c-format
-#| msgid "Use software floating point"
 msgid "Use software floating point comparisons."
 msgstr "ソフトウェア浮動小数点を使用する"
 
@@ -10522,13 +9680,11 @@ msgstr ""
 
 #: config/epiphany/epiphany.opt:76
 #, fuzzy, no-c-format
-#| msgid "Generate call insns as indirect calls, if necessary"
 msgid "Generate call insns as indirect calls."
 msgstr "必要があれば、命令呼び出しを間接呼び出しとして生成する"
 
 #: config/epiphany/epiphany.opt:80
 #, fuzzy, no-c-format
-#| msgid "Generate call insns as indirect calls, if necessary"
 msgid "Generate call insns as direct calls."
 msgstr "必要があれば、命令呼び出しを間接呼び出しとして生成する"
 
@@ -10544,7 +9700,6 @@ msgstr ""
 
 #: config/epiphany/epiphany.opt:112
 #, fuzzy, no-c-format
-#| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Vectorize for double-word operations."
 msgstr "二倍ワードコピー用の強く整列された構造体を使用する"
 
@@ -10555,7 +9710,6 @@ msgstr ""
 
 #: config/epiphany/epiphany.opt:132
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point conversion instructions"
 msgid "Use the floating point unit for integer add/subtract."
 msgstr "ハードウェア浮動小数点変換命令を使用する"
 
@@ -10566,32 +9720,27 @@ msgstr ""
 
 #: config/ft32/ft32.opt:23
 #, fuzzy, no-c-format
-#| msgid "Target the AM33 processor"
 msgid "Target the software simulator."
 msgstr "AM33 プロセッサをターゲットとする"
 
 #: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:393
 #: config/arc/arc.opt:406
 #, fuzzy, no-c-format
-#| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
 msgstr "RAM の代わりに ROM を使用する"
 
 #: config/ft32/ft32.opt:31
 #, fuzzy, no-c-format
-#| msgid "Allow the use of MDMX instructions"
 msgid "Avoid use of the DIV and MOD instructions."
 msgstr "MDMX 命令の使用を許可する"
 
 #: config/ft32/ft32.opt:35
 #, fuzzy, no-c-format
-#| msgid "Target the AM33 processor"
 msgid "Target the FT32B architecture."
 msgstr "AM33 プロセッサをターゲットとする"
 
 #: config/ft32/ft32.opt:39
 #, fuzzy, no-c-format
-#| msgid "Enable function profiling"
 msgid "Enable FT32B code compression."
 msgstr "関数プロファイルを有効にする"
 
@@ -10602,61 +9751,51 @@ msgstr ""
 
 #: config/h8300/h8300.opt:23
 #, fuzzy, no-c-format
-#| msgid "Generate H8S code"
 msgid "Generate H8S code."
 msgstr "H8S コードを生成する"
 
 #: config/h8300/h8300.opt:27
 #, fuzzy, no-c-format
-#| msgid "Generate H8SX code"
 msgid "Generate H8SX code."
 msgstr "H8SX コードを生成する"
 
 #: config/h8300/h8300.opt:31
 #, fuzzy, no-c-format
-#| msgid "Generate H8S/2600 code"
 msgid "Generate H8S/2600 code."
 msgstr "H8S/2600 コードを生成する"
 
 #: config/h8300/h8300.opt:35
 #, fuzzy, no-c-format
-#| msgid "Make integers 32 bits wide"
 msgid "Make integers 32 bits wide."
 msgstr "整数を 32 ビット幅とする"
 
 #: config/h8300/h8300.opt:42
 #, fuzzy, no-c-format
-#| msgid "Use registers for argument passing"
 msgid "Use registers for argument passing."
 msgstr "引数をレジスタ渡しにする"
 
 #: config/h8300/h8300.opt:46
 #, fuzzy, no-c-format
-#| msgid "Consider access to byte sized memory slow"
 msgid "Consider access to byte sized memory slow."
 msgstr "バイトサイズ単位のメモリアクセスが遅いことを考慮する"
 
 #: config/h8300/h8300.opt:50
 #, fuzzy, no-c-format
-#| msgid "Enable linker relaxing"
 msgid "Enable linker relaxing."
 msgstr "リンカの緩和を有効にする"
 
 #: config/h8300/h8300.opt:54
 #, fuzzy, no-c-format
-#| msgid "Generate H8/300H code"
 msgid "Generate H8/300H code."
 msgstr "H8/300H コードを生成する"
 
 #: config/h8300/h8300.opt:58
 #, fuzzy, no-c-format
-#| msgid "Enable the normal mode"
 msgid "Enable the normal mode."
 msgstr "通常モードを有効にする"
 
 #: config/h8300/h8300.opt:62
 #, fuzzy, no-c-format
-#| msgid "Use H8/300 alignment rules"
 msgid "Use H8/300 alignment rules."
 msgstr "H8/300 整列規則を使用する"
 
@@ -10682,116 +9821,97 @@ msgstr ""
 
 #: config/pru/pru.opt:40
 #, fuzzy, no-c-format
-#| msgid "Allow gcc to generate LIW instructions"
 msgid "Allow (or do not allow) gcc to use the LOOP instruction."
 msgstr "gcc が LIW 命令を生成することを許可する"
 
 #: config/pru/pru.opt:44
 #, fuzzy, no-c-format
-#| msgid "Set the target VM version"
 msgid "Select target ABI variant."
 msgstr "ターゲット VM バージョンを設定する"
 
 #: config/pru/pru.opt:48
 #, fuzzy, no-c-format
-#| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgid "ABI variant code generation (for use with -mabi= option):"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
 #: config/pdp11/pdp11.opt:23
 #, fuzzy, no-c-format
-#| msgid "Generate code for an 11/10"
 msgid "Generate code for an 11/10."
 msgstr "11/10 用のコードを生成する"
 
 #: config/pdp11/pdp11.opt:27
 #, fuzzy, no-c-format
-#| msgid "Generate code for an 11/40"
 msgid "Generate code for an 11/40."
 msgstr "11/40 用のコードを生成する"
 
 #: config/pdp11/pdp11.opt:31
 #, fuzzy, no-c-format
-#| msgid "Generate code for an 11/45"
 msgid "Generate code for an 11/45."
 msgstr "11/45 用のコードを生成する"
 
 #: config/pdp11/pdp11.opt:35
 #, fuzzy, no-c-format
-#| msgid "Return floating-point results in ac0 (fr0 in Unix assembler syntax)"
 msgid "Return floating-point results in ac0 (fr0 in Unix assembler syntax)."
 msgstr "浮動小数点の結果を ac0 で返す (Unix アセンブラ構文では fr0)"
 
 #: config/pdp11/pdp11.opt:39
 #, fuzzy, no-c-format
-#| msgid "Use the DEC assembler syntax"
 msgid "Use the DEC assembler syntax."
 msgstr "DEC アセンブラ構文を使用する"
 
 #: config/pdp11/pdp11.opt:43
 #, fuzzy, no-c-format
-#| msgid "Use the DEC assembler syntax"
 msgid "Use the GNU assembler syntax."
 msgstr "DEC アセンブラ構文を使用する"
 
 #: config/pdp11/pdp11.opt:47 config/rs6000/rs6000.opt:191
 #: config/frv/frv.opt:158
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point"
 msgid "Use hardware floating point."
 msgstr "ハードウェア浮動小数点を利用する"
 
 #: config/pdp11/pdp11.opt:51
 #, fuzzy, no-c-format
-#| msgid "Use 16 bit int"
 msgid "Use 16 bit int."
 msgstr "16 ビット整数を使用する"
 
 #: config/pdp11/pdp11.opt:55
 #, fuzzy, no-c-format
-#| msgid "Use 32 bit int"
 msgid "Use 32 bit int."
 msgstr "32 ビット整数を使用する"
 
 #: config/pdp11/pdp11.opt:59 config/rs6000/rs6000.opt:187
 #, fuzzy, no-c-format
-#| msgid "Do not use hardware floating point"
 msgid "Do not use hardware floating point."
 msgstr "ハードウェア浮動小数点を使用しない"
 
 #: config/pdp11/pdp11.opt:63
 #, fuzzy, no-c-format
-#| msgid "Target has split I&D"
 msgid "Target has split I&D."
 msgstr "ターゲットは split 命令とデータメモリを持つ"
 
 #: config/pdp11/pdp11.opt:67
 #, fuzzy, no-c-format
-#| msgid "Use UNIX assembler syntax"
 msgid "Use UNIX assembler syntax."
 msgstr "UNIX アセンブラ構文を使用する"
 
 #: config/pdp11/pdp11.opt:71
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Use LRA register allocator."
 msgstr "短い load 命令の使用を有効にする"
 
 #: config/xtensa/xtensa.opt:23
 #, fuzzy, no-c-format
-#| msgid "Use CONST16 instruction to load constants"
 msgid "Use CONST16 instruction to load constants."
 msgstr "定数をロードするために CONST16 命令を使用する"
 
 #: config/xtensa/xtensa.opt:27
 #, fuzzy, no-c-format
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
 msgid "Disable position-independent code (PIC) for use in OS kernel code."
 msgstr "OS カーネルコード内で使用するために位置非依存コード (PIC) を無効にする"
 
 #: config/xtensa/xtensa.opt:31
 #, fuzzy, no-c-format
-#| msgid "Use indirect CALLXn instructions for large programs"
 msgid "Use indirect CALLXn instructions for large programs."
 msgstr "大きなプログラム用に間接 CALLXn 命令を使用する"
 
@@ -10817,37 +9937,31 @@ msgstr ""
 
 #: config/i386/cygming.opt:23
 #, fuzzy, no-c-format
-#| msgid "Create console application"
 msgid "Create console application."
 msgstr "コンソールアプリケーションを作成する"
 
 #: config/i386/cygming.opt:27
 #, fuzzy, no-c-format
-#| msgid "Generate code for a DLL"
 msgid "Generate code for a DLL."
 msgstr "DLL 用のコードを生成する"
 
 #: config/i386/cygming.opt:31
 #, fuzzy, no-c-format
-#| msgid "Ignore dllimport for functions"
 msgid "Ignore dllimport for functions."
 msgstr "関数への dllimport を無視する"
 
 #: config/i386/cygming.opt:35
 #, fuzzy, no-c-format
-#| msgid "Use Mingw-specific thread support"
 msgid "Use Mingw-specific thread support."
 msgstr "Mingw 固有のスレッドサポートを使用する"
 
 #: config/i386/cygming.opt:39
 #, fuzzy, no-c-format
-#| msgid "Set Windows defines"
 msgid "Set Windows defines."
 msgstr "Windows の define を設定する"
 
 #: config/i386/cygming.opt:43
 #, fuzzy, no-c-format
-#| msgid "Create GUI application"
 msgid "Create GUI application."
 msgstr "GUI アプリケーションを作成する"
 
@@ -10873,7 +9987,6 @@ msgstr ""
 
 #: config/i386/mingw.opt:29
 #, fuzzy, no-c-format
-#| msgid "Warn about none ISO msvcrt scanf/printf width extensions"
 msgid "Warn about none ISO msvcrt scanf/printf width extensions."
 msgstr "非 ISO の msvcrt scanf/printf の幅拡張に関して警告する"
 
@@ -10884,87 +9997,73 @@ msgstr ""
 
 #: config/i386/i386.opt:188
 #, fuzzy, no-c-format
-#| msgid "sizeof(long double) is 16"
 msgid "sizeof(long double) is 16."
 msgstr "sizeof(long double) を 16 とする"
 
 #: config/i386/i386.opt:192 config/i386/i386.opt:360
 #, fuzzy, no-c-format
-#| msgid "Use hardware fp"
 msgid "Use hardware fp."
 msgstr "ハードウェア浮動小数点を使用する"
 
 #: config/i386/i386.opt:196
 #, fuzzy, no-c-format
-#| msgid "sizeof(long double) is 12"
 msgid "sizeof(long double) is 12."
 msgstr "sizeof(long double) を 12 とする"
 
 #: config/i386/i386.opt:200
 #, fuzzy, no-c-format
-#| msgid "Use 128-bit long double"
 msgid "Use 80-bit long double."
 msgstr "128 ビット long double を使用する"
 
 #: config/i386/i386.opt:204 config/s390/s390.opt:157
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy, no-c-format
-#| msgid "Use 64-bit long double"
 msgid "Use 64-bit long double."
 msgstr "64 ビット long double を使用する"
 
 #: config/i386/i386.opt:208 config/s390/s390.opt:153
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy, no-c-format
-#| msgid "Use 128-bit long double"
 msgid "Use 128-bit long double."
 msgstr "128 ビット long double を使用する"
 
 #: config/i386/i386.opt:212 config/sh/sh.opt:179
 #, fuzzy, no-c-format
-#| msgid "Generate cld instruction in the function prologue."
 msgid "Reserve space for outgoing arguments in the function prologue."
 msgstr "関数プロローグ内で cld 命令を生成する"
 
 #: config/i386/i386.opt:216
 #, fuzzy, no-c-format
-#| msgid "Align some doubles on dword boundary"
 msgid "Align some doubles on dword boundary."
 msgstr "double を dword 境界に整列する"
 
 #: config/i386/i386.opt:220
 #, fuzzy, no-c-format
-#| msgid "Function starts are aligned to this power of 2"
 msgid "Function starts are aligned to this power of 2."
 msgstr "関数の開始位置をこの二の累乗に整列する"
 
 #: config/i386/i386.opt:224
 #, fuzzy, no-c-format
-#| msgid "Jump targets are aligned to this power of 2"
 msgid "Jump targets are aligned to this power of 2."
 msgstr "ジャンプ先をこの二の累乗に整列する"
 
 #: config/i386/i386.opt:228
 #, fuzzy, no-c-format
-#| msgid "Loop code aligned to this power of 2"
 msgid "Loop code aligned to this power of 2."
 msgstr "ループコードをこの二の累乗に整列する"
 
 #: config/i386/i386.opt:232
 #, fuzzy, no-c-format
-#| msgid "Align destination of the string operations"
 msgid "Align destination of the string operations."
 msgstr "文字列操作の書込み先を整列する"
 
 #: config/i386/i386.opt:253 config/s390/s390.opt:56
 #, fuzzy, no-c-format
-#| msgid "Generate code for given CPU"
 msgid "Generate code for given CPU."
 msgstr "与えられたCPU 用のコードを生成する"
 
 #: config/i386/i386.opt:257
 #, fuzzy, no-c-format
-#| msgid "Use given assembler dialect"
 msgid "Use given assembler dialect."
 msgstr "与えられたアセンブラ形式を使用する"
 
@@ -10975,25 +10074,21 @@ msgstr ""
 
 #: config/i386/i386.opt:271
 #, fuzzy, no-c-format
-#| msgid "Branches are this expensive (1-5, arbitrary units)"
 msgid "Branches are this expensive (arbitrary units)."
 msgstr "分岐のコストを指定する (1-5, 任意の個数)"
 
 #: config/i386/i386.opt:275
 #, fuzzy, no-c-format
-#| msgid "Data greater than given threshold will go into .ldata section in x86-64 medium model"
 msgid "-mlarge-data-threshold=<number>\tData greater than given threshold will go into .ldata section in x86-64 medium model."
 msgstr "x86-64 メディアモデルでは与えられた閾値より大きいデータを .ldata セクションに配置する"
 
 #: config/i386/i386.opt:279
 #, fuzzy, no-c-format
-#| msgid "Use given x86-64 code model"
 msgid "Use given x86-64 code model."
 msgstr "与えられた x86-64 コードモデルを使用する"
 
 #: config/i386/i386.opt:302
 #, fuzzy, no-c-format
-#| msgid "Use given x86-64 code model"
 msgid "Use given address mode."
 msgstr "与えられた x86-64 コードモデルを使用する"
 
@@ -11004,37 +10099,31 @@ msgstr ""
 
 #: config/i386/i386.opt:319
 #, fuzzy, no-c-format
-#| msgid "Generate sin, cos, sqrt for FPU"
 msgid "Generate sin, cos, sqrt for FPU."
 msgstr "FPU 用の sin, cos, sqrt を生成する"
 
 #: config/i386/i386.opt:323
 #, fuzzy, no-c-format
-#| msgid "Always use Dynamic Realigned Argument Pointer (DRAP) to realign stack"
 msgid "Always use Dynamic Realigned Argument Pointer (DRAP) to realign stack."
 msgstr "スタックを再整列するために動的再整列引数ポインタ (Dynamic Realigned Argument Pointer, DRAP) を常に使用する"
 
 #: config/i386/i386.opt:327
 #, fuzzy, no-c-format
-#| msgid "Return values of functions in FPU registers"
 msgid "Return values of functions in FPU registers."
 msgstr "FPU レジスタ内の機能の値を返す"
 
 #: config/i386/i386.opt:331
 #, fuzzy, no-c-format
-#| msgid "Generate floating point mathematics using given instruction set"
 msgid "Generate floating point mathematics using given instruction set."
 msgstr "与えられた命令集合を使用して浮動小数数値計算を生成する"
 
 #: config/i386/i386.opt:335
 #, fuzzy, no-c-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mfpmath=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/i386/i386.opt:368
 #, fuzzy, no-c-format
-#| msgid "Inline all known string operations"
 msgid "Inline all known string operations."
 msgstr "既知の全ての文字列操作を inline にする"
 
@@ -11050,55 +10139,46 @@ msgstr ""
 
 #: config/i386/i386.opt:399
 #, fuzzy, no-c-format
-#| msgid "Set 80387 floating-point precision (-mpc32, -mpc64, -mpc80)"
 msgid "Set 80387 floating-point precision to 32-bit."
 msgstr "80387 浮動小数点精度を設定する (-mpc32, -mpc64, -mpc80)"
 
 #: config/i386/i386.opt:403
 #, fuzzy, no-c-format
-#| msgid "Set 80387 floating-point precision (-mpc32, -mpc64, -mpc80)"
 msgid "Set 80387 floating-point precision to 64-bit."
 msgstr "80387 浮動小数点精度を設定する (-mpc32, -mpc64, -mpc80)"
 
 #: config/i386/i386.opt:407
 #, fuzzy, no-c-format
-#| msgid "Set 80387 floating-point precision (-mpc32, -mpc64, -mpc80)"
 msgid "Set 80387 floating-point precision to 80-bit."
 msgstr "80387 浮動小数点精度を設定する (-mpc32, -mpc64, -mpc80)"
 
 #: config/i386/i386.opt:415
 #, fuzzy, no-c-format
-#| msgid "Assume incoming stack aligned to this power of 2"
 msgid "Assume incoming stack aligned to this power of 2."
 msgstr "入ってくるスタックがこの二の累乗に整列されていると見なす"
 
 #: config/i386/i386.opt:419
 #, fuzzy, no-c-format
-#| msgid "Use push instructions to save outgoing arguments"
 msgid "Use push instructions to save outgoing arguments."
 msgstr "出力する引数をセーブするため push 命令を使う"
 
 #: config/i386/i386.opt:423
 #, fuzzy, no-c-format
-#| msgid "Generate 64bit x86-64 code"
 msgid "Use red-zone in the x86-64 code."
 msgstr "64 ビット x86-64 コードを生成する"
 
 #: config/i386/i386.opt:427
 #, fuzzy, no-c-format
-#| msgid "Number of registers used to pass integer arguments"
 msgid "Number of registers used to pass integer arguments."
 msgstr "レジスタの数が整数を引数を渡すために使われる"
 
 #: config/i386/i386.opt:431
 #, fuzzy, no-c-format
-#| msgid "Alternate calling convention"
 msgid "Alternate calling convention."
 msgstr "呼び出し規約を入れ替える"
 
 #: config/i386/i386.opt:435 config/alpha/alpha.opt:23
 #, fuzzy, no-c-format
-#| msgid "Do not use hardware fp"
 msgid "Do not use hardware fp."
 msgstr "ハードウェア浮動小数点を利用しない"
 
@@ -11109,13 +10189,11 @@ msgstr ""
 
 #: config/i386/i386.opt:443
 #, fuzzy, no-c-format
-#| msgid "Realign stack in prologue"
 msgid "Realign stack in prologue."
 msgstr "prologue 内のスタックを再整列する"
 
 #: config/i386/i386.opt:447
 #, fuzzy, no-c-format
-#| msgid "Enable stack probing"
 msgid "Enable stack probing."
 msgstr "スタック探索を有効にする"
 
@@ -11136,13 +10214,11 @@ msgstr ""
 
 #: config/i386/i386.opt:463
 #, fuzzy, no-c-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mstringop-strategy=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/i386/i386.opt:491
 #, fuzzy, no-c-format
-#| msgid "Use given thread-local storage dialect"
 msgid "Use given thread-local storage dialect."
 msgstr "与えられたスレッド局所記憶域 (TLS) 形式を使用する"
 
@@ -11153,7 +10229,6 @@ msgstr ""
 
 #: config/i386/i386.opt:505
 #, fuzzy, no-c-format
-#| msgid "Use direct references against %gs when accessing tls data"
 msgid "Use direct references against %gs when accessing tls data."
 msgstr "TLS データにアクセスするときに %gs に対する直接参照を使用する"
 
@@ -11169,13 +10244,11 @@ msgstr ""
 
 #: config/i386/i386.opt:524
 #, fuzzy, no-c-format
-#| msgid "Generate code that conforms to the given ABI"
 msgid "Generate code that conforms to Intel MCU psABI."
 msgstr "与えられた ABI に準拠したコードを生成する"
 
 #: config/i386/i386.opt:528
 #, fuzzy, no-c-format
-#| msgid "Generate code that conforms to the given ABI"
 msgid "Generate code that conforms to the given ABI."
 msgstr "与えられた ABI に準拠したコードを生成する"
 
@@ -11191,19 +10264,16 @@ msgstr ""
 
 #: config/i386/i386.opt:546 config/rs6000/rs6000.opt:203
 #, fuzzy, no-c-format
-#| msgid "Vector library ABI to use"
 msgid "Vector library ABI to use."
 msgstr "与えられたベクトルライブラリ ABI を使用する"
 
 #: config/i386/i386.opt:550
 #, fuzzy, no-c-format
-#| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
 #: config/i386/i386.opt:560
 #, fuzzy, no-c-format
-#| msgid "Return 8-byte vectors in memory"
 msgid "Return 8-byte vectors in memory."
 msgstr "8 バイトベクトルをメモリに返す"
 
@@ -11244,235 +10314,196 @@ msgstr "自動ベクトル化で 256 ビット AVX 命令の代わりに 128 ビ
 
 #: config/i386/i386.opt:595
 #, fuzzy, no-c-format
-#| msgid "Use 128-bit AVX instructions instead of 256-bit AVX instructions in the auto-vectorizer."
 msgid "Use given register vector width instructions instead of maximum register width in the auto-vectorizer."
 msgstr "自動ベクトル化で 256 ビット AVX 命令の代わりに 128 ビット AVX 命令を使用する"
 
 #: config/i386/i386.opt:599
 #, fuzzy, no-c-format
-#| msgid "invalid __fp16 format option: -mfp16-format=%s"
 msgid "Known preferred register vector length (to use with the -mprefer-vector-width= option):"
 msgstr "無効な __fp16 書式オプションです: -mfp16-format=%s"
 
 #: config/i386/i386.opt:617
 #, fuzzy, no-c-format
-#| msgid "Generate 32bit i386 code"
 msgid "Generate 32bit i386 code."
 msgstr "32 ビット i386 コードを生成する"
 
 #: config/i386/i386.opt:621
 #, fuzzy, no-c-format
-#| msgid "Generate 64bit x86-64 code"
 msgid "Generate 64bit x86-64 code."
 msgstr "64 ビット x86-64 コードを生成する"
 
 #: config/i386/i386.opt:625
 #, fuzzy, no-c-format
-#| msgid "Generate 64bit x86-64 code"
 msgid "Generate 32bit x86-64 code."
 msgstr "64 ビット x86-64 コードを生成する"
 
 #: config/i386/i386.opt:629
 #, fuzzy, no-c-format
-#| msgid "Generate 32bit i386 code"
 msgid "Generate 16bit i386 code."
 msgstr "32 ビット i386 コードを生成する"
 
 #: config/i386/i386.opt:633
 #, fuzzy, no-c-format
-#| msgid "Support MMX built-in functions"
 msgid "Support MMX built-in functions."
 msgstr "MMX 組み込み関数をサポートする"
 
 #: config/i386/i386.opt:637
 #, fuzzy, no-c-format
-#| msgid "Support 3DNow! built-in functions"
 msgid "Support 3DNow! built-in functions."
 msgstr "3DNow! 組み込み関数をサポートする"
 
 #: config/i386/i386.opt:641
 #, fuzzy, no-c-format
-#| msgid "Support Athlon 3Dnow! built-in functions"
 msgid "Support Athlon 3Dnow! built-in functions."
 msgstr "Athlon 3Dnow! 組み込み関数をサポートする"
 
 #: config/i386/i386.opt:645
 #, fuzzy, no-c-format
-#| msgid "Support MMX and SSE built-in functions and code generation"
 msgid "Support MMX and SSE built-in functions and code generation."
 msgstr "MMX と SSE の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:649
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE and SSE2 built-in functions and code generation"
 msgid "Support MMX, SSE and SSE2 built-in functions and code generation."
 msgstr "MMX、SSE および SSE2 の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:653
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2 and SSE3 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2 and SSE3 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2 および SSE3 の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:657
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3 and SSSE3 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3 and SSSE3 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3 および SSSE3 の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:661
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3 and SSE4.1 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3 and SSE4.1 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3 および SSE4.1 の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:665 config/i386/i386.opt:669
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 and SSE4.2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 and SSE4.2 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1 および SSE4.2 の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:673
 #, fuzzy, no-c-format
-#| msgid "Do not support SSE4.1 and SSE4.2 built-in functions and code generation"
 msgid "Do not support SSE4.1 and SSE4.2 built-in functions and code generation."
 msgstr "SSE4.1 と SSE4.2 の組み込み関数とコード生成をサポートしない"
 
 #: config/i386/i386.opt:681
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 and AVX built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 and AVX built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2 および AVX の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:685
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:689
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:693
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512PF built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:697
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512ER built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:701
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512CD built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:705
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512DQ built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:709
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512BW built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:713
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VL built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:717
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:721
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:725
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124FMAPS built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:729
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124VNNIW built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:733
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VPOPCNTDQ built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:737
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VBMI2 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:741
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support AVX512VNNI built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:745
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BITALG built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:749
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support AVX512VP2INTERSECT built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:753
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:757
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3 and SSE4A built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3 and SSE4A built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3 および SSE4A の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:761
 #, fuzzy, no-c-format
-#| msgid "Support FMA4 built-in functions and code generation "
 msgid "Support FMA4 built-in functions and code generation."
 msgstr "FMA4 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:765
 #, fuzzy, no-c-format
-#| msgid "Support XOP built-in functions and code generation "
 msgid "Support XOP built-in functions and code generation."
 msgstr "XOP 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:769
 #, fuzzy, no-c-format
-#| msgid "Support LWP built-in functions and code generation "
 msgid "Support LWP built-in functions and code generation."
 msgstr "LWP 組み込み関数とコード生成をサポートする"
 
@@ -11488,67 +10519,56 @@ msgstr "popcnt 命令のコード生成をサポートする。"
 
 #: config/i386/i386.opt:781
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support PCONFIG built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:785
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support WBNOINVD built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:789
 #, fuzzy, no-c-format
-#| msgid "Support TBM built-in functions and code generation"
 msgid "Support PTWRITE built-in functions and code generation."
 msgstr "TBM 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:793
 #, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support SGX built-in functions and code generation."
 msgstr "AES 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:797
 #, fuzzy, no-c-format
-#| msgid "Support RDRND built-in functions and code generation"
 msgid "Support RDPID built-in functions and code generation."
 msgstr "RDRND 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:801
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support GFNI built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:805
 #, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support VAES built-in functions and code generation."
 msgstr "AES 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:809
 #, fuzzy, no-c-format
-#| msgid "Support PCLMUL built-in functions and code generation"
 msgid "Support VPCLMULQDQ built-in functions and code generation."
 msgstr "PCLMUL 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:813
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support BMI built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:817
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support BMI2 built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:821
 #, fuzzy, no-c-format
-#| msgid "Support TBM built-in functions and code generation"
 msgid "Support LZCNT built-in function and code generation."
 msgstr "TBM 組み込み関数とコード生成をサポートする"
 
@@ -11559,7 +10579,6 @@ msgstr ""
 
 #: config/i386/i386.opt:829
 #, fuzzy, no-c-format
-#| msgid "Use SmartMIPS instructions"
 msgid "Support RDSEED instruction."
 msgstr "SmartMIPS 命令を使用する"
 
@@ -11570,7 +10589,6 @@ msgstr ""
 
 #: config/i386/i386.opt:837
 #, fuzzy, no-c-format
-#| msgid "Support code generation of crc32 instruction."
 msgid "Support flag-preserving add-carry instructions."
 msgstr "crc32 命令のコード生成をサポートする。"
 
@@ -11581,7 +10599,6 @@ msgstr ""
 
 #: config/i386/i386.opt:845
 #, fuzzy, no-c-format
-#| msgid "Support MMX built-in functions"
 msgid "Support CLWB instruction."
 msgstr "MMX 組み込み関数をサポートする"
 
@@ -11592,19 +10609,16 @@ msgstr ""
 
 #: config/i386/i386.opt:856
 #, fuzzy, no-c-format
-#| msgid "Support code generation of movbe instruction."
 msgid "Support XSAVE and XRSTOR instructions."
 msgstr "movbe 命令のコード生成をサポートする。"
 
 #: config/i386/i386.opt:860
 #, fuzzy, no-c-format
-#| msgid "Support MMX built-in functions"
 msgid "Support XSAVEOPT instruction."
 msgstr "MMX 組み込み関数をサポートする"
 
 #: config/i386/i386.opt:864
 #, fuzzy, no-c-format
-#| msgid "Support MMX built-in functions"
 msgid "Support XSAVEC instructions."
 msgstr "MMX 組み込み関数をサポートする"
 
@@ -11615,7 +10629,6 @@ msgstr ""
 
 #: config/i386/i386.opt:872
 #, fuzzy, no-c-format
-#| msgid "Support TBM built-in functions and code generation"
 msgid "Support TBM built-in functions and code generation."
 msgstr "TBM 組み込み関数とコード生成をサポートする"
 
@@ -11641,49 +10654,41 @@ msgstr "crc32 命令のコード生成をサポートする。"
 
 #: config/i386/i386.opt:892
 #, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support AES built-in functions and code generation."
 msgstr "AES 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:896
 #, fuzzy, no-c-format
-#| msgid "Support MMX and SSE built-in functions and code generation"
 msgid "Support SHA1 and SHA256 built-in functions and code generation."
 msgstr "MMX と SSE の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:900
 #, fuzzy, no-c-format
-#| msgid "Support PCLMUL built-in functions and code generation"
 msgid "Support PCLMUL built-in functions and code generation."
 msgstr "PCLMUL 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:904
 #, fuzzy, no-c-format
-#| msgid "Encode SSE instructions with VEX prefix"
 msgid "Encode SSE instructions with VEX prefix."
 msgstr "SSE 命令を VEX 接頭辞を付けてエンコードする"
 
 #: config/i386/i386.opt:908
 #, fuzzy, no-c-format
-#| msgid "Support FSGSBASE built-in functions and code generation"
 msgid "Support FSGSBASE built-in functions and code generation."
 msgstr "FSGSBASE 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:912
 #, fuzzy, no-c-format
-#| msgid "Support RDRND built-in functions and code generation"
 msgid "Support RDRND built-in functions and code generation."
 msgstr "RDRND 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:916
 #, fuzzy, no-c-format
-#| msgid "Support F16C built-in functions and code generation"
 msgid "Support F16C built-in functions and code generation."
 msgstr "F16C 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:920
 #, fuzzy, no-c-format
-#| msgid "Support F16C built-in functions and code generation"
 msgid "Support PREFETCHWT1 built-in functions and code generation."
 msgstr "F16C 組み込み関数とコード生成をサポートする"
 
@@ -11734,25 +10739,21 @@ msgstr ""
 
 #: config/i386/i386.opt:961
 #, fuzzy, no-c-format
-#| msgid "Support TBM built-in functions and code generation"
 msgid "Support RTM built-in functions and code generation."
 msgstr "TBM 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:969
 #, fuzzy, no-c-format
-#| msgid "Support MMX and SSE built-in functions and code generation"
 msgid "Support MWAITX and MONITORX built-in functions and code generation."
 msgstr "MMX と SSE の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:973
 #, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support CLZERO built-in functions and code generation."
 msgstr "AES 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:977
 #, fuzzy, no-c-format
-#| msgid "Support PCLMUL built-in functions and code generation"
 msgid "Support PKU built-in functions and code generation."
 msgstr "PCLMUL 組み込み関数とコード生成をサポートする"
 
@@ -11793,7 +10794,6 @@ msgstr ""
 
 #: config/i386/i386.opt:1035
 #, fuzzy, no-c-format
-#| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
 msgstr "関数呼び出しと戻り用に call と rtc を使用する"
 
@@ -11804,7 +10804,6 @@ msgstr ""
 
 #: config/i386/i386.opt:1043
 #, fuzzy, no-c-format
-#| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "関数の返す型が関数であってはなりません"
 
@@ -11820,31 +10819,26 @@ msgstr ""
 
 #: config/i386/i386.opt:1067
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support MOVDIRI built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:1071
 #, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support MOVDIR64B built-in functions and code generation."
 msgstr "BMI 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:1075
 #, fuzzy, no-c-format
-#| msgid "Support LWP built-in functions and code generation "
 msgid "Support WAITPKG built-in functions and code generation."
 msgstr "LWP 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:1079
 #, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support CLDEMOTE built-in functions and code generation."
 msgstr "AES 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:1083
 #, fuzzy, no-c-format
-#| msgid "argument of function call might be a candidate for a format attribute"
 msgid "Instrument function exit in instrumented functions with __fentry__."
 msgstr "関数呼び出しの引数が format 属性の候補であるようです"
 
@@ -11860,62 +10854,52 @@ msgstr ""
 
 #: config/i386/i386.opt:1104
 #, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BF16 built-in functions and code generation."
 msgstr "MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX および FMA の組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:1109
 #, fuzzy, no-c-format
-#| msgid "Support RDRND built-in functions and code generation"
 msgid "Support ENQCMD built-in functions and code generation."
 msgstr "RDRND 組み込み関数とコード生成をサポートする"
 
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy, no-c-format
-#| msgid "Assume code will be linked by GNU ld"
 msgid "Assume code will be linked by GNU ld."
 msgstr "コードが GNU ld によってリンクされると見なす"
 
 #: config/pa/pa64-hpux.opt:27
 #, fuzzy, no-c-format
-#| msgid "Assume code will be linked by HP ld"
 msgid "Assume code will be linked by HP ld."
 msgstr "コードが HP ld によってリンクされると見なす"
 
 #: config/pa/pa-hpux1010.opt:23 config/pa/pa-hpux.opt:31
 #: config/pa/pa-hpux1131.opt:23 config/pa/pa-hpux1111.opt:23
 #, fuzzy, no-c-format
-#| msgid "Specify UNIX standard for predefines and linking"
 msgid "Specify UNIX standard for predefines and linking."
 msgstr "前定義とリンク用に UNIX 標準を指定する"
 
 #: config/pa/pa-hpux.opt:27
 #, fuzzy, no-c-format
-#| msgid "Generate cpp defines for server IO"
 msgid "Generate cpp defines for server IO."
 msgstr "サーバ IO 用の cpp 定義を生成する"
 
 #: config/pa/pa-hpux.opt:35
 #, fuzzy, no-c-format
-#| msgid "Generate cpp defines for workstation IO"
 msgid "Generate cpp defines for workstation IO."
 msgstr "ワークステーション IO 用に cpp 定義を生成する"
 
 #: config/pa/pa.opt:30 config/pa/pa.opt:91 config/pa/pa.opt:103
 #, fuzzy, no-c-format
-#| msgid "Generate PA1.0 code"
 msgid "Generate PA1.0 code."
 msgstr "PA1.0 コードを生成する"
 
 #: config/pa/pa.opt:34 config/pa/pa.opt:107 config/pa/pa.opt:148
 #, fuzzy, no-c-format
-#| msgid "Generate PA1.1 code"
 msgid "Generate PA1.1 code."
 msgstr "PA1.1 コードを生成する"
 
 #: config/pa/pa.opt:38 config/pa/pa.opt:111
 #, fuzzy, no-c-format
-#| msgid "Generate PA2.0 code (requires binutils 2.10 or later)"
 msgid "Generate PA2.0 code (requires binutils 2.10 or later)."
 msgstr "PA2.0 コードを生成する (binutils 2.10 以降が必要)"
 
@@ -11931,31 +10915,26 @@ msgstr ""
 
 #: config/pa/pa.opt:54
 #, fuzzy, no-c-format
-#| msgid "Disable FP regs"
 msgid "Disable FP regs."
 msgstr "浮動小数点レジスタを無効にする"
 
 #: config/pa/pa.opt:58
 #, fuzzy, no-c-format
-#| msgid "Disable preprocessing"
 msgid "Disable indexed addressing."
 msgstr "前処理を無効にする"
 
 #: config/pa/pa.opt:62
 #, fuzzy, no-c-format
-#| msgid "Use indirect calls"
 msgid "Generate fast indirect calls."
 msgstr "間接呼び出しを使用する"
 
 #: config/pa/pa.opt:70
 #, fuzzy, no-c-format
-#| msgid "Assume code will be assembled by GAS"
 msgid "Assume code will be assembled by GAS."
 msgstr "コードが GAS によってアセンブルされると見なす"
 
 #: config/pa/pa.opt:79
 #, fuzzy, no-c-format
-#| msgid "Enable linker optimizations"
 msgid "Enable linker optimizations."
 msgstr "リンカ最適化を有効にする"
 
@@ -11971,7 +10950,6 @@ msgstr ""
 
 #: config/pa/pa.opt:95
 #, fuzzy, no-c-format
-#| msgid "Disable FP regs"
 msgid "Disable space regs."
 msgstr "浮動小数点レジスタを無効にする"
 
@@ -11982,7 +10960,6 @@ msgstr ""
 
 #: config/pa/pa.opt:115
 #, fuzzy, no-c-format
-#| msgid "Use portable calling conventions"
 msgid "Use portable calling conventions."
 msgstr "移植性のある呼び出し規約を使用する"
 
@@ -11993,79 +10970,66 @@ msgstr ""
 
 #: config/pa/pa.opt:144 config/frv/frv.opt:215
 #, fuzzy, no-c-format
-#| msgid "Use software floating point"
 msgid "Use software floating point."
 msgstr "ソフトウェア浮動小数点を使用する"
 
 #: config/pa/pa.opt:152
 #, fuzzy, no-c-format
-#| msgid "Disable FP regs"
 msgid "Do not disable space regs."
 msgstr "浮動小数点レジスタを無効にする"
 
 #: config/v850/v850.opt:29
 #, fuzzy, no-c-format
-#| msgid "Use registers r2 and r5"
 msgid "Use registers r2 and r5."
 msgstr "レジスタ r2 と r5 を使用する"
 
 #: config/v850/v850.opt:33
 #, fuzzy, no-c-format
-#| msgid "Use 4 byte entries in switch tables"
 msgid "Use 4 byte entries in switch tables."
 msgstr "switch 表で 4 バイトエントリを使用する"
 
 #: config/v850/v850.opt:37
 #, fuzzy, no-c-format
-#| msgid "Enable backend debugging"
 msgid "Enable backend debugging."
 msgstr "バックエンドデバッグを有効にする"
 
 #: config/v850/v850.opt:41
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the callt instruction (default)."
 msgstr "callt 命令を使用しない"
 
 #: config/v850/v850.opt:45
 #, fuzzy, no-c-format
-#| msgid "Reuse r30 on a per function basis"
 msgid "Reuse r30 on a per function basis."
 msgstr "関数の主要部分毎に r30 を再利用する"
 
 #: config/v850/v850.opt:52
 #, fuzzy, no-c-format
-#| msgid "Prohibit PC relative function calls"
 msgid "Prohibit PC relative function calls."
 msgstr "PC 関連の関数呼び出しを禁止する"
 
 #: config/v850/v850.opt:56
 #, fuzzy, no-c-format
-#| msgid "Use stubs for function prologues"
 msgid "Use stubs for function prologues."
 msgstr "関数プロローグ用のスタブを使用する"
 
 #: config/v850/v850.opt:60
 #, fuzzy, no-c-format
-#| msgid "Set the max size of data eligible for the SDA area"
 msgid "Set the max size of data eligible for the SDA area."
 msgstr "SDA 領域にとって望ましい最大データサイズを設定する"
 
 #: config/v850/v850.opt:67
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the short load instructions."
 msgstr "短い load 命令の使用を有効にする"
 
 #: config/v850/v850.opt:71
 #, fuzzy, no-c-format
-#| msgid "Same as: -mep -mprolog-function"
 msgid "Same as: -mep -mprolog-function."
 msgstr "-mep -mprolog-function と同様"
 
 #: config/v850/v850.opt:75
 #, fuzzy, no-c-format
-#| msgid "Set the max size of data eligible for the TDA area"
 msgid "Set the max size of data eligible for the TDA area."
 msgstr "TDA 領域にとって望ましい最大データサイズを設定する"
 
@@ -12081,19 +11045,16 @@ msgstr ""
 
 #: config/v850/v850.opt:93
 #, fuzzy, no-c-format
-#| msgid "Compile for the v850 processor"
 msgid "Compile for the v850 processor."
 msgstr "v850 プロセッサ用にコンパイルする"
 
 #: config/v850/v850.opt:97
 #, fuzzy, no-c-format
-#| msgid "Compile for the v850e processor"
 msgid "Compile for the v850e processor."
 msgstr "v850e プロセッサ用にコンパイルする"
 
 #: config/v850/v850.opt:101
 #, fuzzy, no-c-format
-#| msgid "Compile for the v850e1 processor"
 msgid "Compile for the v850e1 processor."
 msgstr "v850e1 プロセッサ用にコンパイルする"
 
@@ -12104,31 +11065,26 @@ msgstr "v850e プロセッサ用にコンパイルする"
 
 #: config/v850/v850.opt:109
 #, fuzzy, no-c-format
-#| msgid "Compile for the v850e2 processor"
 msgid "Compile for the v850e2 processor."
 msgstr "v850e2 プロセッサ用にコンパイルする"
 
 #: config/v850/v850.opt:113
 #, fuzzy, no-c-format
-#| msgid "Compile for the v850e2v3 processor"
 msgid "Compile for the v850e2v3 processor."
 msgstr "v850e2v3 プロセッサ用にコンパイルする"
 
 #: config/v850/v850.opt:117
 #, fuzzy, no-c-format
-#| msgid "Compile for the v850e processor"
 msgid "Compile for the v850e3v5 processor."
 msgstr "v850e プロセッサ用にコンパイルする"
 
 #: config/v850/v850.opt:124
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable v850e3v5 loop instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/v850/v850.opt:128
 #, fuzzy, no-c-format
-#| msgid "Set the max size of data eligible for the ZDA area"
 msgid "Set the max size of data eligible for the ZDA area."
 msgstr "ZDA 領域にとって望ましい最大データサイズを設定する"
 
@@ -12139,25 +11095,21 @@ msgstr ""
 
 #: config/v850/v850.opt:139
 #, fuzzy, no-c-format
-#| msgid "Prohibit PC relative function calls"
 msgid "Prohibit PC relative jumps."
 msgstr "PC 関連の関数呼び出しを禁止する"
 
 #: config/v850/v850.opt:143
 #, fuzzy, no-c-format
-#| msgid "Prevent the use of all hardware floating-point instructions"
 msgid "Inhibit the use of hardware floating point instructions."
 msgstr "すべてのハードウェア浮動小数点命令の使用を防止する"
 
 #: config/v850/v850.opt:147
 #, fuzzy, no-c-format
-#| msgid "Allow the use of hardware floating-point ABI and instructions"
 msgid "Allow the use of hardware floating point instructions for V850E2V3 and up."
 msgstr "ハードウェア浮動小数点の ABI と命令の使用を許可する"
 
 #: config/v850/v850.opt:151
 #, fuzzy, no-c-format
-#| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable support for the RH850 ABI.  This is the default."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
@@ -12178,31 +11130,26 @@ msgstr ""
 
 #: config/lynx.opt:23
 #, fuzzy, no-c-format
-#| msgid "Support legacy multi-threading"
 msgid "Support legacy multi-threading."
 msgstr "古いマルチスレッドをサポートする"
 
 #: config/lynx.opt:27
 #, fuzzy, no-c-format
-#| msgid "Use shared libraries"
 msgid "Use shared libraries."
 msgstr "共有ライブラリを使用する"
 
 #: config/lynx.opt:31
 #, fuzzy, no-c-format
-#| msgid "Support multi-threading"
 msgid "Support multi-threading."
 msgstr "マルチスレッドをサポートする"
 
 #: config/nvptx/nvptx.opt:22 config/gcn/gcn.opt:47
 #, fuzzy, no-c-format
-#| msgid "Generate code for a Fido A"
 msgid "Generate code for a 32-bit ABI."
 msgstr "Fido A 用のコードを生成する"
 
 #: config/nvptx/nvptx.opt:26 config/gcn/gcn.opt:51
 #, fuzzy, no-c-format
-#| msgid "Generate code for a Fido A"
 msgid "Generate code for a 64-bit ABI."
 msgstr "Fido A 用のコードを生成する"
 
@@ -12238,37 +11185,31 @@ msgstr ""
 
 #: config/nvptx/nvptx.opt:54
 #, fuzzy, no-c-format
-#| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgid "Known PTX ISA versions (for use with the -misa= option):"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
 #: config/nvptx/nvptx.opt:64
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target CPU"
 msgid "Specify the version of the ptx ISA to use."
 msgstr "ターゲット CPU の名前を指定する"
 
 #: config/vxworks.opt:36
 #, fuzzy, no-c-format
-#| msgid "Assume the VxWorks RTP environment"
 msgid "Assume the VxWorks RTP environment."
 msgstr "VxWorks RTP 環境と見なす"
 
 #: config/vxworks.opt:43
 #, fuzzy, no-c-format
-#| msgid "Assume the VxWorks vThreads environment"
 msgid "Assume the VxWorks vThreads environment."
 msgstr "VxWorks vThreads 環境と見なす"
 
 #: config/cr16/cr16.opt:27
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate SBIT, CBIT instructions."
 msgstr "ビット命令を生成する"
 
 #: config/cr16/cr16.opt:31
 #, fuzzy, no-c-format
-#| msgid "Support multiply accumulate instructions"
 msgid "Support multiply accumulate instructions."
 msgstr "乗算-加算浮動小数点命令を使用する"
 
@@ -12279,37 +11220,31 @@ msgstr ""
 
 #: config/cr16/cr16.opt:42
 #, fuzzy, no-c-format
-#| msgid "Generate code for a cpu32"
 msgid "Generate code for CR16C architecture."
 msgstr "cpu32 用のコードを生成する"
 
 #: config/cr16/cr16.opt:46
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU assembler (gas)"
 msgid "Generate code for CR16C+ architecture (Default)."
 msgstr "GNU アセンブラ (gas) 用のコードを生成する"
 
 #: config/cr16/cr16.opt:50
 #, fuzzy, no-c-format
-#| msgid "Pointers are 32-bit"
 msgid "Treat integers as 32-bit."
 msgstr "ポインタを 32 ビットとする"
 
 #: config/avr/avr.opt:23
 #, fuzzy, no-c-format
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use subroutines for function prologues and epilogues."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
 #: config/avr/avr.opt:27
 #, fuzzy, no-c-format
-#| msgid "-mmcu=MCU\tSelect the target MCU"
 msgid "-mmcu=MCU\tSelect the target MCU."
 msgstr "-mmcu=MCU\tターゲット MCU を設定する"
 
 #: config/avr/avr.opt:31
 #, fuzzy, no-c-format
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Allow usage of __gcc_isr pseudo instructions in ISR prologues and epilogues."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
@@ -12335,13 +11270,11 @@ msgstr ""
 
 #: config/avr/avr.opt:57
 #, fuzzy, no-c-format
-#| msgid "Use an 8-bit 'int' type"
 msgid "Use an 8-bit 'int' type."
 msgstr "8 ビット 'int' 型を使用する"
 
 #: config/avr/avr.opt:61
 #, fuzzy, no-c-format
-#| msgid "Change the stack pointer without disabling interrupts"
 msgid "Change the stack pointer without disabling interrupts."
 msgstr "割り込みを無効化しないでスタックポインタを変更する"
 
@@ -12357,13 +11290,11 @@ msgstr ""
 
 #: config/avr/avr.opt:79
 #, fuzzy, no-c-format
-#| msgid "Change only the low 8 bits of the stack pointer"
 msgid "Change only the low 8 bits of the stack pointer."
 msgstr "スタックポインタの下位 8 ビットだけを変更する"
 
 #: config/avr/avr.opt:83
 #, fuzzy, no-c-format
-#| msgid "Relax branches"
 msgid "Relax branches."
 msgstr "分岐を緩和する"
 
@@ -12389,7 +11320,6 @@ msgstr ""
 
 #: config/avr/avr.opt:104
 #, fuzzy, no-c-format
-#| msgid "taking the address of a label is non-standard"
 msgid "Warn if the address space of an address is changed."
 msgstr "ラベルのアドレスを取得することは非標準です"
 
@@ -12435,97 +11365,81 @@ msgstr ""
 
 #: config/m32r/m32r.opt:34
 #, fuzzy, no-c-format
-#| msgid "Compile for the m32rx"
 msgid "Compile for the m32rx."
 msgstr "m32rx 用にコンパイルする"
 
 #: config/m32r/m32r.opt:38
 #, fuzzy, no-c-format
-#| msgid "Compile for the m32r2"
 msgid "Compile for the m32r2."
 msgstr "m32r2 用にコンパイルする"
 
 #: config/m32r/m32r.opt:42
 #, fuzzy, no-c-format
-#| msgid "Compile for the m32r"
 msgid "Compile for the m32r."
 msgstr "m32r 用にコンパイルする"
 
 #: config/m32r/m32r.opt:46
 #, fuzzy, no-c-format
-#| msgid "Align all loops to 32 byte boundary"
 msgid "Align all loops to 32 byte boundary."
 msgstr "全てのループを 32 バイト境界に整列する"
 
 #: config/m32r/m32r.opt:50
 #, fuzzy, no-c-format
-#| msgid "Prefer branches over conditional execution"
 msgid "Prefer branches over conditional execution."
 msgstr "条件付き実行より分岐の生成を優先する"
 
 #: config/m32r/m32r.opt:54
 #, fuzzy, no-c-format
-#| msgid "Give branches their default cost"
 msgid "Give branches their default cost."
 msgstr "分岐にデフォルトのコストを与える"
 
 #: config/m32r/m32r.opt:58
 #, fuzzy, no-c-format
-#| msgid "Display compile time statistics"
 msgid "Display compile time statistics."
 msgstr "コンパイル時間統計値を表示する"
 
 #: config/m32r/m32r.opt:62
 #, fuzzy, no-c-format
-#| msgid "Specify cache flush function"
 msgid "Specify cache flush function."
 msgstr "キャッシュフラッシュ関数を指定する"
 
 #: config/m32r/m32r.opt:66
 #, fuzzy, no-c-format
-#| msgid "Specify cache flush trap number"
 msgid "Specify cache flush trap number."
 msgstr "キャッシュフラッシュトラップ番号を指定する"
 
 #: config/m32r/m32r.opt:70
 #, fuzzy, no-c-format
-#| msgid "Only issue one instruction per cycle"
 msgid "Only issue one instruction per cycle."
 msgstr "サイクル毎に一つの命令だけを発行する"
 
 #: config/m32r/m32r.opt:74
 #, fuzzy, no-c-format
-#| msgid "Allow two instructions to be issued per cycle"
 msgid "Allow two instructions to be issued per cycle."
 msgstr "サイクル毎に二つの命令を発行することを許可する"
 
 #: config/m32r/m32r.opt:78
 #, fuzzy, no-c-format
-#| msgid "Code size: small, medium or large"
 msgid "Code size: small, medium or large."
 msgstr "コードサイズ: small、medium または large"
 
 #: config/m32r/m32r.opt:94
 #, fuzzy, no-c-format
-#| msgid "Don't call any cache flush functions"
 msgid "Don't call any cache flush functions."
 msgstr "キャッシュフラッシュ関数を全く呼び出さない"
 
 #: config/m32r/m32r.opt:98
 #, fuzzy, no-c-format
-#| msgid "Don't call any cache flush trap"
 msgid "Don't call any cache flush trap."
 msgstr "キャッシュフラッシュトラップを全く呼び出さない"
 
 #: config/m32r/m32r.opt:105
 #, fuzzy, no-c-format
-#| msgid "Small data area: none, sdata, use"
 msgid "Small data area: none, sdata, use."
 msgstr "small データ領域: none, sdata, use"
 
 #: config/s390/tpf.opt:23
 #, fuzzy, no-c-format
-#| msgid "Enable TPF-OS tracing code"
 msgid "Enable TPF-OS tracing code."
 msgstr "TPF-OS 追跡コードを有効にする"
 
@@ -12556,19 +11470,16 @@ msgstr ""
 
 #: config/s390/tpf.opt:47
 #, fuzzy, no-c-format
-#| msgid "Specify main object for TPF-OS"
 msgid "Specify main object for TPF-OS."
 msgstr "TPF-OS 用の main オブジェクトを指定する"
 
 #: config/s390/s390.opt:48
 #, fuzzy, no-c-format
-#| msgid "31 bit ABI"
 msgid "31 bit ABI."
 msgstr "31 ビット ABI"
 
 #: config/s390/s390.opt:52
 #, fuzzy, no-c-format
-#| msgid "64 bit ABI"
 msgid "64 bit ABI."
 msgstr "64 ビット ABI"
 
@@ -12579,25 +11490,21 @@ msgstr ""
 
 #: config/s390/s390.opt:127
 #, fuzzy, no-c-format
-#| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "追加のデバッグ情報を表示する"
 
 #: config/s390/s390.opt:131
 #, fuzzy, no-c-format
-#| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "ESA/390 アーキテクチャ"
 
 #: config/s390/s390.opt:135
 #, fuzzy, no-c-format
-#| msgid "Enable decimal floating point hardware support"
 msgid "Enable decimal floating point hardware support."
 msgstr "十進浮動小数点ハードウェアのサポートを有効にする"
 
 #: config/s390/s390.opt:139
 #, fuzzy, no-c-format
-#| msgid "Enable hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "ハードウェア浮動小数点を有効にする"
 
@@ -12608,13 +11515,11 @@ msgstr ""
 
 #: config/s390/s390.opt:161
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
 #: config/s390/s390.opt:165
 #, fuzzy, no-c-format
-#| msgid "hardware decimal floating point instructions not available on %s"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
@@ -12630,7 +11535,6 @@ msgstr ""
 
 #: config/s390/s390.opt:177
 #, fuzzy, no-c-format
-#| msgid "Disable hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "ハードウェア浮動小数点を無効にする"
 
@@ -12656,7 +11560,6 @@ msgstr ""
 
 #: config/s390/s390.opt:201
 #, fuzzy, no-c-format
-#| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "ブロック移動用の string 命令を生成する"
 
@@ -12667,19 +11570,16 @@ msgstr ""
 
 #: config/s390/s390.opt:210
 #, fuzzy, no-c-format
-#| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "関数で alloca を使用するか、または動的サイズの配列を作成した場合に、警告する"
 
 #: config/s390/s390.opt:214
 #, fuzzy, no-c-format
-#| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "一つの関数のフレームサイズが与えられたフレームサイズを超過する場合に警告する"
 
 #: config/s390/s390.opt:218
 #, fuzzy, no-c-format
-#| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Architecture"
 
@@ -12750,7 +11650,6 @@ msgstr ""
 
 #: config/rl78/rl78.opt:50
 #, fuzzy, no-c-format
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Use all registers, reserving none for interrupt handlers."
 msgstr "割り込みハンドラ用に予約されるレジスタサイズを指定する"
 
@@ -12766,19 +11665,16 @@ msgstr ""
 
 #: config/rl78/rl78.opt:77
 #, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
 msgid "Alias for -mcpu=g10."
 msgstr "--help=target の別名"
 
 #: config/rl78/rl78.opt:81
 #, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
 msgid "Alias for -mcpu=g13."
 msgstr "--help=target の別名"
 
 #: config/rl78/rl78.opt:85 config/rl78/rl78.opt:89
 #, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
 msgid "Alias for -mcpu=g14."
 msgstr "--help=target の別名"
 
@@ -12794,7 +11690,6 @@ msgstr ""
 
 #: config/stormy16/stormy16.opt:24
 #, fuzzy, no-c-format
-#| msgid "Provide libraries for the simulator"
 msgid "Provide libraries for the simulator."
 msgstr "シミュレータ用ライブラリを提供する"
 
@@ -12820,7 +11715,6 @@ msgstr ""
 
 #: config/arm/arm.opt:45
 #, fuzzy, no-c-format
-#| msgid "Specify an ABI"
 msgid "Specify an ABI."
 msgstr "ABI を指定する"
 
@@ -12831,43 +11725,36 @@ msgstr ""
 
 #: config/arm/arm.opt:68
 #, fuzzy, no-c-format
-#| msgid "Generate a call to abort if a noreturn function returns"
 msgid "Generate a call to abort if a noreturn function returns."
 msgstr "noreturn 関数が return するとき abort の呼び出しを生成する"
 
 #: config/arm/arm.opt:75
 #, fuzzy, no-c-format
-#| msgid "Generate APCS conformant stack frames"
 msgid "Generate APCS conformant stack frames."
 msgstr "APCS に準拠したスタックフレームを生成する"
 
 #: config/arm/arm.opt:79
 #, fuzzy, no-c-format
-#| msgid "Generate re-entrant, PIC code"
 msgid "Generate re-entrant, PIC code."
 msgstr "再入可能な PIC コードを生成する"
 
 #: config/arm/arm.opt:95
 #, fuzzy, no-c-format
-#| msgid "Generate code for 32 bit addressing"
 msgid "Generate code in 32 bit ARM state."
 msgstr "32 ビットアドレス用のコードを生成する"
 
 #: config/arm/arm.opt:103
 #, fuzzy, no-c-format
-#| msgid "Thumb: Assume non-static functions may be called from ARM code"
 msgid "Thumb: Assume non-static functions may be called from ARM code."
 msgstr "Thumb: 非静的関数が ARM コードから呼び出される可能性があるとみなす"
 
 #: config/arm/arm.opt:107
 #, fuzzy, no-c-format
-#| msgid "Thumb: Assume function pointers may go to non-Thumb aware code"
 msgid "Thumb: Assume function pointers may go to non-Thumb aware code."
 msgstr "Thumb: 関数ポインタが非 Thumb と認識するコードに突入する可能性があるとみなす"
 
 #: config/arm/arm.opt:115
 #, fuzzy, no-c-format
-#| msgid "Specify if floating point hardware should be used"
 msgid "Specify if floating point hardware should be used."
 msgstr "浮動小数点ハードウェアを使用するかどうかを指定する"
 
@@ -12888,103 +11775,86 @@ msgstr ""
 
 #: config/arm/arm.opt:140
 #, fuzzy, no-c-format
-#| msgid "Specify the __fp16 floating-point format"
 msgid "Specify the __fp16 floating-point format."
 msgstr "__fp16 浮動小数点形式を指定する"
 
 #: config/arm/arm.opt:144
 #, fuzzy, no-c-format
-#| msgid "invalid __fp16 format option: -mfp16-format=%s"
 msgid "Known __fp16 formats (for use with the -mfp16-format= option):"
 msgstr "無効な __fp16 書式オプションです: -mfp16-format=%s"
 
 #: config/arm/arm.opt:157
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify the name of the target floating point hardware/format."
 msgstr "ターゲット浮動小数点ハードウェア/形式の名前を指定する"
 
 #: config/arm/arm.opt:168
 #, fuzzy, no-c-format
-#| msgid "Generate call insns as indirect calls, if necessary"
 msgid "Generate call insns as indirect calls, if necessary."
 msgstr "必要があれば、命令呼び出しを間接呼び出しとして生成する"
 
 #: config/arm/arm.opt:176
 #, fuzzy, no-c-format
-#| msgid "Specify the register to be used for PIC addressing"
 msgid "Specify the register to be used for PIC addressing."
 msgstr "PIC アドレシングに利用されるレジスタを指定する"
 
 #: config/arm/arm.opt:180
 #, fuzzy, no-c-format
-#| msgid "Store function names in object code"
 msgid "Store function names in object code."
 msgstr "オブジェクトコードに関数名を格納する"
 
 #: config/arm/arm.opt:184
 #, fuzzy, no-c-format
-#| msgid "Permit scheduling of a function's prologue sequence"
 msgid "Permit scheduling of a function's prologue sequence."
 msgstr "関数のプロローグシーケンスのスケジューリングを許す"
 
 #: config/arm/arm.opt:188 config/rs6000/rs6000.opt:243
 #, fuzzy, no-c-format
-#| msgid "Do not load the PIC register in function prologues"
 msgid "Do not load the PIC register in function prologues."
 msgstr "関数プロローグ内で PIC レジスタをロードしない"
 
 #: config/arm/arm.opt:195
 #, fuzzy, no-c-format
-#| msgid "Specify the minimum bit alignment of structures"
 msgid "Specify the minimum bit alignment of structures. (Deprecated)."
 msgstr "構造体の整列の最小ビット数を指定する"
 
 #: config/arm/arm.opt:199
 #, fuzzy, no-c-format
-#| msgid "Generate code for huge switch statements"
 msgid "Generate code for Thumb state."
 msgstr "巨大な swich 文用コードを生成する"
 
 #: config/arm/arm.opt:203
 #, fuzzy, no-c-format
-#| msgid "Support calls between Thumb and ARM instruction sets"
 msgid "Support calls between Thumb and ARM instruction sets."
 msgstr "Thumb と ARM 命令セット間の呼び出しをサポートする"
 
 #: config/arm/arm.opt:207
 #, fuzzy, no-c-format
-#| msgid "Use given thread-local storage dialect"
 msgid "Specify thread local storage scheme."
 msgstr "与えられたスレッド局所記憶域 (TLS) 形式を使用する"
 
 #: config/arm/arm.opt:211
 #, fuzzy, no-c-format
-#| msgid "Specify how to access the thread pointer"
 msgid "Specify how to access the thread pointer."
 msgstr "スレッドポインタへのアクセス方法を指定する"
 
 #: config/arm/arm.opt:215
 #, fuzzy, no-c-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mtp=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/arm/arm.opt:228
 #, fuzzy, no-c-format
-#| msgid "Thumb: Generate (non-leaf) stack frames even if not needed"
 msgid "Thumb: Generate (non-leaf) stack frames even if not needed."
 msgstr "Thumb: 不要な場合でも(非末端)スタックフレームを生成する"
 
 #: config/arm/arm.opt:232
 #, fuzzy, no-c-format
-#| msgid "Thumb: Generate (leaf) stack frames even if not needed"
 msgid "Thumb: Generate (leaf) stack frames even if not needed."
 msgstr "Thumb: 不要な場合でも(末端)スタックフレームを生成する"
 
 #: config/arm/arm.opt:236 config/mn10300/mn10300.opt:42
 #, fuzzy, no-c-format
-#| msgid "Tune code for the given processor"
 msgid "Tune code for the given processor."
 msgstr "与えられたプロセッサ用に調整する"
 
@@ -12995,13 +11865,11 @@ msgstr ""
 
 #: config/arm/arm.opt:251
 #, fuzzy, no-c-format
-#| msgid "Use Neon quad-word (rather than double-word) registers for vectorization"
 msgid "Use Neon quad-word (rather than double-word) registers for vectorization."
 msgstr "ベクトル化用に Neon 四倍ワード (二倍ワードではなく) レジスタを使用する"
 
 #: config/arm/arm.opt:255
 #, fuzzy, no-c-format
-#| msgid "Use Neon quad-word (rather than double-word) registers for vectorization"
 msgid "Use Neon double-word (rather than quad-word) registers for vectorization."
 msgstr "ベクトル化用に Neon 四倍ワード (二倍ワードではなく) レジスタを使用する"
 
@@ -13032,7 +11900,6 @@ msgstr ""
 
 #: config/arm/arm.opt:280
 #, fuzzy, no-c-format
-#| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This option is deprecated and has no effect."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
@@ -13063,92 +11930,77 @@ msgstr ""
 
 #: config/arm/arm.opt:304 config/sh/sh.opt:195
 #, fuzzy, no-c-format
-#| msgid "Cost to assume for a branch insn"
 msgid "Cost to assume for a branch insn."
 msgstr "分岐命令用のコストを設定する"
 
 #: config/arm/arm.opt:308
 #, fuzzy, no-c-format
-#| msgid "Generate code which uses hardware floating point instructions"
 msgid "Generate code which uses the core registers only (r0-r14)."
 msgstr "ハードウェア浮動小数点命令を使用するコードを生成する"
 
 #: config/sparc/sparc.opt:30 config/sparc/sparc.opt:34
 #: config/visium/visium.opt:37
 #, fuzzy, no-c-format
-#| msgid "Use hardware FP"
 msgid "Use hardware FP."
 msgstr "ハードウェア浮動小数点を使用する"
 
 #: config/sparc/sparc.opt:38 config/visium/visium.opt:41
 #, fuzzy, no-c-format
-#| msgid "Do not use hardware FP"
 msgid "Do not use hardware FP."
 msgstr "ハードウェア浮動小数点を使用しない"
 
 #: config/sparc/sparc.opt:42
 #, fuzzy, no-c-format
-#| msgid "Use alternate register names"
 msgid "Use flat register window model."
 msgstr "代替レジスタ名を使用する"
 
 #: config/sparc/sparc.opt:46
 #, fuzzy, no-c-format
-#| msgid "Assume possible double misalignment"
 msgid "Assume possible double misalignment."
 msgstr "double が整列されていない可能性があると見なす"
 
 #: config/sparc/sparc.opt:50
 #, fuzzy, no-c-format
-#| msgid "Use ABI reserved registers"
 msgid "Use ABI reserved registers."
 msgstr "ABI 予約レジスタを使用する"
 
 #: config/sparc/sparc.opt:54
 #, fuzzy, no-c-format
-#| msgid "Use hardware quad FP instructions"
 msgid "Use hardware quad FP instructions."
 msgstr "ハードウェア四倍精度浮動小数点命令を使用する"
 
 #: config/sparc/sparc.opt:58
 #, fuzzy, no-c-format
-#| msgid "Do not use hardware quad fp instructions"
 msgid "Do not use hardware quad fp instructions."
 msgstr "ハードウェア四倍精度浮動小数点命令を使用しない"
 
 #: config/sparc/sparc.opt:62
 #, fuzzy, no-c-format
-#| msgid "Enables a register move optimization"
 msgid "Enable Local Register Allocation."
 msgstr "レジスタによる移動命令の最適化を有効にする"
 
 #: config/sparc/sparc.opt:66
 #, fuzzy, no-c-format
-#| msgid "Compile for V8+ ABI"
 msgid "Compile for V8+ ABI."
 msgstr "V8+ ABI 用にコンパイルする"
 
 #: config/sparc/sparc.opt:70
 #, fuzzy, no-c-format
-#| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 1.0 extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
 #: config/sparc/sparc.opt:74
 #, fuzzy, no-c-format
-#| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 2.0 extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
 #: config/sparc/sparc.opt:78
 #, fuzzy, no-c-format
-#| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 3.0 extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
 #: config/sparc/sparc.opt:82
 #, fuzzy, no-c-format
-#| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 4.0 extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
@@ -13159,13 +12011,11 @@ msgstr ""
 
 #: config/sparc/sparc.opt:90
 #, fuzzy, no-c-format
-#| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
 #: config/sparc/sparc.opt:94
 #, fuzzy, no-c-format
-#| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
@@ -13176,7 +12026,6 @@ msgstr "浮動小数の乗算/加算命令を生成する"
 
 #: config/sparc/sparc.opt:102
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point instructions"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
@@ -13187,43 +12036,36 @@ msgstr ""
 
 #: config/sparc/sparc.opt:110
 #, fuzzy, no-c-format
-#| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "ポインタを 64 ビットとする"
 
 #: config/sparc/sparc.opt:114
 #, fuzzy, no-c-format
-#| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "ポインタを 32 ビットとする"
 
 #: config/sparc/sparc.opt:118
 #, fuzzy, no-c-format
-#| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "64 ビット ABI を使用する"
 
 #: config/sparc/sparc.opt:122
 #, fuzzy, no-c-format
-#| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "32 ビット ABI を使用する"
 
 #: config/sparc/sparc.opt:126
 #, fuzzy, no-c-format
-#| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "スタックバイアスを使用する"
 
 #: config/sparc/sparc.opt:130
 #, fuzzy, no-c-format
-#| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "二倍ワードコピー用の強く整列された構造体を使用する"
 
 #: config/sparc/sparc.opt:134
 #, fuzzy, no-c-format
-#| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "アセンブラとリンカで末尾呼び出し命令を最適化する"
 
@@ -13234,19 +12076,16 @@ msgstr ""
 
 #: config/sparc/sparc.opt:142
 #, fuzzy, no-c-format
-#| msgid "Use features of and schedule code for given CPU"
 msgid "Use instructions of and schedule code for given CPU."
 msgstr "与えられた CPU 用の機能とスケジュールコードを利用する"
 
 #: config/sparc/sparc.opt:225
 #, fuzzy, no-c-format
-#| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "与えられた SPARC-V9 コードモデルを使用する"
 
 #: config/sparc/sparc.opt:247
 #, fuzzy, no-c-format
-#| msgid "-mdebug=\tEnable debug output"
 msgid "Enable debug output."
 msgstr "-mdebug=\tデバッグ出力を有効にする"
 
@@ -13282,13 +12121,11 @@ msgstr ""
 
 #: config/rs6000/darwin.opt:38 config/rs6000/sysv4.opt:145
 #, fuzzy, no-c-format
-#| msgid "Generate 64-bit code"
 msgid "Generate 64-bit code."
 msgstr "64 ビットコードを生成する"
 
 #: config/rs6000/darwin.opt:42 config/rs6000/sysv4.opt:149
 #, fuzzy, no-c-format
-#| msgid "Generate 32-bit code"
 msgid "Generate 32-bit code."
 msgstr "32 ビットコードを生成する"
 
@@ -13304,79 +12141,66 @@ msgstr ""
 
 #: config/rs6000/aix64.opt:24
 #, fuzzy, no-c-format
-#| msgid "Compile for 64-bit pointers"
 msgid "Compile for 64-bit pointers."
 msgstr "64 ビットポインタ用にコンパイルする"
 
 #: config/rs6000/aix64.opt:28
 #, fuzzy, no-c-format
-#| msgid "Compile for 32-bit pointers"
 msgid "Compile for 32-bit pointers."
 msgstr "32 ビットポインタ用にコンパイルする"
 
 #: config/rs6000/aix64.opt:32 config/rs6000/linux64.opt:28
 #, fuzzy, no-c-format
-#| msgid "Select code model"
 msgid "Select code model."
 msgstr "コードモデルを選択する"
 
 #: config/rs6000/aix64.opt:49
 #, fuzzy, no-c-format
-#| msgid "Support message passing with the Parallel Environment"
 msgid "Support message passing with the Parallel Environment."
 msgstr "並列環境でのメッセージパッシングをサポートする"
 
 #: config/rs6000/linux64.opt:24
 #, fuzzy, no-c-format
-#| msgid "Call mcount for profiling before a function prologue"
 msgid "Call mcount for profiling before a function prologue."
 msgstr "関数プロローグの前にプロファイル用の mcount を呼び出す"
 
 #: config/rs6000/rs6000.opt:121
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC-64 instruction set"
 msgid "Use PowerPC-64 instruction set."
 msgstr "PowerPC-64 命令セットを使用する"
 
 #: config/rs6000/rs6000.opt:125
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC General Purpose group optional instructions"
 msgid "Use PowerPC General Purpose group optional instructions."
 msgstr "PowerPC 汎用グループオプション命令を使用する"
 
 #: config/rs6000/rs6000.opt:129
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC Graphics group optional instructions"
 msgid "Use PowerPC Graphics group optional instructions."
 msgstr "PowerPC グラフィクスグループオプション命令を使用しない"
 
 #: config/rs6000/rs6000.opt:133
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC V2.01 single field mfcr instruction"
 msgid "Use PowerPC V2.01 single field mfcr instruction."
 msgstr "PowerPC V2.01 単一フィールド mfcr 命令を使用する"
 
 #: config/rs6000/rs6000.opt:137
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC V2.02 popcntb instruction"
 msgid "Use PowerPC V2.02 popcntb instruction."
 msgstr "PowerPC V2.02 popcntb 命令を使用する"
 
 #: config/rs6000/rs6000.opt:141
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC V2.02 floating point rounding instructions"
 msgid "Use PowerPC V2.02 floating point rounding instructions."
 msgstr "PowerPC V2.02 浮動小数点丸め命令を使用する"
 
 #: config/rs6000/rs6000.opt:145
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC V2.05 compare bytes instruction"
 msgid "Use PowerPC V2.05 compare bytes instruction."
 msgstr "PowerPC V2.05 バイト比較命令を使用する"
 
 #: config/rs6000/rs6000.opt:156
 #, fuzzy, no-c-format
-#| msgid "Use AltiVec instructions"
 msgid "Use AltiVec instructions."
 msgstr "AltiVec 命令を使用する"
 
@@ -13387,31 +12211,26 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:164
 #, fuzzy, no-c-format
-#| msgid "Use decimal floating point instructions"
 msgid "Use decimal floating point instructions."
 msgstr "十進浮動小数点命令を使用する"
 
 #: config/rs6000/rs6000.opt:168
 #, fuzzy, no-c-format
-#| msgid "Use 4xx half-word multiply instructions"
 msgid "Use 4xx half-word multiply instructions."
 msgstr "4xx ハーフワード乗算命令を使用する"
 
 #: config/rs6000/rs6000.opt:172
 #, fuzzy, no-c-format
-#| msgid "Use 4xx string-search dlmzb instruction"
 msgid "Use 4xx string-search dlmzb instruction."
 msgstr "4xx 文字列探査 dlmzb 命令を使用する"
 
 #: config/rs6000/rs6000.opt:176
 #, fuzzy, no-c-format
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate load/store multiple instructions."
 msgstr "複数命令のロード/ストアを生成する"
 
 #: config/rs6000/rs6000.opt:195
 #, fuzzy, no-c-format
-#| msgid "Use PowerPC V2.06 popcntd instruction"
 msgid "Use PowerPC V2.06 popcntd instruction."
 msgstr "PowerPC V2.06 popcntd 命令を使用する"
 
@@ -13422,19 +12241,16 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:207
 #, fuzzy, no-c-format
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector/scalar (VSX) instructions."
 msgstr "vector/scalar (VSX) 命令を使用する"
 
 #: config/rs6000/rs6000.opt:235
 #, fuzzy, no-c-format
-#| msgid "Do not generate load/store with update instructions"
 msgid "Do not generate load/store with update instructions."
 msgstr "update 命令と一緒にロード/ストア命令を生成しない"
 
 #: config/rs6000/rs6000.opt:239
 #, fuzzy, no-c-format
-#| msgid "Generate load/store with update instructions"
 msgid "Generate load/store with update instructions."
 msgstr "update 命令と一緒にロード/ストア命令を生成する"
 
@@ -13445,19 +12261,16 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:254
 #, fuzzy, no-c-format
-#| msgid "Set start-address of the program"
 msgid "Schedule the start and end of the procedure."
 msgstr "プログラムの開始アドレスを設定する"
 
 #: config/rs6000/rs6000.opt:258
 #, fuzzy, no-c-format
-#| msgid "Return all structures in memory (AIX default)"
 msgid "Return all structures in memory (AIX default)."
 msgstr "すべての構造体をメモリ内で返す (AIX のデフォルト)"
 
 #: config/rs6000/rs6000.opt:262
 #, fuzzy, no-c-format
-#| msgid "Return small structures in registers (SVR4 default)"
 msgid "Return small structures in registers (SVR4 default)."
 msgstr "小さな構造体をレジスタ内で返す (SVR4 のデフォルト)"
 
@@ -13478,25 +12291,21 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:282
 #, fuzzy, no-c-format
-#| msgid "Do not place floating point constants in TOC"
 msgid "Do not place floating point constants in TOC."
 msgstr "TOC 内に浮動小数点定数を配置しない"
 
 #: config/rs6000/rs6000.opt:286
 #, fuzzy, no-c-format
-#| msgid "Place floating point constants in TOC"
 msgid "Place floating point constants in TOC."
 msgstr "TOC 内に浮動小数点定数を配置する"
 
 #: config/rs6000/rs6000.opt:290
 #, fuzzy, no-c-format
-#| msgid "Do not place symbol+offset constants in TOC"
 msgid "Do not place symbol+offset constants in TOC."
 msgstr "TOC 内にシンボル+オフセット定数を配置しない"
 
 #: config/rs6000/rs6000.opt:294
 #, fuzzy, no-c-format
-#| msgid "Place symbol+offset constants in TOC"
 msgid "Place symbol+offset constants in TOC."
 msgstr "TOC 内にシンボル+オフセット定数を配置する"
 
@@ -13507,25 +12316,21 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:309
 #, fuzzy, no-c-format
-#| msgid "Put everything in the regular TOC"
 msgid "Put everything in the regular TOC."
 msgstr "全てを通常 TOC 内に配置する"
 
 #: config/rs6000/rs6000.opt:313
 #, fuzzy, no-c-format
-#| msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgid "Generate VRSAVE instructions when generating AltiVec code."
 msgstr "AltiVec コードを生成しているときに VRSAVE 命令を生成する"
 
 #: config/rs6000/rs6000.opt:317
 #, fuzzy, no-c-format
-#| msgid "-mvrsave=yes/no\tDeprecated option.  Use -mvrsave/-mno-vrsave instead"
 msgid "Deprecated option.  Use -mno-vrsave instead."
 msgstr "-mvrsave=yes/no\t廃止されたオプションです。代わりに -mvrsave/-mno-vrsave を使用してください"
 
 #: config/rs6000/rs6000.opt:321
 #, fuzzy, no-c-format
-#| msgid "Deprecated.  Use -Os instead"
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "廃止されました。代わりに -Os を使用してください"
 
@@ -13546,73 +12351,61 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:337
 #, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
 msgid "Max number of bytes to compare."
 msgstr "SCoP 内のパラメータの最大数"
 
 #: config/rs6000/rs6000.opt:341
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate isel instructions."
 msgstr "isel 命令を生成する"
 
 #: config/rs6000/rs6000.opt:345
 #, fuzzy, no-c-format
-#| msgid "-mdebug=\tEnable debug output"
 msgid "-mdebug=\tEnable debug output."
 msgstr "-mdebug=\tデバッグ出力を有効にする"
 
 #: config/rs6000/rs6000.opt:349
 #, fuzzy, no-c-format
-#| msgid "Use AltiVec instructions"
 msgid "Use the AltiVec ABI extensions."
 msgstr "AltiVec 命令を使用する"
 
 #: config/rs6000/rs6000.opt:353
 #, fuzzy, no-c-format
-#| msgid "Do not use the bit-field instructions"
 msgid "Do not use the AltiVec ABI extensions."
 msgstr "ビットフィールド命令を使用しない"
 
 #: config/rs6000/rs6000.opt:357
 #, fuzzy, no-c-format
-#| msgid "Use EABI"
 msgid "Use the ELFv1 ABI."
 msgstr "EABI を使用する"
 
 #: config/rs6000/rs6000.opt:361
 #, fuzzy, no-c-format
-#| msgid "Use EABI"
 msgid "Use the ELFv2 ABI."
 msgstr "EABI を使用する"
 
 #: config/rs6000/rs6000.opt:381
 #, fuzzy, no-c-format
-#| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU."
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
 #: config/rs6000/rs6000.opt:385
 #, fuzzy, no-c-format
-#| msgid "-mtune=\tSchedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\t与えられた CPU 用のスケジュールコードを使用する"
 
 #: config/rs6000/rs6000.opt:389
 #, fuzzy, no-c-format
-#| msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
 msgstr "-mtraceback=\tトレースバック表を full、part、または no のいずれかにする"
 
 #: config/rs6000/rs6000.opt:405
 #, fuzzy, no-c-format
-#| msgid "Disable all optional instructions"
 msgid "Avoid all range limits on call instructions."
 msgstr "すべてのオプションの命令を無効にする"
 
 #: config/rs6000/rs6000.opt:413
 #, fuzzy, no-c-format
-#| msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage."
 msgstr "廃止された 'vector long ...' AltiVec 型の使用について警告する"
 
@@ -13633,13 +12426,11 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:434
 #, fuzzy, no-c-format
-#| msgid "Specify the minimum bit alignment of structures"
 msgid "Specify alignment of structure fields default/natural."
 msgstr "構造体の整列の最小ビット数を指定する"
 
 #: config/rs6000/rs6000.opt:438
 #, fuzzy, no-c-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -malign-:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -13665,13 +12456,11 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:468
 #, fuzzy, no-c-format
-#| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations."
 msgstr "文字列操作の書込み先を整列する"
 
 #: config/rs6000/rs6000.opt:472
 #, fuzzy, no-c-format
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector and scalar instructions added in ISA 2.07."
 msgstr "vector/scalar (VSX) 命令を使用する"
 
@@ -13682,13 +12471,11 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:483
 #, fuzzy, no-c-format
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "vector/scalar (VSX) 命令を使用する"
 
 #: config/rs6000/rs6000.opt:487
 #, fuzzy, no-c-format
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "複数命令のロード/ストアを生成する"
 
@@ -13729,7 +12516,6 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:523
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
 msgstr "isel 命令を生成する"
 
@@ -13740,7 +12526,6 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:531
 #, fuzzy, no-c-format
-#| msgid "Enable 32-bit multiply instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "32 ビット乗算命令を有効にする"
 
@@ -13751,37 +12536,31 @@ msgstr ""
 
 #: config/rs6000/rs6000.opt:572
 #, fuzzy, no-c-format
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use instructions added in ISA 3.1."
 msgstr "vector/scalar (VSX) 命令を使用する"
 
 #: config/rs6000/rs6000.opt:576
 #, fuzzy, no-c-format
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate (do not generate) prefixed memory instructions."
 msgstr "複数命令のロード/ストアを生成する"
 
 #: config/rs6000/rs6000.opt:580
 #, fuzzy, no-c-format
-#| msgid "Do not use unaligned memory references"
 msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "整列されていないメモリ参照を使用しない"
 
 #: config/rs6000/rs6000.opt:584
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate (do not generate) MMA instructions."
-msgstr "ビット命令を生成する"
+msgstr "複数命令のロード/ストアを生成する"
 
 #: config/rs6000/sysv4.opt:24
 #, fuzzy, no-c-format
-#| msgid "Select ABI calling convention"
 msgid "-mcall-ABI\tSelect ABI calling convention."
 msgstr "ABI 呼び出し規約を選択する"
 
 #: config/rs6000/sysv4.opt:28
 #, fuzzy, no-c-format
-#| msgid "Select method for sdata handling"
 msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
 msgstr "Select method for sdata 取り扱い用の方法を選択する"
 
@@ -13792,7 +12571,6 @@ msgstr ""
 
 #: config/rs6000/sysv4.opt:36
 #, fuzzy, no-c-format
-#| msgid "Specify bit size of immediate TLS offsets"
 msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
 msgstr "即値 TLS オフセットのビットサイズを指定する"
 
@@ -13808,19 +12586,16 @@ msgstr ""
 
 #: config/rs6000/sysv4.opt:61 config/rs6000/sysv4.opt:65
 #, fuzzy, no-c-format
-#| msgid "Produce code relocatable at runtime"
 msgid "Produce code relocatable at runtime."
 msgstr "実行時に再配置可能なコードを生成する"
 
 #: config/rs6000/sysv4.opt:69 config/rs6000/sysv4.opt:73
 #, fuzzy, no-c-format
-#| msgid "Produce little endian code"
 msgid "Produce little endian code."
 msgstr "リトルエンディアンコードを生成する"
 
 #: config/rs6000/sysv4.opt:77 config/rs6000/sysv4.opt:81
 #, fuzzy, no-c-format
-#| msgid "Produce big endian code"
 msgid "Produce big endian code."
 msgstr "ビッグエンディアンコードを生成する"
 
@@ -13828,79 +12603,66 @@ msgstr "ビッグエンディアンコードを生成する"
 #: config/rs6000/sysv4.opt:99 config/rs6000/sysv4.opt:141
 #: config/rs6000/sysv4.opt:153
 #, fuzzy, no-c-format
-#| msgid "no description yet"
 msgid "No description yet."
 msgstr "説明はまだありません"
 
 #: config/rs6000/sysv4.opt:94
 #, fuzzy, no-c-format
-#| msgid "Assume all variable arg functions are prototyped"
 msgid "Assume all variable arg functions are prototyped."
 msgstr "すべての可変引数関数がプロトタイプ宣言されていると見なす"
 
 #: config/rs6000/sysv4.opt:103
 #, fuzzy, no-c-format
-#| msgid "Use EABI"
 msgid "Use EABI."
 msgstr "EABI を使用する"
 
 #: config/rs6000/sysv4.opt:107
 #, fuzzy, no-c-format
-#| msgid "Allow bit-fields to cross word boundaries"
 msgid "Allow bit-fields to cross word boundaries."
 msgstr "ビットフィールドがワード境界をまたがることを許す"
 
 #: config/rs6000/sysv4.opt:111
 #, fuzzy, no-c-format
-#| msgid "Use alternate register names"
 msgid "Use alternate register names."
 msgstr "代替レジスタ名を使用する"
 
 #: config/rs6000/sysv4.opt:117
 #, fuzzy, no-c-format
-#| msgid "Use default method for sdata handling"
 msgid "Use default method for sdata handling."
 msgstr "デフォルトの sdata 取り扱い方法を使用する"
 
 #: config/rs6000/sysv4.opt:121
 #, fuzzy, no-c-format
-#| msgid "Link with libsim.a, libc.a and sim-crt0.o"
 msgid "Link with libsim.a, libc.a and sim-crt0.o."
 msgstr "libsim.a、libc.a および sim-crt0.o とリンクする"
 
 #: config/rs6000/sysv4.opt:125
 #, fuzzy, no-c-format
-#| msgid "Link with libads.a, libc.a and crt0.o"
 msgid "Link with libads.a, libc.a and crt0.o."
 msgstr "libads.a、libc.a および crt0.o とリンクする"
 
 #: config/rs6000/sysv4.opt:129
 #, fuzzy, no-c-format
-#| msgid "Link with libyk.a, libc.a and crt0.o"
 msgid "Link with libyk.a, libc.a and crt0.o."
 msgstr "libyk.a、libc.a および crt0.o とリンクする"
 
 #: config/rs6000/sysv4.opt:133
 #, fuzzy, no-c-format
-#| msgid "Link with libmvme.a, libc.a and crt0.o"
 msgid "Link with libmvme.a, libc.a and crt0.o."
 msgstr "libmvme.a、libc.a および crt0.o とリンクする"
 
 #: config/rs6000/sysv4.opt:137
 #, fuzzy, no-c-format
-#| msgid "Set the PPC_EMB bit in the ELF flags header"
 msgid "Set the PPC_EMB bit in the ELF flags header."
 msgstr "PPC_EMB ビットを ELF フラグヘッダ内で設定する"
 
 #: config/rs6000/sysv4.opt:157
 #, fuzzy, no-c-format
-#| msgid "Generate code to use a non-exec PLT and GOT"
 msgid "Generate code to use a non-exec PLT and GOT."
 msgstr "実行できない PLT と GOT を使用するようにコードを生成する"
 
 #: config/rs6000/sysv4.opt:161
 #, fuzzy, no-c-format
-#| msgid "Generate code for old exec BSS PLT"
 msgid "Generate code for old exec BSS PLT."
 msgstr "古い実行可能な BSS PLT 用コードを生成する"
 
@@ -13916,133 +12678,111 @@ msgstr ""
 
 #: config/alpha/alpha.opt:27
 #, fuzzy, no-c-format
-#| msgid "Use fp registers"
 msgid "Use fp registers."
 msgstr "浮動小数点レジスタを利用する"
 
 #: config/alpha/alpha.opt:35
 #, fuzzy, no-c-format
-#| msgid "Request IEEE-conformant math library routines (OSF/1)"
 msgid "Request IEEE-conformant math library routines (OSF/1)."
 msgstr "IEEE 準拠の数学ライブラリルーチン (OSF/1) を要求する"
 
 #: config/alpha/alpha.opt:39
 #, fuzzy, no-c-format
-#| msgid "Emit IEEE-conformant code, without inexact exceptions"
 msgid "Emit IEEE-conformant code, without inexact exceptions."
 msgstr "不適切な例外を除いて IEEE 準拠のコードを発行する"
 
 #: config/alpha/alpha.opt:46
 #, fuzzy, no-c-format
-#| msgid "Do not emit complex integer constants to read-only memory"
 msgid "Do not emit complex integer constants to read-only memory."
 msgstr "複素数の整数定数を読み込み専用メモリに展開させない"
 
 #: config/alpha/alpha.opt:50
 #, fuzzy, no-c-format
-#| msgid "Use VAX fp"
 msgid "Use VAX fp."
 msgstr "VAX 浮動小数点を利用する"
 
 #: config/alpha/alpha.opt:54
 #, fuzzy, no-c-format
-#| msgid "Do not use VAX fp"
 msgid "Do not use VAX fp."
 msgstr "VAX 浮動小数点を利用しない"
 
 #: config/alpha/alpha.opt:58
 #, fuzzy, no-c-format
-#| msgid "Emit code for the byte/word ISA extension"
 msgid "Emit code for the byte/word ISA extension."
 msgstr "バイト/ワード ISA 拡張用のコードを発行する"
 
 #: config/alpha/alpha.opt:62
 #, fuzzy, no-c-format
-#| msgid "Emit code for the motion video ISA extension"
 msgid "Emit code for the motion video ISA extension."
 msgstr "モーションビデオ ISA 拡張用のコードを発行する"
 
 #: config/alpha/alpha.opt:66
 #, fuzzy, no-c-format
-#| msgid "Emit code for the fp move and sqrt ISA extension"
 msgid "Emit code for the fp move and sqrt ISA extension."
 msgstr "浮動小数点 move と sqrt ISA 拡張用のコードを発行する"
 
 #: config/alpha/alpha.opt:70
 #, fuzzy, no-c-format
-#| msgid "Emit code for the counting ISA extension"
 msgid "Emit code for the counting ISA extension."
 msgstr "カウント ISA 拡張用のコードを発行する"
 
 #: config/alpha/alpha.opt:74
 #, fuzzy, no-c-format
-#| msgid "Emit code using explicit relocation directives"
 msgid "Emit code using explicit relocation directives."
 msgstr "明示的再配置指示を使用したコードを発行する"
 
 #: config/alpha/alpha.opt:78
 #, fuzzy, no-c-format
-#| msgid "Emit 16-bit relocations to the small data areas"
 msgid "Emit 16-bit relocations to the small data areas."
 msgstr "small データ領域への 16 ビット再配置を発行する"
 
 #: config/alpha/alpha.opt:82
 #, fuzzy, no-c-format
-#| msgid "Emit 32-bit relocations to the small data areas"
 msgid "Emit 32-bit relocations to the small data areas."
 msgstr "small データ領域への 32 ビット再配置を発行する"
 
 #: config/alpha/alpha.opt:86
 #, fuzzy, no-c-format
-#| msgid "Emit direct branches to local functions"
 msgid "Emit direct branches to local functions."
 msgstr "局所関数への直接分岐を発行する"
 
 #: config/alpha/alpha.opt:90
 #, fuzzy, no-c-format
-#| msgid "Emit indirect branches to local functions"
 msgid "Emit indirect branches to local functions."
 msgstr "局所関数への間接分岐を発行する"
 
 #: config/alpha/alpha.opt:94
 #, fuzzy, no-c-format
-#| msgid "Emit rdval instead of rduniq for thread pointer"
 msgid "Emit rdval instead of rduniq for thread pointer."
 msgstr "スレッドポインタ用に rduniq の代わりに rdval を発行する"
 
 #: config/alpha/alpha.opt:106
 #, fuzzy, no-c-format
-#| msgid "Use features of and schedule given CPU"
 msgid "Use features of and schedule given CPU."
 msgstr "与えられた CPU の特徴やスケジュールを利用する"
 
 #: config/alpha/alpha.opt:110
 #, fuzzy, no-c-format
-#| msgid "Schedule given CPU"
 msgid "Schedule given CPU."
 msgstr "与えられた CPU のスケジュールを使用する"
 
 #: config/alpha/alpha.opt:114
 #, fuzzy, no-c-format
-#| msgid "Control the generated fp rounding mode"
 msgid "Control the generated fp rounding mode."
 msgstr "生成された浮動小数点丸めモードを制御する"
 
 #: config/alpha/alpha.opt:118
 #, fuzzy, no-c-format
-#| msgid "Control the IEEE trap mode"
 msgid "Control the IEEE trap mode."
 msgstr "IEEE トラップモードを制御する"
 
 #: config/alpha/alpha.opt:122
 #, fuzzy, no-c-format
-#| msgid "Control the precision given to fp exceptions"
 msgid "Control the precision given to fp exceptions."
 msgstr "浮動小数点例外に与えられた精度を制御する"
 
 #: config/alpha/alpha.opt:126
 #, fuzzy, no-c-format
-#| msgid "Tune expected memory latency"
 msgid "Tune expected memory latency."
 msgstr "予期されるメモリレイテンシを調整する"
 
@@ -14053,7 +12793,6 @@ msgstr ""
 
 #: config/tilepro/tilepro.opt:28 config/tilegx/tilegx.opt:26
 #, fuzzy, no-c-format
-#| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and schedule code for given CPU."
 msgstr "-mcpu=\t与えられた CPU 用の機能とスケジュールコードを使用する"
 
@@ -14064,31 +12803,26 @@ msgstr ""
 
 #: config/lm32/lm32.opt:24
 #, fuzzy, no-c-format
-#| msgid "Enable multiply instructions"
 msgid "Enable multiply instructions."
 msgstr "乗算命令を有効にする"
 
 #: config/lm32/lm32.opt:28
 #, fuzzy, no-c-format
-#| msgid "Enable divide and modulus instructions"
 msgid "Enable divide and modulus instructions."
 msgstr "除算と剰余命令を有効にする"
 
 #: config/lm32/lm32.opt:32
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable barrel shift instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/lm32/lm32.opt:36
 #, fuzzy, no-c-format
-#| msgid "Enable sign extend instructions"
 msgid "Enable sign extend instructions."
 msgstr "符号付き拡張命令を有効にする"
 
 #: config/lm32/lm32.opt:40
 #, fuzzy, no-c-format
-#| msgid "Enable user-defined instructions"
 msgid "Enable user-defined instructions."
 msgstr "利用者定義命令を有効にする"
 
@@ -14129,7 +12863,6 @@ msgstr ""
 
 #: config/or1k/or1k.opt:51
 #, fuzzy, no-c-format
-#| msgid "Prevent the use of all hardware floating-point instructions"
 msgid "Enable generation of hardware floating point instructions. The default is -msoft-float."
 msgstr "すべてのハードウェア浮動小数点命令の使用を防止する"
 
@@ -14175,7 +12908,6 @@ msgstr ""
 
 #: config/nios2/elf.opt:26
 #, fuzzy, no-c-format
-#| msgid "Link with the fast floating-point library"
 msgid "Link with a limited version of the C library."
 msgstr "高速な浮動小数ライブラリとリンクする"
 
@@ -14201,7 +12933,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:39
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable MUL instructions."
 msgstr "clip 命令を有効にする"
 
@@ -14212,19 +12943,16 @@ msgstr ""
 
 #: config/nios2/nios2.opt:47
 #, fuzzy, no-c-format
-#| msgid "Use the software emulation for divides (default)"
 msgid "Use table based fast divide (default at -O3)."
 msgstr "ソフトウェア除算エミュレーションを使用する (デフォルト)"
 
 #: config/nios2/nios2.opt:51
 #, fuzzy, no-c-format
-#| msgid "Enable unaligned load/store instruction"
 msgid "All memory accesses use I/O load/store instructions."
 msgstr "整列されていない load/store 命令を有効にする"
 
 #: config/nios2/nios2.opt:55
 #, fuzzy, no-c-format
-#| msgid "Enable unaligned load/store instruction"
 msgid "Volatile memory accesses use I/O load/store instructions."
 msgstr "整列されていない load/store 命令を有効にする"
 
@@ -14235,7 +12963,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:63
 #, fuzzy, no-c-format
-#| msgid "unusual TP-relative address"
 msgid "Enable/disable GP-relative addressing."
 msgstr "通常ではない TP 関連アドレスです"
 
@@ -14257,14 +12984,12 @@ msgstr ""
 #: config/nios2/nios2.opt:94 config/c6x/c6x.opt:30 config/mips/mips.opt:134
 #: config/tilegx/tilegx.opt:45
 #, fuzzy, no-c-format
-#| msgid "Use big-endian byte order"
 msgid "Use big-endian byte order."
 msgstr "ビッグエンディアンのバイト順を使用する"
 
 #: config/nios2/nios2.opt:98 config/c6x/c6x.opt:34 config/mips/mips.opt:138
 #: config/tilegx/tilegx.opt:49
 #, fuzzy, no-c-format
-#| msgid "Use little-endian byte order"
 msgid "Use little-endian byte order."
 msgstr "リトルエンディアンのバイト順を使用する"
 
@@ -14275,7 +13000,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:106
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the ftruncds custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14286,7 +13010,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:114
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fextsd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14297,7 +13020,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:122
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixdu custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14308,7 +13030,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:130
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixdi custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14319,7 +13040,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:138
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixsu custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14330,7 +13050,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:146
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixsi custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14341,7 +13060,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:154
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatud custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14352,7 +13070,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:162
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatid custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14363,7 +13080,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:170
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatus custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14374,7 +13090,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:178
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatis custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14385,7 +13100,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:186
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpned custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14396,7 +13110,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:194
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpeqd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14407,7 +13120,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:202
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpged custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14418,7 +13130,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:210
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpgtd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14429,7 +13140,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:218
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpled custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14440,7 +13150,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:226
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpltd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14451,7 +13160,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:234
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the flogd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14462,7 +13170,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:242
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fexpd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14473,7 +13180,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:250
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fatand custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14484,7 +13190,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:258
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the ftand custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14495,7 +13200,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:266
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsind custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14506,7 +13210,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:274
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcosd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14517,7 +13220,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:282
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsqrtd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14528,7 +13230,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:290
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fabsd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14539,7 +13240,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:298
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fnegd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14550,7 +13250,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:306
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmaxd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14561,7 +13260,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:314
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmind custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14572,7 +13270,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:322
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fdivd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14583,7 +13280,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:330
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmuld custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14594,7 +13290,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:338
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsubd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14605,7 +13300,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:346
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the faddd custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14616,7 +13310,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:354
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpnes custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14627,7 +13320,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:362
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpeqs custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14638,7 +13330,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:370
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpges custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14649,7 +13340,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:378
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpgts custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14660,7 +13350,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:386
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmples custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14671,7 +13360,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:394
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmplts custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14682,7 +13370,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:402
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the flogs custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14693,7 +13380,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:410
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fexps custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14704,7 +13390,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:418
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fatans custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14715,7 +13400,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:426
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the ftans custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14726,7 +13410,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:434
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsins custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14737,7 +13420,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:442
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcoss custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14748,7 +13430,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:450
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsqrts custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14759,7 +13440,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:458
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fabss custom instr."
 msgstr "callt 命令を使用しない"
 
@@ -14770,7 +13450,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:466
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fnegs custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14781,7 +13460,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:474
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmaxs custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14792,7 +13470,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:482
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmins custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14803,7 +13480,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:490
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fdivs custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14814,7 +13490,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:498
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmuls custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14825,7 +13500,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:506
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsubs custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14836,7 +13510,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:514
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fadds custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14847,7 +13520,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:522
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the frdy custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14858,7 +13530,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:530
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the frdxhi custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14869,7 +13540,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:538
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the frdxlo custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14880,7 +13550,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:546
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fwry custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14891,7 +13560,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:554
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fwrx custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14902,7 +13570,6 @@ msgstr ""
 
 #: config/nios2/nios2.opt:562
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the round custom instruction."
 msgstr "callt 命令を使用しない"
 
@@ -14918,13 +13585,11 @@ msgstr ""
 
 #: config/nios2/nios2.opt:584
 #, fuzzy, no-c-format
-#| msgid "Enable saturation instructions"
 msgid "Enable generation of R2 BMX instructions."
 msgstr "飽和命令を有効にする"
 
 #: config/nios2/nios2.opt:588
 #, fuzzy, no-c-format
-#| msgid "Enable saturation instructions"
 msgid "Enable generation of R2 CDX instructions."
 msgstr "飽和命令を有効にする"
 
@@ -14965,7 +13630,6 @@ msgstr "double を 32 ビットで保存する (デフォルト)。"
 
 #: config/rx/rx.opt:37
 #, fuzzy, no-c-format
-#| msgid "Disable the use of RX FPU instructions.  "
 msgid "Disable the use of RX FPU instructions."
 msgstr "RX FPU 命令の使用を無効にする。"
 
@@ -15026,7 +13690,6 @@ msgstr ""
 
 #: config/rx/rx.opt:133
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the LRA register allocator."
 msgstr "短い load 命令の使用を有効にする"
 
@@ -15042,43 +13705,36 @@ msgstr ""
 
 #: config/visium/visium.opt:25
 #, fuzzy, no-c-format
-#| msgid "Link with libyk.a, libc.a and crt0.o"
 msgid "Link with libc.a and libdebug.a."
 msgstr "libyk.a、libc.a および crt0.o とリンクする"
 
 #: config/visium/visium.opt:29
 #, fuzzy, no-c-format
-#| msgid "Link with libsim.a, libc.a and sim-crt0.o"
 msgid "Link with libc.a and libsim.a."
 msgstr "libsim.a、libc.a および sim-crt0.o とリンクする"
 
 #: config/visium/visium.opt:33
 #, fuzzy, no-c-format
-#| msgid "Use hardware FP"
 msgid "Use hardware FP (default)."
 msgstr "ハードウェア浮動小数点を使用する"
 
 #: config/visium/visium.opt:45
 #, fuzzy, no-c-format
-#| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "与えられた CPU 用の機能とスケジュールコードを利用する"
 
 #: config/visium/visium.opt:65
 #, fuzzy, no-c-format
-#| msgid "Generate code for the Android platform."
 msgid "Generate code for the supervisor mode (default)."
 msgstr "Android プラットフォーム用コードを生成する。"
 
 #: config/visium/visium.opt:69
 #, fuzzy, no-c-format
-#| msgid "Generate code for the Boehm GC"
 msgid "Generate code for the user mode."
 msgstr "Boehm GC 用コードを生成する"
 
 #: config/visium/visium.opt:73
 #, fuzzy, no-c-format
-#| msgid "Does nothing. Preserved for backward compatibility."
 msgid "Only retained for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
@@ -15089,49 +13745,41 @@ msgstr ""
 
 #: config/sol2.opt:36
 #, fuzzy, no-c-format
-#| msgid "Pass -z text to linker"
 msgid "Pass -z text to linker."
 msgstr "-z text をリンカに渡す"
 
 #: config/moxie/moxie.opt:31
 #, fuzzy, no-c-format
-#| msgid "Enable sign extend instructions"
 msgid "Enable MUL.X and UMUL.X instructions."
 msgstr "符号付き拡張命令を有効にする"
 
 #: config/microblaze/microblaze.opt:40
 #, fuzzy, no-c-format
-#| msgid "Use software emulation for floating point (default)"
 msgid "Use software emulation for floating point (default)."
 msgstr "浮動小数点用にソフトウェアエミュレーションを使用する (デフォルト)"
 
 #: config/microblaze/microblaze.opt:44
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point instructions"
 msgid "Use hardware floating point instructions."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
 #: config/microblaze/microblaze.opt:48
 #, fuzzy, no-c-format
-#| msgid "Use table lookup optimization for small signed integer divisions"
 msgid "Use table lookup optimization for small signed integer divisions."
 msgstr "小さな符号付き除算で表探査による最適化を使用する"
 
 #: config/microblaze/microblaze.opt:52
 #, fuzzy, no-c-format
-#| msgid "-mcpu=PROCESSOR\t\tUse features of and schedule code for given CPU"
 msgid "-mcpu=PROCESSOR\t\tUse features of and schedule code for given CPU."
 msgstr "-mcpu=PROCESSOR\t\t与えられた CPU 用の機能とスケジュールされたコードを使用する"
 
 #: config/microblaze/microblaze.opt:56
 #, fuzzy, no-c-format
-#| msgid "Don't optimize block moves, use memcpy"
 msgid "Don't optimize block moves, use memcpy."
 msgstr "ブロック移動を最適化せず、memcpy を使用する"
 
 #: config/microblaze/microblaze.opt:68
 #, fuzzy, no-c-format
-#| msgid "Use the soft multiply emulation (default)"
 msgid "Use the soft multiply emulation (default)."
 msgstr "ソフトウェア乗算エミュレーションを使用する (デフォルト)"
 
@@ -15142,7 +13790,6 @@ msgstr ""
 
 #: config/microblaze/microblaze.opt:76
 #, fuzzy, no-c-format
-#| msgid "Use the software emulation for divides (default)"
 msgid "Use the software emulation for divides (default)."
 msgstr "ソフトウェア除算エミュレーションを使用する (デフォルト)"
 
@@ -15153,19 +13800,16 @@ msgstr ""
 
 #: config/microblaze/microblaze.opt:84
 #, fuzzy, no-c-format
-#| msgid "Use pattern compare instructions"
 msgid "Use pattern compare instructions."
 msgstr "パターン比較命令を使用する"
 
 #: config/microblaze/microblaze.opt:88
 #, fuzzy, no-c-format
-#| msgid "Check for stack overflow at runtime"
 msgid "Check for stack overflow at runtime."
 msgstr "実行時にスタックオーバーフローを検査する"
 
 #: config/microblaze/microblaze.opt:92 config/iq2000/iq2000.opt:65
 #, fuzzy, no-c-format
-#| msgid "Use GP relative sdata/sbss sections"
 msgid "Use GP relative sdata/sbss sections."
 msgstr "GP 関連 sdata/sbss セクションを使用する"
 
@@ -15181,13 +13825,11 @@ msgstr ""
 
 #: config/microblaze/microblaze.opt:104
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point conversion instructions"
 msgid "Use hardware floating point conversion instructions."
 msgstr "ハードウェア浮動小数点変換命令を使用する"
 
 #: config/microblaze/microblaze.opt:108
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point square root instruction"
 msgid "Use hardware floating point square root instruction."
 msgstr "ハードウェア浮動小数点二乗根命令を使用する"
 
@@ -15213,7 +13855,6 @@ msgstr ""
 
 #: config/microblaze/microblaze.opt:128
 #, fuzzy, no-c-format
-#| msgid "Use hardware quad FP instructions"
 msgid "Use hardware prefetch instruction."
 msgstr "ハードウェア四倍精度浮動小数点命令を使用する"
 
@@ -15224,37 +13865,31 @@ msgstr ""
 
 #: config/vax/vax.opt:23 config/vax/vax.opt:27
 #, fuzzy, no-c-format
-#| msgid "Target DFLOAT double precision code"
 msgid "Target DFLOAT double precision code."
 msgstr "DFLOAT 倍精度コードをターゲットとする"
 
 #: config/vax/vax.opt:31 config/vax/vax.opt:35
 #, fuzzy, no-c-format
-#| msgid "Generate GFLOAT double precision code"
 msgid "Generate GFLOAT double precision code."
 msgstr "GFLOAT 倍精度コードを生成する"
 
 #: config/vax/vax.opt:39
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU assembler (gas)"
 msgid "Generate code for GNU assembler (gas)."
 msgstr "GNU アセンブラ (gas) 用のコードを生成する"
 
 #: config/vax/vax.opt:43
 #, fuzzy, no-c-format
-#| msgid "Generate code for UNIX assembler"
 msgid "Generate code for UNIX assembler."
 msgstr "UNIX アセンブラ用のコードを生成する"
 
 #: config/vax/vax.opt:47
 #, fuzzy, no-c-format
-#| msgid "Use VAXC structure conventions"
 msgid "Use VAXC structure conventions."
 msgstr "VAXC 構造体規約を使用する"
 
 #: config/vax/vax.opt:51
 #, fuzzy, no-c-format
-#| msgid "Use new adddi3/subdi3 patterns"
 msgid "Use new adddi3/subdi3 patterns."
 msgstr "新しい adddi3/subdi3 パターンを使用する"
 
@@ -15270,49 +13905,41 @@ msgstr ""
 
 #: config/frv/frv.opt:38
 #, fuzzy, no-c-format
-#| msgid "Enable label alignment optimizations"
 msgid "Enable label alignment optimizations."
 msgstr "ラベル整列最適化を有効にする"
 
 #: config/frv/frv.opt:42
 #, fuzzy, no-c-format
-#| msgid "Dynamically allocate cc registers"
 msgid "Dynamically allocate cc registers."
 msgstr "cc レジスタを動的に割り当てる"
 
 #: config/frv/frv.opt:49
 #, fuzzy, no-c-format
-#| msgid "Set the cost of branches"
 msgid "Set the cost of branches."
 msgstr "分岐コストを設定する"
 
 #: config/frv/frv.opt:53
 #, fuzzy, no-c-format
-#| msgid "Enable conditional execution other than moves/scc"
 msgid "Enable conditional execution other than moves/scc."
 msgstr "moves/scc 以外で条件付き実行を有効にする"
 
 #: config/frv/frv.opt:57
 #, fuzzy, no-c-format
-#| msgid "Change the maximum length of conditionally-executed sequences"
 msgid "Change the maximum length of conditionally-executed sequences."
 msgstr "条件付き実行シーケンスの長さの最大値を変更する"
 
 #: config/frv/frv.opt:61
 #, fuzzy, no-c-format
-#| msgid "Change the number of temporary registers that are available to conditionally-executed sequences"
 msgid "Change the number of temporary registers that are available to conditionally-executed sequences."
 msgstr "条件付き実行シーケンスで利用できる一時レジスタの数を変更する"
 
 #: config/frv/frv.opt:65
 #, fuzzy, no-c-format
-#| msgid "Enable conditional moves"
 msgid "Enable conditional moves."
 msgstr "条件付き move を有効にする"
 
 #: config/frv/frv.opt:69
 #, fuzzy, no-c-format
-#| msgid "Set the target CPU type"
 msgid "Set the target CPU type."
 msgstr "ターゲットの CPU 型を設定する"
 
@@ -15323,55 +13950,46 @@ msgstr ""
 
 #: config/frv/frv.opt:122
 #, fuzzy, no-c-format
-#| msgid "Use fp double instructions"
 msgid "Use fp double instructions."
 msgstr "倍精度浮動小数命令を有効にする"
 
 #: config/frv/frv.opt:126
 #, fuzzy, no-c-format
-#| msgid "Change the ABI to allow double word insns"
 msgid "Change the ABI to allow double word insns."
 msgstr "二倍ワード命令を許可するように ABI を変更する"
 
 #: config/frv/frv.opt:134
 #, fuzzy, no-c-format
-#| msgid "Just use icc0/fcc0"
 msgid "Just use icc0/fcc0."
 msgstr "icc0/fcc0 だけ使用する"
 
 #: config/frv/frv.opt:138
 #, fuzzy, no-c-format
-#| msgid "Only use 32 FPRs"
 msgid "Only use 32 FPRs."
 msgstr "32 個の浮動小数点レジスタ (FPR) のみ使用する"
 
 #: config/frv/frv.opt:142
 #, fuzzy, no-c-format
-#| msgid "Use 64 FPRs"
 msgid "Use 64 FPRs."
 msgstr "64 個の浮動小数点レジスタ (FPR) を使用する"
 
 #: config/frv/frv.opt:146
 #, fuzzy, no-c-format
-#| msgid "Only use 32 GPRs"
 msgid "Only use 32 GPRs."
 msgstr "32 個の汎用レジスタ (GPR) のみ使用する"
 
 #: config/frv/frv.opt:150
 #, fuzzy, no-c-format
-#| msgid "Use 64 GPRs"
 msgid "Use 64 GPRs."
 msgstr "64 個の汎用レジスタ (GPR) を使用する"
 
 #: config/frv/frv.opt:154
 #, fuzzy, no-c-format
-#| msgid "Enable use of GPREL for read-only data in FDPIC"
 msgid "Enable use of GPREL for read-only data in FDPIC."
 msgstr "FDPIC 内の読み取り専用データ用 GPREL の使用を有効にする"
 
 #: config/frv/frv.opt:166
 #, fuzzy, no-c-format
-#| msgid "Enable PIC support for building libraries"
 msgid "Enable PIC support for building libraries."
 msgstr "ライブラリ構築用に PIC サポートを有効にする"
 
@@ -15382,55 +14000,46 @@ msgstr ""
 
 #: config/frv/frv.opt:174
 #, fuzzy, no-c-format
-#| msgid "Disallow direct calls to global functions"
 msgid "Disallow direct calls to global functions."
 msgstr "大域関数の直接呼び出しを無効にする"
 
 #: config/frv/frv.opt:178
 #, fuzzy, no-c-format
-#| msgid "Use media instructions"
 msgid "Use media instructions."
 msgstr "media 命令を使用する"
 
 #: config/frv/frv.opt:182
 #, fuzzy, no-c-format
-#| msgid "Enable multiply instructions"
 msgid "Use multiply add/subtract instructions."
 msgstr "乗算命令を有効にする"
 
 #: config/frv/frv.opt:186
 #, fuzzy, no-c-format
-#| msgid "Enable optimizing &&/|| in conditional execution"
 msgid "Enable optimizing &&/|| in conditional execution."
 msgstr "条件付き実行内にある &&/|| の最適化を有効にする"
 
 #: config/frv/frv.opt:190
 #, fuzzy, no-c-format
-#| msgid "Enable nested conditional execution optimizations"
 msgid "Enable nested conditional execution optimizations."
 msgstr "入れ子にされた条件付き実行の最適化を有効にする"
 
 #: config/frv/frv.opt:195
 #, fuzzy, no-c-format
-#| msgid "Do not mark ABI switches in e_flags"
 msgid "Do not mark ABI switches in e_flags."
 msgstr "e_flags 内の ABI スイッチをマークしない"
 
 #: config/frv/frv.opt:199
 #, fuzzy, no-c-format
-#| msgid "Remove redundant membars"
 msgid "Remove redundant membars."
 msgstr "冗長なメンバを削除する"
 
 #: config/frv/frv.opt:203
 #, fuzzy, no-c-format
-#| msgid "Use AltiVec instructions"
 msgid "Pack VLIW instructions."
 msgstr "AltiVec 命令を使用する"
 
 #: config/frv/frv.opt:207
 #, fuzzy, no-c-format
-#| msgid "Enable setting GPRs to the result of comparisons"
 msgid "Enable setting GPRs to the result of comparisons."
 msgstr "比較結果を汎用レジスタに設定することを有効にする"
 
@@ -15441,13 +14050,11 @@ msgstr ""
 
 #: config/frv/frv.opt:219
 #, fuzzy, no-c-format
-#| msgid "Assume a large TLS segment"
 msgid "Assume a large TLS segment."
 msgstr "大きな TLS セグメントであると見なす"
 
 #: config/frv/frv.opt:223
 #, fuzzy, no-c-format
-#| msgid "Do not assume a large TLS segment"
 msgid "Do not assume a large TLS segment."
 msgstr "大きな TLS セグメントであると見なさない"
 
@@ -15458,43 +14065,36 @@ msgstr ""
 
 #: config/frv/frv.opt:233
 #, fuzzy, no-c-format
-#| msgid "Link with the library-pic libraries"
 msgid "Link with the library-pic libraries."
 msgstr "library-pic ライブラリとリンクする"
 
 #: config/frv/frv.opt:237
 #, fuzzy, no-c-format
-#| msgid "Allow gcc to use the repeat/erepeat instructions"
 msgid "Allow branches to be packed with other instructions."
 msgstr "gcc が repeat/erepeat 命令を使用することを許可する"
 
 #: config/mn10300/mn10300.opt:30
 #, fuzzy, no-c-format
-#| msgid "Target the AM33 processor"
 msgid "Target the AM33 processor."
 msgstr "AM33 プロセッサをターゲットとする"
 
 #: config/mn10300/mn10300.opt:34
 #, fuzzy, no-c-format
-#| msgid "Target the AM33/2.0 processor"
 msgid "Target the AM33/2.0 processor."
 msgstr "AM33/2.0 プロセッサをターゲットとする"
 
 #: config/mn10300/mn10300.opt:38
 #, fuzzy, no-c-format
-#| msgid "Target the AM34 processor"
 msgid "Target the AM34 processor."
 msgstr "AM34 プロセッサをターゲットとする"
 
 #: config/mn10300/mn10300.opt:46
 #, fuzzy, no-c-format
-#| msgid "Work around hardware multiply bug"
 msgid "Work around hardware multiply bug."
 msgstr "ハードウェア乗算バグを回避する"
 
 #: config/mn10300/mn10300.opt:55
 #, fuzzy, no-c-format
-#| msgid "Enable linker relaxations"
 msgid "Enable linker relaxations."
 msgstr "リンカの緩和を有効にする"
 
@@ -15505,13 +14105,11 @@ msgstr ""
 
 #: config/mn10300/mn10300.opt:63
 #, fuzzy, no-c-format
-#| msgid "Allow gcc to generate LIW instructions"
 msgid "Allow gcc to generate LIW instructions."
 msgstr "gcc が LIW 命令を生成することを許可する"
 
 #: config/mn10300/mn10300.opt:67
 #, fuzzy, no-c-format
-#| msgid "Allow gcc to generate LIW instructions"
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "gcc が LIW 命令を生成することを許可する"
 
@@ -15527,25 +14125,21 @@ msgstr ""
 
 #: config/nds32/nds32.opt:29 config/nds32/nds32.opt:89
 #, fuzzy, no-c-format
-#| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "ビッグエンディアンモードでコードを生成する"
 
 #: config/nds32/nds32.opt:33 config/nds32/nds32.opt:93
 #, fuzzy, no-c-format
-#| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "リトルエンディアンモードでコードを生成する"
 
 #: config/nds32/nds32.opt:37
 #, fuzzy, no-c-format
-#| msgid "Perform cross-jumping optimization"
 msgid "Force performing fp-as-gp optimization."
 msgstr "ジャンプをまたがった最適化を行う"
 
 #: config/nds32/nds32.opt:41
 #, fuzzy, no-c-format
-#| msgid "Perform cross-jumping optimization"
 msgid "Forbid performing fp-as-gp optimization."
 msgstr "ジャンプをまたがった最適化を行う"
 
@@ -15566,13 +14160,11 @@ msgstr ""
 
 #: config/nds32/nds32.opt:71
 #, fuzzy, no-c-format
-#| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
 #: config/nds32/nds32.opt:75
 #, fuzzy, no-c-format
-#| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
@@ -15603,55 +14195,46 @@ msgstr ""
 
 #: config/nds32/nds32.opt:109
 #, fuzzy, no-c-format
-#| msgid "invalid __fp16 format option: -mfp16-format=%s"
 msgid "Known cmodel types (for use with the -mict-model= option):"
 msgstr "無効な __fp16 書式オプションです: -mfp16-format=%s"
 
 #: config/nds32/nds32.opt:119
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate conditional move instructions."
 msgstr "ビット命令を生成する"
 
 #: config/nds32/nds32.opt:123
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate hardware abs instructions."
 msgstr "ビット命令を生成する"
 
 #: config/nds32/nds32.opt:127
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate performance extension instructions."
 msgstr "ビット命令を生成する"
 
 #: config/nds32/nds32.opt:131
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point conversion instructions"
 msgid "Generate performance extension version 2 instructions."
 msgstr "ハードウェア浮動小数点変換命令を使用する"
 
 #: config/nds32/nds32.opt:135
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate string extension instructions."
 msgstr "ビット命令を生成する"
 
 #: config/nds32/nds32.opt:139
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate DSP extension instructions."
 msgstr "ビット命令を生成する"
 
 #: config/nds32/nds32.opt:143
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "isel 命令を生成する"
 
 #: config/nds32/nds32.opt:147
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate 16-bit instructions."
 msgstr "ビット命令を生成する"
 
@@ -15662,7 +14245,6 @@ msgstr ""
 
 #: config/nds32/nds32.opt:155
 #, fuzzy, no-c-format
-#| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
 msgstr "複数コアサポートを有効にする"
 
@@ -15688,7 +14270,6 @@ msgstr ""
 
 #: config/nds32/nds32.opt:197
 #, fuzzy, no-c-format
-#| msgid "Specify the register allocation order"
 msgid "Specify the cpu for pipeline model."
 msgstr "レジスタ確保順を指定する"
 
@@ -15719,13 +14300,11 @@ msgstr ""
 
 #: config/nds32/nds32.opt:425
 #, fuzzy, no-c-format
-#| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "すべてのコンストラクタとデストラクタが非公開の場合に警告する"
 
 #: config/nds32/nds32.opt:429
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "isel 命令を生成する"
 
@@ -15736,13 +14315,11 @@ msgstr "浮動小数の乗算/加算命令を生成する"
 
 #: config/nds32/nds32.opt:437
 #, fuzzy, no-c-format
-#| msgid "Generate code that uses 68881 floating-point instructions"
 msgid "Generate single-precision floating-point instructions."
 msgstr "68881 浮動小数点命令を使用したコードを生成する"
 
 #: config/nds32/nds32.opt:441
 #, fuzzy, no-c-format
-#| msgid "Generate code that uses 68881 floating-point instructions"
 msgid "Generate double-precision floating-point instructions."
 msgstr "68881 浮動小数点命令を使用したコードを生成する"
 
@@ -15753,13 +14330,11 @@ msgstr ""
 
 #: config/nds32/nds32.opt:449
 #, fuzzy, no-c-format
-#| msgid "Permit scheduling of a function's prologue sequence"
 msgid "Permit scheduling of a function's prologue and epilogue sequence."
 msgstr "関数のプロローグシーケンスのスケジューリングを許す"
 
 #: config/nds32/nds32.opt:453
 #, fuzzy, no-c-format
-#| msgid "Generate cld instruction in the function prologue."
 msgid "Generate return instruction in naked function."
 msgstr "関数プロローグ内で cld 命令を生成する"
 
@@ -15775,13 +14350,11 @@ msgstr ""
 
 #: config/iq2000/iq2000.opt:31
 #, fuzzy, no-c-format
-#| msgid "Specify CPU for code generation purposes"
 msgid "Specify CPU for code generation purposes."
 msgstr "コード生成用 CPU を指定する"
 
 #: config/iq2000/iq2000.opt:47
 #, fuzzy, no-c-format
-#| msgid "Specify CPU for scheduling purposes"
 msgid "Specify CPU for scheduling purposes."
 msgstr "スケジュール用 CPU を指定する"
 
@@ -15792,133 +14365,111 @@ msgstr ""
 
 #: config/iq2000/iq2000.opt:61 config/mips/mips.opt:142
 #, fuzzy, no-c-format
-#| msgid "Use ROM instead of RAM"
 msgid "Use ROM instead of RAM."
 msgstr "RAM の代わりに ROM を使用する"
 
 #: config/iq2000/iq2000.opt:70
 #, fuzzy, no-c-format
-#| msgid "No default crt0.o"
 msgid "No default crt0.o."
 msgstr "crt0.o をデフォルトとしない"
 
 #: config/iq2000/iq2000.opt:74 config/mips/mips.opt:409
 #, fuzzy, no-c-format
-#| msgid "Put uninitialized constants in ROM (needs -membedded-data)"
 msgid "Put uninitialized constants in ROM (needs -membedded-data)."
 msgstr "未初期化定数を ROM に置く(-membedded-data が必要)"
 
 #: config/csky/csky.opt:34
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target architecture"
 msgid "Specify the target architecture."
 msgstr "ターゲットアーキテクチャの名前を指定する"
 
 #: config/csky/csky.opt:38
 #, fuzzy, no-c-format
-#| msgid "Specify the target CPU"
 msgid "Specify the target processor."
 msgstr "ターゲット CPU を指定する"
 
 #: config/csky/csky.opt:61
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point instructions"
 msgid "Enable hardware floating-point instructions."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
 #: config/csky/csky.opt:65
 #, fuzzy, no-c-format
-#| msgid "Use software emulation for floating point (default)"
 msgid "Use library calls to perform floating-point operations (default)."
 msgstr "浮動小数点用にソフトウェアエミュレーションを使用する (デフォルト)"
 
 #: config/csky/csky.opt:69
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify the target floating-point hardware/format."
 msgstr "ターゲット浮動小数点ハードウェア/形式の名前を指定する"
 
 #: config/csky/csky.opt:73
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in default format"
 msgid "Generate C-SKY FPU double float instructions (default for hard float)."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
 #: config/csky/csky.opt:77
 #, fuzzy, no-c-format
-#| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate frecipd/fsqrtd/fdivd instructions (default for hard float)."
 msgstr "ループ内の配列で、可能であればプリフェッチ命令を生成する"
 
 #: config/csky/csky.opt:85
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Enable the extended LRW instruction (default for CK801)."
 msgstr "callt 命令を使用しない"
 
 #: config/csky/csky.opt:89
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable interrupt stack instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:93
 #, fuzzy, no-c-format
-#| msgid "Enable multiply instructions"
 msgid "Enable multiprocessor instructions."
 msgstr "乗算命令を有効にする"
 
 #: config/csky/csky.opt:97
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable coprocessor instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:101
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable cache prefetch instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:105
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable C-SKY SECURE instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:112
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable C-SKY TRUST instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:116
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable C-SKY DSP instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:120
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable C-SKY Enhanced DSP instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:124
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable C-SKY Vector DSP instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/csky/csky.opt:130
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate divide instructions."
 msgstr "isel 命令を生成する"
 
 #: config/csky/csky.opt:134
 #, fuzzy, no-c-format
-#| msgid "Generate code for a 5206e"
 msgid "Generate code for Smart Mode."
 msgstr "5206e 用のコードを生成する"
 
@@ -15929,19 +14480,16 @@ msgstr ""
 
 #: config/csky/csky.opt:142
 #, fuzzy, no-c-format
-#| msgid "Generate code in little endian mode"
 msgid "Generate code using global anchor symbol addresses."
 msgstr "リトルエンディアンモードでコードを生成する"
 
 #: config/csky/csky.opt:146
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate push/pop instructions (default)."
 msgstr "isel 命令を生成する"
 
 #: config/csky/csky.opt:150
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate stm/ldm instructions (default)."
 msgstr "isel 命令を生成する"
 
@@ -15952,43 +14500,36 @@ msgstr ""
 
 #: config/csky/csky.opt:161
 #, fuzzy, no-c-format
-#| msgid "Do not generate .size directives"
 msgid "Emit .stack_size directives."
 msgstr ".size 指示を生成しない"
 
 #: config/csky/csky.opt:165
 #, fuzzy, no-c-format
-#| msgid "Generate code for GNU runtime environment"
 msgid "Generate code for C-SKY compiler runtime instead of libgcc."
 msgstr "GNU 実行環境用のコードを生成する"
 
 #: config/csky/csky.opt:169
 #, fuzzy, no-c-format
-#| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
 msgid "Set the branch costs to roughly the specified number of instructions."
 msgstr "-mbranch-cost=COST\t分岐コストを大体 COST 命令分に設定する"
 
 #: config/csky/csky.opt:173
 #, fuzzy, no-c-format
-#| msgid "Permit scheduling of a function's prologue sequence"
 msgid "Permit scheduling of function prologue and epilogue sequences."
 msgstr "関数のプロローグシーケンスのスケジューリングを許す"
 
 #: config/csky/csky_tables.opt:24
 #, fuzzy, no-c-format
-#| msgid "invalid __fp16 format option: -mfp16-format=%s"
 msgid "Known CSKY CPUs (for use with the -mcpu= options):"
 msgstr "無効な __fp16 書式オプションです: -mfp16-format=%s"
 
 #: config/csky/csky_tables.opt:199
 #, fuzzy, no-c-format
-#| msgid "invalid __fp16 format option: -mfp16-format=%s"
 msgid "Known CSKY architectures (for use with the -march= option):"
 msgstr "無効な __fp16 書式オプションです: -mfp16-format=%s"
 
 #: config/csky/csky_tables.opt:218
 #, fuzzy, no-c-format
-#| msgid "invalid __fp16 format option: -mfp16-format=%s"
 msgid "Known CSKY FPUs (for use with the -mfpu= option):"
 msgstr "無効な __fp16 書式オプションです: -mfp16-format=%s"
 
@@ -15999,19 +14540,16 @@ msgstr ""
 
 #: config/c6x/c6x.opt:42
 #, fuzzy, no-c-format
-#| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
 msgstr "Select method for sdata 取り扱い用の方法を選択する"
 
 #: config/c6x/c6x.opt:46
 #, fuzzy, no-c-format
-#| msgid "unrecognized argument '%s' to -mcpu= option"
 msgid "Valid arguments for the -msdata= option:"
 msgstr "-mcpu= オプションへの認識出来ない引数 '%s' です"
 
 #: config/c6x/c6x.opt:59
 #, fuzzy, no-c-format
-#| msgid "Create a shared library"
 msgid "Compile for the DSBT shared library ABI."
 msgstr "共有ライブラリを作成する"
 
@@ -16022,73 +14560,61 @@ msgstr ""
 
 #: config/cris/cris.opt:45
 #, fuzzy, no-c-format
-#| msgid "Work around bug in multiplication instruction"
 msgid "Work around bug in multiplication instruction."
 msgstr "乗算命令内のバグを回避する"
 
 #: config/cris/cris.opt:51
 #, fuzzy, no-c-format
-#| msgid "Compile for ETRAX 4 (CRIS v3)"
 msgid "Compile for ETRAX 4 (CRIS v3)."
 msgstr "ETRAX 4 (CRIS v3) 用にコンパイルする"
 
 #: config/cris/cris.opt:56
 #, fuzzy, no-c-format
-#| msgid "Compile for ETRAX 100 (CRIS v8)"
 msgid "Compile for ETRAX 100 (CRIS v8)."
 msgstr "ETRAX 100 (CRIS v8) 用にコンパイルする"
 
 #: config/cris/cris.opt:64
 #, fuzzy, no-c-format
-#| msgid "Emit verbose debug information in assembly code"
 msgid "Emit verbose debug information in assembly code."
 msgstr "アセンブラコード内に冗長でバッグ情報を発行する"
 
 #: config/cris/cris.opt:71
 #, fuzzy, no-c-format
-#| msgid "Do not use the callt instruction"
 msgid "Do not use condition codes from normal instructions."
 msgstr "callt 命令を使用しない"
 
 #: config/cris/cris.opt:80
 #, fuzzy, no-c-format
-#| msgid "Do not use direct addressing mode for soft registers"
 msgid "Do not emit addressing modes with side-effect assignment."
 msgstr "ソフトレジスタ用に直接アドレスモードを使用しない"
 
 #: config/cris/cris.opt:89
 #, fuzzy, no-c-format
-#| msgid "Do not tune stack alignment"
 msgid "Do not tune stack alignment."
 msgstr "スタック整列を調整しない"
 
 #: config/cris/cris.opt:98
 #, fuzzy, no-c-format
-#| msgid "Do not tune writable data alignment"
 msgid "Do not tune writable data alignment."
 msgstr "書き込み可能データ整列を調整しない"
 
 #: config/cris/cris.opt:107
 #, fuzzy, no-c-format
-#| msgid "Do not tune code and read-only data alignment"
 msgid "Do not tune code and read-only data alignment."
 msgstr "コードと読み取り専用データ整列を調整しない"
 
 #: config/cris/cris.opt:116
 #, fuzzy, no-c-format
-#| msgid "Align code and data to 32 bits"
 msgid "Align code and data to 32 bits."
 msgstr "コードとデータを 32 ビットに整列する"
 
 #: config/cris/cris.opt:133
 #, fuzzy, no-c-format
-#| msgid "Don't align items in code or data"
 msgid "Don't align items in code or data."
 msgstr "コードまたはデータ内の要素を整列しない"
 
 #: config/cris/cris.opt:142
 #, fuzzy, no-c-format
-#| msgid "Do not emit function prologue or epilogue"
 msgid "Do not emit function prologue or epilogue."
 msgstr "関数プロローグまたはエピローグを発行しない"
 
@@ -16099,25 +14625,21 @@ msgstr ""
 
 #: config/cris/cris.opt:158
 #, fuzzy, no-c-format
-#| msgid "Override -mbest-lib-options"
 msgid "Override -mbest-lib-options."
 msgstr "-mbest-lib-options を上書きする"
 
 #: config/cris/cris.opt:165
 #, fuzzy, no-c-format
-#| msgid "-march=ARCH\tGenerate code for the specified chip or CPU version"
 msgid "-march=ARCH\tGenerate code for the specified chip or CPU version."
 msgstr "-march=ARCH\t指定したチップまたは CPU バージョン用のコードを生成する"
 
 #: config/cris/cris.opt:169
 #, fuzzy, no-c-format
-#| msgid "-mtune=ARCH\tTune alignment for the specified chip or CPU version"
 msgid "-mtune=ARCH\tTune alignment for the specified chip or CPU version."
 msgstr "-mtune=ARCH\t指定したチップまたは CPU 用に整列を調整する"
 
 #: config/cris/cris.opt:173
 #, fuzzy, no-c-format
-#| msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size"
 msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size."
 msgstr "-mmax-stackframe=SIZE\tスタックフレームが指定したサイズより大きい場合に警告する"
 
@@ -16148,115 +14670,96 @@ msgstr "実行時名。"
 
 #: config/sh/sh.opt:42
 #, fuzzy, no-c-format
-#| msgid "Generate SH1 code"
 msgid "Generate SH1 code."
 msgstr "SH1 コードを生成する"
 
 #: config/sh/sh.opt:46
 #, fuzzy, no-c-format
-#| msgid "Generate SH2 code"
 msgid "Generate SH2 code."
 msgstr "SH2 コードを生成する"
 
 #: config/sh/sh.opt:50
 #, fuzzy, no-c-format
-#| msgid "Generate default double-precision SH2a-FPU code"
 msgid "Generate default double-precision SH2a-FPU code."
 msgstr "デフォルトで倍精度 SH2a-FPU コードを生成する"
 
 #: config/sh/sh.opt:54
 #, fuzzy, no-c-format
-#| msgid "Generate SH2a FPU-less code"
 msgid "Generate SH2a FPU-less code."
 msgstr "FPU が無い SH2a 用のコードを生成する"
 
 #: config/sh/sh.opt:58
 #, fuzzy, no-c-format
-#| msgid "Generate default single-precision SH2a-FPU code"
 msgid "Generate default single-precision SH2a-FPU code."
 msgstr "デフォルトで単精度 SH2a-FPU コードを生成する"
 
 #: config/sh/sh.opt:62
 #, fuzzy, no-c-format
-#| msgid "Generate only single-precision SH2a-FPU code"
 msgid "Generate only single-precision SH2a-FPU code."
 msgstr "単精度 SH2a-FPU コードのみを生成する"
 
 #: config/sh/sh.opt:66
 #, fuzzy, no-c-format
-#| msgid "Generate SH2e code"
 msgid "Generate SH2e code."
 msgstr "SH2e コードを生成する"
 
 #: config/sh/sh.opt:70
 #, fuzzy, no-c-format
-#| msgid "Generate SH3 code"
 msgid "Generate SH3 code."
 msgstr "SH3 用コードを生成する"
 
 #: config/sh/sh.opt:74
 #, fuzzy, no-c-format
-#| msgid "Generate SH3e code"
 msgid "Generate SH3e code."
 msgstr "SH3e コードを生成する"
 
 #: config/sh/sh.opt:78
 #, fuzzy, no-c-format
-#| msgid "Generate SH4 code"
 msgid "Generate SH4 code."
 msgstr "SH4 コードを生成する"
 
 #: config/sh/sh.opt:82
 #, fuzzy, no-c-format
-#| msgid "Generate SH4-100 code"
 msgid "Generate SH4-100 code."
 msgstr "SH4-100 コードを生成する"
 
 #: config/sh/sh.opt:86
 #, fuzzy, no-c-format
-#| msgid "Generate SH4-200 code"
 msgid "Generate SH4-200 code."
 msgstr "SH4-200 コードを生成する"
 
 #: config/sh/sh.opt:92
 #, fuzzy, no-c-format
-#| msgid "Generate SH4-300 code"
 msgid "Generate SH4-300 code."
 msgstr "SH4-300 コードを生成する"
 
 #: config/sh/sh.opt:96
 #, fuzzy, no-c-format
-#| msgid "Generate SH4 FPU-less code"
 msgid "Generate SH4 FPU-less code."
 msgstr "FPU 無しの SH4 コードを生成する"
 
 #: config/sh/sh.opt:100
 #, fuzzy, no-c-format
-#| msgid "Generate SH4-100 FPU-less code"
 msgid "Generate SH4-100 FPU-less code."
 msgstr "FPU 無しの SH4-100 コードを生成する"
 
 #: config/sh/sh.opt:104
 #, fuzzy, no-c-format
-#| msgid "Generate SH4-200 FPU-less code"
 msgid "Generate SH4-200 FPU-less code."
 msgstr "FPU 無しの SH4-200 コードを生成する"
 
 #: config/sh/sh.opt:108
 #, fuzzy, no-c-format
-#| msgid "Generate SH4-300 FPU-less code"
 msgid "Generate SH4-300 FPU-less code."
 msgstr "FPU 無しの SH4-300 コードを生成する"
 
 #: config/sh/sh.opt:112
 #, fuzzy, no-c-format
-#| msgid "Generate code for SH4 340 series (MMU/FPU-less)"
 msgid "Generate code for SH4 340 series (MMU/FPU-less)."
 msgstr "SH4 340 シリーズ (MMU/FPU 無し) 用コードを生成する"
 
 #: config/sh/sh.opt:117
 #, fuzzy, no-c-format
-#| msgid "Generate code for SH4 400 series (MMU/FPU-less)"
 msgid "Generate code for SH4 400 series (MMU/FPU-less)."
 msgstr "SH4 400 シリーズ (MMU/FPU 無し) 用のコードを生成する"
 
@@ -16267,97 +14770,81 @@ msgstr "SH4 500 シリーズ (FPU 無し) 用のコードを生成する"
 
 #: config/sh/sh.opt:127
 #, fuzzy, no-c-format
-#| msgid "Generate default single-precision SH4 code"
 msgid "Generate default single-precision SH4 code."
 msgstr "デフォルトで単精度 SH4 コードを生成する"
 
 #: config/sh/sh.opt:131
 #, fuzzy, no-c-format
-#| msgid "Generate default single-precision SH4-100 code"
 msgid "Generate default single-precision SH4-100 code."
 msgstr "デフォルトで単精度 SH4-100 コードを生成する"
 
 #: config/sh/sh.opt:135
 #, fuzzy, no-c-format
-#| msgid "Generate default single-precision SH4-200 code"
 msgid "Generate default single-precision SH4-200 code."
 msgstr "デフォルトで単精度 SH4-200 コードを生成する"
 
 #: config/sh/sh.opt:139
 #, fuzzy, no-c-format
-#| msgid "Generate default single-precision SH4-300 code"
 msgid "Generate default single-precision SH4-300 code."
 msgstr "デフォルトで単精度 SH4-300 コードを生成する"
 
 #: config/sh/sh.opt:143
 #, fuzzy, no-c-format
-#| msgid "Generate only single-precision SH4 code"
 msgid "Generate only single-precision SH4 code."
 msgstr "単精度 SH4 コードのみを生成する"
 
 #: config/sh/sh.opt:147
 #, fuzzy, no-c-format
-#| msgid "Generate only single-precision SH4-100 code"
 msgid "Generate only single-precision SH4-100 code."
 msgstr "単精度 SH4-100 コードのみを生成する"
 
 #: config/sh/sh.opt:151
 #, fuzzy, no-c-format
-#| msgid "Generate only single-precision SH4-200 code"
 msgid "Generate only single-precision SH4-200 code."
 msgstr "単精度 SH4-200 コードのみを生成する"
 
 #: config/sh/sh.opt:155
 #, fuzzy, no-c-format
-#| msgid "Generate only single-precision SH4-300 code"
 msgid "Generate only single-precision SH4-300 code."
 msgstr "単精度 SH4-300 コードのみを生成する"
 
 #: config/sh/sh.opt:159
 #, fuzzy, no-c-format
-#| msgid "Generate SH4a code"
 msgid "Generate SH4a code."
 msgstr "SH4a コードを生成する"
 
 #: config/sh/sh.opt:163
 #, fuzzy, no-c-format
-#| msgid "Generate SH4a FPU-less code"
 msgid "Generate SH4a FPU-less code."
 msgstr "FPU 無し SH4a コードを生成する"
 
 #: config/sh/sh.opt:167
 #, fuzzy, no-c-format
-#| msgid "Generate default single-precision SH4a code"
 msgid "Generate default single-precision SH4a code."
 msgstr "デフォルトで単精度 SH4a コードを生成する"
 
 #: config/sh/sh.opt:171
 #, fuzzy, no-c-format
-#| msgid "Generate only single-precision SH4a code"
 msgid "Generate only single-precision SH4a code."
 msgstr "単精度 SH4a コードのみを生成する"
 
 #: config/sh/sh.opt:175
 #, fuzzy, no-c-format
-#| msgid "Generate SH4al-dsp code"
 msgid "Generate SH4al-dsp code."
 msgstr "SH4al-dsp コードを生成する"
 
 #: config/sh/sh.opt:183
 #, fuzzy, no-c-format
-#| msgid "Generate code in big endian mode"
 msgid "Generate code in big endian mode."
 msgstr "ビッグエンディアンモードでコードを生成する"
 
 #: config/sh/sh.opt:187
 #, fuzzy, no-c-format
-#| msgid "Generate 32-bit offsets in switch tables"
 msgid "Generate 32-bit offsets in switch tables."
 msgstr "switch 表内で 32 ビットオフセットを生成する"
 
 #: config/sh/sh.opt:191
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate bit instructions."
 msgstr "ビット命令を生成する"
 
@@ -16373,7 +14860,6 @@ msgstr ""
 
 #: config/sh/sh.opt:207
 #, fuzzy, no-c-format
-#| msgid "Align doubles at 64-bit boundaries"
 msgid "Align doubles at 64-bit boundaries."
 msgstr "double を 64 ビット境界に整列する"
 
@@ -16384,13 +14870,11 @@ msgstr ""
 
 #: config/sh/sh.opt:215
 #, fuzzy, no-c-format
-#| msgid "Specify name for 32 bit signed division function"
 msgid "Specify name for 32 bit signed division function."
 msgstr "32 ビット符号付き除算関数の名前を指定する"
 
 #: config/sh/sh.opt:219
 #, fuzzy, no-c-format
-#| msgid "Generate LP64 code"
 msgid "Generate ELF FDPIC code."
 msgstr "LP64 コードを生成する"
 
@@ -16401,13 +14885,11 @@ msgstr "fmov 命令での 64 ビット浮動小数点レジスタの使用を有
 
 #: config/sh/sh.opt:231 config/sh/sh.opt:269
 #, fuzzy, no-c-format
-#| msgid "Follow Renesas (formerly Hitachi) / SuperH calling conventions"
 msgid "Follow Renesas (formerly Hitachi) / SuperH calling conventions."
 msgstr "Renesas (以前の Hitachi) / SuperH 呼び出し規約に従う"
 
 #: config/sh/sh.opt:235
 #, fuzzy, no-c-format
-#| msgid "Increase the IEEE compliance for floating-point code"
 msgid "Increase the IEEE compliance for floating-point comparisons."
 msgstr "浮動小数点コードで IEEE 適合性を高める"
 
@@ -16423,37 +14905,31 @@ msgstr ""
 
 #: config/sh/sh.opt:247
 #, fuzzy, no-c-format
-#| msgid "Generate code in little endian mode"
 msgid "Generate code in little endian mode."
 msgstr "リトルエンディアンモードでコードを生成する"
 
 #: config/sh/sh.opt:251
 #, fuzzy, no-c-format
-#| msgid "Mark MAC register as call-clobbered"
 msgid "Mark MAC register as call-clobbered."
 msgstr "MAC レジスタを呼び出しで破壊されるとマークする"
 
 #: config/sh/sh.opt:257
 #, fuzzy, no-c-format
-#| msgid "Make structs a multiple of 4 bytes (warning: ABI altered)"
 msgid "Make structs a multiple of 4 bytes (warning: ABI altered)."
 msgstr "構造体を 4 バイトの倍数にする (警告: ABI が変更される)"
 
 #: config/sh/sh.opt:261
 #, fuzzy, no-c-format
-#| msgid "Emit function-calls using global offset table when generating PIC"
 msgid "Emit function-calls using global offset table when generating PIC."
 msgstr "PIC 生成時に大域オフセット表を使用して関数呼び出しを発行する"
 
 #: config/sh/sh.opt:265
 #, fuzzy, no-c-format
-#| msgid "Shorten address references during linking"
 msgid "Shorten address references during linking."
 msgstr "リンク中にアドレス参照を短くする"
 
 #: config/sh/sh.opt:273
 #, fuzzy, no-c-format
-#| msgid "Generate code for built-in atomic operations"
 msgid "Specify the model for atomic operations."
 msgstr "組み込み不可分操作用のコードを生成する"
 
@@ -16464,7 +14940,6 @@ msgstr ""
 
 #: config/sh/sh.opt:281
 #, fuzzy, no-c-format
-#| msgid "Cost to assume for a multiply insn"
 msgid "Cost to assume for a multiply insn."
 msgstr "乗算命令のコストを設定する"
 
@@ -16480,13 +14955,11 @@ msgstr ""
 
 #: config/sh/sh.opt:295
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the fsca instruction."
 msgstr "短い load 命令の使用を有効にする"
 
 #: config/sh/sh.opt:299
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the fsrra instruction."
 msgstr "短い load 命令の使用を有効にする"
 
@@ -16502,7 +14975,6 @@ msgstr ""
 
 #: config/gcn/gcn.opt:39 config/gcn/gcn.opt:43
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target CPU"
 msgid "Specify the name of the target GPU."
 msgstr "ターゲット CPU の名前を指定する"
 
@@ -16518,31 +14990,26 @@ msgstr ""
 
 #: config/gcn/gcn.opt:78
 #, fuzzy, no-c-format
-#| msgid "Warn about implicit function declarations"
 msgid "Warn about invalid OpenACC dimensions."
 msgstr "暗黙の関数宣言に関して警告する"
 
 #: config/fr30/fr30.opt:23
 #, fuzzy, no-c-format
-#| msgid "Assume small address space"
 msgid "Assume small address space."
 msgstr "スモールアドレス空間とみなす"
 
 #: config/bpf/bpf.opt:28
 #, fuzzy, no-c-format
-#| msgid "Generate code for the kernel or loadable kernel extensions"
 msgid "Generate eBPF for the given Linux kernel version."
 msgstr "カーネル用、またはロード可能カーネル拡張用のコードを生成する"
 
 #: config/bpf/bpf.opt:115
 #, fuzzy, no-c-format
-#| msgid "Generate big-endian code"
 msgid "Generate big-endian eBPF."
 msgstr "ビッグエンディアンコードを生成する"
 
 #: config/bpf/bpf.opt:119
 #, fuzzy, no-c-format
-#| msgid "Generate little-endian code"
 msgid "Generate little-endian eBPF."
 msgstr "リトルエンディアンコードを生成する"
 
@@ -16553,7 +15020,6 @@ msgstr ""
 
 #: config/mips/mips.opt:32
 #, fuzzy, no-c-format
-#| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the given ABI."
 msgstr "-mabi=ABI\t与えられた ABI に準拠したコードを生成する"
 
@@ -16564,31 +15030,26 @@ msgstr ""
 
 #: config/mips/mips.opt:55
 #, fuzzy, no-c-format
-#| msgid "Generate code that can be used in SVR4-style dynamic objects"
 msgid "Generate code that can be used in SVR4-style dynamic objects."
 msgstr "SVR4 スタイルの動的オブジェクト内で使用できるコードを生成する"
 
 #: config/mips/mips.opt:59
 #, fuzzy, no-c-format
-#| msgid "Use PMC-style 'mad' instructions"
 msgid "Use PMC-style 'mad' instructions."
 msgstr "PMC スタイルの 'mad' 命令を使用する"
 
 #: config/mips/mips.opt:63
 #, fuzzy, no-c-format
-#| msgid "Use fp double instructions"
 msgid "Use integer madd/msub instructions."
 msgstr "倍精度浮動小数命令を有効にする"
 
 #: config/mips/mips.opt:67
 #, fuzzy, no-c-format
-#| msgid "-march=ISA\tGenerate code for the given ISA"
 msgid "-march=ISA\tGenerate code for the given ISA."
 msgstr "-march=ISA\t与えられた ISA 用のコードを生成する"
 
 #: config/mips/mips.opt:71
 #, fuzzy, no-c-format
-#| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
 msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions."
 msgstr "-mbranch-cost=COST\t分岐コストを大体 COST 命令分に設定する"
 
@@ -16604,7 +15065,6 @@ msgstr ""
 
 #: config/mips/mips.opt:83
 #, fuzzy, no-c-format
-#| msgid "Trap on integer divide by zero"
 msgid "Trap on integer divide by zero."
 msgstr "整数のゼロ除算をトラップする"
 
@@ -16615,7 +15075,6 @@ msgstr ""
 
 #: config/mips/mips.opt:91
 #, fuzzy, no-c-format
-#| msgid "invalid argument %qs to -fdebug-prefix-map"
 msgid "Valid arguments to -mcode-readable=:"
 msgstr "-fdebug-prefix-map への無効な引数 %qs です"
 
@@ -16626,43 +15085,36 @@ msgstr ""
 
 #: config/mips/mips.opt:108
 #, fuzzy, no-c-format
-#| msgid "Trap on integer divide by zero"
 msgid "Use trap instructions to check for integer divide by zero."
 msgstr "整数のゼロ除算をトラップする"
 
 #: config/mips/mips.opt:112
 #, fuzzy, no-c-format
-#| msgid "Allow the use of MDMX instructions"
 msgid "Allow the use of MDMX instructions."
 msgstr "MDMX 命令の使用を許可する"
 
 #: config/mips/mips.opt:116
 #, fuzzy, no-c-format
-#| msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations"
 msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations."
 msgstr "32 ビット操作と 64 ビット操作の両方でのハードウェア浮動小数点命令使用を許可する"
 
 #: config/mips/mips.opt:120
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-DSP instructions"
 msgid "Use MIPS-DSP instructions."
 msgstr "MIPS-DSP 命令を使用する"
 
 #: config/mips/mips.opt:124
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-DSP REV 2 instructions"
 msgid "Use MIPS-DSP REV 2 instructions."
 msgstr "MIPS-DSP REV 2 命令を使用する"
 
 #: config/mips/mips.opt:146
 #, fuzzy, no-c-format
-#| msgid "Use the bit-field instructions"
 msgid "Use Enhanced Virtual Addressing instructions."
 msgstr "ビットフィールド命令を使用する"
 
 #: config/mips/mips.opt:150
 #, fuzzy, no-c-format
-#| msgid "Use NewABI-style %reloc() assembly operators"
 msgid "Use NewABI-style %reloc() assembly operators."
 msgstr "NewABI スタイルの %reloc() アセンブラ操作を使用する"
 
@@ -16673,73 +15125,61 @@ msgstr ""
 
 #: config/mips/mips.opt:158
 #, fuzzy, no-c-format
-#| msgid "Work around certain R4000 errata"
 msgid "Work around certain 24K errata."
 msgstr "R4000 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:162
 #, fuzzy, no-c-format
-#| msgid "Work around certain R4000 errata"
 msgid "Work around certain R4000 errata."
 msgstr "R4000 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:166
 #, fuzzy, no-c-format
-#| msgid "Work around certain R4400 errata"
 msgid "Work around certain R4400 errata."
 msgstr "R4400 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:170
 #, fuzzy, no-c-format
-#| msgid "Work around certain R4000 errata"
 msgid "Work around the R5900 short loop erratum."
 msgstr "R4000 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:174
 #, fuzzy, no-c-format
-#| msgid "Work around certain R4000 errata"
 msgid "Work around certain RM7000 errata."
 msgstr "R4000 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:178
 #, fuzzy, no-c-format
-#| msgid "Work around certain R10000 errata"
 msgid "Work around certain R10000 errata."
 msgstr "R10000 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:182
 #, fuzzy, no-c-format
-#| msgid "Work around errata for early SB-1 revision 2 cores"
 msgid "Work around errata for early SB-1 revision 2 cores."
 msgstr "初期の SB-1 リビジョン 2 コアのエラッタ回避を行う"
 
 #: config/mips/mips.opt:186
 #, fuzzy, no-c-format
-#| msgid "Work around certain VR4120 errata"
 msgid "Work around certain VR4120 errata."
 msgstr "VR4120 固有のエラッタ回避を行う"
 
 #: config/mips/mips.opt:190
 #, fuzzy, no-c-format
-#| msgid "Work around VR4130 mflo/mfhi errata"
 msgid "Work around VR4130 mflo/mfhi errata."
 msgstr "VR4130 mflo/mfhi エラッタ回避を行う"
 
 #: config/mips/mips.opt:194
 #, fuzzy, no-c-format
-#| msgid "Work around an early 4300 hardware bug"
 msgid "Work around an early 4300 hardware bug."
 msgstr "初期の 4300 ハードウェアバグの回避を行う"
 
 #: config/mips/mips.opt:198
 #, fuzzy, no-c-format
-#| msgid "FP exceptions are enabled"
 msgid "FP exceptions are enabled."
 msgstr "浮動小数点例外を有効にする"
 
 #: config/mips/mips.opt:202
 #, fuzzy, no-c-format
-#| msgid "Use 32-bit floating-point registers"
 msgid "Use 32-bit floating-point registers."
 msgstr "32 ビット浮動小数点レジスタを使用する"
 
@@ -16750,7 +15190,6 @@ msgstr ""
 
 #: config/mips/mips.opt:210
 #, fuzzy, no-c-format
-#| msgid "Use 64-bit floating-point registers"
 msgid "Use 64-bit floating-point registers."
 msgstr "64 ビット浮動小数点レジスタを使用する"
 
@@ -16776,13 +15215,11 @@ msgstr ""
 
 #: config/mips/mips.opt:236
 #, fuzzy, no-c-format
-#| msgid "Use 32-bit general registers"
 msgid "Use 32-bit general registers."
 msgstr "32 ビット汎用レジスタを使用する"
 
 #: config/mips/mips.opt:240
 #, fuzzy, no-c-format
-#| msgid "Use 64-bit general registers"
 msgid "Use 64-bit general registers."
 msgstr "64 ビット汎用レジスタを使用する"
 
@@ -16793,73 +15230,61 @@ msgstr ""
 
 #: config/mips/mips.opt:248
 #, fuzzy, no-c-format
-#| msgid "When generating -mabicalls code, make the code suitable for use in shared libraries"
 msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations."
 msgstr "-mabicalls コードを生成しているときに、共有ライブラリで使用するのに適したコードを作成する"
 
 #: config/mips/mips.opt:252
 #, fuzzy, no-c-format
-#| msgid "Allow the use of hardware floating-point ABI and instructions"
 msgid "Allow the use of hardware floating-point ABI and instructions."
 msgstr "ハードウェア浮動小数点の ABI と命令の使用を許可する"
 
 #: config/mips/mips.opt:256
 #, fuzzy, no-c-format
-#| msgid "Generate code that can be safely linked with MIPS16 code."
 msgid "Generate code that is link-compatible with MIPS16 and microMIPS code."
 msgstr "MIPS16 コードと安全にリンクできるコードを生成する。"
 
 #: config/mips/mips.opt:260
 #, fuzzy, no-c-format
-#| msgid "Does nothing. Preserved for backward compatibility."
 msgid "An alias for minterlink-compressed provided for backward-compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
 #: config/mips/mips.opt:264
 #, fuzzy, no-c-format
-#| msgid "-mipsN\tGenerate code for ISA level N"
 msgid "-mipsN\tGenerate code for ISA level N."
 msgstr "-mipsN\tISA レベル N 用のコードを生成する"
 
 #: config/mips/mips.opt:268
 #, fuzzy, no-c-format
-#| msgid "Generate MIPS16 code"
 msgid "Generate MIPS16 code."
 msgstr "MIPS16 コードを生成する"
 
 #: config/mips/mips.opt:272
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-3D instructions"
 msgid "Use MIPS-3D instructions."
 msgstr "MIPS-3D 命令を使用する"
 
 #: config/mips/mips.opt:276
 #, fuzzy, no-c-format
-#| msgid "Use ll, sc and sync instructions"
 msgid "Use ll, sc and sync instructions."
 msgstr "ll、sc および sync 命令を使用する"
 
 #: config/mips/mips.opt:280
 #, fuzzy, no-c-format
-#| msgid "Use -G for object-local data"
 msgid "Use -G for object-local data."
 msgstr "オブジェクト局所データ用に -G を使用する"
 
 #: config/mips/mips.opt:284
 #, fuzzy, no-c-format
-#| msgid "Use indirect calls"
 msgid "Use indirect calls."
 msgstr "間接呼び出しを使用する"
 
 #: config/mips/mips.opt:288
 #, fuzzy, no-c-format
-#| msgid "Use a 32-bit long type"
 msgid "Use a 32-bit long type."
 msgstr "32 ビット long 型を使用する"
 
 #: config/mips/mips.opt:292
 #, fuzzy, no-c-format
-#| msgid "Use a 64-bit long type"
 msgid "Use a 64-bit long type."
 msgstr "64 ビット long 型を使用する"
 
@@ -16870,37 +15295,31 @@ msgstr ""
 
 #: config/mips/mips.opt:300
 #, fuzzy, no-c-format
-#| msgid "Don't optimize block moves"
 msgid "Don't optimize block moves."
 msgstr "ブロック移動を最適化しない"
 
 #: config/mips/mips.opt:304
 #, fuzzy, no-c-format
-#| msgid "Use SmartMIPS instructions"
 msgid "Use microMIPS instructions."
 msgstr "SmartMIPS 命令を使用する"
 
 #: config/mips/mips.opt:308
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-DSP instructions"
 msgid "Use MIPS MSA Extension instructions."
 msgstr "MIPS-DSP 命令を使用する"
 
 #: config/mips/mips.opt:312
 #, fuzzy, no-c-format
-#| msgid "Allow the use of MT instructions"
 msgid "Allow the use of MT instructions."
 msgstr "MT 命令の使用を許可する"
 
 #: config/mips/mips.opt:316
 #, fuzzy, no-c-format
-#| msgid "Prevent the use of all floating-point operations"
 msgid "Prevent the use of all floating-point operations."
 msgstr "すべての浮動小数点操作の使用を防止する"
 
 #: config/mips/mips.opt:320
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-3D instructions"
 msgid "Use MCU instructions."
 msgstr "MIPS-3D 命令を使用する"
 
@@ -16911,25 +15330,21 @@ msgstr ""
 
 #: config/mips/mips.opt:328
 #, fuzzy, no-c-format
-#| msgid "Do not use MDMX instructions"
 msgid "Do not use MDMX instructions."
 msgstr "MDMX 命令を使用しない"
 
 #: config/mips/mips.opt:332
 #, fuzzy, no-c-format
-#| msgid "Generate normal-mode code"
 msgid "Generate normal-mode code."
 msgstr "ノーマルモードコードを生成する"
 
 #: config/mips/mips.opt:336
 #, fuzzy, no-c-format
-#| msgid "Do not use MIPS-3D instructions"
 msgid "Do not use MIPS-3D instructions."
 msgstr "MIPS-3D 命令を使用しない"
 
 #: config/mips/mips.opt:340
 #, fuzzy, no-c-format
-#| msgid "Use hardware floating point instructions"
 msgid "Use paired-single floating-point instructions."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
@@ -16940,55 +15355,46 @@ msgstr ""
 
 #: config/mips/mips.opt:348
 #, fuzzy, no-c-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mr10k-cache-barrier=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/mips/mips.opt:361
 #, fuzzy, no-c-format
-#| msgid "Try to allow the linker to turn PIC calls into direct calls"
 msgid "Try to allow the linker to turn PIC calls into direct calls."
 msgstr "リンカが PIC 呼び出しを直接呼び出しに変更することを許可するように試みる"
 
 #: config/mips/mips.opt:365
 #, fuzzy, no-c-format
-#| msgid "When generating -mabicalls code, make the code suitable for use in shared libraries"
 msgid "When generating -mabicalls code, make the code suitable for use in shared libraries."
 msgstr "-mabicalls コードを生成しているときに、共有ライブラリで使用するのに適したコードを作成する"
 
 #: config/mips/mips.opt:369
 #, fuzzy, no-c-format
-#| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "Restrict the use of hardware floating-point instructions to 32-bit operations."
 msgstr "ハードウェア浮動小数点命令の使用を 32 ビット操作に制限する"
 
 #: config/mips/mips.opt:373
 #, fuzzy, no-c-format
-#| msgid "Use SmartMIPS instructions"
 msgid "Use SmartMIPS instructions."
 msgstr "SmartMIPS 命令を使用する"
 
 #: config/mips/mips.opt:377
 #, fuzzy, no-c-format
-#| msgid "Prevent the use of all hardware floating-point instructions"
 msgid "Prevent the use of all hardware floating-point instructions."
 msgstr "すべてのハードウェア浮動小数点命令の使用を防止する"
 
 #: config/mips/mips.opt:381
 #, fuzzy, no-c-format
-#| msgid "Optimize lui/addiu address loads"
 msgid "Optimize lui/addiu address loads."
 msgstr "lui/addiu アドレスロードを最適化する"
 
 #: config/mips/mips.opt:385
 #, fuzzy, no-c-format
-#| msgid "Assume all symbols have 32-bit values"
 msgid "Assume all symbols have 32-bit values."
 msgstr "すべてのシンボルが 32 ビット値を持つと見なす"
 
 #: config/mips/mips.opt:389
 #, fuzzy, no-c-format
-#| msgid "Use synci instruction to invalidate i-cache"
 msgid "Use synci instruction to invalidate i-cache."
 msgstr "i-cache を無効にするために synci 命令を使用する"
 
@@ -17004,31 +15410,26 @@ msgstr ""
 
 #: config/mips/mips.opt:413
 #, fuzzy, no-c-format
-#| msgid "Use AltiVec instructions"
 msgid "Use Virtualization (VZ) instructions."
 msgstr "AltiVec 命令を使用する"
 
 #: config/mips/mips.opt:417
 #, fuzzy, no-c-format
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use eXtended Physical Address (XPA) instructions."
 msgstr "vector/scalar (VSX) 命令を使用する"
 
 #: config/mips/mips.opt:421
 #, fuzzy, no-c-format
-#| msgid "Use ll, sc and sync instructions"
 msgid "Use Cyclic Redundancy Check (CRC) instructions."
 msgstr "ll、sc および sync 命令を使用する"
 
 #: config/mips/mips.opt:425
 #, fuzzy, no-c-format
-#| msgid "Use AltiVec instructions"
 msgid "Use Global INValidate (GINV) instructions."
 msgstr "AltiVec 命令を使用する"
 
 #: config/mips/mips.opt:429
 #, fuzzy, no-c-format
-#| msgid "Perform VR4130-specific alignment optimizations"
 msgid "Perform VR4130-specific alignment optimizations."
 msgstr "VR4130 固有の整列最適化を行う"
 
@@ -17039,19 +15440,16 @@ msgstr ""
 
 #: config/mips/mips.opt:437
 #, fuzzy, no-c-format
-#| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Enable use of odd-numbered single-precision registers."
 msgstr "拡張精度レジスタ内に float と double を配置しない"
 
 #: config/mips/mips.opt:441
 #, fuzzy, no-c-format
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize frame header."
 msgstr "速度よりもサイズを重視した最適化を行う"
 
 #: config/mips/mips.opt:448
 #, fuzzy, no-c-format
-#| msgid "Enable dead store elimination"
 msgid "Enable load/store bonding."
 msgstr "不要な記憶域 (dead store) の除去を行う"
 
@@ -17072,13 +15470,11 @@ msgstr ""
 
 #: config/mips/mips.opt:473
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-DSP instructions"
 msgid "Use Loongson EXTension (EXT) instructions."
 msgstr "MIPS-DSP 命令を使用する"
 
 #: config/mips/mips.opt:477
 #, fuzzy, no-c-format
-#| msgid "Use MIPS-DSP instructions"
 msgid "Use Loongson EXTension R2 (EXT2) instructions."
 msgstr "MIPS-DSP 命令を使用する"
 
@@ -17099,19 +15495,16 @@ msgstr ""
 
 #: config/tilegx/tilegx.opt:37
 #, fuzzy, no-c-format
-#| msgid "Compile for 32-bit pointers"
 msgid "Compile with 32 bit longs and pointers."
 msgstr "32 ビットポインタ用にコンパイルする"
 
 #: config/tilegx/tilegx.opt:41
 #, fuzzy, no-c-format
-#| msgid "Compile for 64-bit pointers"
 msgid "Compile with 64 bit longs and pointers."
 msgstr "64 ビットポインタ用にコンパイルする"
 
 #: config/tilegx/tilegx.opt:53
 #, fuzzy, no-c-format
-#| msgid "Use given x86-64 code model"
 msgid "Use given TILE-Gx code model."
 msgstr "与えられた x86-64 コードモデルを使用する"
 
@@ -17122,13 +15515,11 @@ msgstr ""
 
 #: config/arc/arc.opt:26
 #, fuzzy, no-c-format
-#| msgid "Generate code in big endian mode"
 msgid "Compile code for big endian mode."
 msgstr "ビッグエンディアンモードでコードを生成する"
 
 #: config/arc/arc.opt:30
 #, fuzzy, no-c-format
-#| msgid "Stores doubles in 32 bits.  This is the default."
 msgid "Compile code for little endian mode.  This is the default."
 msgstr "double を 32 ビットで保存する (デフォルト)。"
 
@@ -17174,13 +15565,11 @@ msgstr ""
 
 #: config/arc/arc.opt:132
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable DIV-REM instructions for ARCv2."
 msgstr "clip 命令を有効にする"
 
 #: config/arc/arc.opt:136
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable code density instructions for ARCv2."
 msgstr "clip 命令を有効にする"
 
@@ -17201,37 +15590,31 @@ msgstr ""
 
 #: config/arc/arc.opt:158
 #, fuzzy, no-c-format
-#| msgid "Generate string instructions for block moves"
 msgid "Generate instructions supported by barrel shifter."
 msgstr "ブロック移動用の string 命令を生成する"
 
 #: config/arc/arc.opt:162
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "Generate norm instruction."
 msgstr "ビット命令を生成する"
 
 #: config/arc/arc.opt:166
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate swap instruction."
 msgstr "isel 命令を生成する"
 
 #: config/arc/arc.opt:170
 #, fuzzy, no-c-format
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "複数命令のロード/ストアを生成する"
 
 #: config/arc/arc.opt:174
 #, fuzzy, no-c-format
-#| msgid "Allow gcc to generate LIW instructions"
 msgid "Do not generate mpy instructions for ARC700."
 msgstr "gcc が LIW 命令を生成することを許可する"
 
 #: config/arc/arc.opt:178
 #, fuzzy, no-c-format
-#| msgid "Allow gcc to generate LIW instructions"
 msgid "Generate extended arithmetic instructions, only valid for ARC700."
 msgstr "gcc が LIW 命令を生成することを許可する"
 
@@ -17242,13 +15625,11 @@ msgstr ""
 
 #: config/arc/arc.opt:186
 #, fuzzy, no-c-format
-#| msgid "Generate call insns as indirect calls, if necessary"
 msgid "Generate call insns as register indirect calls."
 msgstr "必要があれば、命令呼び出しを間接呼び出しとして生成する"
 
 #: config/arc/arc.opt:190
 #, fuzzy, no-c-format
-#| msgid "Generate cld instruction in the function prologue."
 msgid "Do no generate BRcc instructions in arc_reorg."
 msgstr "関数プロローグ内で cld 命令を生成する"
 
@@ -17259,7 +15640,6 @@ msgstr ""
 
 #: config/arc/arc.opt:198
 #, fuzzy, no-c-format
-#| msgid "Generate Cell microcode"
 msgid "Generate millicode thunks."
 msgstr "Cell マイクロコードを生成する"
 
@@ -17270,7 +15650,6 @@ msgstr ""
 
 #: config/arc/arc.opt:210
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "FPX: Generate Single Precision FPX (fast) instructions."
 msgstr "ビット命令を生成する"
 
@@ -17281,13 +15660,11 @@ msgstr ""
 
 #: config/arc/arc.opt:218 config/arc/arc.opt:222
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "FPX: Generate Double Precision FPX (compact) instructions."
 msgstr "ビット命令を生成する"
 
 #: config/arc/arc.opt:226
 #, fuzzy, no-c-format
-#| msgid "Generate bit instructions"
 msgid "FPX: Generate Double Precision FPX (fast) instructions."
 msgstr "ビット命令を生成する"
 
@@ -17303,7 +15680,6 @@ msgstr ""
 
 #: config/arc/arc.opt:238
 #, fuzzy, no-c-format
-#| msgid "-mcpu=CPU\tCompile code for ARC variant CPU"
 msgid "-mcpu=CPU\tCompile code for ARC variant CPU."
 msgstr "-mcpu=CPU\tARC 類型 CPU 用にコードをコンパイルする"
 
@@ -17314,19 +15690,16 @@ msgstr ""
 
 #: config/arc/arc.opt:250
 #, fuzzy, no-c-format
-#| msgid "Cost to assume for a multiply insn"
 msgid "Cost to assume for a multiply instruction, with 4 being equal to a normal insn."
 msgstr "乗算命令のコストを設定する"
 
 #: config/arc/arc.opt:254
 #, fuzzy, no-c-format
-#| msgid "-mcpu=CPU\tCompile code for ARC variant CPU"
 msgid "-mtune=TUNE\tTune code for given ARC variant."
 msgstr "-mcpu=CPU\tARC 類型 CPU 用にコードをコンパイルする"
 
 #: config/arc/arc.opt:285
 #, fuzzy, no-c-format
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of indexed loads."
 msgstr "短い load 命令の使用を有効にする"
 
@@ -17337,7 +15710,6 @@ msgstr ""
 
 #: config/arc/arc.opt:293
 #, fuzzy, no-c-format
-#| msgid "Generate auto-inc/dec instructions"
 msgid "Generate 32x16 multiply and mac instructions."
 msgstr "自動増加/減少命令を生成する"
 
@@ -17358,7 +15730,6 @@ msgstr ""
 
 #: config/arc/arc.opt:311
 #, fuzzy, no-c-format
-#| msgid "Disable all optional instructions"
 msgid "Do alignment optimizations for call instructions."
 msgstr "すべてのオプションの命令を無効にする"
 
@@ -17374,7 +15745,6 @@ msgstr ""
 
 #: config/arc/arc.opt:323
 #, fuzzy, no-c-format
-#| msgid "Enable cbranchdi4 pattern"
 msgid "Enable pre-reload use of cbranchsi pattern."
 msgstr "cbranchdi4 パターンを有効にする"
 
@@ -17390,13 +15760,11 @@ msgstr ""
 
 #: config/arc/arc.opt:335
 #, fuzzy, no-c-format
-#| msgid "Enable cbranchdi4 pattern"
 msgid "Enable compact casesi pattern."
 msgstr "cbranchdi4 パターンを有効にする"
 
 #: config/arc/arc.opt:339
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable 'q' instruction alternatives."
 msgstr "clip 命令を有効にする"
 
@@ -17412,13 +15780,11 @@ msgstr ""
 
 #: config/arc/arc.opt:354
 #, fuzzy, no-c-format
-#| msgid "Enable Plan 9 language extensions"
 msgid "Enable DSP 3.1 Pack A extensions."
 msgstr "Plan 9 言語拡張を有効にする"
 
 #: config/arc/arc.opt:358
 #, fuzzy, no-c-format
-#| msgid "Enable linker relaxation."
 msgid "Enable dual viterbi butterfly extension."
 msgstr "リンカの緩和を有効にする。"
 
@@ -17439,31 +15805,26 @@ msgstr "条件的 move 命令の利用を有効にする"
 
 #: config/arc/arc.opt:381
 #, fuzzy, no-c-format
-#| msgid "Enable sign extend instructions"
 msgid "Enable swap byte ordering extension instruction."
 msgstr "符号付き拡張命令を有効にする"
 
 #: config/arc/arc.opt:385
 #, fuzzy, no-c-format
-#| msgid "Enable bit manipulation instructions"
 msgid "Enable 64-bit Time-Stamp Counter extension instruction."
 msgstr "ビット操作命令を有効にする"
 
 #: config/arc/arc.opt:389
 #, fuzzy, no-c-format
-#| msgid "Pass -z text to linker"
 msgid "Pass -EB option through to linker."
 msgstr "-z text をリンカに渡す"
 
 #: config/arc/arc.opt:393
 #, fuzzy, no-c-format
-#| msgid "Pass -z text to linker"
 msgid "Pass -EL option through to linker."
 msgstr "-z text をリンカに渡す"
 
 #: config/arc/arc.opt:397
 #, fuzzy, no-c-format
-#| msgid "Pass -z text to linker"
 msgid "Pass -marclinux option through to linker."
 msgstr "-z text をリンカに渡す"
 
@@ -17489,25 +15850,21 @@ msgstr ""
 
 #: config/arc/arc.opt:430
 #, fuzzy, no-c-format
-#| msgid "Enable clip instructions"
 msgid "Enable atomic instructions."
 msgstr "clip 命令を有効にする"
 
 #: config/arc/arc.opt:434
 #, fuzzy, no-c-format
-#| msgid "Enable unaligned load/store instruction"
 msgid "Enable double load/store instructions for ARC HS."
 msgstr "整列されていない load/store 命令を有効にする"
 
 #: config/arc/arc.opt:438
 #, fuzzy, no-c-format
-#| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify the name of the target floating point configuration."
 msgstr "ターゲット浮動小数点ハードウェア/形式の名前を指定する"
 
 #: config/arc/arc.opt:481
 #, fuzzy, no-c-format
-#| msgid "Specify the register allocation order"
 msgid "Specify thread pointer register number."
 msgstr "レジスタ確保順を指定する"
 
@@ -17523,13 +15880,11 @@ msgstr ""
 
 #: config/arc/arc.opt:500
 #, fuzzy, no-c-format
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Specifies the registers that the processor saves on an interrupt entry and exit."
 msgstr "割り込みハンドラ用に予約されるレジスタサイズを指定する"
 
 #: config/arc/arc.opt:504
 #, fuzzy, no-c-format
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Specifies the number of registers replicated in second register bank on entry to fast interrupt."
 msgstr "割り込みハンドラ用に予約されるレジスタサイズを指定する"
 
@@ -17545,7 +15900,6 @@ msgstr ""
 
 #: config/arc/arc.opt:537
 #, fuzzy, no-c-format
-#| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable use of BI/BIH instructions when available."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
@@ -17591,13 +15945,11 @@ msgstr ""
 
 #: lto/lang.opt:83
 #, fuzzy, no-c-format
-#| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Dump only the defined symbols."
 msgstr "%q+D が未定義シンボル %qE の別名となっています"
 
 #: lto/lang.opt:87
 #, fuzzy, no-c-format
-#| msgid "Warn about uninitialized automatic variables"
 msgid "Print the initial values of the variables."
 msgstr "初期化されていない自動変数に関して警告する"
 
@@ -17613,7 +15965,6 @@ msgstr ""
 
 #: lto/lang.opt:99
 #, fuzzy, no-c-format
-#| msgid "Display the compiler's version"
 msgid "Display the symbols in reverse order."
 msgstr "`コンパイラのバージョンを表示する"
 
@@ -17639,7 +15990,6 @@ msgstr ""
 
 #: lto/lang.opt:128
 #, fuzzy, no-c-format
-#| msgid "unrecognized command line option %qs"
 msgid "Dump the dump tool command line options."
 msgstr "認識できないコマンドラインオプション %qs です"
 
@@ -17660,55 +16010,46 @@ msgstr ""
 
 #: common.opt:289
 #, fuzzy, no-c-format
-#| msgid "Display this information"
 msgid "Display this information."
 msgstr "この情報を表示する"
 
 #: common.opt:293
 #, fuzzy, no-c-format
-#| msgid "--help=<class>\tDisplay descriptions of a specific class of options.  <class> is one or more of optimizers, target, warnings, undocumented, params"
 msgid "--help=<class>\tDisplay descriptions of a specific class of options.  <class> is one or more of optimizers, target, warnings, undocumented, params."
 msgstr "--help=<class>\tオプションの指定したクラスの説明を表示する。<class> は optimizers、target、warnings、undocumented、params のうちの一つ以上とする"
 
 #: common.opt:414
 #, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
 msgid "Alias for --help=target."
 msgstr "--help=target の別名"
 
 #: common.opt:460
 #, fuzzy, no-c-format
-#| msgid "-O<number>\tSet optimization level to <number>"
 msgid "-O<number>\tSet optimization level to <number>."
 msgstr "-O<number>\t最適化レベルを <number> に設定する"
 
 #: common.opt:464
 #, fuzzy, no-c-format
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize for space rather than speed."
 msgstr "速度よりもサイズを重視した最適化を行う"
 
 #: common.opt:468
 #, fuzzy, no-c-format
-#| msgid "Optimize for speed disregarding exact standards compliance"
 msgid "Optimize for speed disregarding exact standards compliance."
 msgstr "標準への厳密な準拠を無視して速度に関する最適化を行う"
 
 #: common.opt:472
 #, fuzzy, no-c-format
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize for debugging experience rather than speed or size."
 msgstr "速度よりもサイズを重視した最適化を行う"
 
 #: common.opt:512
 #, fuzzy, no-c-format
-#| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -Wextra instead."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
 #: common.opt:525
 #, fuzzy, no-c-format
-#| msgid "Warn about returning structures, unions or arrays"
 msgid "Warn about returning structures, unions or arrays."
 msgstr "構造体、共用体または配列を返すものに関して警告する"
 
@@ -17719,13 +16060,11 @@ msgstr ""
 
 #: common.opt:533 common.opt:537
 #, fuzzy, no-c-format
-#| msgid "Warn if an array is accessed out of bounds"
 msgid "Warn if an array is accessed out of bounds."
 msgstr "配列の範囲外にアクセスがある場合に警告する"
 
 #: common.opt:541
 #, fuzzy, no-c-format
-#| msgid "Warn about inappropriate attribute usage"
 msgid "Warn about inappropriate attribute usage."
 msgstr "不適切な属性の使用法に関して警告する"
 
@@ -17741,67 +16080,56 @@ msgstr ""
 
 #: common.opt:558 common.opt:562
 #, fuzzy, no-c-format
-#| msgid "Warn about pointer casts which increase alignment"
 msgid "Warn about pointer casts which increase alignment."
 msgstr "ポインタのキャストによって整列が増加する場合に警告する"
 
 #: common.opt:566
 #, fuzzy, no-c-format
-#| msgid "Warn when a #warning directive is encountered"
 msgid "Warn when a #warning directive is encountered."
 msgstr "#warning 指示に遭遇したときに警告する"
 
 #: common.opt:570
 #, fuzzy, no-c-format
-#| msgid "Warn about uses of __attribute__((deprecated)) declarations"
 msgid "Warn about uses of __attribute__((warning)) declarations."
 msgstr "__attribute__((deprecated)) 宣言の使用に関して警告する"
 
 #: common.opt:574
 #, fuzzy, no-c-format
-#| msgid "Warn if a deprecated compiler feature, class, method, or field is used"
 msgid "Warn if a deprecated compiler feature, class, method, or field is used."
 msgstr "廃止されたコンパイラ機能、クラス、メソッドまたはフィールドが使用されたときに警告する"
 
 #: common.opt:578
 #, fuzzy, no-c-format
-#| msgid "Warn about uses of __attribute__((deprecated)) declarations"
 msgid "Warn about uses of __attribute__((deprecated)) declarations."
 msgstr "__attribute__((deprecated)) 宣言の使用に関して警告する"
 
 #: common.opt:582
 #, fuzzy, no-c-format
-#| msgid "Warn when an optimization pass is disabled"
 msgid "Warn when an optimization pass is disabled."
 msgstr "最適化過程が無効化された場合に警告する"
 
 #: common.opt:586
 #, fuzzy, no-c-format
-#| msgid "Treat all warnings as errors"
 msgid "Treat all warnings as errors."
 msgstr "全ての警告をエラーとして取り扱う"
 
 #: common.opt:590
 #, fuzzy, no-c-format
-#| msgid "Treat specified warning as error"
 msgid "Treat specified warning as error."
 msgstr "指定した警告をエラーとして取り扱う"
 
 #: common.opt:594
 #, fuzzy, no-c-format
-#| msgid "Print extra (possibly unwanted) warnings"
 msgid "Print extra (possibly unwanted) warnings."
 msgstr "余分な (望まないかもしれない) 警告を表示する"
 
 #: common.opt:598
 #, fuzzy, no-c-format
-#| msgid "Exit on the first error occurred"
 msgid "Exit on the first error occurred."
 msgstr "最初のエラーが発生したときに終了する"
 
 #: common.opt:602
 #, fuzzy, no-c-format
-#| msgid "-Wframe-larger-than=<number>\tWarn if a function's stack frame requires more than <number> bytes"
 msgid "-Wframe-larger-than=<byte-size>\tWarn if a function's stack frame requires in excess of <byte-size>."
 msgstr "-Wframe-larger-than=<number>\t関数スタックフレームが <number> バイト以上要求した場合に警告する"
 
@@ -17812,13 +16140,11 @@ msgstr ""
 
 #: common.opt:610
 #, fuzzy, no-c-format
-#| msgid "%Kattempt to free a non-heap object"
 msgid "Warn when attempting to free a non-heap object."
 msgstr "%K ヒープではないオブジェクトを free する試みです"
 
 #: common.opt:614
 #, fuzzy, no-c-format
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Warn when a function cannot be expanded to HSAIL."
 msgstr "インライン関数をインライン化できない場合に警告する"
 
@@ -17829,7 +16155,6 @@ msgstr ""
 
 #: common.opt:625
 #, fuzzy, no-c-format
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Warn when an inlined function cannot be inlined."
 msgstr "インライン関数をインライン化できない場合に警告する"
 
@@ -17840,7 +16165,6 @@ msgstr ""
 
 #: common.opt:636
 #, fuzzy, no-c-format
-#| msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
 msgid "-Wlarger-than=<byte-size>\tWarn if an object's size exceeds <byte-size>."
 msgstr "-Wlarger-than=<number>\tオブジェクトが <number> バイト以上の場合に警告する"
 
@@ -17866,7 +16190,6 @@ msgstr ""
 
 #: common.opt:663
 #, fuzzy, no-c-format
-#| msgid "Warn about overflow in arithmetic expressions"
 msgid "Warn about overflow in arithmetic expressions."
 msgstr "計算式内のオーバーフローに関して警告する"
 
@@ -17877,7 +16200,6 @@ msgstr ""
 
 #: common.opt:671
 #, fuzzy, no-c-format
-#| msgid "Warn when the packed attribute has no effect on struct layout"
 msgid "Warn when the packed attribute has no effect on struct layout."
 msgstr "packed 属性が構造体配置に影響しない場合に警告する"
 
@@ -17888,37 +16210,31 @@ msgstr ""
 
 #: common.opt:679
 #, fuzzy, no-c-format
-#| msgid "Issue warnings needed for strict compliance to the standard"
 msgid "Issue warnings needed for strict compliance to the standard."
 msgstr "標準に厳密に準拠するために必要な警告を出力する"
 
 #: common.opt:683
 #, fuzzy, no-c-format
-#| msgid "returning reference to temporary"
 msgid "Warn about returning a pointer/reference to a local or temporary variable."
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
 #: common.opt:687
 #, fuzzy, no-c-format
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one variable shadows another.  Same as -Wshadow=global."
 msgstr "あるローカル変数が他のものを覆い隠すときに警告する"
 
 #: common.opt:691
 #, fuzzy, no-c-format
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one variable shadows another (globally)."
 msgstr "あるローカル変数が他のものを覆い隠すときに警告する"
 
 #: common.opt:695
 #, fuzzy, no-c-format
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one local variable shadows another local variable or parameter."
 msgstr "あるローカル変数が他のものを覆い隠すときに警告する"
 
 #: common.opt:702
 #, fuzzy, no-c-format
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one local variable shadows another local variable or parameter of compatible type."
 msgstr "あるローカル変数が他のものを覆い隠すときに警告する"
 
@@ -17929,7 +16245,6 @@ msgstr ""
 
 #: common.opt:713
 #, fuzzy, no-c-format
-#| msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size"
 msgid "-Wstack-usage=<byte-size>\tWarn if stack usage might exceed <byte-size>."
 msgstr "-mmax-stackframe=SIZE\tスタックフレームが指定したサイズより大きい場合に警告する"
 
@@ -17940,43 +16255,36 @@ msgstr ""
 
 #: common.opt:721 common.opt:725
 #, fuzzy, no-c-format
-#| msgid "Warn about code which might break strict aliasing rules"
 msgid "Warn about code which might break strict aliasing rules."
 msgstr "厳密な別名規約を壊す可能性があるコードに関して警告する"
 
 #: common.opt:729 common.opt:733
 #, fuzzy, no-c-format
-#| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Warn about optimizations that assume that signed overflow is undefined."
 msgstr "デフォルトの浮動小数点丸め動作と見なせる最適化を無効にする"
 
 #: common.opt:737
 #, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for __attribute__((const))"
 msgid "Warn about functions which might be candidates for __attribute__((cold))."
 msgstr "関数が __attribute__((const)) の候補となりそうな場合に警告する"
 
 #: common.opt:741
 #, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for __attribute__((const))"
 msgid "Warn about functions which might be candidates for __attribute__((const))."
 msgstr "関数が __attribute__((const)) の候補となりそうな場合に警告する"
 
 #: common.opt:745
 #, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for __attribute__((pure))"
 msgid "Warn about functions which might be candidates for __attribute__((pure))."
 msgstr "関数が __attribute__((pure)) の候補となりそうな場合に警告する"
 
 #: common.opt:749
 #, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for __attribute__((noreturn))"
 msgid "Warn about functions which might be candidates for __attribute__((noreturn))."
 msgstr "関数が __attribute__((noreturn)) の候補となりそうな場合に警告する"
 
 #: common.opt:753
 #, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for __attribute__((const))"
 msgid "Warn about functions which might be candidates for __attribute__((malloc))."
 msgstr "関数が __attribute__((const)) の候補となりそうな場合に警告する"
 
@@ -17992,85 +16300,71 @@ msgstr ""
 
 #: common.opt:765
 #, fuzzy, no-c-format
-#| msgid "Warn about all enumerated switches missing a specific case"
 msgid "Warn about statements between switch's controlling expression and the first case."
 msgstr "列挙定数を使用した switch 文で特定の case が無い場合に警告する"
 
 #: common.opt:770
 #, fuzzy, no-c-format
-#| msgid "Do not suppress warnings from system headers"
 msgid "Do not suppress warnings from system headers."
 msgstr "システムヘッダからの警告を抑制しない"
 
 #: common.opt:774
 #, fuzzy, no-c-format
-#| msgid "Warn whenever type qualifiers are ignored."
 msgid "Warn whenever a trampoline is generated."
 msgstr "型修飾子が無視された場合はいつも警告する"
 
 #: common.opt:778
 #, fuzzy, no-c-format
-#| msgid "Warn if a comparison is always true or always false due to the limited range of the data type"
 msgid "Warn if a comparison is always true or always false due to the limited range of the data type."
 msgstr "データ型の範囲制限により比較が常に true または常に false になる場合に警告する"
 
 #: common.opt:782
 #, fuzzy, no-c-format
-#| msgid "Warn about uninitialized automatic variables"
 msgid "Warn about uninitialized automatic variables."
 msgstr "初期化されていない自動変数に関して警告する"
 
 #: common.opt:786
 #, fuzzy, no-c-format
-#| msgid "Warn about uninitialized automatic variables"
 msgid "Warn about maybe uninitialized automatic variables."
 msgstr "初期化されていない自動変数に関して警告する"
 
 #: common.opt:794
 #, fuzzy, no-c-format
-#| msgid "Enable all -Wunused- warnings"
 msgid "Enable all -Wunused- warnings."
 msgstr "すべての -Wunused- 警告を有効にする"
 
 #: common.opt:798
 #, fuzzy, no-c-format
-#| msgid "Warn when a function parameter is only set, otherwise unused"
 msgid "Warn when a function parameter is only set, otherwise unused."
 msgstr "関数の仮引数が設定されているだけで、使用されていない場合に警告する"
 
 #: common.opt:802
 #, fuzzy, no-c-format
-#| msgid "Warn when a variable is only set, otherwise unused"
 msgid "Warn when a variable is only set, otherwise unused."
 msgstr "変数が設定されているだけで、使用されていない場合に警告する"
 
 #: common.opt:806
 #, fuzzy, no-c-format
-#| msgid "Warn when a function is unused"
 msgid "Warn when a function is unused."
 msgstr "関数が使用されていない場合に警告する"
 
 #: common.opt:810
 #, fuzzy, no-c-format
-#| msgid "Warn when a label is unused"
 msgid "Warn when a label is unused."
 msgstr "ラベルが使用されていないときに警告する"
 
 #: common.opt:814
 #, fuzzy, no-c-format
-#| msgid "Warn when a function parameter is unused"
 msgid "Warn when a function parameter is unused."
 msgstr "関数の仮引数が使用されていない場合に警告する"
 
 #: common.opt:818
 #, fuzzy, no-c-format
-#| msgid "Warn when an expression value is unused"
 msgid "Warn when an expression value is unused."
 msgstr "式の値が使用されていない場合に警告する"
 
 #: common.opt:822
 #, fuzzy, no-c-format
-#| msgid "Warn when a variable is unused"
 msgid "Warn when a variable is unused."
 msgstr "変数が使用されていない場合に警告する"
 
@@ -18081,7 +16375,6 @@ msgstr ""
 
 #: common.opt:830
 #, fuzzy, no-c-format
-#| msgid "Warn about user-specified include directories that do not exist"
 msgid "Warn in case profiles in -fprofile-use do not exist."
 msgstr "利用者が指定したインクルードディレクトリが存在しない場合に警告する"
 
@@ -18092,25 +16385,21 @@ msgstr ""
 
 #: common.opt:850
 #, fuzzy, no-c-format
-#| msgid "-aux-info <file>\tEmit declaration information into <file>"
 msgid "-aux-info <file>\tEmit declaration information into <file>."
 msgstr "-aux-info <file>\t宣言情報を <file> に発行する"
 
 #: common.opt:869
 #, fuzzy, no-c-format
-#| msgid "-d<letters>\tEnable dumps from specific passes of the compiler"
 msgid "-d<letters>\tEnable dumps from specific passes of the compiler."
 msgstr "-d<letters>\tコンパイラの特定の過程からのダンプを有効にする"
 
 #: common.opt:873
 #, fuzzy, no-c-format
-#| msgid "-dumpbase <file>\tSet the file basename to be used for dumps"
 msgid "-dumpbase <file>\tSet the file basename to be used for dumps."
 msgstr "-dumpbase <file>\tダンプ用に使用されるファイルの基となる名前を設定する"
 
 #: common.opt:877
 #, fuzzy, no-c-format
-#| msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\tダンプ用に使用されるディレクトリ名を設定する"
 
@@ -18126,25 +16415,21 @@ msgstr ""
 
 #: common.opt:971
 #, fuzzy, no-c-format
-#| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "関数に開始を整列する"
 
 #: common.opt:981
 #, fuzzy, no-c-format
-#| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "ジャンプの到達先となるラベルのみ整列する"
 
 #: common.opt:988
 #, fuzzy, no-c-format
-#| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "全てのラベルを整列する"
 
 #: common.opt:995
 #, fuzzy, no-c-format
-#| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "ループの開始を整列する"
 
@@ -18155,7 +16440,6 @@ msgstr ""
 
 #: common.opt:1006
 #, fuzzy, no-c-format
-#| msgid "Enable traditional preprocessing"
 msgid "Enable static analysis pass."
 msgstr "伝統的な前処理を有効にする"
 
@@ -18186,7 +16470,6 @@ msgstr ""
 
 #: common.opt:1047
 #, fuzzy, no-c-format
-#| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
@@ -18202,7 +16485,6 @@ msgstr ""
 
 #: common.opt:1062
 #, fuzzy, no-c-format
-#| msgid "Generate auto-inc/dec instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "自動増加/減少命令を生成する"
 
@@ -18218,7 +16500,6 @@ msgstr ""
 
 #: common.opt:1080
 #, fuzzy, no-c-format
-#| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "配列の添え字を使用する前に境界検査を行うコードを生成する"
 
@@ -18229,61 +16510,51 @@ msgstr "加算、比較ブランチの代わりにカウントレジスタのブ
 
 #: common.opt:1088
 #, fuzzy, no-c-format
-#| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "分岐経路推測用のプロファイル情報を利用する"
 
 #: common.opt:1104
 #, fuzzy, no-c-format
-#| msgid "Output stack usage information on a per-function basis"
 msgid "Output callgraph information on a per-file basis."
 msgstr "関数単位でスタック使用情報を出力する"
 
 #: common.opt:1108
 #, fuzzy, no-c-format
-#| msgid "Output stack usage information on a per-function basis"
 msgid "Output callgraph information on a per-file basis with decorations."
 msgstr "関数単位でスタック使用情報を出力する"
 
 #: common.opt:1112
 #, fuzzy, no-c-format
-#| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>  <register> が関数を通じて保全されるとマークする"
 
 #: common.opt:1116
 #, fuzzy, no-c-format
-#| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\t<register> が関数呼び出しによって変更されるとマークする"
 
 #: common.opt:1123
 #, fuzzy, no-c-format
-#| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "関数呼び出しの前後でレジスタを保存する"
 
 #: common.opt:1127
 #, fuzzy, no-c-format
-#| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
 #: common.opt:1131
 #, fuzzy, no-c-format
-#| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "new の戻り値を検査する"
 
 #: common.opt:1135 common.opt:1139
 #, fuzzy, no-c-format
-#| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "内部一貫性がありません"
 
 #: common.opt:1143
 #, fuzzy, no-c-format
-#| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "関数プロファイルを有効にする"
 
@@ -18294,7 +16565,6 @@ msgstr "スタック調整およびスタック参照を削減する機会を探
 
 #: common.opt:1151
 #, fuzzy, no-c-format
-#| msgid "Do not put uninitialized globals in the common section"
 msgid "Put uninitialized globals in the common section."
 msgstr "初期化されない大域変数類を共通セクションに配置しない"
 
@@ -18305,37 +16575,31 @@ msgstr ""
 
 #: common.opt:1163
 #, fuzzy, no-c-format
-#| msgid "recompiling with -fcompare-debug"
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "-fcompare-debug 付きで再コンパイルしています"
 
 #: common.opt:1167
 #, fuzzy, no-c-format
-#| msgid "Perform comparison elimination after register allocation has finished"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "レジスタは位置が完了した後に比較の除去を行う"
 
 #: common.opt:1171
 #, fuzzy, no-c-format
-#| msgid "Do not perform optimizations increasing noticeably stack usage"
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "スタック使用量を著しく増加させる最適化を行わない"
 
 #: common.opt:1175
 #, fuzzy, no-c-format
-#| msgid "Perform whole program optimizations"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "プログラム全体の最適化を実行する"
 
 #: common.opt:1179
 #, fuzzy, no-c-format
-#| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "ジャンプをまたがった最適化を行う"
 
 #: common.opt:1183
 #, fuzzy, no-c-format
-#| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "CSE で動作するとき、それらのターゲットへのジャンプに追随する"
 
@@ -18346,13 +16610,11 @@ msgstr ""
 
 #: common.opt:1195
 #, fuzzy, no-c-format
-#| msgid "Complex multiplication and division follow Fortran rules"
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Fortran 規格に従った複素数の乗除算を行う"
 
 #: common.opt:1199
 #, fuzzy, no-c-format
-#| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "データ項目をそれら自身のセクションに配置する"
 
@@ -18363,19 +16625,16 @@ msgstr ""
 
 #: common.opt:1207
 #, fuzzy, no-c-format
-#| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tデバッグカウンタ制限を設定する。"
 
 #: common.opt:1211
 #, fuzzy, no-c-format
-#| msgid "Map one directory name to another in debug information"
 msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
 #: common.opt:1215
 #, fuzzy, no-c-format
-#| msgid "Map one directory name to another in debug information"
 msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
@@ -18386,13 +16645,11 @@ msgstr ""
 
 #: common.opt:1225
 #, fuzzy, no-c-format
-#| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "関数引数をスタックから pop するのを呼び出し後まで遅らせる"
 
 #: common.opt:1229
 #, fuzzy, no-c-format
-#| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "分岐命令の遅延スロットを使うことを試みる"
 
@@ -18403,7 +16660,6 @@ msgstr ""
 
 #: common.opt:1237
 #, fuzzy, no-c-format
-#| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "無意味な null ポインタ検査を削除する"
 
@@ -18414,7 +16670,6 @@ msgstr ""
 
 #: common.opt:1245
 #, fuzzy, no-c-format
-#| msgid "Perform DWARF2 duplicate elimination"
 msgid "Perform speculative devirtualization."
 msgstr "DWARF2 重複削除を行う"
 
@@ -18507,25 +16762,21 @@ msgstr ""
 
 #: common.opt:1391
 #, fuzzy, no-c-format
-#| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
 #: common.opt:1398
 #, fuzzy, no-c-format
-#| msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=filename\t翻訳終了時に filename へ命令をダンプする"
 
 #: common.opt:1402
 #, fuzzy, no-c-format
-#| msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=filename\t全ての宣言を Go コードとしてファイルに書き込む"
 
 #: common.opt:1406
 #, fuzzy, no-c-format
-#| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "デバッグダンプ内でアドレスの出力を抑止する"
 
@@ -18546,13 +16797,11 @@ msgstr ""
 
 #: common.opt:1423
 #, fuzzy, no-c-format
-#| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "デバッグダンプ内で命令番号、行番号情報およびアドレスの出力を抑止する"
 
 #: common.opt:1427
 #, fuzzy, no-c-format
-#| msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "デバッグダンプ内で前と次の命令番号の出力を抑止する"
 
@@ -18563,7 +16812,6 @@ msgstr "GAS アセンブラ指示を経由して CFI 表を有効にする"
 
 #: common.opt:1435
 #, fuzzy, no-c-format
-#| msgid "Perform partial inlining"
 msgid "Perform early inlining."
 msgstr "部分的なインライン化を行う"
 
@@ -18574,13 +16822,11 @@ msgstr ""
 
 #: common.opt:1447
 #, fuzzy, no-c-format
-#| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
 #: common.opt:1451
 #, fuzzy, no-c-format
-#| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
@@ -18591,19 +16837,16 @@ msgstr "C++ クラスデバッグ情報を抑止しない。"
 
 #: common.opt:1459
 #, fuzzy, no-c-format
-#| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "例外処理を有効にする"
 
 #: common.opt:1463
 #, fuzzy, no-c-format
-#| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "多くの、目立たないがコストが高い最適化を行う"
 
 #: common.opt:1467
 #, fuzzy, no-c-format
-#| msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\t余分な浮動小数点精度の取り扱いを指定する"
 
@@ -18619,7 +16862,6 @@ msgstr ""
 
 #: common.opt:1502
 #, fuzzy, no-c-format
-#| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "NaN または無限大が生成されないと見なす"
 
@@ -18630,13 +16872,11 @@ msgstr ""
 
 #: common.opt:1510
 #, fuzzy, no-c-format
-#| msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\t<register> がコンパイラでは使用できないとマークする"
 
 #: common.opt:1514
 #, fuzzy, no-c-format
-#| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "拡張精度レジスタ内に float と double を配置しない"
 
@@ -18657,43 +16897,36 @@ msgstr ""
 
 #: common.opt:1550
 #, fuzzy, no-c-format
-#| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "関数アドレスをレジスタに持たせる事を許可する"
 
 #: common.opt:1554
 #, fuzzy, no-c-format
-#| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "それぞれの関数をそれ自身のセクションに配置する"
 
 #: common.opt:1558
 #, fuzzy, no-c-format
-#| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
 #: common.opt:1562
 #, fuzzy, no-c-format
-#| msgid "Perform global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
 #: common.opt:1566
 #, fuzzy, no-c-format
-#| msgid "Perform global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
 #: common.opt:1570
 #, fuzzy, no-c-format
-#| msgid "Perform global common subexpression elimination"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
 #: common.opt:1575
 #, fuzzy, no-c-format
-#| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "レジスタ配置後に大域共通部分式の除去を行う"
 
@@ -18719,7 +16952,6 @@ msgstr "条件的 move 命令の利用を有効にする"
 
 #: common.opt:1614
 #, fuzzy, no-c-format
-#| msgid "Mark all loops as parallel"
 msgid "Mark all loops as parallel."
 msgstr "全てのループを並列としてマークする"
 
@@ -18735,7 +16967,6 @@ msgstr "並列命令を有効にする"
 
 #: common.opt:1630
 #, fuzzy, no-c-format
-#| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "全てのループでループ展開を行なう"
 
@@ -18751,7 +16982,6 @@ msgstr ""
 
 #: common.opt:1646
 #, fuzzy, no-c-format
-#| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "ラベル整列最適化を有効にする"
 
@@ -18767,13 +16997,11 @@ msgstr ""
 
 #: common.opt:1658
 #, fuzzy, no-c-format
-#| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "分岐可能性の推測を有効にする"
 
 #: common.opt:1666
 #, fuzzy, no-c-format
-#| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "#ident 指示を処理する"
 
@@ -18784,7 +17012,6 @@ msgstr ""
 
 #: common.opt:1674
 #, fuzzy, no-c-format
-#| msgid "Prefer branches over conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "条件付き実行より分岐の生成を優先する"
 
@@ -18800,13 +17027,11 @@ msgstr ""
 
 #: common.opt:1706
 #, fuzzy, no-c-format
-#| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr ".size 指示を生成しない"
 
 #: common.opt:1710
 #, fuzzy, no-c-format
-#| msgid "Perform indirect inlining"
 msgid "Perform indirect inlining."
 msgstr "間接インライン化を実行する"
 
@@ -18817,25 +17042,21 @@ msgstr ""
 
 #: common.opt:1720
 #, fuzzy, no-c-format
-#| msgid "Integrate simple functions into their callers when code size is known to not growth"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "コードサイズが増加しないと分かってる場合は単純な関数を呼び出し側に統合する"
 
 #: common.opt:1724
 #, fuzzy, no-c-format
-#| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
 #: common.opt:1728
 #, fuzzy, no-c-format
-#| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
 #: common.opt:1735
 #, fuzzy, no-c-format
-#| msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "  -finline-limit=<number> インライン関数のサイズを <number> に制限する"
 
@@ -18891,7 +17112,6 @@ msgstr ""
 
 #: common.opt:1802
 #, fuzzy, no-c-format
-#| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "純粋および定数関数を見つける"
 
@@ -18912,13 +17132,11 @@ msgstr ""
 
 #: common.opt:1818
 #, fuzzy, no-c-format
-#| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only and non addressable static variables."
 msgstr "読み取り専用およびアドレス付けできない静的変数を見つける"
 
 #: common.opt:1822
 #, fuzzy, no-c-format
-#| msgid "Discover readonly and non addressable static variables"
 msgid "Discover read-only, write-only and non-addressable static variables."
 msgstr "読み取り専用およびアドレス付けできない静的変数を見つける"
 
@@ -18934,13 +17152,11 @@ msgstr ""
 
 #: common.opt:1842
 #, fuzzy, no-c-format
-#| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority] 使用する IRA アルゴリズムを設定する"
 
 #: common.opt:1855
 #, fuzzy, no-c-format
-#| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] IRA 用の範囲を設定する"
 
@@ -18976,31 +17192,26 @@ msgstr "ループの中の全ての一般誘導変数を強度削減する"
 
 #: common.opt:1897
 #, fuzzy, no-c-format
-#| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "十分に大きな switch 文ではジャンプ表を使用する"
 
 #: common.opt:1901
 #, fuzzy, no-c-format
-#| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
 #: common.opt:1905
 #, fuzzy, no-c-format
-#| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
 #: common.opt:1909
 #, fuzzy, no-c-format
-#| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "使用されない静的定数変数であっても出力する"
 
 #: common.opt:1913
 #, fuzzy, no-c-format
-#| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "外部シンボルの先頭に下線 (_) を付ける"
 
@@ -19031,61 +17242,51 @@ msgstr ""
 
 #: common.opt:1964
 #, fuzzy, no-c-format
-#| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics."
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
 #: common.opt:1968
 #, fuzzy, no-c-format
-#| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
 #: common.opt:1972
 #, fuzzy, no-c-format
-#| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "組み込み数学関数の後に errno をセットする"
 
 #: common.opt:1976
 #, fuzzy, no-c-format
-#| msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<number>\tエラー報告する最大数を <number> にする"
 
 #: common.opt:1980
 #, fuzzy, no-c-format
-#| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "永続的なメモリ確保に関して報告する"
 
 #: common.opt:1984
 #, fuzzy, no-c-format
-#| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "永続的なメモリ確保に関して報告する"
 
 #: common.opt:1991
 #, fuzzy, no-c-format
-#| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "定数と定数変数の併合を試みる"
 
 #: common.opt:1995
 #, fuzzy, no-c-format
-#| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "コンパイル単位をまたがった同一の定数の併合を試みる"
 
 #: common.opt:1999
 #, fuzzy, no-c-format
-#| msgid "Attempt to merge identical debug strings across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "コンパイル単位をまたがった同一のデバッグ文字列の併合を試みる"
 
 #: common.opt:2003
 #, fuzzy, no-c-format
-#| msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<number>\t一行あたりの診断メッセージ文字数を <number> に制限する。0 の場合は改行しない"
 
@@ -19101,19 +17302,16 @@ msgstr ""
 
 #: common.opt:2015
 #, fuzzy, no-c-format
-#| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "ループの中で変更がない計算をループの外に移動する"
 
 #: common.opt:2019
 #, fuzzy, no-c-format
-#| msgid "Use the RTL dead code elimination pass"
 msgid "Use the RTL dead code elimination pass."
 msgstr "RTL 不要なコード (dead code) の除去過程を使用する"
 
 #: common.opt:2023
 #, fuzzy, no-c-format
-#| msgid "Use the RTL dead store elimination pass"
 msgid "Use the RTL dead store elimination pass."
 msgstr "RTL 不要な記憶域 (dead store) 除去過程を使用する"
 
@@ -19124,7 +17322,6 @@ msgstr ""
 
 #: common.opt:2031
 #, fuzzy, no-c-format
-#| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "同期非呼び出し例外をサポートする"
 
@@ -19140,7 +17337,6 @@ msgstr ""
 
 #: common.opt:2052
 #, fuzzy, no-c-format
-#| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "可能な場合、スタックフレームを生成しない"
 
@@ -19161,13 +17357,11 @@ msgstr ""
 
 #: common.opt:2072
 #, fuzzy, no-c-format
-#| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "sibling 呼び出しや末尾再帰呼び出しを最適化する"
 
 #: common.opt:2076
 #, fuzzy, no-c-format
-#| msgid "Perform partial inlining"
 msgid "Perform partial inlining."
 msgstr "部分的なインライン化を行う"
 
@@ -19178,7 +17372,6 @@ msgstr ""
 
 #: common.opt:2088
 #, fuzzy, no-c-format
-#| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "構造体メンバを穴が開かないようにパックする"
 
@@ -19189,19 +17382,16 @@ msgstr ""
 
 #: common.opt:2096
 #, fuzzy, no-c-format
-#| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "小さな集合体を (レジスタではなく) メモリで返す"
 
 #: common.opt:2100
 #, fuzzy, no-c-format
-#| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "ループの展開を行う"
 
 #: common.opt:2104
 #, fuzzy, no-c-format
-#| msgid "Enable nested conditional execution optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "入れ子にされた条件付き実行の最適化を有効にする"
 
@@ -19212,25 +17402,21 @@ msgstr ""
 
 #: common.opt:2112
 #, fuzzy, no-c-format
-#| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "可能であれば位置非依存コードを生成する (large モード)"
 
 #: common.opt:2116
 #, fuzzy, no-c-format
-#| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "可能であれば実行可能な位置非依存コードを生成する (large モード)"
 
 #: common.opt:2120
 #, fuzzy, no-c-format
-#| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "可能であれば胃非値非損コードを生成する (small モード)"
 
 #: common.opt:2124
 #, fuzzy, no-c-format
-#| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "可能であれば実行可能な非値非依存コードを生成する (small モード)"
 
@@ -19241,13 +17427,11 @@ msgstr ""
 
 #: common.opt:2132
 #, fuzzy, no-c-format
-#| msgid "Specify a plugin to load"
 msgid "Specify a plugin to load."
 msgstr "ロードするプラグインを指定する"
 
 #: common.opt:2136
 #, fuzzy, no-c-format
-#| msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<name>-<key>[=<value>]\tプラグイン <name> 用に引数 <key>=<value> を指定する"
 
@@ -19258,13 +17442,11 @@ msgstr ""
 
 #: common.opt:2144
 #, fuzzy, no-c-format
-#| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "ループ内の配列で、可能であればプリフェッチ命令を生成する"
 
 #: common.opt:2148
 #, fuzzy, no-c-format
-#| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "基本プログラムプロファイリングコードを有効にする"
 
@@ -19275,25 +17457,21 @@ msgstr ""
 
 #: common.opt:2156
 #, fuzzy, no-c-format
-#| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "円弧ベースプログラムプロファイリングコードを挿入する"
 
 #: common.opt:2160
 #, fuzzy, no-c-format
-#| msgid "Set the top-level directory for storing the profile data."
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "プロファイルデータ保存用の最上位ディレクリーを設定する"
 
 #: common.opt:2165
 #, fuzzy, no-c-format
-#| msgid "Set the top-level directory for storing the profile data."
 msgid "Select the name for storing the profile note file."
 msgstr "プロファイルデータ保存用の最上位ディレクリーを設定する"
 
 #: common.opt:2169
 #, fuzzy, no-c-format
-#| msgid "Enable correction of flow inconsistent profile data input"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "フロー一貫性が無いデータ入力の訂正を有効にする"
 
@@ -19349,31 +17527,26 @@ msgstr ""
 
 #: common.opt:2237
 #, fuzzy, no-c-format
-#| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "式の値をプロファイルするためのコードを挿入する"
 
 #: common.opt:2241
 #, fuzzy, no-c-format
-#| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "内部一貫性がありません"
 
 #: common.opt:2245
 #, fuzzy, no-c-format
-#| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "コード配置を改善するために関数を並べ替える"
 
 #: common.opt:2249
 #, fuzzy, no-c-format
-#| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "関数プロローグ内で cld 命令を生成する"
 
 #: common.opt:2256
 #, fuzzy, no-c-format
-#| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<string>\t<string> を使用してコンパイルを再現可能にする"
 
@@ -19384,7 +17557,6 @@ msgstr "オブジェクトファイル内に gcc のコマンドラインスイ
 
 #: common.opt:2270
 #, fuzzy, no-c-format
-#| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "小さな集合体をレジスタで返す"
 
@@ -19410,7 +17582,6 @@ msgstr ""
 
 #: common.opt:2312
 #, fuzzy, no-c-format
-#| msgid "Perform whole program optimizations"
 msgid "Perform a register renaming optimization pass."
 msgstr "プログラム全体の最適化を実行する"
 
@@ -19421,7 +17592,6 @@ msgstr ""
 
 #: common.opt:2320
 #, fuzzy, no-c-format
-#| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
@@ -19432,31 +17602,26 @@ msgstr ""
 
 #: common.opt:2337
 #, fuzzy, no-c-format
-#| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
 #: common.opt:2341
 #, fuzzy, no-c-format
-#| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "コード配置を改善するために関数を並べ替える"
 
 #: common.opt:2345
 #, fuzzy, no-c-format
-#| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "ループ最適化後に共通部分式を除去する過程を追加する"
 
 #: common.opt:2353
 #, fuzzy, no-c-format
-#| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "デフォルトの浮動小数点丸め動作と見なせる最適化を無効にする"
 
 #: common.opt:2357
 #, fuzzy, no-c-format
-#| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "基本ブロックをまたがるスケジューリングを有効にする"
 
@@ -19467,25 +17632,21 @@ msgstr ""
 
 #: common.opt:2365
 #, fuzzy, no-c-format
-#| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "非ロードでの不確実な動作を許可する"
 
 #: common.opt:2369
 #, fuzzy, no-c-format
-#| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "いくつかのロードでの不確実な動作を許可する"
 
 #: common.opt:2373
 #, fuzzy, no-c-format
-#| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "より多くのロードでの不確実な動作を許可する"
 
 #: common.opt:2377
 #, fuzzy, no-c-format
-#| msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<number>\tスケジューラの冗長レベルを設定する"
 
@@ -19496,13 +17657,11 @@ msgstr ""
 
 #: common.opt:2389
 #, fuzzy, no-c-format
-#| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
 #: common.opt:2393
 #, fuzzy, no-c-format
-#| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "レジスタ確保の後で命令を並べ直す"
 
@@ -19513,7 +17672,6 @@ msgstr ""
 
 #: common.opt:2404
 #, fuzzy, no-c-format
-#| msgid "Run selective scheduling after reload"
 msgid "Run selective scheduling after reload."
 msgstr "再ロード後に選択的スケジューリングを実行する"
 
@@ -19574,7 +17732,6 @@ msgstr ""
 
 #: common.opt:2458
 #, fuzzy, no-c-format
-#| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
@@ -19585,7 +17742,6 @@ msgstr ""
 
 #: common.opt:2466
 #, fuzzy, no-c-format
-#| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
@@ -19606,7 +17762,6 @@ msgstr ""
 
 #: common.opt:2490
 #, fuzzy, no-c-format
-#| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "診断内で利用可能な場合に列番号を表示する。デフォルトで有効"
 
@@ -19632,31 +17787,26 @@ msgstr ""
 
 #: common.opt:2511
 #, fuzzy, no-c-format
-#| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "浮動小数点定数を単精度定数に変換する"
 
 #: common.opt:2515
 #, fuzzy, no-c-format
-#| msgid "Apply variable expansion when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "ループを展開したときに変数の展開を行う"
 
 #: common.opt:2519
 #, fuzzy, no-c-format
-#| msgid "Generate discontiguous stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "不連続なスタックフレームを生成する"
 
 #: common.opt:2523
 #, fuzzy, no-c-format
-#| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers."
 msgstr "ワイド型を独立したレジスタに分割する"
 
 #: common.opt:2527
 #, fuzzy, no-c-format
-#| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers earlier."
 msgstr "ワイド型を独立したレジスタに分割する"
 
@@ -19677,19 +17827,16 @@ msgstr ""
 
 #: common.opt:2543
 #, fuzzy, no-c-format
-#| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "ループを展開したときに変数の展開を行う"
 
 #: common.opt:2547
 #, fuzzy, no-c-format
-#| msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tプログラム内にスタック検査コードを挿入する"
 
 #: common.opt:2551
 #, fuzzy, no-c-format
-#| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "プログラム内にスタック検査コードを挿入する。 -fstack-check=specific と同様"
 
@@ -19700,55 +17847,46 @@ msgstr ""
 
 #: common.opt:2563
 #, fuzzy, no-c-format
-#| msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tスタックがレジスタ <register> より後に行った場合にトラップする"
 
 #: common.opt:2567
 #, fuzzy, no-c-format
-#| msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<name>\tスタックがシンボル <name> より後に行った場合にトラップする"
 
 #: common.opt:2571
 #, fuzzy, no-c-format
-#| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "スタック保護方法としてプロポリス (propolice) を使用する"
 
 #: common.opt:2575
 #, fuzzy, no-c-format
-#| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
 #: common.opt:2579
 #, fuzzy, no-c-format
-#| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
 #: common.opt:2583
 #, fuzzy, no-c-format
-#| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
 #: common.opt:2587
 #, fuzzy, no-c-format
-#| msgid "Output stack usage information on a per-function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "関数単位でスタック使用情報を出力する"
 
 #: common.opt:2599
 #, fuzzy, no-c-format
-#| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "厳密な別名規則を適用するとみなす"
 
 #: common.opt:2603
 #, fuzzy, no-c-format
-#| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "符号のオーバーフローを未定義として取り扱う"
 
@@ -19759,25 +17897,21 @@ msgstr ""
 
 #: common.opt:2611
 #, fuzzy, no-c-format
-#| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "構文エラーを検査して、そこで停止する"
 
 #: common.opt:2615
 #, fuzzy, no-c-format
-#| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "\"gcov\" で必要となるデータファイルを作成する"
 
 #: common.opt:2619
 #, fuzzy, no-c-format
-#| msgid "Perform cross-jumping optimization"
 msgid "Perform jump threading optimizations."
 msgstr "ジャンプをまたがった最適化を行う"
 
 #: common.opt:2623
 #, fuzzy, no-c-format
-#| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "各コンパイル過程で費やした時間を報告する"
 
@@ -19788,13 +17922,11 @@ msgstr ""
 
 #: common.opt:2631
 #, fuzzy, no-c-format
-#| msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tデフォルトのスレッド局所記憶域 (TLS) コード生成モデルを設定する"
 
 #: common.opt:2650
 #, fuzzy, no-c-format
-#| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "トップレベルの関数、変数、アセンブラを並べ替える"
 
@@ -19810,13 +17942,11 @@ msgstr ""
 
 #: common.opt:2666
 #, fuzzy, no-c-format
-#| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "浮動小数点操作をトラップできると見なす"
 
 #: common.opt:2670
 #, fuzzy, no-c-format
-#| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "加算、減算、乗算内での符号付きのオーバーフローをトラップする"
 
@@ -19862,7 +17992,6 @@ msgstr "SSA 最適化を有効にする"
 
 #: common.opt:2722
 #, fuzzy, no-c-format
-#| msgid "Enable linker optimizations"
 msgid "Enable dominator optimizations."
 msgstr "リンカ最適化を有効にする"
 
@@ -19873,7 +18002,6 @@ msgstr "SSA 最適化を有効にする"
 
 #: common.opt:2730
 #, fuzzy, no-c-format
-#| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "不要な記憶域 (dead store) の除去を行う"
 
@@ -19929,7 +18057,6 @@ msgstr "SSA 最適化を有効にする"
 
 #: common.opt:2783
 #, fuzzy, no-c-format
-#| msgid "Enable automatic parallelization of loops"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "ループの自動並列化を有効にする"
 
@@ -20000,19 +18127,16 @@ msgstr ""
 
 #: common.opt:2844
 #, fuzzy, no-c-format
-#| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "コンパイル単位全体を一回でコンパイルする"
 
 #: common.opt:2848
 #, fuzzy, no-c-format
-#| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "反復回数が既知のとき、ループ展開を行なう"
 
 #: common.opt:2852
 #, fuzzy, no-c-format
-#| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "全てのループでループ展開を行なう"
 
@@ -20038,7 +18162,6 @@ msgstr "全てのループでループ展開を行なう"
 
 #: common.opt:2888
 #, fuzzy, no-c-format
-#| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "ループの展開を行う"
 
@@ -20049,7 +18172,6 @@ msgstr ""
 
 #: common.opt:2896
 #, fuzzy, no-c-format
-#| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "巻き戻しを行なう例外補足用テーブルを生成する"
 
@@ -20070,13 +18192,11 @@ msgstr ""
 
 #: common.opt:2920
 #, fuzzy, no-c-format
-#| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "変数追跡を実施する"
 
 #: common.opt:2928
 #, fuzzy, no-c-format
-#| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "変数追跡を実施する"
 
@@ -20117,7 +18237,6 @@ msgstr ""
 
 #: common.opt:2983
 #, fuzzy, no-c-format
-#| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
@@ -20128,13 +18247,11 @@ msgstr ""
 
 #: common.opt:3001
 #, fuzzy, no-c-format
-#| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "余分なコメントをアセンブラ出力に追加する"
 
 #: common.opt:3005
 #, fuzzy, no-c-format
-#| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tシンボル可視性のデフォルトを設定する"
 
@@ -20165,49 +18282,41 @@ msgstr ""
 
 #: common.opt:3056
 #, fuzzy, no-c-format
-#| msgid "Enable conditional execution other than moves/scc"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "moves/scc 以外で条件付き実行を有効にする"
 
 #: common.opt:3060
 #, fuzzy, no-c-format
-#| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "プログラム全体の最適化を実行する"
 
 #: common.opt:3064
 #, fuzzy, no-c-format
-#| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
 #: common.opt:3068
 #, fuzzy, no-c-format
-#| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
 #: common.opt:3072
 #, fuzzy, no-c-format
-#| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
 #: common.opt:3076
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
 #: common.opt:3080
 #, fuzzy, no-c-format
-#| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
 #: common.opt:3084
 #, fuzzy, no-c-format
-#| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
@@ -20218,25 +18327,21 @@ msgstr ""
 
 #: common.opt:3108
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
 #: common.opt:3112
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in DWARF v2 (or later) format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 (またはそれ以降) 形式でデバッグ情報を生成する"
 
 #: common.opt:3116
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "デフォルト拡張形式でデバッグ情報を生成する"
 
 #: common.opt:3120
 #, fuzzy, no-c-format
-#| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions."
 msgstr "各関数で単一の終了点を生成する"
 
@@ -20262,25 +18367,21 @@ msgstr ""
 
 #: common.opt:3144
 #, fuzzy, no-c-format
-#| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
 #: common.opt:3148
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
 #: common.opt:3152
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "STABS 形式でデバッグ情報を生成する"
 
 #: common.opt:3156
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "拡張 STABS 形式でデバッグ情報を生成する"
 
@@ -20301,7 +18402,6 @@ msgstr ""
 
 #: common.opt:3172
 #, fuzzy, no-c-format
-#| msgid "Toggle debug information generation"
 msgid "Toggle debug information generation."
 msgstr "デバッグ情報生成の有効・無効を切り替える"
 
@@ -20312,25 +18412,21 @@ msgstr ""
 
 #: common.opt:3183
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "VMS 形式でデバッグ情報を生成する"
 
 #: common.opt:3187
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF 形式でデバッグ情報を生成する"
 
 #: common.opt:3191
 #, fuzzy, no-c-format
-#| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "拡張 XCOFF 形式でデバッグ情報を生成する"
 
 #: common.opt:3209
 #, fuzzy, no-c-format
-#| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "isel 命令を生成する"
 
@@ -20341,79 +18437,66 @@ msgstr ""
 
 #: common.opt:3220
 #, fuzzy, no-c-format
-#| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
 #: common.opt:3224
 #, fuzzy, no-c-format
-#| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
 #: common.opt:3249
 #, fuzzy, no-c-format
-#| msgid "-o <file>\tPlace output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t出力を <file> に配置する"
 
 #: common.opt:3253
 #, fuzzy, no-c-format
-#| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "関数プロファイルを有効にする"
 
 #: common.opt:3263
 #, fuzzy, no-c-format
-#| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic と同様だが、エラーとして出力する"
 
 #: common.opt:3303
 #, fuzzy, no-c-format
-#| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "コンパイルされた関数または費やした時間に関して出力しない"
 
 #: common.opt:3335
 #, fuzzy, no-c-format
-#| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "冗長な出力を有効にする"
 
 #: common.opt:3339
 #, fuzzy, no-c-format
-#| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "`コンパイラのバージョンを表示する"
 
 #: common.opt:3343
 #, fuzzy, no-c-format
-#| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "警告を抑止する"
 
 #: common.opt:3353
 #, fuzzy, no-c-format
-#| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "共有ライブラリを作成する"
 
 #: common.opt:3398
 #, fuzzy, no-c-format
-#| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
 #: common.opt:3402
 #, fuzzy, no-c-format
-#| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
 #: common.opt:3406
 #, fuzzy, no-c-format
-#| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
@@ -20434,7 +18517,6 @@ msgstr ""
 
 #: params.opt:35
 #, fuzzy, no-c-format
-#| msgid "Enable all optional instructions"
 msgid "Enable asan globals protection."
 msgstr "すべてのオプションの命令を有効にする"
 
@@ -20445,13 +18527,11 @@ msgstr ""
 
 #: params.opt:43
 #, fuzzy, no-c-format
-#| msgid "Enable all optional instructions"
 msgid "Enable asan load operations protection."
 msgstr "すべてのオプションの命令を有効にする"
 
 #: params.opt:47
 #, fuzzy, no-c-format
-#| msgid "Enable saturation instructions"
 msgid "Enable asan store operations protection."
 msgstr "飽和命令を有効にする"
 
@@ -20462,13 +18542,11 @@ msgstr ""
 
 #: params.opt:55
 #, fuzzy, no-c-format
-#| msgid "Enable saturation instructions"
 msgid "Enable asan builtin functions protection."
 msgstr "飽和命令を有効にする"
 
 #: params.opt:59
 #, fuzzy, no-c-format
-#| msgid "Enable stack probing"
 msgid "Enable asan stack protection."
 msgstr "スタック探索を有効にする"
 
@@ -20509,19 +18587,16 @@ msgstr ""
 
 #: params.opt:91
 #, fuzzy, no-c-format
-#| msgid "Maximum number of nops to insert for a hint (Default 2)"
 msgid "Maximum number of namespaces to search for alternatives when name lookup fails."
 msgstr "ヒント用に挿入される nops の最大数 (デフォルト: 2)"
 
 #: params.opt:95
 #, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of queries into the alias oracle per store."
 msgstr "SCoP 内のパラメータの最大数"
 
 #: params.opt:99
 #, fuzzy, no-c-format
-#| msgid "Maximum size in bytes of constant values allowed as operands."
 msgid "Maximum size (in bytes) of objects tracked bytewise by dead store elimination."
 msgstr "被演算子として許可される定数値のバイト単位での最大サイズ"
 
@@ -20587,13 +18662,11 @@ msgstr ""
 
 #: params.opt:151
 #, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of arrays per SCoP."
 msgstr "SCoP 内のパラメータの最大数"
 
 #: params.opt:155
 #, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
 msgid "Maximum number of parameters in a SCoP."
 msgstr "SCoP 内のパラメータの最大数"
 
@@ -20639,7 +18712,6 @@ msgstr ""
 
 #: params.opt:191
 #, fuzzy, no-c-format
-#| msgid "The upper bound for sharing integer constants"
 msgid "The upper bound for sharing integer constants."
 msgstr "整数定数を共有するための上限値"
 
@@ -20655,7 +18727,6 @@ msgstr ""
 
 #: params.opt:203
 #, fuzzy, no-c-format
-#| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "Maximum depth of recursive cloning for self-recursive function."
 msgstr "インライン関数を再帰的にインライン化する時の最大深度"
 
@@ -20696,7 +18767,6 @@ msgstr ""
 
 #: params.opt:235
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -20742,7 +18812,6 @@ msgstr ""
 
 #: params.opt:271
 #, fuzzy, no-c-format
-#| msgid "Perform a number of minor, expensive optimizations"
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
 msgstr "多くの、目立たないがコストが高い最適化を行う"
 
@@ -20758,49 +18827,41 @@ msgstr ""
 
 #: params.opt:283
 #, fuzzy, no-c-format
-#| msgid "The size of L1 cache"
 msgid "The size of L1 cache line."
 msgstr "L1 キャッシュサイズ"
 
 #: params.opt:287
 #, fuzzy, no-c-format
-#| msgid "The size of L1 cache"
 msgid "The size of L1 cache."
 msgstr "L1 キャッシュサイズ"
 
 #: params.opt:291
 #, fuzzy, no-c-format
-#| msgid "The size of L2 cache"
 msgid "The size of L2 cache."
 msgstr "L2 キャッシュサイズ"
 
 #: params.opt:295
 #, fuzzy, no-c-format
-#| msgid "Maximal stack frame growth due to inlining (in percent)"
 msgid "Maximal growth due to inlining of large function (in percent)."
 msgstr "インライン化によって増加するスタックフレームの最大量 (百分率)"
 
 #: params.opt:299
 #, fuzzy, no-c-format
-#| msgid "The size of function body to be considered large"
 msgid "The size of function body to be considered large."
 msgstr "大きいと見なされる関数本体のサイズ"
 
 #: params.opt:303
 #, fuzzy, no-c-format
-#| msgid "The size of stack frame to be considered large"
 msgid "The size of stack frame to be considered large."
 msgstr "大きいと見なされるスタックフレームのサイズ"
 
 #: params.opt:307
 #, fuzzy, no-c-format
-#| msgid "Maximal stack frame growth due to inlining (in percent)"
 msgid "Maximal stack frame growth due to inlining (in percent)."
 msgstr "インライン化によって増加するスタックフレームの最大量 (百分率)"
 
 #: params.opt:311
 #, fuzzy, no-c-format
-#| msgid "The size of translation unit to be considered large"
 msgid "The size of translation unit to be considered large."
 msgstr "大きいと見なされる翻訳単位のサイズ"
 
@@ -20821,7 +18882,6 @@ msgstr ""
 
 #: params.opt:327
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of stmts in loop nest for loop interchange."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -20842,13 +18902,11 @@ msgstr ""
 
 #: params.opt:343
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:347
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
 msgstr "自動インライン化が行われる最大命令数"
 
@@ -20869,7 +18927,6 @@ msgstr ""
 
 #: params.opt:363
 #, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
 msgid "maximal number of LTO partitions streamed in parallel."
 msgstr "SCoP 内のパラメータの最大数"
 
@@ -20885,13 +18942,11 @@ msgstr ""
 
 #: params.opt:375
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:379
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of insns combine tries to combine."
 msgstr "自動インライン化が行われる最大命令数"
 
@@ -20907,13 +18962,11 @@ msgstr "RPTS 用の最大反復数を指定する"
 
 #: params.opt:391
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of insns of a completely peeled loop."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:395
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of incoming edges to consider for crossjumping."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -20924,13 +18977,11 @@ msgstr ""
 
 #: params.opt:403
 #, fuzzy, no-c-format
-#| msgid "Change the maximum length of conditionally-executed sequences"
 msgid "The maximum length of path considered in cse."
 msgstr "条件付き実行シーケンスの長さの最大値を変更する"
 
 #: params.opt:407
 #, fuzzy, no-c-format
-#| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum memory locations recorded by cselib."
 msgstr "GCSE によって配置されるメモリの最大量"
 
@@ -20941,13 +18992,11 @@ msgstr ""
 
 #: params.opt:415
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions to consider to fill a delay slot."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:419
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions to consider to find accurate live register information."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -20958,7 +19007,6 @@ msgstr ""
 
 #: params.opt:427
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of nested indirect inlining performed by early inliner."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -20979,7 +19027,6 @@ msgstr ""
 
 #: params.opt:443
 #, fuzzy, no-c-format
-#| msgid "Maximum number of nops to insert for a hint (Default 2)"
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
 msgstr "ヒント用に挿入される nops の最大数 (デフォルト: 2)"
 
@@ -20990,13 +19037,11 @@ msgstr ""
 
 #: params.opt:451
 #, fuzzy, no-c-format
-#| msgid "The maximum amount of memory to be allocated by GCSE"
 msgid "The maximum amount of memory to be allocated by GCSE."
 msgstr "GCSE によって配置されるメモリの最大量"
 
 #: params.opt:455
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
 msgstr "自動インライン化が行われる最大命令数"
 
@@ -21012,55 +19057,46 @@ msgstr ""
 
 #: params.opt:467
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:471
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:475
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:479
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions in a single function eligible for inlining."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:483
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when inlining for size."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:487
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions when automatically inlining small functions."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:491
 #, fuzzy, no-c-format
-#| msgid "The maximum depth of recursive inlining for inline functions"
 msgid "The maximum depth of recursive inlining for inline functions."
 msgstr "インライン関数を再帰的にインライン化する時の最大深度"
 
 #: params.opt:495
 #, fuzzy, no-c-format
-#| msgid "The maximum depth of recursive inlining for non-inline functions"
 msgid "The maximum depth of recursive inlining for non-inline functions."
 msgstr "非インライン関数を再帰的にインライン化する時の最大深度"
 
 #: params.opt:499
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "Maximum number of isl operations, 0 means unlimited."
 msgstr "自動インライン化が行われる最大命令数"
 
@@ -21111,7 +19147,6 @@ msgstr "RPTS 用の最大反復数を指定する"
 
 #: params.opt:539
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of insns of a peeled loop."
 msgstr "自動インライン化が行われる最大命令数"
 
@@ -21122,13 +19157,11 @@ msgstr ""
 
 #: params.opt:547 params.opt:591
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:551 params.opt:595
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21144,13 +19177,11 @@ msgstr "RPTS 用の最大反復数を指定する"
 
 #: params.opt:563
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:567
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21226,25 +19257,21 @@ msgstr ""
 
 #: params.opt:635
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of unrollings of a single loop."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
 #: params.opt:639
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of instructions to consider to unroll in a loop."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:643
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
 msgid "The maximum number of insns of an unswitched loop."
 msgstr "自動インライン化が行われる最大命令数"
 
 #: params.opt:647
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of unswitchings in a single loop."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21280,7 +19307,6 @@ msgstr ""
 
 #: params.opt:675
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The minimum number of matching instructions to consider for crossjumping."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21351,7 +19377,6 @@ msgstr ""
 
 #: params.opt:749
 #, fuzzy, no-c-format
-#| msgid "The number of insns executed before prefetch is completed"
 msgid "The number of insns executed before prefetch is completed."
 msgstr "プリフェッチが完了する前に実行される命令数"
 
@@ -21367,7 +19392,6 @@ msgstr ""
 
 #: params.opt:761
 #, fuzzy, no-c-format
-#| msgid "Use stubs for function prologues"
 msgid "Use internal function id in profile lookup."
 msgstr "関数プロローグ用のスタブを使用する"
 
@@ -21418,7 +19442,6 @@ msgstr ""
 
 #: params.opt:801
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21434,7 +19457,6 @@ msgstr ""
 
 #: params.opt:813
 #, fuzzy, no-c-format
-#| msgid "The number of prefetches that can run at the same time"
 msgid "The number of prefetches that can run at the same time."
 msgstr "同時に実行可能なプリフェッチの数"
 
@@ -21445,7 +19467,6 @@ msgstr ""
 
 #: params.opt:821
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "Maximum number of instructions in basic block to be considered for SLP vectorization."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21486,7 +19507,6 @@ msgstr ""
 
 #: params.opt:853
 #, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
 msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
 msgstr "インライン化するのが適格であるとされる単一の関数内の最大命令数"
 
@@ -21537,7 +19557,6 @@ msgstr ""
 
 #: params.opt:893
 #, fuzzy, no-c-format
-#| msgid "Maximal stack frame growth due to inlining (in percent)"
 msgid "Maximal code growth caused by tail duplication (in percent)."
 msgstr "インライン化によって増加するスタックフレームの最大量 (百分率)"
 
@@ -21568,13 +19587,11 @@ msgstr ""
 
 #: params.opt:917
 #, fuzzy, no-c-format
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Instruction accounted for function prologue, epilogue and other overhead."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
 #: params.opt:921
 #, fuzzy, no-c-format
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Time accounted for function prologue, epilogue and other overhead."
 msgstr "関数プロローグとエピローグ用にサブルーチンを使用する"
 
@@ -21657,20 +19674,17 @@ msgstr "数値型が予期されます"
 
 #: go/gofrontend/expressions.cc:5043
 #, fuzzy
-#| msgid "expected integer or boolean type"
 msgid "expected boolean type"
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:5048 c/c-parser.c:15301 c/c-parser.c:15308
 #: cp/parser.c:36357 cp/parser.c:36364
 #, fuzzy, gcc-internal-format
-#| msgid "expected pointer"
 msgid "expected integer"
 msgstr "ポインタが予期されます"
 
 #: go/gofrontend/expressions.cc:6816
 #, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of nil with nil"
 msgstr "gimple 条件内で無効な比較コードです"
 
@@ -21680,7 +19694,6 @@ msgstr ""
 
 #: go/gofrontend/expressions.cc:6860
 #, fuzzy
-#| msgid "division by zero"
 msgid "integer division by zero"
 msgstr "ゼロ除算が発生しました"
 
@@ -21691,7 +19704,6 @@ msgstr "被演算子が非整数型のシフト演算です"
 #: go/gofrontend/expressions.cc:6871 go/gofrontend/expressions.cc:6874
 #: go/gofrontend/expressions.cc:6882
 #, fuzzy
-#| msgid "shift count not unsigned integer"
 msgid "shift count not integer"
 msgstr "シフト数が符号無し整数ではありません"
 
@@ -21709,7 +19721,6 @@ msgstr "メソッド型がオブジェクト型に一致しません"
 
 #: go/gofrontend/expressions.cc:8205
 #, fuzzy
-#| msgid "invalid argument to built-in function"
 msgid "invalid use of %<...%> with builtin function"
 msgstr "組み込み関数への無効な引数です"
 
@@ -21743,7 +19754,6 @@ msgstr "引数が多すぎます"
 
 #: go/gofrontend/expressions.cc:8295
 #, fuzzy
-#| msgid "argument must be a constant"
 msgid "argument 1 must be a map"
 msgstr "引数は定数でなければいけません"
 
@@ -21761,7 +19771,6 @@ msgstr ""
 
 #: go/gofrontend/expressions.cc:8701
 #, fuzzy
-#| msgid "too many arguments to %qE"
 msgid "too many arguments to make"
 msgstr "%qE への引数が多すぎます"
 
@@ -21799,13 +19808,11 @@ msgstr "要素の型が同じでなければいけません"
 
 #: go/gofrontend/expressions.cc:10105
 #, fuzzy
-#| msgid "last argument must be an immediate"
 msgid "first argument must be []byte"
 msgstr "最後の引数は即値でなければいけません"
 
 #: go/gofrontend/expressions.cc:10108
 #, fuzzy
-#| msgid "argument must be a constant"
 msgid "second argument must be slice or string"
 msgstr "引数は定数でなければいけません"
 
@@ -21864,7 +19871,6 @@ msgstr ""
 
 #: go/gofrontend/expressions.cc:12821
 #, fuzzy
-#| msgid "index must be integer"
 msgid "slice capacity must be integer"
 msgstr "添え字は整数でなければいけません"
 
@@ -21931,7 +19937,6 @@ msgstr ""
 
 #: go/gofrontend/statements.cc:3145 go/gofrontend/statements.cc:3175
 #, fuzzy
-#| msgid "not enough arguments"
 msgid "not enough arguments to return"
 msgstr "十分な引数がありません"
 
@@ -21969,13 +19974,11 @@ msgstr ""
 
 #: go/gofrontend/types.cc:533
 #, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of non-ordered type"
 msgstr "gimple 条件内で無効な比較コードです"
 
 #: go/gofrontend/types.cc:549
 #, fuzzy
-#| msgid "-mmulticore can only be used with BF561"
 msgid "slice can only be compared to nil"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
@@ -21990,37 +19993,31 @@ msgstr ""
 
 #: go/gofrontend/types.cc:559
 #, fuzzy, c-format
-#| msgid "invalid operand to %%R"
 msgid "invalid operation (%s)"
 msgstr "%%R への無効な被演算子です"
 
 #: go/gofrontend/types.cc:582
 #, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of non-comparable type"
 msgstr "gimple 条件内で無効な比較コードです"
 
 #: go/gofrontend/types.cc:595
 #, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of generated struct"
 msgstr "gimple 条件内で無効な比較コードです"
 
 #: go/gofrontend/types.cc:606
 #, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of non-comparable struct"
 msgstr "gimple 条件内で無効な比較コードです"
 
 #: go/gofrontend/types.cc:616
 #, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of generated array"
 msgstr "gimple 条件内で無効な比較コードです"
 
 #: go/gofrontend/types.cc:623
 #, fuzzy
-#| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of non-comparable array"
 msgstr "非左辺値配列の無効な使用です"
 
@@ -22040,7 +20037,6 @@ msgstr "型 %s を型 %s として使用できません"
 
 #: go/gofrontend/types.cc:779
 #, fuzzy
-#| msgid "conversion to incomplete type"
 msgid "conversion from normal type to notinheap type"
 msgstr "不完全型への変換です"
 
@@ -22105,13 +20101,11 @@ msgstr "メソッド %s%s%s がありません"
 
 #: go/gofrontend/types.cc:9322
 #, fuzzy, c-format
-#| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "メソッド %s%s%s にはポインタが必要です"
 
 #: go/gofrontend/types.cc:9340
 #, fuzzy, c-format
-#| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "メソッド %s%s%s にはポインタが必要です"
 
@@ -22122,7 +20116,6 @@ msgstr ""
 
 #: attribs.c:446
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE 属性は %s 属性と競合します"
 
@@ -22143,7 +20136,6 @@ msgstr "%qE 属性指示が無視されました"
 
 #: attribs.c:571
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute directive ignored"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qE 属性指示が無視されました"
 
@@ -22154,7 +20146,6 @@ msgstr "%qE 属性用に間違った数の引数が指定されました"
 
 #: attribs.c:586
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected %<(%> or end of line"
 msgid "expected %i or more, found %i"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
@@ -22265,7 +20256,6 @@ msgstr "%q+D は dllimport 属性無しで再宣言されました: 前の dllim
 
 #: attribs.c:1666
 #, fuzzy, gcc-internal-format
-#| msgid "inline function %q+D declared as  dllimport: attribute ignored"
 msgid "inline function %q+D declared as dllimport: attribute ignored"
 msgstr "インライン関数 %q+D は dllimport として宣言されました: 属性が無視されました"
 
@@ -22297,7 +20287,6 @@ msgstr[0] ""
 
 #: attribs.c:1996 attribs.c:2016
 #, fuzzy, gcc-internal-format
-#| msgid "%qD was declared here"
 msgid "%qD target declared here"
 msgstr "%qD はここで定義されています"
 
@@ -22314,7 +20303,6 @@ msgstr ""
 
 #: auto-profile.c:863
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<.%>"
 msgid "Not expected TAG."
 msgstr "%<.%> が予期されます"
 
@@ -22350,19 +20338,16 @@ msgstr "呼び出されたオブジェクトは関数ではありません"
 
 #: builtins.c:559 builtins.c:3160 builtins.c:3214 gimple-ssa-sprintf.c:3281
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "referenced argument declared here"
 msgstr "%qD はここで宣言されています"
 
 #: builtins.c:811
 #, fuzzy, gcc-internal-format
-#| msgid "offset outside bounds of constant string"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "オフセットが定数文字列の境界の外にあります"
 
 #: builtins.c:815 cp/name-lookup.c:5335
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%qE declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -22547,13 +20532,11 @@ msgstr "関数 %<va_start%> への引数が少なすぎます"
 
 #: builtins.c:5736
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %qD"
 msgid "invalid argument to %qD"
 msgstr "無効な %qD の使用です"
 
 #: builtins.c:5749
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument to %qD"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
@@ -22586,7 +20569,6 @@ msgstr ""
 
 #: builtins.c:6688
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "invalid memory model argument to builtin"
 msgstr "組み込み関数への無効な引数です"
 
@@ -22602,55 +20584,46 @@ msgstr ""
 
 #: builtins.c:6942
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無効な %<auto%> の使用です"
 
 #: builtins.c:6974 builtins.c:7167
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無効な %<auto%> の使用です"
 
 #: builtins.c:7288
 #, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 1 to %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
 #: builtins.c:7330
 #, fuzzy, gcc-internal-format
-#| msgid "missing argument to %qs"
 msgid "non-integer argument 1 to %qs"
 msgstr "%qs への引数がありません"
 
 #: builtins.c:7394
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: builtins.c:7414
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: builtins.c:7473
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s not supported: ignored"
 msgid "%qs only supported in OpenACC code"
 msgstr "-f%s はサポートされていません: 無視されました"
 
 #: builtins.c:7480
 #, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "non-constant argument 0 to %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
 #: builtins.c:7492
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "illegal argument 0 to %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -22680,7 +20653,6 @@ msgstr "ターゲット形式は無限大をサポートしません"
 
 #: builtins.c:10785
 #, fuzzy, gcc-internal-format
-#| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> が引数の数が固定の関数内で使用されました"
 
@@ -22706,19 +20678,16 @@ msgstr "%<va_start%> の第二引数が、最後の名前付き引数ではあ
 
 #: builtins.c:10858
 #, fuzzy, gcc-internal-format
-#| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "%<va_start%> の第二引数が %<register%> 記憶域の場合の動作は不定です"
 
 #: builtins.c:10887
 #, fuzzy, gcc-internal-format
-#| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
 #: builtins.c:10900
 #, fuzzy, gcc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
@@ -22769,13 +20738,11 @@ msgstr ""
 
 #: calls.c:1487 calls.c:1490
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument %i in the range [%E, %E]"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
 #: calls.c:1501
 #, fuzzy, gcc-internal-format
-#| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
@@ -22811,13 +20778,11 @@ msgstr ""
 
 #: calls.c:1851
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "argument %qD declared here"
 msgstr "%qD はここで宣言されています"
 
 #: calls.c:1865
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[%s が見つかりません]"
 
@@ -22843,7 +20808,6 @@ msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
 #: calls.c:2165
 #, fuzzy, gcc-internal-format
-#| msgid "invalid element type for attribute %qs"
 msgid "in a call with type %qT and attribute %qs"
 msgstr "%qs 属性用の無効なエレメント型です"
 
@@ -22854,13 +20818,11 @@ msgstr "関数呼び出しが集合体の値を持っています"
 
 #: calls.c:4472
 #, fuzzy, gcc-internal-format
-#| msgid "missing argument to %qs"
 msgid "passing too large argument on stack"
 msgstr "%qs への引数がありません"
 
 #: cfgexpand.c:1699
 #, fuzzy, gcc-internal-format
-#| msgid "total size of local objects too large"
 msgid "total size of local objects is too large"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
@@ -22871,7 +20833,6 @@ msgstr "変数 %q+D のサイズが大きすぎます"
 
 #: cfgexpand.c:1714
 #, fuzzy, gcc-internal-format
-#| msgid "global register variable %qD used in nested function"
 msgid "cannot allocate stack for variable %q+D, naked function"
 msgstr "帯域レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
@@ -22899,7 +20860,6 @@ msgstr "PIC レジスタが %qs によって %<asm%> 内で破壊されます"
 #. ??? Diagnose during gimplification?
 #: cfgexpand.c:2861
 #, fuzzy, gcc-internal-format
-#| msgid "register specified for %q+D isn%'t suitable for data type"
 msgid "the register %qs cannot be clobbered in %<asm%> for the current target"
 msgstr "%q+D 用に指定されたレジスタがデータ型に適合しません"
 
@@ -22926,7 +20886,6 @@ msgstr "不明なレジスタ名 %qs が %<asm%> 内にあります"
 
 #: cfgexpand.c:3058
 #, fuzzy, gcc-internal-format
-#| msgid "invalid Z register replacement for insn"
 msgid "invalid hard register usage between output operands"
 msgstr "命令に対して無効な Z レジスタ置換です"
 
@@ -22947,19 +20906,16 @@ msgstr "出力番号 %d は直接アドレス指定できません"
 
 #: cfgexpand.c:3244
 #, fuzzy, gcc-internal-format
-#| msgid "asm operand %d probably doesn%'t match constraints"
 msgid "%<asm%> operand %d probably does not match constraints"
 msgstr "asm 被演算子 %d は制約に適合しない可能性があります"
 
 #: cfgexpand.c:3428
 #, fuzzy, gcc-internal-format
-#| msgid "%<asm%> operand constraint incompatible with operand size"
 msgid "%<asm%> clobber conflict with output operand"
 msgstr "%<asm%> 被演算子制約が被演算子サイズと互換性がありません"
 
 #: cfgexpand.c:3433
 #, fuzzy, gcc-internal-format
-#| msgid "%<asm%> operand constraint incompatible with operand size"
 msgid "%<asm%> clobber conflict with input operand"
 msgstr "%<asm%> 被演算子制約が被演算子サイズと互換性がありません"
 
@@ -23015,7 +20971,6 @@ msgstr ""
 
 #: cfghooks.c:183
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "verify_flow_info failed"
 msgid "verify_flow_info: Wrong probability of edge %i->%i"
 msgstr "verify_flow_info に失敗しました"
 
@@ -23051,7 +21006,6 @@ msgstr "verify_flow_info に失敗しました"
 
 #: cfghooks.c:327
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s does not support duplicate_block"
 msgid "%s does not support dump_bb_for_graph"
 msgstr "%s は duplicate_block をサポートしていません"
 
@@ -23122,7 +21076,6 @@ msgstr "%s は make_forwarder_block をサポートしていません"
 
 #: cfghooks.c:1025
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s does not support move_block_after"
 msgid "%s does not support force_nonfallthru"
 msgstr "%s は move_block_after をサポートしていません"
 
@@ -23193,7 +21146,6 @@ msgstr ""
 
 #: cfgloop.c:1497
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "size of loop %d should be %d, not %d"
 msgid "bb %d has father loop %d, should be loop %d"
 msgstr "ループ %d のサイズは %d であるべきです。%d ではありません"
 
@@ -23529,13 +21481,11 @@ msgstr ""
 
 #: cgraph.c:3331
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "insufficient arguments to overloaded function %s"
 msgid "missing direct call for speculation %i"
 msgstr "オーバーロードされた関数 %s への不十分な引数です"
 
 #: cgraph.c:3336
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Use control speculation"
 msgid "missing ref for speculation %i"
 msgstr "制御投機を使用する"
 
@@ -23561,19 +21511,16 @@ msgstr ""
 
 #: cgraph.c:3391
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not constant"
 msgid "inline clone count is not compatible"
 msgstr "初期化子の要素が定数ではありません"
 
 #: cgraph.c:3398
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "tp_first_run must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: cgraph.c:3403
 #, fuzzy, gcc-internal-format
-#| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "シンボルが有効であると見なす"
 
@@ -23614,7 +21561,6 @@ msgstr ""
 
 #: cgraph.c:3451 cgraph.c:3511
 #, fuzzy, gcc-internal-format
-#| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "edge count is not compatible with function count"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
@@ -23755,7 +21701,6 @@ msgstr ""
 
 #: cgraph.c:3752
 #, fuzzy, gcc-internal-format
-#| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "文が予期されます"
 
@@ -23801,7 +21746,6 @@ msgstr "重複した初期化子"
 
 #: cgraphunit.c:740
 #, fuzzy, gcc-internal-format
-#| msgid "previously defined here"
 msgid "same version was previously defined here"
 msgstr "前はここで定義されました"
 
@@ -23812,25 +21756,21 @@ msgstr ""
 
 #: cgraphunit.c:752
 #, fuzzy, gcc-internal-format
-#| msgid "Assume symbols might be invalid"
 msgid "common symbol cannot be versioned"
 msgstr "シンボルが有効であると見なす"
 
 #: cgraphunit.c:758
 #, fuzzy, gcc-internal-format
-#| msgid "Assume symbols might be invalid"
 msgid "comdat symbol cannot be versioned"
 msgstr "シンボルが有効であると見なす"
 
 #: cgraphunit.c:764
 #, fuzzy, gcc-internal-format
-#| msgid "weak %q+D cannot be defined %qE"
 msgid "weakref cannot be versioned"
 msgstr "弱い %q+D は %qE として定義できません"
 
 #: cgraphunit.c:770
 #, fuzzy, gcc-internal-format
-#| msgid "weak declaration of %q+D must be public"
 msgid "versioned symbol must be public"
 msgstr "%q+D の弱い (weak) 宣言は公開 (public) でなければいけません"
 
@@ -23846,7 +21786,6 @@ msgstr "弱い参照属性は別名属性より前に出現しなければいけ
 
 #: cgraphunit.c:860
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on types"
 msgid "%<flatten%> attribute is ignored on aliases"
 msgstr "%qE 属性は型に関しては無視されます"
 
@@ -23867,7 +21806,6 @@ msgstr "%qE 属性は %qT が既に定義されているため無視されます
 
 #: cgraphunit.c:902
 #, fuzzy, gcc-internal-format
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "%<always_inline%> function might not be inlinable"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
@@ -23889,19 +21827,16 @@ msgstr "%q+F が %<static%> と宣言されましたが定義されていませ
 
 #: cgraphunit.c:1123
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D defined but not used"
 msgid "%qD defined but not used"
 msgstr "%q+D が定義されましたが使用されません"
 
 #: cgraphunit.c:1455
 #, fuzzy, gcc-internal-format
-#| msgid "%<operator new%> must return type %qT"
 msgid "%<ifunc%> resolver for %qD must return %qT"
 msgstr "%<operator new%> の戻り型は %qT でなければいけません"
 
 #: cgraphunit.c:1458 cgraphunit.c:1481
 #, fuzzy, gcc-internal-format
-#| msgid "indirect function %q+D cannot be declared weakref"
 msgid "resolver indirect function declared here"
 msgstr "間接関数 %q+D は弱い参照として宣言できません"
 
@@ -23912,13 +21847,11 @@ msgstr ""
 
 #: cgraphunit.c:1488
 #, fuzzy, gcc-internal-format
-#| msgid "Warn about casting functions to incompatible types"
 msgid "%qD alias between functions of incompatible types %qT and %qT"
 msgstr "互換性のない型への関数キャストに関して警告する"
 
 #: cgraphunit.c:1491 cgraphunit.c:1573
 #, fuzzy, gcc-internal-format
-#| msgid "shadowed declaration is here"
 msgid "aliased declaration here"
 msgstr "隠された宣言はここです"
 
@@ -23959,7 +21892,6 @@ msgstr "%q+D の戻り値のサイズが %u バイトです"
 
 #: cgraphunit.c:2331
 #, fuzzy, gcc-internal-format
-#| msgid "size of return value of %q+D is larger than %wd bytes"
 msgid "size of return value of %q+D is larger than %wu bytes"
 msgstr "%q+D の戻り値のサイズが %wd バイトより大きいです"
 
@@ -23970,7 +21902,6 @@ msgstr "メモリを解放していないノードが見つかりました"
 
 #: collect-utils.c:68
 #, fuzzy, gcc-internal-format
-#| msgid "can't get program status"
 msgid "cannot get program status: %m"
 msgstr "プログラムの状態を取得できません"
 
@@ -24001,13 +21932,11 @@ msgstr "応答ファイル %s を閉じられませんでした"
 
 #: collect-utils.c:179
 #, fuzzy, gcc-internal-format
-#| msgid "[cannot find %s]"
 msgid "cannot find %qs"
 msgstr "[%s が見つかりません]"
 
 #: collect-utils.c:183 collect2.c:2378 gcc.c:3200 gcc.c:6963
 #, fuzzy, gcc-internal-format
-#| msgid "pex_init failed: %m"
 msgid "%<pex_init%> failed: %m"
 msgstr "pex_init に失敗しました: %m"
 
@@ -24018,7 +21947,6 @@ msgstr "%s: %m"
 
 #: collect2.c:621
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable COLLECT_GCC must be set"
 msgid "environment variable %<COLLECT_LTO_WRAPPER%> must be set"
 msgstr "環境変数 COLLECT_GCC が設定されていなければいけません"
 
@@ -24046,25 +21974,21 @@ msgstr "`この設定内では LTO サポートが有効になっていません
 #: collect2.c:1336 graph.c:55 lto-wrapper.c:1520 lto-wrapper.c:1576
 #: toplev.c:1733 objc/objc-act.c:461
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "%s を開けません: %m"
 
 #: collect2.c:1456
 #, fuzzy, gcc-internal-format
-#| msgid "unknown demangling style '%s'"
 msgid "unknown demangling style %qs"
 msgstr "不明な名前復元 (demangle) スタイル '%s' です"
 
 #: collect2.c:1558 collect2.c:1736 collect2.c:1776
 #, fuzzy, gcc-internal-format
-#| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
 #: collect2.c:1561 collect2.c:1741 collect2.c:1779
 #, fuzzy, gcc-internal-format
-#| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
@@ -24077,13 +22001,11 @@ msgstr "%s: %s"
 
 #: collect2.c:2352
 #, fuzzy, gcc-internal-format
-#| msgid "cannot find 'nm'"
 msgid "cannot find %<nm%>"
 msgstr "'nm' が見つかりません"
 
 #: collect2.c:2400
 #, fuzzy, gcc-internal-format
-#| msgid "can't open nm output"
 msgid "cannot open nm output: %m"
 msgstr "nm の出力を開けません"
 
@@ -24099,7 +22021,6 @@ msgstr "fini 関数をオブジェクト %s で見つけました"
 
 #: collect2.c:2523
 #, fuzzy, gcc-internal-format
-#| msgid "cannot find 'ldd'"
 msgid "cannot find %<ldd%>"
 msgstr "'ldd' が見つかりません"
 
@@ -24110,7 +22031,6 @@ msgstr "pex_init に失敗しました: %m"
 
 #: collect2.c:2569
 #, fuzzy, gcc-internal-format
-#| msgid "can't open ldd output"
 msgid "cannot open ldd output: %m"
 msgstr "ldd の出力を開けません"
 
@@ -24121,7 +22041,6 @@ msgstr "動的依存関係 %s が見つかりません"
 
 #: collect2.c:2599
 #, fuzzy, gcc-internal-format
-#| msgid "unable to open dynamic dependency '%s'"
 msgid "unable to open dynamic dependency %qs"
 msgstr "動的依存関係 '%s' を開けません"
 
@@ -24147,13 +22066,11 @@ msgstr "ポインタ型へ変換できません"
 
 #: convert.c:332
 #, fuzzy, gcc-internal-format
-#| msgid "pointer value used where a floating point value was expected"
 msgid "pointer value used where a floating-point was expected"
 msgstr "浮動小数点数があるべき箇所で、ポインタ値が使われました"
 
 #: convert.c:336
 #, fuzzy, gcc-internal-format
-#| msgid "aggregate value used where a fixed-point was expected"
 msgid "aggregate value used where a floating-point was expected"
 msgstr "固定小数点型があるべき箇所で、集合体の値が使われました"
 
@@ -24164,7 +22081,6 @@ msgstr "不完全型への変換です"
 
 #: convert.c:946
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t convert between vector values of different size"
 msgid "cannot convert a vector of type %qT to type %qT which has different size"
 msgstr "異なるサイズのベクトル値の間での変換はできません"
 
@@ -24185,13 +22101,11 @@ msgstr "複素数型があるべき箇所で、集合体の値が使われまし
 
 #: convert.c:1083
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t convert between vector values of different size"
 msgid "cannot convert a value of type %qT to vector type %qT which has different size"
 msgstr "異なるサイズのベクトル値の間での変換はできません"
 
 #: convert.c:1091
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t convert value to a vector"
 msgid "cannot convert value to a vector"
 msgstr "値をベクトルへ変換できません"
 
@@ -24227,7 +22141,6 @@ msgstr "%qs がオーバーフローしました"
 
 #: coverage.c:285
 #, fuzzy, gcc-internal-format
-#| msgid "%s:corrupted\n"
 msgid "%qs is corrupted"
 msgstr "%s: 破損しています\n"
 
@@ -24273,7 +22186,6 @@ msgstr "%qs へ書き込み中にエラーが発生しました"
 
 #: coverage.c:1235
 #, fuzzy, gcc-internal-format
-#| msgid "switch %qs does not start with %<-%>"
 msgid "filename %qs does not start with profile prefix %qs"
 msgstr "スイッチ %qs が %<-%> で開始されていません"
 
@@ -24309,7 +22221,6 @@ msgstr ""
 
 #: dbgcnt.c:226
 #, fuzzy, gcc-internal-format
-#| msgid "Runtime name."
 msgid "counter name"
 msgstr "実行時名。"
 
@@ -24340,7 +22251,6 @@ msgstr "%s 内、位置 %s:%d"
 
 #: diagnostic.c:1894
 #, fuzzy, gcc-internal-format
-#| msgid "debug: "
 msgid "debug path"
 msgstr "デバッグ: "
 
@@ -24361,13 +22271,11 @@ msgstr "ダンプファイル %qs を開けませんでした: %m"
 
 #: dumpfile.c:1826
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "ignoring unknown option %q.*s"
 msgstr "不明なオプション %q.*s (%<-fdump-%s%> 内) を無視しています"
 
 #: dumpfile.c:1972
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option %q.*s in %<-fopt-info-%s%>"
 msgstr "不明なオプション %q.*s (%<-fdump-%s%> 内) を無視しています"
 
@@ -24423,19 +22331,16 @@ msgstr "%<__builtin_eh_return_regno%> の引数は定数でなければいけま
 
 #: except.c:2300
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_eh_return%> not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: except.c:3424 except.c:3449
 #, fuzzy, gcc-internal-format
-#| msgid "region_array is corrupted for region %i"
 msgid "%<region_array%> is corrupted for region %i"
 msgstr "領域 %i 用の region_array が破損しています"
 
 #: except.c:3437 except.c:3468
 #, fuzzy, gcc-internal-format
-#| msgid "lp_array is corrupted for lp %i"
 msgid "%<lp_array%> is corrupted for lp %i"
 msgstr "%i 用の lp_array が破損しています"
 
@@ -24461,19 +22366,16 @@ msgstr ""
 
 #: except.c:3505
 #, fuzzy, gcc-internal-format
-#| msgid "region_array does not match region_tree"
 msgid "%<region_array%> does not match %<region_tree%>"
 msgstr "region_array が region_tree と適合しません"
 
 #: except.c:3510
 #, fuzzy, gcc-internal-format
-#| msgid "lp_array does not match region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array が region_tree と適合しません"
 
 #: except.c:3517 tree.c:14728 value-prof.c:517
 #, fuzzy, gcc-internal-format
-#| msgid "atexit failed"
 msgid "%qs failed"
 msgstr "atexit に失敗しました"
 
@@ -24514,13 +22416,11 @@ msgstr ""
 
 #: file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "invalid argument %qs to %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: final.c:1797
 #, fuzzy, gcc-internal-format
-#| msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgid "the frame size of %wu bytes is larger than %wu bytes"
 msgstr "フレームサイズ (%wd バイト) が %wd バイトより大きいです"
 
@@ -24581,13 +22481,11 @@ msgstr ""
 
 #: function.c:249
 #, fuzzy, gcc-internal-format
-#| msgid "total size of local objects too large"
 msgid "total size of local objects %wu exceeds maximum %wu"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
 #: function.c:253
 #, fuzzy, gcc-internal-format
-#| msgid "total size of local objects too large"
 msgid "total size of local objects exceeds maximum %wu"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
@@ -24613,13 +22511,11 @@ msgstr "関数が集合体を返します"
 
 #: gcc.c:2028
 #, fuzzy, gcc-internal-format
-#| msgid "could not open response file %s"
 msgid "cannot open nested response file"
 msgstr "応答ファイル %s を開けませんでした"
 
 #: gcc.c:2039
 #, fuzzy, gcc-internal-format
-#| msgid "could not close response file %s"
 msgid "cannot close nonexistent response file"
 msgstr "応答ファイル %s を閉じられませんでした"
 
@@ -24641,7 +22537,6 @@ msgstr "一時応答ファイル %s を閉じることが出来ませんでし
 #. This leaves DESC open, but the OS will save us.
 #: gcc.c:2107
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t read %s: %m"
 msgid "cannot read spec file %qs: %m"
 msgstr "%s を読み込めません: %m"
 
@@ -24687,19 +22582,16 @@ msgstr "システムパス %qs が絶対パスではありません"
 
 #: gcc.c:3078
 #, fuzzy, gcc-internal-format
-#| msgid "-pipe not supported"
 msgid "%<-pipe%> not supported"
 msgstr "-pipe は実装されていません"
 
 #: gcc.c:3217 gcc.c:6972
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t open %s: %m"
 msgid "cannot execute %qs: %s: %m"
 msgstr "%s を開けません: %m"
 
 #: gcc.c:3218 gcc.c:6973
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t open %s: %m"
 msgid "cannot execute %qs: %s"
 msgstr "%s を開けません: %m"
 
@@ -24716,13 +22608,11 @@ msgstr "プロセス時間の取得に失敗しました: %m"
 #. The inferior failed to catch the signal.
 #: gcc.c:3269 gcc.c:3293
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Use alternate register names"
 msgid "%s signal terminated program %s"
 msgstr "代替レジスタ名を使用する"
 
 #: gcc.c:3771 opts-common.c:1364 opts-common.c:1396
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %qs"
 msgid "unrecognized command-line option %qs"
 msgstr "認識できないコマンドラインオプション %qs です"
 
@@ -24733,25 +22623,21 @@ msgstr ""
 
 #: gcc.c:4154
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is an unknown -save-temps option"
 msgid "%qs is an unknown %<-save-temps%> option"
 msgstr "%qs は不明な -save-temps オプションです"
 
 #: gcc.c:4627 toplev.c:860
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid output file"
 msgid "input file %qs is the same as output file"
 msgstr "%qs は有効な出力ファイルではありません"
 
 #: gcc.c:4632
 #, fuzzy, gcc-internal-format
-#| msgid "output filename specified twice"
 msgid "output filename may not be empty"
 msgstr "出力ファイル名が二回指定されています"
 
 #: gcc.c:4657
 #, fuzzy, gcc-internal-format
-#| msgid "-pipe ignored because -save-temps specified"
 msgid "%<-pipe%> ignored because %<-save-temps%> specified"
 msgstr "-save-temps が指定されたため、-pipe は無視されました"
 
@@ -24792,7 +22678,6 @@ msgstr "spec %qs に無効な %<%%W%c%> があります"
 
 #: gcc.c:5804
 #, fuzzy, gcc-internal-format
-#| msgid "spec %qs has invalid %<%%0%c%>"
 msgid "spec %qs has invalid %<%%@%c%>"
 msgstr "spec %qs に無効な %<%%0%c%> があります"
 
@@ -24821,7 +22706,6 @@ msgstr "不明な spec 関数 %qs です"
 
 #: gcc.c:6172
 #, fuzzy, gcc-internal-format
-#| msgid "error in args to spec function %qs"
 msgid "error in arguments to spec function %qs"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
@@ -24843,7 +22727,6 @@ msgstr "間違った形式の spec 関数引数です"
 
 #: gcc.c:6432
 #, fuzzy, gcc-internal-format
-#| msgid "braced spec %qs is invalid at %qc"
 msgid "braced spec %qs ends in escape"
 msgstr "忠括弧で括られた spec %qs は無効です(位置 %qc)"
 
@@ -24864,7 +22747,6 @@ msgstr "%s:比較デバッグファイル %s の長さを決定することが
 
 #: gcc.c:7282
 #, fuzzy, gcc-internal-format
-#| msgid "%s: -fcompare-debug failure (length)"
 msgid "%s: %<-fcompare-debug%> failure (length)"
 msgstr "%s: -fcompare-debug 失敗です (長さ)"
 
@@ -24875,31 +22757,26 @@ msgstr "%s: 比較デバッグファイル %s を開くことが出来ません"
 
 #: gcc.c:7312 gcc.c:7349
 #, fuzzy, gcc-internal-format
-#| msgid "%s: -fcompare-debug failure"
 msgid "%s: %<-fcompare-debug%> failure"
 msgstr "%s: -fcompare-debug 失敗です"
 
 #: gcc.c:7652
 #, fuzzy, gcc-internal-format
-#| msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgid "spec failure: more than one argument to %<SYSROOT_SUFFIX_SPEC%>"
 msgstr "spec 失敗: SYSROOT_SUFFIX_SPEC に二個以上の引数があります"
 
 #: gcc.c:7677
 #, fuzzy, gcc-internal-format
-#| msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgid "spec failure: more than one argument to %<SYSROOT_HEADERS_SUFFIX_SPEC%>"
 msgstr "spec 失敗: SYSROOT_HEADERS_SUFFIX_SPEC に二個以上の引数があります"
 
 #: gcc.c:7883
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command-line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
 #: gcc.c:7887
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command-line option %<-%s%>"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
@@ -24915,7 +22792,6 @@ msgstr "入力ファイルがありません"
 
 #: gcc.c:8125
 #, fuzzy, gcc-internal-format
-#| msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgid "cannot specify %<-o%> with %<-c%>, %<-S%> or %<-E%> with multiple files"
 msgstr "複数ファイルがあるときに -o と -c、-S または -E を併せて指定できません"
 
@@ -24926,13 +22802,11 @@ msgstr "%s: %s コンパイラはこのシステムにインストールされ
 
 #: gcc.c:8192
 #, fuzzy, gcc-internal-format
-#| msgid "recompiling with -fcompare-debug"
 msgid "recompiling with %<-fcompare-debug%>"
 msgstr "-fcompare-debug 付きで再コンパイルしています"
 
 #: gcc.c:8208
 #, fuzzy, gcc-internal-format
-#| msgid "during -fcompare-debug recompilation"
 msgid "during %<-fcompare-debug%> recompilation"
 msgstr "-fcompare-debug 再コンパイルの間"
 
@@ -24973,7 +22847,6 @@ msgstr ""
 
 #: gcc.c:8970
 #, fuzzy, gcc-internal-format
-#| msgid "multilib spec %qs is invalid"
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib spec %qs は無効です"
 
@@ -25034,31 +22907,26 @@ msgstr "%%:compare-debug-auxbase-opt への引数が多すぎます"
 
 #: gcc.c:9878
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgid "argument to %%:compare-debug-auxbase-opt does not end in %<.gk%>"
 msgstr "%%:compare-debug-auxbase-opt への引数が .gk で終了していません"
 
 #: gcc.c:9952
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "関数への引数が少なすぎます"
 
 #: gcc.c:10005
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
 #: gcov-tool.c:73
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "error writing %qs"
 msgid "error in removing %s"
 msgstr "%qs へ書き込み中にエラーが発生しました"
 
 #: gcov-tool.c:104
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "Cannot make directory %s"
 msgstr "重複したディレクトリ \"%s\" を無視します\n"
 
@@ -25094,7 +22962,6 @@ msgstr ""
 
 #: gcse.c:4013
 #, fuzzy, gcc-internal-format
-#| msgid "%s: %d basic blocks and %d registers"
 msgid "%s: %d basic blocks and %d registers; increase %<--param max-gcse-memory%> above %d"
 msgstr "%s: %d 個の基本ブロックおよび %d 個のレジスタ"
 
@@ -25146,26 +23013,22 @@ msgstr "重複した初期化子"
 #: ggc-common.c:386 ggc-common.c:394 ggc-common.c:463 ggc-common.c:481
 #: ggc-page.c:2493 ggc-page.c:2524 ggc-page.c:2531
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t write PCH file: %m"
 msgid "cannot write PCH file: %m"
 msgstr "PCH ファイルを書き込めません: %m"
 
 #: ggc-common.c:474
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t get position in PCH file: %m"
 msgid "cannot get position in PCH file: %m"
 msgstr "PCH ファイルの位置を取得できません: %m"
 
 #: ggc-common.c:484
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t write PCH file: %m"
 msgid "cannot write padding to PCH file: %m"
 msgstr "PCH ファイルを書き込めません: %m"
 
 #: ggc-common.c:606 ggc-common.c:614 ggc-common.c:617 ggc-common.c:627
 #: ggc-common.c:630 ggc-page.c:2595
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t read PCH file: %m"
 msgid "cannot read PCH file: %m"
 msgstr "PCH ファイルを読み込めません: %m"
 
@@ -25181,7 +23044,6 @@ msgstr "/dev/zero を開きます: %m"
 
 #: ggc-page.c:2509 ggc-page.c:2515
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t write PCH file"
 msgid "cannot write PCH file"
 msgstr "PCH ファイルを書き込めません"
 
@@ -25212,19 +23074,16 @@ msgstr ""
 
 #: gimple-ssa-isolate-paths.c:290
 #, fuzzy, gcc-internal-format
-#| msgid "target is not pointer or reference"
 msgid "potential null pointer dereference"
 msgstr "ターゲットはポインタまたは参照ではありません"
 
 #: gimple-ssa-isolate-paths.c:330
 #, fuzzy, gcc-internal-format
-#| msgid "null pointer"
 msgid "null pointer dereference"
 msgstr "NULL ポインタ"
 
 #: gimple-ssa-isolate-paths.c:408
 #, fuzzy, gcc-internal-format
-#| msgid "function returns address of local variable"
 msgid "function may return address of local variable"
 msgstr "関数が局所変数のアドレスを返します"
 
@@ -25427,7 +23286,6 @@ msgstr ""
 
 #: gimple-ssa-sprintf.c:3109
 #, fuzzy
-#| msgid "too few arguments to %qE"
 msgid "%G%<%.*s%> directive argument is null"
 msgstr "%qE への引数が少なすぎます"
 
@@ -25484,13 +23342,11 @@ msgstr[0] ""
 
 #: gimple-ssa-sprintf.c:3295
 #, fuzzy, gcc-internal-format
-#| msgid "too few arguments to %qE"
 msgid "directive argument %qE"
 msgstr "%qE への引数が少なすぎます"
 
 #: gimple-ssa-sprintf.c:3297
 #, fuzzy, gcc-internal-format
-#| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "directive argument in the range [%E, %E]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
@@ -25587,7 +23443,6 @@ msgstr ""
 
 #: gimple-ssa-sprintf.c:4623
 #, fuzzy
-#| msgid "null pointer"
 msgid "%Gnull destination pointer"
 msgstr "NULL ポインタ"
 
@@ -25603,19 +23458,16 @@ msgstr "フォーマット文字列が null です"
 
 #: gimple-ssa-warn-alloca.c:532
 #, fuzzy
-#| msgid "invalid use of %<auto%>"
 msgid "%Guse of %<alloca%>"
 msgstr "無効な %<auto%> の使用です"
 
 #: gimple-ssa-warn-alloca.c:569
 #, fuzzy
-#| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array may be too large"
 msgstr "可変長配列が使用されたときに警告する"
 
 #: gimple-ssa-warn-alloca.c:571
 #, fuzzy
-#| msgid "value passed to %<-m%s%> is too large"
 msgid "%Gargument to %<alloca%> may be too large"
 msgstr "%<-m%s%> へ渡された値が大きすぎます"
 
@@ -25626,13 +23478,11 @@ msgstr ""
 
 #: gimple-ssa-warn-alloca.c:589
 #, fuzzy
-#| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array is too large"
 msgstr "可変長配列が使用されたときに警告する"
 
 #: gimple-ssa-warn-alloca.c:591
 #, fuzzy
-#| msgid "value passed to %<-m%s%> is too large"
 msgid "%Gargument to %<alloca%> is too large"
 msgstr "%<-m%s%> へ渡された値が大きすぎます"
 
@@ -25643,7 +23493,6 @@ msgstr ""
 
 #: gimple-ssa-warn-alloca.c:605
 #, fuzzy
-#| msgid "variable length array is used"
 msgid "%Gvariable-length array bound is unknown"
 msgstr "可変長配列が使用されています"
 
@@ -25654,37 +23503,31 @@ msgstr "レジスタ '%c' が不明です"
 
 #: gimple-ssa-warn-alloca.c:612
 #, fuzzy
-#| msgid "ISO C90 forbids variable length array"
 msgid "%Gunbounded use of variable-length array"
 msgstr "ISO C90 は可変長の配列を禁止しています"
 
 #: gimple-ssa-warn-alloca.c:613
 #, fuzzy
-#| msgid "invalid use of %<auto%>"
 msgid "%Gunbounded use of %<alloca%>"
 msgstr "無効な %<auto%> の使用です"
 
 #: gimple-ssa-warn-alloca.c:619
 #, fuzzy
-#| msgid "invalid use of %<auto%>"
 msgid "%Guse of %<alloca%> within a loop"
 msgstr "無効な %<auto%> の使用です"
 
 #: gimple-ssa-warn-alloca.c:625
 #, fuzzy
-#| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array may be too large due to conversion from %qT to %qT"
 msgstr "可変長配列が使用されたときに警告する"
 
 #: gimple-ssa-warn-alloca.c:628
 #, fuzzy
-#| msgid "value passed to %<-m%s%> is too large"
 msgid "%Gargument to %<alloca%> may be too large due to conversion from %qT to %qT"
 msgstr "%<-m%s%> へ渡された値が大きすぎます"
 
 #: gimple-ssa-warn-alloca.c:635
 #, fuzzy
-#| msgid "Warn if a variable length array is used"
 msgid "%Gargument to variable-length array is zero"
 msgstr "可変長配列が使用されたときに警告する"
 
@@ -25794,7 +23637,6 @@ msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1765
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "array %qD declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -25851,7 +23693,6 @@ msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1846 gimple-ssa-warn-restrict.c:1867
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "subobject %qD declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -25875,7 +23716,6 @@ msgstr ""
 
 #: gimplify.c:1959
 #, fuzzy, gcc-internal-format
-#| msgid "statement with no effect"
 msgid "statement will never be executed"
 msgstr "効果がない文です"
 
@@ -25908,7 +23748,6 @@ msgstr ""
 
 #: gimplify.c:6291
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of type"
 msgid "invalid lvalue in %<asm%> output %d"
 msgstr "無効な型の使用法です"
 
@@ -25924,19 +23763,16 @@ msgstr ""
 
 #: gimplify.c:7101
 #, fuzzy, gcc-internal-format
-#| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
 #: gimplify.c:7103
 #, fuzzy, gcc-internal-format
-#| msgid "error closing %s: %m"
 msgid "enclosing region"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
 #: gimplify.c:7107
 #, fuzzy, gcc-internal-format
-#| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
@@ -25962,7 +23798,6 @@ msgstr "`%s' の宣言が矛盾しています"
 
 #: gimplify.c:7202
 #, fuzzy, gcc-internal-format
-#| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
@@ -25983,7 +23818,6 @@ msgstr ""
 
 #: gimplify.c:7416
 #, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
@@ -25994,13 +23828,11 @@ msgstr "`%s' の宣言が矛盾しています"
 
 #: gimplify.c:7472
 #, fuzzy, gcc-internal-format
-#| msgid "error closing %s: %m"
 msgid "enclosing %<target%>"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
 #: gimplify.c:7502 gimplify.c:8814
 #, fuzzy, gcc-internal-format
-#| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
@@ -26072,7 +23904,6 @@ msgstr ""
 
 #: gimplify.c:9156
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -26128,7 +23959,6 @@ msgstr ""
 
 #: gimplify.c:10524
 #, fuzzy, gcc-internal-format
-#| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD の無効なテンプレート宣言です"
 
@@ -26179,7 +24009,6 @@ msgstr ""
 
 #: gimplify.c:13253
 #, fuzzy, gcc-internal-format
-#| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend%> clause with %<sink%> modifier does not match number of iteration variables"
 msgstr "結果の数が値の数と一致しません"
 
@@ -26235,7 +24064,6 @@ msgstr ""
 
 #: hsa-common.c:243
 #, fuzzy, gcc-internal-format
-#| msgid "move insn not handled"
 msgid "HSA image ops not handled"
 msgstr "move 命令は取り扱われません"
 
@@ -26286,7 +24114,6 @@ msgstr ""
 
 #: internal-fn.c:506
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%>"
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "無効な %<auto%> の使用です"
 
@@ -26333,7 +24160,6 @@ msgstr ""
 
 #: ipa-devirt.c:805
 #, fuzzy, gcc-internal-format
-#| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
@@ -26405,19 +24231,16 @@ msgstr ""
 
 #: ipa-devirt.c:1054 ipa-devirt.c:1151
 #, fuzzy, gcc-internal-format
-#| msgid "enum type defined here"
 msgid "the incompatible type is defined here"
 msgstr "列挙型がここで定義されています"
 
 #: ipa-devirt.c:1082
 #, fuzzy, gcc-internal-format
-#| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
 msgstr "配列参照が範囲外です"
 
 #: ipa-devirt.c:1097
 #, fuzzy, gcc-internal-format
-#| msgid "<return value> "
 msgid "return value type mismatch"
 msgstr "<戻り値> "
 
@@ -26433,7 +24256,6 @@ msgstr "型が前方の外部宣言と一致しません"
 
 #: ipa-devirt.c:1126
 #, fuzzy, gcc-internal-format
-#| msgid "different parameter types"
 msgid "types have different parameter counts"
 msgstr "引数の型が異なります"
 
@@ -26444,7 +24266,6 @@ msgstr ""
 
 #: ipa-devirt.c:1148
 #, fuzzy, gcc-internal-format
-#| msgid "argument of type %qT does not match %qT"
 msgid "type %qT should match type %qT"
 msgstr "型 %qT の引数が %qT と一致しません"
 
@@ -26555,13 +24376,11 @@ msgstr ""
 
 #: ipa-devirt.c:1564
 #, fuzzy, gcc-internal-format
-#| msgid "<return value> "
 msgid "memory layout mismatch"
 msgstr "<戻り値> "
 
 #: ipa-devirt.c:1687
 #, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
 msgid "the extra base is defined here"
 msgstr "ラベル %qD はここで定義されています"
 
@@ -26618,19 +24437,16 @@ msgstr "`%s' は関数でもメンバ関数でもありません -- friend と
 
 #: ipa-prop.c:4538 ipa-prop.c:4580 ipa-prop.c:4664 ipa-prop.c:4709
 #, fuzzy, gcc-internal-format
-#| msgid "invalid function in call statement"
 msgid "invalid jump function in LTO stream"
 msgstr "call 文内で無効な関数です"
 
 #: ipa-pure-const.c:216
 #, fuzzy, gcc-internal-format
-#| msgid "function might be candidate for attribute %<%s%>"
 msgid "function might be candidate for attribute %qs"
 msgstr "関数は属性 %<%s%> の候補のようです"
 
 #: ipa-pure-const.c:217
 #, fuzzy, gcc-internal-format
-#| msgid "function might be candidate for attribute %<%s%> if it is known to return normally"
 msgid "function might be candidate for attribute %qs if it is known to return normally"
 msgstr "関数は正常に戻ると分かった場合、属性 %<%s%> の候補のようです"
 
@@ -26696,7 +24512,6 @@ msgstr "フレームサイズが大きすぎて、スタック検査が信頼で
 
 #: lra-assigns.c:1693
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "maximum number of parameters in a SCoP"
 msgid "maximum number of LRA assignment passes is achieved (%d)"
 msgstr "SCoP 内のパラメータの最大数"
 
@@ -26707,7 +24522,6 @@ msgstr "%<asm%> 被演算子が不可能な制約を持っています"
 
 #: lra-assigns.c:1840
 #, fuzzy, gcc-internal-format
-#| msgid "unable to use '%s' for PIC register"
 msgid "unable to find a register to spill"
 msgstr "PIC レジスタ用に '%s' を使用できません"
 
@@ -26773,7 +24587,6 @@ msgstr ""
 
 #: lto-cgraph.c:1813
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
 msgstr "無効な回転 (rotate) 命令です"
 
@@ -26800,7 +24613,6 @@ msgstr ""
 
 #: lto-compress.c:413
 #, fuzzy, gcc-internal-format
-#| msgid "this target does not support %qs"
 msgid "compiler does not support ZSTD LTO compression"
 msgstr "このターゲットでは %qs はサポートされていません"
 
@@ -26831,13 +24643,11 @@ msgstr ""
 
 #: lto-streamer-in.c:916
 #, fuzzy, gcc-internal-format
-#| msgid "operand number out of range"
 msgid "Reference statement index out of range"
 msgstr "被演算子の数字が範囲外です"
 
 #: lto-streamer-in.c:920
 #, fuzzy, gcc-internal-format
-#| msgid "Warn if deprecated empty statements are found"
 msgid "Reference statement index not found"
 msgstr "推奨されない空文が見つかれば警告する"
 
@@ -26868,13 +24678,11 @@ msgstr ""
 
 #: lto-streamer-in.c:1729
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
 msgid "%s - unsupported mode %qs"
 msgstr "サポートされていない組み合わせです: %s"
 
 #: lto-streamer-out.c:462 lto-streamer-out.c:704
 #, fuzzy, gcc-internal-format
-#| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "tree code %qs is not supported in LTO streams"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
@@ -26890,13 +24698,11 @@ msgstr ""
 
 #: lto-wrapper.c:122
 #, fuzzy, gcc-internal-format
-#| msgid "deleting LTRANS file %s"
 msgid "deleting LTRANS file %s: %m"
 msgstr "LTRANS ファイル %s を削除しています"
 
 #: lto-wrapper.c:286
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "created and used with different endianness"
 msgid "option %s with different values"
 msgstr "作成時と使用時でエンディアンが異なります"
 
@@ -26927,13 +24733,11 @@ msgstr ""
 
 #: lto-wrapper.c:947
 #, fuzzy, gcc-internal-format
-#| msgid "no input files"
 msgid "reading input file"
 msgstr "入力ファイルがありません"
 
 #: lto-wrapper.c:952
 #, fuzzy, gcc-internal-format
-#| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s: 出力ファイル '%s' を書き込み中にエラーが発生しました\n"
 
@@ -26944,56 +24748,47 @@ msgstr ""
 
 #: lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable COLLECT_GCC must be set"
 msgid "environment variable %<COLLECT_GCC%> must be set"
 msgstr "環境変数 COLLECT_GCC が設定されていなければいけません"
 
 #: lto-wrapper.c:1303
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgid "environment variable %<COLLECT_GCC_OPTIONS%> must be set"
 msgstr "環境変数 COLLECT_GCC_OPTIONS が設定されていなければいけません"
 
 #: lto-wrapper.c:1523 lto-wrapper.c:1582 c-family/c-pch.c:211
 #: c-family/c-pch.c:252 c-family/c-pch.c:303
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "%s を読み込めません: %m"
 
 #: lto-wrapper.c:1550
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid #pragma %s"
 msgid "invalid format of %s"
 msgstr "無効な #pragma %s です"
 
 #: lto-wrapper.c:1751
 #, fuzzy, gcc-internal-format
-#| msgid "fopen: %s"
 msgid "%<fopen%>: %s: %m"
 msgstr "fopen: %s"
 
 #: lto-wrapper.c:1768
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "opening output file %s: %m"
 msgid "corrupted ltrans output file %s"
 msgstr "出力ファイル %s を開いています: %m"
 
 #: lto-wrapper.c:1958
 #, fuzzy, gcc-internal-format
-#| msgid "atexit failed"
 msgid "%<atexit%> failed"
 msgstr "atexit に失敗しました"
 
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "the call requires %<ifunc%>, which is not supported by this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: multiple_target.c:83
 #, fuzzy, gcc-internal-format
-#| msgid "target format does not support infinity"
 msgid "target does not support function version dispatcher"
 msgstr "ターゲット形式は無限大をサポートしません"
 
@@ -27004,7 +24799,6 @@ msgstr ""
 
 #: multiple_target.c:350
 #, fuzzy, gcc-internal-format
-#| msgid "%<fast_interrupt%> attribute directive ignored"
 msgid "single %<target_clones%> attribute is ignored"
 msgstr "%<fast_interrupt%> 属性指示は無視されました"
 
@@ -27015,13 +24809,11 @@ msgstr ""
 
 #: multiple_target.c:362
 #, fuzzy, gcc-internal-format
-#| msgid "function %q+F can never be copied because it receives a non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "関数 %q+F は非局所 goto を受け取るため決して複製されません"
 
 #: multiple_target.c:383
 #, fuzzy, gcc-internal-format
-#| msgid "no default argument for %qD"
 msgid "%<default%> target was not set"
 msgstr "%qD 用のデフォルト引数がありません"
 
@@ -27032,7 +24824,6 @@ msgstr ""
 
 #: multiple_target.c:391
 #, fuzzy, gcc-internal-format
-#| msgid "multiple default labels in one switch"
 msgid "multiple %<default%> targets were set"
 msgstr "一つの switch に複数の default ラベルがあります"
 
@@ -27053,7 +24844,6 @@ msgstr ""
 
 #: omp-general.c:1810
 #, fuzzy, gcc-internal-format
-#| msgid "previously used here"
 msgid "... to the previous %qs clause here"
 msgstr "前にここで使われました"
 
@@ -27074,7 +24864,6 @@ msgstr ""
 
 #: omp-general.c:1899
 #, fuzzy, gcc-internal-format
-#| msgid "switch starts here"
 msgid "... with %qs clause here"
 msgstr "switch がここから開始します"
 
@@ -27105,13 +24894,11 @@ msgstr ""
 
 #: omp-low.c:2491
 #, fuzzy, gcc-internal-format
-#| msgid "conflicting types for %q+D"
 msgid "conflicting reduction operations for %qE"
 msgstr "%q+D と型が競合しています"
 
 #: omp-low.c:2494
 #, fuzzy, gcc-internal-format
-#| msgid "no previous declaration for %qD"
 msgid "location of the previous reduction for %qE"
 msgstr "前に %qD 用の定義がありません"
 
@@ -27192,7 +24979,6 @@ msgstr ""
 
 #: omp-low.c:3124
 #, fuzzy, gcc-internal-format
-#| msgid "invalid PHI argument"
 msgid "invalid arguments"
 msgstr "無効な PHI 引数です"
 
@@ -27303,20 +25089,17 @@ msgstr ""
 
 #: omp-low.c:13183
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid entry to OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 
 #: omp-low.c:13185 omp-low.c:13190
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
 msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 
 #. Otherwise, be vague and lazy, but efficient.
 #: omp-low.c:13194
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
 msgstr "OpenMP 構造化ブロックへ/からの無効な分岐です"
 
@@ -27347,7 +25130,6 @@ msgstr ""
 
 #: omp-offload.c:1264
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "routine %qD declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -27373,7 +25155,6 @@ msgstr ""
 
 #: omp-simd-clone.c:197
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring duplicate directory \"%s\"\n"
 msgid "ignoring large linear step"
 msgstr "重複したディレクトリ \"%s\" を無視します\n"
 
@@ -27394,13 +25175,11 @@ msgstr ""
 
 #: optabs.c:4319
 #, fuzzy, gcc-internal-format
-#| msgid "section attributes are not supported for this target"
 msgid "indirect jumps are not available on this target"
 msgstr "セクション属性はこのターゲットでは実装されていません"
 
 #: opts-common.c:1275
 #, fuzzy, gcc-internal-format
-#| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "コマンドラインオプション %qs はこの設定ではサポートされていません"
 
@@ -27411,7 +25190,6 @@ msgstr "%qs への引数がありません"
 
 #: opts-common.c:1292
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qs should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "%qs への引数は非負整数であるべきです"
 
@@ -27422,7 +25200,6 @@ msgstr "%qs への引数は非負整数であるべきです"
 
 #: opts-common.c:1303
 #, fuzzy, gcc-internal-format
-#| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
@@ -27433,7 +25210,6 @@ msgstr "オプション %qs 内で認識できない引数です"
 
 #: opts-common.c:1329 config/i386/i386-options.c:1479
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -27449,27 +25225,23 @@ msgstr "%qs スイッチは既にサポートされていません"
 
 #: opts-common.c:1764
 #, fuzzy, gcc-internal-format
-#| msgid "malformed COLLECT_GCC_OPTIONS"
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "誤った形式の COLLECT_GCC_OPTIONS です"
 
 #: opts-global.c:102
 #, fuzzy, gcc-internal-format
-#| msgid "command line option %qs is valid for %s but not for %s"
 msgid "command-line option %qs is valid for the driver but not for %s"
 msgstr "コマンドラインオプション %qs は %s 用としては有効ですが、%s 用としては有効ではありません"
 
 #. Eventually this should become a hard error IMO.
 #: opts-global.c:108
 #, fuzzy, gcc-internal-format
-#| msgid "command line option %qs is valid for %s but not for %s"
 msgid "command-line option %qs is valid for %s but not for %s"
 msgstr "コマンドラインオプション %qs は %s 用としては有効ですが、%s 用としては有効ではありません"
 
 #. Happens for -Werror=warning_name.
 #: opts-global.c:112
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "%<-Werror=%> argument %qs is not valid for %s"
 msgstr "%qs は %qs 用には有効ではありません"
 
@@ -27480,13 +25252,11 @@ msgstr ""
 
 #: opts-global.c:389
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command-line option %<-fdump-%s%>"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
 #: opts-global.c:394
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command-line option %<-fopt-info-%s%>"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
@@ -27507,7 +25277,6 @@ msgstr ""
 
 #: opts-global.c:468
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized address"
 msgid "unrecognized shadow offset %qs"
 msgstr "認識できないアドレス"
 
@@ -27528,31 +25297,26 @@ msgstr ""
 
 #: opts.c:594
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qs should be a non-negative integer"
 msgid "argument to %<-O%> should be a non-negative integer, %<g%>, %<s%> or %<fast%>"
 msgstr "%qs への引数は非負整数であるべきです"
 
 #: opts.c:691
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fipa-cp-clone%> is incompatible with %<-flive-patching=inline-only-static%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
 #: opts.c:698
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fipa-sra%> is incompatible with %<-flive-patching=inline-only-static%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
 #: opts.c:705
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fpartial-inlining%> is incompatible with %<-flive-patching=inline-only-static%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
 #: opts.c:712
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fipa-cp%> is incompatible with %<-flive-patching=inline-only-static%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
@@ -27638,19 +25402,16 @@ msgstr ""
 
 #: opts.c:970 config/darwin.c:3223
 #, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では動作しません"
 
 #: opts.c:986
 #, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition does not support unwind info on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では巻き戻し (unwind) 情報をサポートしません"
 
 #: opts.c:1004 config/pa/pa.c:554
 #, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では動作しません"
 
@@ -27661,7 +25422,6 @@ msgstr ""
 
 #: opts.c:1048
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<-gsplit-dwarf%> is not supported with LTO, disabling"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
@@ -27692,13 +25452,11 @@ msgstr ""
 
 #: opts.c:1114
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fsanitize=leak%> is incompatible with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
 #: opts.c:1120
 #, fuzzy, gcc-internal-format
-#| msgid "-falign-loops=%d is not supported"
 msgid "%<-fsanitize-recover=%s%> is not supported"
 msgstr "-falign-loops=%d はサポートされていません"
 
@@ -27719,19 +25477,16 @@ msgstr ""
 
 #: opts.c:1161
 #, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
 msgid "live patching is not supported with LTO"
 msgstr "-mg でのプロファイルはサポートされていません"
 
 #: opts.c:1165
 #, fuzzy, gcc-internal-format
-#| msgid "weakref is not supported in this configuration"
 msgid "vtable verification is not supported with LTO"
 msgstr "弱い参照はこの設定ではサポートされていません"
 
 #: opts.c:1676
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
 msgstr "print_specific_help へ認識できない include_flags 0x%x が渡されました"
 
@@ -27742,55 +25497,46 @@ msgstr ""
 
 #: opts.c:1930
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
 #: opts.c:1936
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
 #: opts.c:1971
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute directive ignored"
 msgid "%qs attribute directive ignored"
 msgstr "%qE 属性指示が無視されました"
 
 #: opts.c:1998
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "invalid arguments for %<-falign-%s%> option: %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: opts.c:2013
 #, fuzzy, gcc-internal-format
-#| msgid "not enough arguments to function %qE"
 msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
 msgstr "関数 %qE へ十分な引数がありません"
 
 #: opts.c:2022
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-falign-%s%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
 #: opts.c:2148
 #, fuzzy, gcc-internal-format
-#| msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 引数 %q.*s は曖昧です。より特定してください"
 
 #: opts.c:2157
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<--help=%> option: %q.*s"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
 #: opts.c:2526
 #, fuzzy, gcc-internal-format
-#| msgid "LTO support has not been enabled in this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "`この設定内では LTO サポートが有効になっていません"
 
@@ -27801,19 +25547,16 @@ msgstr ""
 
 #: opts.c:2546
 #, fuzzy, gcc-internal-format
-#| msgid "structure alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %wu"
 msgstr "構造体の整列は %d ではなく、小さな二の累乗でなければいけません"
 
 #: opts.c:2621
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "invalid arguments for %<-fpatchable_function_entry%>"
 msgstr "組み込み関数への無効な引数です"
 
 #: opts.c:2679
 #, fuzzy, gcc-internal-format
-#| msgid "unknown stack check parameter \"%s\""
 msgid "unknown stack check parameter %qs"
 msgstr "不明なスタック検査パラメータ \"%s\" です"
 
@@ -27825,13 +25568,11 @@ msgstr ""
 # 規格に合わせて DWARF と大文字で表記する
 #: opts.c:2718
 #, fuzzy, gcc-internal-format
-#| msgid "dwarf version %d is not supported"
 msgid "dwarf version %wu is not supported"
 msgstr "DWARF バージョン %d はサポートされていません"
 
 #: opts.c:2772
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to %<-flto=%> option: %qs"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
@@ -27842,19 +25583,16 @@ msgstr "ターゲットシステムはデバッグ出力をサポートしてい
 
 #: opts.c:2959
 #, fuzzy, gcc-internal-format
-#| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "デバッグ形式 \"%s\" は前の選択と競合しています"
 
 #: opts.c:2977
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "認識できないでバッグ出力レベル \"%s\" です"
 
 #: opts.c:2979
 #, fuzzy, gcc-internal-format
-#| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "デバッグ出力レベル %s は高すぎます"
 
@@ -27875,25 +25613,21 @@ msgstr "認識できない gcc デバッグオプションです: %c"
 
 #: opts.c:3077
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
 #: opts.c:3081
 #, fuzzy, gcc-internal-format
-#| msgid "-Werror=%s: no option -%s"
 msgid "%<-W%serror=%s%>: no option %<-%s%>"
 msgstr "-Werror=%s: オプション -%s はありません"
 
 #: opts.c:3085
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
 msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
 msgstr "%qs は前処理の有効なオプションではありません"
 
 #: passes.c:84
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s does not support split_edge"
 msgid "pass %s does not support cloning"
 msgstr "%s は split_edge をサポートしていません"
 
@@ -27904,25 +25638,21 @@ msgstr ""
 
 #: passes.c:1026
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized option %<-%s%>"
 msgid "unrecognized option %<-fenable%>"
 msgstr "認識できないオプション %<-%s%> です"
 
 #: passes.c:1028
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized option %<-%s%>"
 msgid "unrecognized option %<-fdisable%>"
 msgstr "認識できないオプション %<-%s%> です"
 
 #: passes.c:1036
 #, fuzzy, gcc-internal-format
-#| msgid "unknown field %qE specified in initializer"
 msgid "unknown pass %s specified in %<-fenable%>"
 msgstr "初期化子内で不明なフィールド %qE が指定されています"
 
 #: passes.c:1038
 #, fuzzy, gcc-internal-format
-#| msgid "unknown field %qE specified in initializer"
 msgid "unknown pass %s specified in %<-fdisable%>"
 msgstr "初期化子内で不明なフィールド %qE が指定されています"
 
@@ -27938,19 +25668,16 @@ msgstr ""
 
 #: passes.c:1102 passes.c:1130
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid floating point option: -mfpu=%s"
 msgid "Invalid range %s in option %s"
 msgstr "無効な浮動小数点オプションです: -mfpu=%s"
 
 #: passes.c:1148
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid storage class for function %qE"
 msgid "enable pass %s for function %s"
 msgstr "関数 %qE 用の無効な記憶域クラスです"
 
 #: passes.c:1159
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid storage class for function %qE"
 msgid "disable pass %s for function %s"
 msgstr "関数 %qE 用の無効な記憶域クラスです"
 
@@ -27991,13 +25718,11 @@ msgstr ""
 
 #: plugin.c:293
 #, fuzzy, gcc-internal-format
-#| msgid "malformed option -fplugin-arg-%s (missing -<key>[=<value>])"
 msgid "malformed option %<-fplugin-arg-%s%>: missing %<-<key>[=<value>]%>"
 msgstr "間違った形式のオプション -fplugin-arg-%s です (-<key>[=<value>] がありません)"
 
 #: plugin.c:357
 #, fuzzy, gcc-internal-format
-#| msgid "plugin %s should be specified before -fplugin-arg-%s in the command line"
 msgid "plugin %s should be specified before %<-fplugin-arg-%s%> in the command line"
 msgstr "プラグイン %s はコマンドライン内の -fplugin-arg-%s より前で指定されるべきです"
 
@@ -28050,9 +25775,6 @@ msgstr "プラグイン %s の初期化に失敗しました"
 
 #: plugin.c:704
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid ""
-#| "cannot load plugin %s\n"
-#| "%s"
 msgid "cannot load plugin %s: %s"
 msgstr ""
 "プラグイン %s をロードできません\n"
@@ -28060,9 +25782,6 @@ msgstr ""
 
 #: plugin.c:714
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid ""
-#| "plugin %s is not licensed under a GPL-compatible license\n"
-#| "%s"
 msgid "plugin %s is not licensed under a GPL-compatible license %s"
 msgstr ""
 "プラグイン %s は GPL に適合したライセンスではありません\n"
@@ -28070,9 +25789,6 @@ msgstr ""
 
 #: plugin.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid ""
-#| "cannot find %s in plugin %s\n"
-#| "%s"
 msgid "cannot find %s in plugin %s: %s"
 msgstr ""
 "%s がプラグイン %s 内に見つかりません\n"
@@ -28080,13 +25796,11 @@ msgstr ""
 
 #: plugin.c:733
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "fail to initialize plugin %s"
 msgid "failed to initialize plugin %s"
 msgstr "プラグイン %s の初期化に失敗しました"
 
 #: plugin.c:1007
 #, fuzzy, gcc-internal-format
-#| msgid "-iplugindir <dir> option not passed from the gcc driver"
 msgid "%<-iplugindir%> <dir> option not passed from the gcc driver"
 msgstr "-iplugindir <dir> オプションが gcc ドライバから渡されませんでした"
 
@@ -28102,7 +25816,6 @@ msgstr ""
 
 #: predict.c:3482
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "insufficient arguments to overloaded function %s"
 msgid "Missing counts for called function %s"
 msgstr "オーバーロードされた関数 %s への不十分な引数です"
 
@@ -28123,7 +25836,6 @@ msgstr ""
 
 #: profile.c:888
 #, fuzzy, gcc-internal-format
-#| msgid "corrupted profile info: run_max * runs < sum_max"
 msgid "corrupted profile info: invalid time profile"
 msgstr "破損したプロファイル情報: run_max * runs < sum_max です"
 
@@ -28144,19 +25856,16 @@ msgstr "関数 `%s' を `mutable' としては宣言できません"
 
 #: read-rtl-function.c:713
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized register name %qs"
 msgid "unrecognized edge flag: %qs"
 msgstr "認識できないレジスタ名 %qs です"
 
 #: read-rtl-function.c:856
 #, fuzzy, gcc-internal-format
-#| msgid "Do not generate #line directives"
 msgid "more than one 'crtl' directive"
 msgstr "#line 指示を生成しない"
 
 #: read-rtl-function.c:984
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized visibility value %qs"
 msgid "unrecognized enum value: %qs"
 msgstr "認識できない可視性の値 %qs です"
 
@@ -28167,7 +25876,6 @@ msgstr ""
 
 #: read-rtl-function.c:1591
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "duplicate %<const%>"
 msgid "duplicate insn UID: %i"
 msgstr "重複した %<const%> です"
 
@@ -28193,7 +25901,6 @@ msgstr "出力制約 %d は単一レジスタを指定しなければいけま
 
 #: reg-stack.c:547
 #, fuzzy, gcc-internal-format
-#| msgid "output constraint %d must specify a single register"
 msgid "output constraint %d cannot be specified together with %qs clobber"
 msgstr "出力制約 %d は単一レジスタを指定しなければいけません"
 
@@ -28239,19 +25946,16 @@ msgstr ""
 
 #: reginfo.c:647
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t use %qs as a call-saved register"
 msgid "cannot use %qs as a call-saved register"
 msgstr "%qs を呼び出しで保存されるレジスタとして使用できません"
 
 #: reginfo.c:651
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t use %qs as a call-used register"
 msgid "cannot use %qs as a call-used register"
 msgstr "%qs を呼び出しで使用されるレジスタとして使用できません"
 
 #: reginfo.c:663
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t use %qs as a fixed register"
 msgid "cannot use %qs as a fixed register"
 msgstr "%qs を固定レジスタとして使用できません"
 
@@ -28274,13 +25978,11 @@ msgstr "大域レジスタ変数が関数定義に続いてあります"
 
 #: reginfo.c:715
 #, fuzzy, gcc-internal-format
-#| msgid "register used for two global register variables"
 msgid "register of %qD used for multiple global register variables"
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
 #: reginfo.c:718 config/rs6000/rs6000-logue.c:5488
 #, fuzzy, gcc-internal-format
-#| msgid "conflicting types for %q+D"
 msgid "conflicts with %qD"
 msgstr "%q+D と型が競合しています"
 
@@ -28306,7 +26008,6 @@ msgstr "%<&%> 制約がレジスタクラス無しで使用されました"
 
 #: reload1.c:2061
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t find a register in class %qs while reloading %<asm%>"
 msgid "cannot find a register in class %qs while reloading %<asm%>"
 msgstr "クラス %qs 内のレジスタを %<asm%> 再ロード中に見つけられません"
 
@@ -28367,7 +26068,6 @@ msgstr "RTL 検査: elt %d(%s) が最後の elt %d(%s 中) と一緒にアクセ
 
 #: rtl.c:937
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
@@ -28428,7 +26128,6 @@ msgstr "一致制約はレジスタでは許可されていません"
 
 #: stmt.c:524
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate asm operand name %qs"
 msgid "duplicate %<asm%> operand name %qs"
 msgstr "重複した asm 被演算子名 %qs です"
 
@@ -28449,7 +26148,6 @@ msgstr ""
 
 #: stor-layout.c:1180
 #, fuzzy, gcc-internal-format
-#| msgid "alignment for %q+D must be at least %d"
 msgid "alignment %u of %qT is less than %u"
 msgstr "%q+D 用の整列は最低 %d でなければいけません"
 
@@ -28515,7 +26213,6 @@ msgstr "配列要素の整列が要素のサイズより大きいです"
 
 #: substring-locations.c:229
 #, fuzzy, gcc-internal-format
-#| msgid "originally defined here"
 msgid "format string is defined here"
 msgstr "元々はここで定義されました"
 
@@ -28536,7 +26233,6 @@ msgstr ""
 
 #: symtab.c:1079
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qE は変数にのみ適用できます"
 
@@ -28577,7 +26273,6 @@ msgstr ""
 
 #: symtab.c:1148
 #, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
@@ -28588,7 +26283,6 @@ msgstr ""
 
 #: symtab.c:1158
 #, fuzzy, gcc-internal-format
-#| msgid "old-style function definition"
 msgid "node is alias but not definition"
 msgstr "古いスタイルの関数定義です"
 
@@ -28604,7 +26298,6 @@ msgstr ""
 
 #: symtab.c:1173
 #, fuzzy, gcc-internal-format
-#| msgid "old-style function definition"
 msgid "node is symver but not alias"
 msgstr "古いスタイルの関数定義です"
 
@@ -28615,7 +26308,6 @@ msgstr ""
 
 #: symtab.c:1189
 #, fuzzy, gcc-internal-format
-#| msgid "%qD was declared %qs which implies default visibility"
 msgid "symver is not exported with default visibility"
 msgstr "%qD は %qs として宣言されていて、暗黙的にデフォルトの可視性になります"
 
@@ -28651,7 +26343,6 @@ msgstr ""
 
 #: symtab.c:1245
 #, fuzzy, gcc-internal-format
-#| msgid "implicit declaration of function %qE"
 msgid "implicit_section flag is set but section isn%'t"
 msgstr "関数 %qE の暗黙的な宣言です"
 
@@ -28682,7 +26373,6 @@ msgstr ""
 
 #: symtab.c:1317 symtab.c:1354
 #, fuzzy, gcc-internal-format
-#| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa に失敗しました"
 
@@ -28693,13 +26383,11 @@ msgstr ""
 
 #: symtab.c:1763
 #, fuzzy, gcc-internal-format
-#| msgid "function %qD redeclared as variable"
 msgid "function %q+D part of alias cycle"
 msgstr "関数 %qD が変数として再宣言されました"
 
 #: symtab.c:1765
 #, fuzzy, gcc-internal-format
-#| msgid "variable %q+D set but not used"
 msgid "variable %q+D part of alias cycle"
 msgstr "変数 %q+D が設定されましたが使用されていません"
 
@@ -28710,7 +26398,6 @@ msgstr ""
 
 #: targhooks.c:191
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs はこのターゲットではサポートされていません"
 
@@ -28731,25 +26418,21 @@ msgstr "target 属性はこのマシン上ではサポートされていませ
 
 #: targhooks.c:1588
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC target is not supported for this machine"
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
 #: toplev.c:864
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t open %s for writing: %m"
 msgid "cannot open %qs for writing: %m"
 msgstr "%s を書き込み用に開けません: %m"
 
 #: toplev.c:886
 #, fuzzy, gcc-internal-format
-#| msgid "-frecord-gcc-switches is not supported by the current target"
 msgid "%<-frecord-gcc-switches%> is not supported by the current target"
 msgstr "-frecord-gcc-switches は現在のターゲットではサポートされていません"
 
 #: toplev.c:935
 #, fuzzy, gcc-internal-format
-#| msgid "-fstack-usage not supported for this target"
 msgid "stack usage computation not supported for this target"
 msgstr "-fstack-usage はこのターゲットではサポートされていません"
 
@@ -28760,19 +26443,16 @@ msgstr ""
 
 #: toplev.c:998
 #, fuzzy, gcc-internal-format
-#| msgid "stackframe too big: %d bytes"
 msgid "stack usage might be %wu bytes"
 msgstr "スタックフレームが大きすぎます: %d バイト"
 
 #: toplev.c:1001
 #, fuzzy, gcc-internal-format
-#| msgid "stackframe too big: %d bytes"
 msgid "stack usage is %wu bytes"
 msgstr "スタックフレームが大きすぎます: %d バイト"
 
 #: toplev.c:1118
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t open %s for writing: %m"
 msgid "cannot open %s for writing: %m"
 msgstr "%s を書き込み用に開けません: %m"
 
@@ -28788,25 +26468,21 @@ msgstr ""
 
 #: toplev.c:1439
 #, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
 msgid "%<-fcf-protection=full%> is not supported for this target"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
 
 #: toplev.c:1446
 #, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
 msgid "%<-fcf-protection=branch%> is not supported for this target"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
 
 #: toplev.c:1453
 #, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
 msgid "%<-fcf-protection=return%> is not supported for this target"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
 
 #: toplev.c:1468
 #, fuzzy, gcc-internal-format
-#| msgid "switch %qs is no longer supported"
 msgid "%<-fabi-version=1%> is no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
@@ -28822,7 +26498,6 @@ msgstr "このターゲットマシンは遅延分岐を持っていません"
 
 #: toplev.c:1519
 #, fuzzy, gcc-internal-format
-#| msgid "-f%sleading-underscore not supported on this target machine"
 msgid "%<-f%sleading-underscore%> not supported on this target machine"
 msgstr "-f%sleading-underscore はこのターゲットマシンではサポートされません"
 
@@ -28833,7 +26508,6 @@ msgstr ""
 
 #: toplev.c:1599
 #, fuzzy, gcc-internal-format
-#| msgid "target system does not support the \"%s\" debug format"
 msgid "target system does not support the %qs debug format"
 msgstr "ターゲットシステムは \"%s\" デバッグ形式をサポートしません"
 
@@ -28869,37 +26543,31 @@ msgstr ""
 
 #: toplev.c:1741
 #, fuzzy, gcc-internal-format
-#| msgid "-ffunction-sections not supported for this target"
 msgid "%<-ffunction-sections%> not supported for this target"
 msgstr "-ffunction-sections はこのターゲットではサポートされていません"
 
 #: toplev.c:1747
 #, fuzzy, gcc-internal-format
-#| msgid "-fdata-sections not supported for this target"
 msgid "%<-fdata-sections%> not supported for this target"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
 #: toplev.c:1755
 #, fuzzy, gcc-internal-format
-#| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target"
 msgstr "-fprefetch-loop-arrays はこのターゲットではサポートされていません"
 
 #: toplev.c:1761
 #, fuzzy, gcc-internal-format
-#| msgid "-fprefetch-loop-arrays not supported for this target (try -march switches)"
 msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
 msgstr "-fprefetch-loop-arrays はこのターゲットではサポートされていません (-march スイッチを試してください)"
 
 #: toplev.c:1771
 #, fuzzy, gcc-internal-format
-#| msgid "-fprefetch-loop-arrays is not supported with -Os"
 msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
 msgstr "-fprefetch-loop-arrays を -Os と併せて使用することはサポートされていません"
 
 #: toplev.c:1783
 #, fuzzy, gcc-internal-format
-#| msgid "-fassociative-math disabled; other options take precedence"
 msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "-fassociative-math は無効です。他のオプションが優先して使用されます"
 
@@ -28915,13 +26583,11 @@ msgstr ""
 
 #: toplev.c:1821
 #, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
 msgid "%<-fstack-protector%> not supported for this target"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
 
 #: toplev.c:1833
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC and -fpic are not supported for this target"
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
 msgstr "-fPIC and -fpic はこのターゲットではサポートされていません"
 
@@ -28942,7 +26608,6 @@ msgstr ""
 
 #: toplev.c:2332
 #, fuzzy, gcc-internal-format
-#| msgid "-mas100-syntax is incompatible with -gdwarf"
 msgid "self-tests incompatible with %<-E%>"
 msgstr "-mas100-syntax と -gdwarf は併用できません"
 
@@ -29008,7 +26673,6 @@ msgstr "大域 register 変数が関数定義の後ろにあります"
 
 #: trans-mem.c:771
 #, fuzzy, gcc-internal-format
-#| msgid "Place each function into its own section"
 msgid "relaxed transaction in atomic transaction"
 msgstr "それぞれの関数をそれ自身のセクションに配置する"
 
@@ -29019,7 +26683,6 @@ msgstr ""
 
 #: trans-mem.c:781
 #, fuzzy, gcc-internal-format
-#| msgid "pointer to a function used in subtraction"
 msgid "outer transaction in transaction"
 msgstr "関数ポインタの差を求めようとしています"
 
@@ -29045,13 +26708,11 @@ msgstr ""
 
 #: tree-cfg.c:2998
 #, fuzzy, gcc-internal-format
-#| msgid "constant not recomputed when ADDR_EXPR changed"
 msgid "constant not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR が変更されたときに定数が再計算されません"
 
 #: tree-cfg.c:3003
 #, fuzzy, gcc-internal-format
-#| msgid "side effects not recomputed when ADDR_EXPR changed"
 msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
 msgstr "ADDR_EXPR が変更されたときに副作用が計算されません"
 
@@ -29077,43 +26738,36 @@ msgstr "間接参照内で無効な被演算子です"
 
 #: tree-cfg.c:3082
 #, fuzzy, gcc-internal-format
-#| msgid "non-scalar type"
 msgid "non-scalar %qs"
 msgstr "非スカラー型"
 
 #: tree-cfg.c:3096
 #, fuzzy, gcc-internal-format
-#| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size operand to %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
 #: tree-cfg.c:3102
 #, fuzzy, gcc-internal-format
-#| msgid "integral result type precision does not match field size of BIT_FIELD_REF"
 msgid "integral result type precision does not match field size of %qs"
 msgstr "整数結果の型精度が BIT_FIELD_REF のフィールドサイズに適合しません"
 
 #: tree-cfg.c:3111
 #, fuzzy, gcc-internal-format
-#| msgid "mode precision of non-integral result does not match field size of BIT_FIELD_REF"
 msgid "mode size of non-integral result does not match field size of %qs"
 msgstr "非整数結果のモード精度が BIT_FIELD_REF のフィールドサイズに適合しません"
 
 #: tree-cfg.c:3119
 #, fuzzy, gcc-internal-format
-#| msgid "shift of non-integer operand"
 msgid "%qs of non-mode-precision operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
 #: tree-cfg.c:3126
 #, fuzzy, gcc-internal-format
-#| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "position plus size exceeds size of referenced object in %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
 #: tree-cfg.c:3137
 #, fuzzy, gcc-internal-format
-#| msgid "type mismatch in array reference"
 msgid "type mismatch in %qs reference"
 msgstr "配列参照内で型不一致です"
 
@@ -29124,7 +26778,6 @@ msgstr ""
 
 #: tree-cfg.c:3168
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand to %%R"
 msgid "invalid operands to %qs"
 msgstr "%%R への無効な被演算子です"
 
@@ -29140,13 +26793,11 @@ msgstr "型が前方の外部宣言と一致しません"
 
 #: tree-cfg.c:3199
 #, fuzzy, gcc-internal-format
-#| msgid "invalid shift operand"
 msgid "invalid %qs offset operator"
 msgstr "無効なシフト被演算子"
 
 #: tree-cfg.c:3223
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of %qs on the left hand side of %qs"
 msgstr "%qT から %qT への変換が曖昧です"
 
@@ -29157,25 +26808,21 @@ msgstr "NaN から整数への変換です"
 
 #: tree-cfg.c:3251 tree-cfg.c:3277
 #, fuzzy, gcc-internal-format
-#| msgid "invalid address operand in MEM_REF"
 msgid "invalid address operand in %qs"
 msgstr "MEM_REF 内で無効なアドレス被演算子です"
 
 #: tree-cfg.c:3258 tree-cfg.c:3284
 #, fuzzy, gcc-internal-format
-#| msgid "invalid offset operand in MEM_REF"
 msgid "invalid offset operand in %qs"
 msgstr "MEM_REF 内で無効なオフセット被演算子です"
 
 #: tree-cfg.c:3265 tree-cfg.c:3291
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %qD"
 msgid "invalid clique in %qs"
 msgstr "無効な %qD の使用です"
 
 #: tree-cfg.c:3298 tree-cfg.c:4503
 #, fuzzy, gcc-internal-format
-#| msgid "INDIRECT_REF in gimple IL"
 msgid "%qs in gimple IL"
 msgstr "INDIRECT_REF が gimple IL 内にあります"
 
@@ -29237,7 +26884,6 @@ msgstr ""
 #. we must make sure arguments are stripped off.
 #: tree-cfg.c:3457
 #, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
@@ -29253,7 +26899,6 @@ msgstr "gimple 比較内で無効な被演算子です"
 
 #: tree-cfg.c:3516
 #, fuzzy, gcc-internal-format
-#| msgid "type mismatch in comparison expression"
 msgid "mismatching comparison operand types"
 msgstr "比較式内で型不一致です"
 
@@ -29264,19 +26909,16 @@ msgstr ""
 
 #: tree-cfg.c:3548
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operands in gimple comparison"
 msgid "non-vector operands in vector comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
 #: tree-cfg.c:3557
 #, fuzzy, gcc-internal-format
-#| msgid "invalid vector permutation constant"
 msgid "invalid vector comparison resulting type"
 msgstr "無効なベクトル順列定数です"
 
 #: tree-cfg.c:3564
 #, fuzzy, gcc-internal-format
-#| msgid "Warn about comparison of different enum types"
 msgid "bogus comparison result type"
 msgstr "異なる列挙型の比較に関して警告する"
 
@@ -29292,7 +26934,6 @@ msgstr "単項演算子内で無効な被演算子です"
 
 #: tree-cfg.c:3615
 #, fuzzy, gcc-internal-format
-#| msgid "invalid types in nop conversion"
 msgid "invalid vector types in nop conversion"
 msgstr "nop 変換内で無効な型です"
 
@@ -29313,7 +26954,6 @@ msgstr "固定小数変換内で無効な型です"
 
 #: tree-cfg.c:3688
 #, fuzzy, gcc-internal-format
-#| msgid "invalid types in conversion to floating point"
 msgid "invalid types in conversion to floating-point"
 msgstr "浮動小数点への変換内で無効な型です"
 
@@ -29324,7 +26964,6 @@ msgstr "整数への変換内で無効な型です"
 
 #: tree-cfg.c:3743
 #, fuzzy, gcc-internal-format
-#| msgid "type mismatch in address expression"
 msgid "type mismatch in %qs expression"
 msgstr "アドレス式内で型不一致です"
 
@@ -29355,19 +26994,16 @@ msgstr "二進演算内で無効な被演算子です"
 
 #: tree-cfg.c:3927
 #, fuzzy, gcc-internal-format
-#| msgid "invalid non-vector operands to vector valued plus"
 msgid "invalid non-vector operands to %qs"
 msgstr "ベクトル値加算への無効な非ベクトル被演算子です"
 
 #: tree-cfg.c:3938
 #, fuzzy, gcc-internal-format
-#| msgid "invalid pointer mode %qs"
 msgid "invalid (pointer) operands %qs"
 msgstr "無効なポインタモード %qs です"
 
 #: tree-cfg.c:4144
 #, fuzzy, gcc-internal-format
-#| msgid "expected integer expression"
 msgid "vector type expected in %qs"
 msgstr "整数式が予期されます"
 
@@ -29393,43 +27029,36 @@ msgstr ""
 
 #: tree-cfg.c:4268 tree-cfg.c:4327
 #, fuzzy, gcc-internal-format
-#| msgid "expected integer expression"
 msgid "vector types expected in %qs"
 msgstr "整数式が予期されます"
 
 #: tree-cfg.c:4283
 #, fuzzy, gcc-internal-format
-#| msgid "Warn about comparison of different enum types"
 msgid "vectors with different element number found in %qs"
 msgstr "異なる列挙型の比較に関して警告する"
 
 #: tree-cfg.c:4299
 #, fuzzy, gcc-internal-format
-#| msgid "invalid rotate insn"
 msgid "invalid mask type in %qs"
 msgstr "無効な回転 (rotate) 命令です"
 
 #: tree-cfg.c:4359
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
 msgid "not allowed type combination in %qs"
 msgstr "サポートされていない組み合わせです: %s"
 
 #: tree-cfg.c:4368
 #, fuzzy, gcc-internal-format
-#| msgid "invalid position or size operand to BIT_FIELD_REF"
 msgid "invalid position or size in %qs"
 msgstr "BIT_FIELD_REF への無効な位置またはサイズ被演算子です"
 
 #: tree-cfg.c:4374
 #, fuzzy, gcc-internal-format
-#| msgid "shift of non-integer operand"
 msgid "%qs into non-mode-precision operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
 #: tree-cfg.c:4384
 #, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "insertion out of range in %qs"
 msgstr "%qs 用の定数引数が範囲外です"
 
@@ -29440,19 +27069,16 @@ msgstr "%s は型 %s ではありません (引数 %d)"
 
 #: tree-cfg.c:4449
 #, fuzzy, gcc-internal-format
-#| msgid "invalid version number %qs"
 msgid "non-trivial conversion in %qs"
 msgstr "無効なバージョン番号 %qs です"
 
 #: tree-cfg.c:4458
 #, fuzzy, gcc-internal-format
-#| msgid "in statement"
 msgid "%qs LHS in clobber statement"
 msgstr "式内"
 
 #: tree-cfg.c:4477
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand to %%R"
 msgid "invalid operand in %qs"
 msgstr "%%R への無効な被演算子です"
 
@@ -29463,13 +27089,11 @@ msgstr "不完全な typedef `%s' の使用は不適切です"
 
 #: tree-cfg.c:4578 tree-cfg.c:4596
 #, fuzzy, gcc-internal-format
-#| msgid "left shift count >= width of type"
 msgid "incorrect type of vector %qs elements"
 msgstr "左シフト回数 >= 型の幅となっています"
 
 #: tree-cfg.c:4587 tree-cfg.c:4604
 #, fuzzy, gcc-internal-format
-#| msgid "not enough arguments to function %qE"
 msgid "incorrect number of vector %qs elements"
 msgstr "関数 %qE へ十分な引数がありません"
 
@@ -29485,13 +27109,11 @@ msgstr ""
 
 #: tree-cfg.c:4628
 #, fuzzy, gcc-internal-format
-#| msgid "PHI argument is not a GIMPLE value"
 msgid "vector %qs element is not a GIMPLE value"
 msgstr "PHI 引数が GIMPLE 値ではありません"
 
 #: tree-cfg.c:4637
 #, fuzzy, gcc-internal-format
-#| msgid "Warn about comparison of different enum types"
 msgid "non-vector %qs with elements"
 msgstr "異なる列挙型の比較に関して警告する"
 
@@ -29522,13 +27144,11 @@ msgstr "switch 文への無効な被演算子です"
 
 #: tree-cfg.c:4773
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand to switch statement"
 msgid "non-integral type switch statement"
 msgstr "switch 文への無効な被演算子です"
 
 #: tree-cfg.c:4783
 #, fuzzy, gcc-internal-format
-#| msgid "%<default%> label not within a switch statement"
 msgid "invalid default case label in switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
@@ -29539,43 +27159,36 @@ msgstr ""
 
 #: tree-cfg.c:4801
 #, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
 msgid "invalid case label in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
 #: tree-cfg.c:4808
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand to switch statement"
 msgid "invalid case range in switch statement"
 msgstr "switch 文への無効な被演算子です"
 
 #: tree-cfg.c:4818
 #, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
 msgid "type mismatch for case label in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
 #: tree-cfg.c:4828
 #, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
 msgid "type precision mismatch in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
 #: tree-cfg.c:4837
 #, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
 msgid "case labels not sorted in switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
 #: tree-cfg.c:4880
 #, fuzzy, gcc-internal-format
-#| msgid "parameter names (without types) in function declaration"
 msgid "label context is not the current function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
 #: tree-cfg.c:4889
 #, fuzzy, gcc-internal-format
-#| msgid "incorrect entry in label_to_block_map"
 msgid "incorrect entry in %<label_to_block_map%>"
 msgstr "label_to_block_map 内に間違ったエントリがあります"
 
@@ -29596,37 +27209,31 @@ msgstr "gimple 条件内で無効なラベルです"
 
 #: tree-cfg.c:5006 tree-cfg.c:5015
 #, fuzzy, gcc-internal-format
-#| msgid "invalid PHI result"
 msgid "invalid %<PHI%> result"
 msgstr "無効な PHI 結果です"
 
 #: tree-cfg.c:5025
 #, fuzzy, gcc-internal-format
-#| msgid "missing PHI def"
 msgid "missing %<PHI%> def"
 msgstr "PHI 定義がありません"
 
 #: tree-cfg.c:5039
 #, fuzzy, gcc-internal-format
-#| msgid "invalid PHI argument"
 msgid "invalid %<PHI%> argument"
 msgstr "無効な PHI 引数です"
 
 #: tree-cfg.c:5046
 #, fuzzy, gcc-internal-format
-#| msgid "incompatible types in PHI argument %u"
 msgid "incompatible types in %<PHI%> argument %u"
 msgstr "PHI 引数 %u 内で互換性のない型です"
 
 #: tree-cfg.c:5144
 #, fuzzy, gcc-internal-format
-#| msgid "verify_gimple failed"
 msgid "%<verify_gimple%> failed"
 msgstr "verify_gimple に失敗しました"
 
 #: tree-cfg.c:5201
 #, fuzzy, gcc-internal-format
-#| msgid "dead STMT in EH table"
 msgid "dead statement in EH table"
 msgstr "EH 表内に不要な (dead) STMT があります"
 
@@ -29772,19 +27379,16 @@ msgstr "制御が非 void 関数の終りに到達しました"
 
 #: tree-cfg.c:9532
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
 #: tree-cfg.c:9537 cp/cvt.c:1110
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている関数の戻り値を無視しています"
 
 #: tree-diagnostic.c:203
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of %q+D"
 msgid "in definition of macro %qs"
 msgstr "%q+D が再定義されました"
 
@@ -29875,7 +27479,6 @@ msgstr "関数 %q+F は非局所 goto を使用しているため決してイン
 
 #: tree-inline.c:3939
 #, fuzzy, gcc-internal-format
-#| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "関数 %q+F は __builtin_return または __builtin_apply_args を使用しているため決してインライン化されません"
 
@@ -29886,7 +27489,6 @@ msgstr ""
 
 #: tree-inline.c:4060
 #, fuzzy, gcc-internal-format
-#| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "関数 %q+F は -fno-inline を使用して抑止されているため決してインライン化されません"
 
@@ -29897,7 +27499,6 @@ msgstr "関数 %q+F はインライン化と競合する属性を使用してい
 
 #: tree-inline.c:4746
 #, fuzzy, gcc-internal-format
-#| msgid "inlining failed in call to %q+F: %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "%q+F 呼び出しのインライン化に失敗しました: %s"
 
@@ -29908,7 +27509,6 @@ msgstr "ここから呼び出されました"
 
 #: tree-inline.c:4752 tree-inline.c:4773
 #, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
 msgid "called from this function"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
@@ -29944,7 +27544,6 @@ msgstr ""
 
 #: tree-profile.c:621
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "invalid regular expression %qs in %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -29959,7 +27558,6 @@ msgstr ""
 
 #: tree-ssa-ccp.c:3567
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "in a call to built-in function %qD"
 msgstr "組み込み関数への無効な引数です"
 
@@ -29985,13 +27583,11 @@ msgstr ""
 
 #: tree-ssa-operands.c:977
 #, fuzzy, gcc-internal-format
-#| msgid "virtual functions cannot be friends"
 msgid "virtual definition of statement not up to date"
 msgstr "仮想関数は friend にできません"
 
 #: tree-ssa-operands.c:984
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand in return statement"
 msgid "virtual def operand missing for statement"
 msgstr "return 文内で無効な被演算子です"
 
@@ -30002,19 +27598,16 @@ msgstr ""
 
 #: tree-ssa-operands.c:1001
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand in return statement"
 msgid "virtual use operand missing for statement"
 msgstr "return 文内で無効な被演算子です"
 
 #: tree-ssa-operands.c:1018
 #, fuzzy, gcc-internal-format
-#| msgid "expected declaration or statement"
 msgid "excess use operand for statement"
 msgstr "宣言または式が予期されます"
 
 #: tree-ssa-operands.c:1028
 #, fuzzy, gcc-internal-format
-#| msgid "operand number missing after %%-letter"
 msgid "use operand missing for statement"
 msgstr "%% 文字の後に被演算子の数字がありません"
 
@@ -30089,7 +27682,6 @@ msgstr ""
 
 #: tree-ssa-strlen.c:2304
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "type of field declared here"
 msgid "at offset %s to an object declared here"
 msgstr "フィールドの型はここで宣言されました"
 
@@ -30151,7 +27743,6 @@ msgstr ""
 
 #: tree-ssa-strlen.c:3436
 #, fuzzy, gcc-internal-format
-#| msgid "length modifier"
 msgid "length computed here"
 msgstr "長さ修飾子"
 
@@ -30173,7 +27764,6 @@ msgstr ""
 
 #: tree-ssa-strlen.c:4365
 #, fuzzy, gcc-internal-format
-#| msgid "  in thrown expression"
 msgid "in this expression"
 msgstr "  throw された式の中"
 
@@ -30194,13 +27784,11 @@ msgstr "%qD はこの関数内初期化されずに使用されるかもしれ
 
 #: tree-ssa-uninit.c:369
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is used uninitialized in this function"
 msgid "%qE is used uninitialized in this function"
 msgstr "%qD はこの関数内で初期化されずに使用されています"
 
 #: tree-ssa-uninit.c:379
 #, fuzzy, gcc-internal-format
-#| msgid "%qD may be used uninitialized in this function"
 msgid "%qE may be used uninitialized in this function"
 msgstr "%qD はこの関数内初期化されずに使用されるかもしれません"
 
@@ -30211,7 +27799,6 @@ msgstr ""
 
 #: tree-ssa.c:681 tree-ssa.c:710
 #, fuzzy, gcc-internal-format
-#| msgid "virtual functions cannot be friends"
 msgid "virtual definition is not an SSA name"
 msgstr "仮想関数は friend にできません"
 
@@ -30392,37 +27979,31 @@ msgstr ""
 
 #: tree-vrp.c:3579
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript %E is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: tree-vrp.c:3605
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: tree-vrp.c:3615
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is above array bounds"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "配列の添字が配列の境界を上回っています"
 
 #: tree-vrp.c:3620
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is below array bounds"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "配列の添字が配列の境界を下回っています"
 
 #: tree-vrp.c:3626
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript %E is outside the bounds of an interior zero-length array %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: tree-vrp.c:3628
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
@@ -30433,37 +28014,31 @@ msgstr ""
 
 #: tree-vrp.c:3658
 #, fuzzy, gcc-internal-format
-#| msgid "union defined here"
 msgid "defined here %qD"
 msgstr "共用体がここで定義されています"
 
 #: tree-vrp.c:3899
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript %wi is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: tree-vrp.c:3904
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: tree-vrp.c:3926
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "intermediate array offset %wi is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: tree-vrp.c:3997
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "配列の添字が配列の境界を下回っています"
 
 #: tree-vrp.c:4011
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "配列の添字が配列の境界を上回っています"
 
@@ -30519,13 +28094,11 @@ msgstr ""
 
 #: tree.c:9919
 #, fuzzy, gcc-internal-format
-#| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
 #: tree.c:9932
 #, fuzzy, gcc-internal-format
-#| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
@@ -30536,19 +28109,16 @@ msgstr ""
 
 #: tree.c:9958
 #, fuzzy, gcc-internal-format
-#| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
 #: tree.c:13079
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
 #: tree.c:13082
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qE は廃止されました"
 
@@ -30669,13 +28239,11 @@ msgstr ""
 
 #: tree.c:14086
 #, fuzzy, gcc-internal-format
-#| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "type is not compatible with its variant"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
 #: tree.c:14398
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable %qs not defined"
 msgid "main variant is not defined"
 msgstr "環境変数 %qs が定義されていません"
 
@@ -30771,13 +28339,11 @@ msgstr ""
 
 #: tree.c:14607
 #, fuzzy, gcc-internal-format
-#| msgid "size of array %qE has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
 #: tree.c:14616
 #, fuzzy, gcc-internal-format
-#| msgid "field %qE has incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
@@ -30843,7 +28409,6 @@ msgstr "破損した値のプロファイルです: %s プロファイルの総
 
 #: var-tracking.c:7187
 #, fuzzy, gcc-internal-format
-#| msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgid "variable tracking size limit exceeded with %<-fvar-tracking-assignments%>, retrying without"
 msgstr "変数追跡サイズ制限が -fvar-tracking-assignments を超過しています。-fvar-tracking-assignments 無しで再度試みています"
 
@@ -30854,37 +28419,31 @@ msgstr "変数追跡サイズ制限が超過しました"
 
 #: varasm.c:338
 #, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D によりセクション型が競合します"
 
 #: varasm.c:341
 #, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict"
 msgid "section type conflict with %qD"
 msgstr "%+D によりセクション型が競合します"
 
 #: varasm.c:346
 #, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D によりセクション型が競合します"
 
 #: varasm.c:348
 #, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict"
 msgid "section type conflict"
 msgstr "%+D によりセクション型が競合します"
 
 #: varasm.c:1043
 #, fuzzy, gcc-internal-format
-#| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "%q+D の整列がオブジェクトファイルの整列の最大値より大きいです。%d を使用します"
 
 #: varasm.c:1196
 #, fuzzy, gcc-internal-format
-#| msgid "Put zero initialized data in the bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
@@ -30905,13 +28464,11 @@ msgstr "%q+D のデータ型がレジスタに適合しません"
 
 #: varasm.c:1414
 #, fuzzy, gcc-internal-format
-#| msgid "register specified for %q+D isn%'t suitable for data type"
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "%q+D 用に指定されたレジスタがデータ型に適合しません"
 
 #: varasm.c:1417
 #, fuzzy, gcc-internal-format
-#| msgid "register used for two global register variables"
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
@@ -30977,7 +28534,6 @@ msgstr "領域 `%s' は関数として宣言されています"
 
 #: varasm.c:5655
 #, fuzzy, gcc-internal-format
-#| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%q+D の弱い (weak) 宣言は定義の前に無ければ行けません"
 
@@ -31003,7 +28559,6 @@ msgstr "弱い参照はこの設定ではサポートされていません"
 
 #: varasm.c:5947
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "%qs is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
@@ -31019,7 +28574,6 @@ msgstr ""
 
 #: varasm.c:6024
 #, fuzzy, gcc-internal-format
-#| msgid "weakref %q+D must have static linkage"
 msgid "%qs symbol %q+D must have static linkage"
 msgstr "弱い参照 %q+D は静的リンクされなければいけません"
 
@@ -31030,7 +28584,6 @@ msgstr "この設定では別名定義はサポートされていません"
 
 #: varasm.c:6041
 #, fuzzy, gcc-internal-format
-#| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this configuration"
 msgstr "%s はこの設定ではサポートされていません"
 
@@ -31086,7 +28639,6 @@ msgstr "%</%> または %<%%%> を %<>>%> または %<&%> へ単純化すると
 
 #: vr-values.c:3262
 #, fuzzy, gcc-internal-format
-#| msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgid "assuming signed overflow does not occur when simplifying %<min/max (X,Y)%> to %<X%> or %<Y%>"
 msgstr "%<abs (X)%> を %<X%> または %<-X%> へ単純化するときに符号のオーバーフローが発生しないと見なしています"
 
@@ -31113,7 +28665,6 @@ msgstr ""
 
 #: c-family/c-ada-spec.c:2850
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
 msgid "unsupported record layout"
 msgstr "サポートされていない組み合わせです: %s"
 
@@ -31129,38 +28680,32 @@ msgstr "マクロ引数 \"%s\" は文字列化されます"
 
 #: c-family/c-attribs.c:563
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute argument has type %qT"
 msgstr "%qE 属性は %qT 型のフィールド用としては無視されます"
 
 #: c-family/c-attribs.c:567
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute argument %i has type %qT"
 msgstr "%qE 属性は %qT 型のフィールド用としては無視されます"
 
 #: c-family/c-attribs.c:578 c-family/c-attribs.c:3610
 #: c-family/c-attribs.c:3614
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%qE attribute argument value %qE is not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c-family/c-attribs.c:583
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%qE attribute argument %i value %qE is not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c-family/c-attribs.c:599
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute argument value %qE does not refer to a function parameter"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
 #: c-family/c-attribs.c:604
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute argument %i value %qE does not refer to a function parameter"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
@@ -31176,25 +28721,21 @@ msgstr "メソッドは関数ポインタに変換できません"
 
 #: c-family/c-attribs.c:650
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute argument value %qE does not refer to a variable argument list"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
 #: c-family/c-attribs.c:654
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute argument %i value %qE does not refer to a variable argument list"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
 #: c-family/c-attribs.c:681 c-family/c-attribs.c:694
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on types"
 msgid "%qE attribute argument value %qE refers to parameter type %qT"
 msgstr "%qE 属性は型に関しては無視されます"
 
 #: c-family/c-attribs.c:685 c-family/c-attribs.c:699
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on types"
 msgid "%qE attribute argument %i value %qE refers to parameter type %qT"
 msgstr "%qE 属性は型に関しては無視されます"
 
@@ -31210,7 +28751,6 @@ msgstr ""
 
 #: c-family/c-attribs.c:738
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute ignored for type %qT"
 msgstr "%qE 属性は %qE 用としては無視されます"
 
@@ -31221,19 +28761,16 @@ msgstr "%qE 属性は %qT 型のフィールド用としては無視されます
 
 #: c-family/c-attribs.c:920 c-family/c-attribs.c:2829
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "%qE argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
 #: c-family/c-attribs.c:1051 ada/gcc-interface/utils.c:6455
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: c-family/c-attribs.c:1100
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored. Use %<-fcf-protection%> option to enable it"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
@@ -31242,7 +28779,6 @@ msgstr "%qE 属性は非クラス型に関しては無視されます"
 #: c-family/c-attribs.c:4409 ada/gcc-interface/utils.c:6714
 #: ada/gcc-interface/utils.c:6748 ada/gcc-interface/utils.c:6754
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%qE 属性は %s 属性と競合します"
 
@@ -31258,13 +28794,11 @@ msgstr "%qE 属性は公開オブジェクトに関してのみ効果があり
 
 #: c-family/c-attribs.c:1385
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "%qE は変数にのみ適用できます"
 
 #: c-family/c-attribs.c:1424 c-family/c-attribs.c:3206
 #, fuzzy, gcc-internal-format
-#| msgid "using result of function returning %<void%>"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
@@ -31275,7 +28809,6 @@ msgstr "init_priority 属性はこのプラットフォームではサポート
 
 #: c-family/c-attribs.c:1464
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "attribute %qE argument must be one of %qs or %qs"
 msgstr "属性 %qE の引数が文字列ではありません"
 
@@ -31316,13 +28849,11 @@ msgstr "不明なマシンモード %qE です"
 
 #: c-family/c-attribs.c:1787
 #, fuzzy, gcc-internal-format
-#| msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgid "specifying vector types with %<__attribute__ ((mode))%> is deprecated"
 msgstr "ベクトル型を __attribute__ ((mode)) で指定することは廃止されています"
 
 #: c-family/c-attribs.c:1790
 #, fuzzy, gcc-internal-format
-#| msgid "use __attribute__ ((vector_size)) instead"
 msgid "use %<__attribute__ ((vector_size))%> instead"
 msgstr "代わりに __attribute__ ((vector_size)) を使用してください"
 
@@ -31348,7 +28879,6 @@ msgstr "モード %qs 用のデータ型がありません"
 
 #: c-family/c-attribs.c:1850
 #, fuzzy, gcc-internal-format
-#| msgid "cannot use mode %qs for enumeral types"
 msgid "cannot use mode %qs for enumerated types"
 msgstr "モード %qs を列挙型用に使用できません"
 
@@ -31369,7 +28899,6 @@ msgstr "セクション属性は %q+D 用には許可されていません"
 
 #: c-family/c-attribs.c:1913
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
@@ -31411,7 +28940,6 @@ msgstr "%q+D 用の整列は前に %d として指定されていて、減らす
 
 #: c-family/c-attribs.c:2139
 #, fuzzy, gcc-internal-format
-#| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%q+D 用の整列が指定されていないようです"
 
@@ -31434,37 +28962,31 @@ msgstr "%qE は変数にのみ適用できます"
 
 #: c-family/c-attribs.c:2230 config/msp430/msp430.c:1432
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute cannot be applied to variables with specific sections"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
 #: c-family/c-attribs.c:2234
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is not supported for R8C target"
 msgid "%qE attribute is specific to ELF targets"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
 #: c-family/c-attribs.c:2274
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
 #: c-family/c-attribs.c:2293
 #, fuzzy, gcc-internal-format
-#| msgid "%qs attribute only applies to functions"
 msgid "%<symver%> attribute only applies to functions and variables"
 msgstr "%qs 属性は関数へのみ適用出来ます"
 
 #: c-family/c-attribs.c:2301
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
 msgid "%<symver%> attribute is only applicable to symbols"
 msgstr "%qE 属性は関数へのみ適用されます"
 
 #: c-family/c-attribs.c:2311
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "%<symver%> attribute argument not a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
@@ -31500,13 +29022,11 @@ msgstr "領域 `%s' は関数として宣言されています"
 
 #: c-family/c-attribs.c:2469
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument cannot be a string"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: c-family/c-attribs.c:2482
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument cannot be a constant arithmetic expression"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
@@ -31527,19 +29047,16 @@ msgstr "`%s' は前にここで宣言されました"
 
 #: c-family/c-attribs.c:2601
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute must apply to a declaration"
 msgstr "%qE 属性は関数へのみ適用されます"
 
 #: c-family/c-attribs.c:2657
 #, fuzzy, gcc-internal-format
-#| msgid "indirect function %q+D cannot be declared weak"
 msgid "indirect function %q+D cannot be declared %qE"
 msgstr "間接関数 %q+D を弱いとして宣言できません"
 
 #: c-family/c-attribs.c:2680
 #, fuzzy, gcc-internal-format
-#| msgid "weakref attribute must appear before alias attribute"
 msgid "%qE attribute must appear before %qs attribute"
 msgstr "弱い参照属性は別名属性より前に出現しなければいけません"
 
@@ -31570,7 +29087,6 @@ msgstr "%qE 属性は型に関しては無視されます"
 
 #: c-family/c-attribs.c:2764
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "attribute %qE argument must be one of %qs, %qs, %qs, or %qs"
 msgstr "属性 %qE の引数が文字列ではありません"
 
@@ -31586,13 +29102,11 @@ msgstr "%qD は %qs として宣言されていて、暗黙的にデフォルト
 
 #: c-family/c-attribs.c:2812
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored because %qT is already defined"
 msgid "%qE attribute ignored because %qD is not a variable"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
 #: c-family/c-attribs.c:2820
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored because %qT is already defined"
 msgid "%qE attribute ignored because %qD does not have thread storage duration"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
@@ -31610,25 +29124,21 @@ msgstr "%qE 属性は関数にのみ適用できます"
 #: c-family/c-attribs.c:2920 c-family/c-attribs.c:2961
 #: c-family/c-attribs.c:2985
 #, fuzzy, gcc-internal-format
-#| msgid "using result of function returning %<void%>"
 msgid "%qE attribute ignored on a function returning %qT"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
 #: c-family/c-attribs.c:3004
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%qE attribute %E is not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c-family/c-attribs.c:3016
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%qE attribute argument %E is not a power of 2"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c-family/c-attribs.c:3029
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "%qE attribute argument %E is not in the range [0, %wu]"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
@@ -31639,25 +29149,21 @@ msgstr ""
 
 #: c-family/c-attribs.c:3186 c-family/c-attribs.c:4483
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t set %qE attribute after definition"
 msgid "cannot set %qE attribute after definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
 #: c-family/c-attribs.c:3253
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "%qE 属性は無視されました"
 
 #: c-family/c-attribs.c:3255
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute follows %qE"
 msgstr "%qE 属性は %qE 用としては無視されます"
 
 #: c-family/c-attribs.c:3354
 #, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
 msgid "type was previously declared %qE"
 msgstr "前はここで宣言されました"
 
@@ -31668,13 +29174,11 @@ msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
 #: c-family/c-attribs.c:3425
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%qE argument not an identifier"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c-family/c-attribs.c:3436
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not declared in %qD"
 msgid "%qD is not compatible with %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
@@ -31705,7 +29209,6 @@ msgstr "右シフト回数が負の数です"
 
 #: c-family/c-attribs.c:3640 c-family/c-attribs.c:3644
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument should be between 0 to 255"
 msgid "%qE attribute argument value %qE exceeds %wu"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
@@ -31726,19 +29229,16 @@ msgstr "ベクトルの要素の数が 2 の累乗ではありません"
 
 #: c-family/c-attribs.c:3728
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute without arguments on a non-prototype"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: c-family/c-attribs.c:3785
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%qE 属性は %qT 型のフィールド用としては無視されます"
 
 #: c-family/c-attribs.c:3793
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not apply to functions"
 msgstr "%qE 属性は型に適用できません"
 
@@ -31749,7 +29249,6 @@ msgstr ""
 
 #: c-family/c-attribs.c:3895
 #, fuzzy, gcc-internal-format
-#| msgid "address area of %q+D conflicts with previous declaration"
 msgid "attribute %qs positional argument 2 conflicts with previous designation"
 msgstr "%q+D  のアドレス領域は前の宣言と競合しています"
 
@@ -31765,13 +29264,11 @@ msgstr ""
 
 #: c-family/c-attribs.c:3975
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "attribute %qE without arguments on a non-prototype"
 msgstr "属性 %qE の引数が文字列ではありません"
 
 #: c-family/c-attribs.c:3998
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored"
 msgid "attribute %qE invalid mode"
 msgstr "%qE 属性は無視されました"
 
@@ -31791,7 +29288,6 @@ msgstr ""
 #. write_only to the rest.
 #: c-family/c-attribs.c:4040
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires a string constant argument"
 msgid "attribute %<%E(%s)%> missing an argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
@@ -31807,7 +29303,6 @@ msgstr ""
 
 #: c-family/c-attribs.c:4109
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "attribute %qs positional argument %i invalid value %wi"
 msgstr "属性 %qE の引数が文字列ではありません"
 
@@ -31818,7 +29313,6 @@ msgstr ""
 
 #: c-family/c-attribs.c:4120
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires a string constant argument"
 msgid "attribute %qs invalid positional argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
@@ -31885,19 +29379,16 @@ msgstr "戻り型が void の関数で、`return' に値があります"
 
 #: c-family/c-attribs.c:4515
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
 #: c-family/c-attribs.c:4551
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%qE attribute argument %qE is not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c-family/c-attribs.c:4572
 #, fuzzy, gcc-internal-format
-#| msgid "unknown property attribute"
 msgid "unknown attribute %qE"
 msgstr "不明な property 属性です"
 
@@ -31908,13 +29399,11 @@ msgstr "`%s' に対するレジスタ名として無効です"
 
 #: c-family/c-attribs.c:4703
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is not supported for R8C target"
 msgid "%qs attribute not supported for %qT in %<__builtin_has_attribute%>"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
 #: c-family/c-attribs.c:4705
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is not supported for R8C target"
 msgid "%qs attribute not supported for %qE in %<__builtin_has_attribute%>"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
@@ -31930,7 +29419,6 @@ msgstr "%qD は関数スコープの外側で定義されていません"
 
 #: c-family/c-common.c:787
 #, fuzzy, gcc-internal-format
-#| msgid "size of array is too large"
 msgid "size of string literal is too large"
 msgstr "配列のサイズが大きすぎます"
 
@@ -31946,19 +29434,16 @@ msgstr ""
 
 #: c-family/c-common.c:1024
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be an 8-bit immediate"
 msgid "%<__builtin_shuffle%> last argument must be an integer vector"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
 #: c-family/c-common.c:1033
 #, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_longjmp%> second argument must be 1"
 msgid "%<__builtin_shuffle%> arguments must be vectors"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
 #: c-family/c-common.c:1040
 #, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_longjmp%> second argument must be 1"
 msgid "%<__builtin_shuffle%> argument vectors must be of the same type"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
@@ -31974,13 +29459,11 @@ msgstr ""
 
 #: c-family/c-common.c:1110
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be an 8-bit immediate"
 msgid "%<__builtin_convertvector%> first argument must be an integer or floating vector"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
 #: c-family/c-common.c:1119
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be an 8-bit immediate"
 msgid "%<__builtin_convertvector%> second argument must be an integer or floating vector type"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
@@ -32021,13 +29504,11 @@ msgstr "データ型の範囲制限によって、比較が常に true となり
 
 #: c-family/c-common.c:3052
 #, fuzzy, gcc-internal-format
-#| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of unsigned expression in %<>= 0%> is always true"
 msgstr "符号無しの式 >= 0 という比較は常に true です"
 
 #: c-family/c-common.c:3060
 #, fuzzy, gcc-internal-format
-#| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of unsigned expression in %<< 0%> is always false"
 msgstr "符号無しの式 < 0 という比較は常に false です"
 
@@ -32043,7 +29524,6 @@ msgstr "関数へのポインタが計算内で使用されています"
 
 #: c-family/c-common.c:3290
 #, fuzzy, gcc-internal-format
-#| msgid "enum constant defined here"
 msgid "enum constant in boolean context"
 msgstr "列挙型定数がここで定義されています"
 
@@ -32064,19 +29544,16 @@ msgstr ""
 
 #: c-family/c-common.c:3389
 #, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<?:%> using integer constants in boolean context, the expression will always evaluate to %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
 #: c-family/c-common.c:3398
 #, fuzzy, gcc-internal-format
-#| msgid "enum constant defined here"
 msgid "%<?:%> using integer constants in boolean context"
 msgstr "列挙型定数がここで定義されています"
 
 #: c-family/c-common.c:3434
 #, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
@@ -32112,13 +29589,11 @@ msgstr "%qs をvoid 型へ適用することは無効です"
 
 #: c-family/c-common.c:3654
 #, fuzzy, gcc-internal-format
-#| msgid "invalid application of %qs to incomplete type %qT "
 msgid "invalid application of %qs to incomplete type %qT"
 msgstr "%qs を不完全型 %qT へ適用することは無効です "
 
 #: c-family/c-common.c:3662
 #, fuzzy, gcc-internal-format
-#| msgid "invalid application of %qs to incomplete type %qT "
 msgid "invalid application of %qs to array type %qT of incomplete element type"
 msgstr "%qs を不完全型 %qT へ適用することは無効です "
 
@@ -32189,25 +29664,21 @@ msgstr "ラベルのアドレスを取得することは非標準です"
 
 #: c-family/c-common.c:5197
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not a constant"
 msgid "requested alignment is not an integer constant"
 msgstr "要求された整列が定数ではありません"
 
 #: c-family/c-common.c:5205 c-family/c-common.c:5215
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not a power of 2"
 msgid "requested alignment %qE is not a positive power of 2"
 msgstr "要求された整列が 2 の累乗ではありません"
 
 #: c-family/c-common.c:5225
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is too large"
 msgid "requested alignment %qE exceeds object file maximum %u"
 msgstr "要求された整列が大きすぎます"
 
 #: c-family/c-common.c:5233
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is too large"
 msgid "requested alignment %qE exceeds maximum %u"
 msgstr "要求された整列が大きすぎます"
 
@@ -32228,13 +29699,11 @@ msgstr ""
 
 #: c-family/c-common.c:5593 c-family/c-common.c:5643
 #, fuzzy, gcc-internal-format
-#| msgid "bad option %s to pragma attribute"
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "pragma 属性への間違ったオプション %s です"
 
 #: c-family/c-common.c:5596 c-family/c-common.c:5647
 #, fuzzy, gcc-internal-format
-#| msgid "bad option %s to pragma attribute"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "pragma 属性への間違ったオプション %s です"
 
@@ -32262,7 +29731,6 @@ msgstr "関数 %qE への引数が多すぎます"
 
 #: c-family/c-common.c:5901
 #, fuzzy, gcc-internal-format
-#| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
@@ -32288,13 +29756,11 @@ msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があり
 
 #: c-family/c-common.c:6004
 #, fuzzy, gcc-internal-format
-#| msgid "non-const integer argument %u in call to function %qE"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
 #: c-family/c-common.c:6021 c-family/c-common.c:6064
 #, fuzzy, gcc-internal-format
-#| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
@@ -32320,13 +29786,11 @@ msgstr "不完全型への変換です"
 
 #: c-family/c-common.c:6070
 #, fuzzy, gcc-internal-format
-#| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
 #: c-family/c-common.c:6076
 #, fuzzy, gcc-internal-format
-#| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
@@ -32362,61 +29826,51 @@ msgstr "配列のサイズが大きすぎます"
 
 #: c-family/c-common.c:6674 c-family/c-common.c:6798
 #, fuzzy, gcc-internal-format
-#| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
 #: c-family/c-common.c:6708
 #, fuzzy, gcc-internal-format
-#| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
 #: c-family/c-common.c:6724
 #, fuzzy, gcc-internal-format
-#| msgid "types are not quite compatible"
 msgid "both arguments must be compatible"
 msgstr "型は全く互換がありません"
 
 #: c-family/c-common.c:6932
 #, fuzzy, gcc-internal-format
-#| msgid "not enough arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "関数 %qE へ十分な引数がありません"
 
 #: c-family/c-common.c:6946
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be an address"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
 #: c-family/c-common.c:6955
 #, fuzzy, gcc-internal-format
-#| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
 #: c-family/c-common.c:6966
 #, fuzzy, gcc-internal-format
-#| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
 #: c-family/c-common.c:6987
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be an address"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
 #: c-family/c-common.c:6995
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
 #: c-family/c-common.c:7001
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be a multiple of %d"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%d 番目の %qE の引数は %d の倍数でなければいけません"
 
@@ -32427,13 +29881,11 @@ msgstr "引数 %d 個の `%s' を渡します"
 
 #: c-family/c-common.c:7021
 #, fuzzy, gcc-internal-format
-#| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
 #: c-family/c-common.c:7034
 #, fuzzy, gcc-internal-format
-#| msgid "incompatible type for argument %d of %qE"
 msgid "invalid memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
@@ -32449,7 +29901,6 @@ msgstr ""
 
 #: c-family/c-common.c:8097 c-family/c-common.c:8146 c-family/c-common.c:8162
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "%qT から %qT への変換が曖昧です"
 
@@ -32457,7 +29908,6 @@ msgstr "%qT から %qT への変換が曖昧です"
 #. no library fallback.
 #: c-family/c-common.c:8250
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD takes one argument only"
 msgid "built-in function %qE must be directly called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
@@ -32473,7 +29923,6 @@ msgstr "定数式が欠けているか無効です"
 
 #: c-family/c-common.c:8277
 #, fuzzy, gcc-internal-format
-#| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "配列 %qE のサイズが負です"
 
@@ -32494,7 +29943,6 @@ msgstr ""
 
 #: c-family/c-common.c:8293
 #, fuzzy, gcc-internal-format
-#| msgid "size of array %qE is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "配列 %qE のサイズが負です"
 
@@ -32520,7 +29968,6 @@ msgstr "書式文字列引数が文字列型ではありません"
 
 #: c-family/c-format.c:259
 #, fuzzy, gcc-internal-format
-#| msgid "found a %<%s%> reference but the format argument should be a string"
 msgid "found a %qs reference but the format argument should be a string"
 msgstr "%<%s%> 参照が見つかりましたが、書式引数は文字列であるべきです"
 
@@ -32531,13 +29978,11 @@ msgstr "%qT 型が見つかりましたが書式引数は文字列であるべ
 
 #: c-family/c-format.c:272
 #, fuzzy, gcc-internal-format
-#| msgid "format argument should be a %<%s%> reference but a string was found"
 msgid "format argument should be a %qs reference but a string was found"
 msgstr "書式引数は %<%s%> への参照であるべきですが、文字列が見つかりました"
 
 #: c-family/c-format.c:294
 #, fuzzy, gcc-internal-format
-#| msgid "format argument should be a %<%s%> reference"
 msgid "format argument should be a %qs reference"
 msgstr "書式引数は %<%s%> への参照であるべきです"
 
@@ -32558,13 +30003,11 @@ msgstr "%qE は認識できない書式関数型です"
 
 #: c-family/c-format.c:393
 #, fuzzy, gcc-internal-format
-#| msgid "format string argument is not a string type"
 msgid "format string argument follows the arguments to be formatted"
 msgstr "書式文字列引数が文字列型ではありません"
 
 #: c-family/c-format.c:1238
 #, fuzzy, gcc-internal-format
-#| msgid "function might be possible candidate for %qs format attribute"
 msgid "function %qD might be a candidate for %qs format attribute"
 msgstr "関数が %qs 書式属性の候補である可能性があります"
 
@@ -32590,7 +30033,6 @@ msgstr "%d 番目の書式引数が %s 書式内で二回以上使用されて
 
 #: c-family/c-format.c:1422
 #, fuzzy, gcc-internal-format
-#| msgid "$ operand number used after format without operand number"
 msgid "%<$%>operand number used after format without operand number"
 msgstr "$ 被演算子番号が被演算子番号が無い書式の後に使用されています"
 
@@ -32598,7 +30040,6 @@ msgstr "$ 被演算子番号が被演算子番号が無い書式の後に使用
 # 苦しい訳です
 #: c-family/c-format.c:1453
 #, fuzzy, gcc-internal-format
-#| msgid "format argument %d unused before used argument %d in $-style format"
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
 msgstr "$-スタイル書式内の %d 番目の引数が、後にある %d 番目の引数が使用されたにも関わらず使用されていません"
 
@@ -32624,7 +30065,6 @@ msgstr "書式への引数が多すぎます"
 
 #: c-family/c-format.c:1599
 #, fuzzy, gcc-internal-format
-#| msgid "unused arguments in $-style format"
 msgid "unused arguments in %<$%>-style format"
 msgstr "$-スタイルの書式で未使用の引数があります"
 
@@ -32640,7 +30080,6 @@ msgstr "書式がワイド文字列です"
 
 #: c-family/c-format.c:1610
 #, fuzzy, gcc-internal-format
-#| msgid "format string argument is not a string type"
 msgid "format string is not an array of type %qs"
 msgstr "書式文字列引数が文字列型ではありません"
 
@@ -32751,7 +30190,6 @@ msgstr "%<%%[%> 書式用の閉じる %<]%> がありません"
 
 #: c-family/c-format.c:2701
 #, fuzzy, gcc-internal-format
-#| msgid "use of %qs length modifier with %qc type character"
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
 msgstr "%qs 長さ修飾子を %qc 型変換文字で使用しています"
 
@@ -32772,37 +30210,31 @@ msgstr "被演算子番号が引数を取らない書式で指定されていま
 
 #: c-family/c-format.c:3115
 #, fuzzy, gcc-internal-format
-#| msgid "repeated %s in format"
 msgid "unquoted type name %<%.*s%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
 #: c-family/c-format.c:3117
 #, fuzzy, gcc-internal-format
-#| msgid "repeated %s in format"
 msgid "unquoted operator %<%.*s%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
 #: c-family/c-format.c:3118
 #, fuzzy, gcc-internal-format
-#| msgid "embedded %<\\0%> in format"
 msgid "unquoted keyword %<%.*s%> in format"
 msgstr "書式内に %<\\0%> が組み込まれています"
 
 #: c-family/c-format.c:3121
 #, fuzzy, gcc-internal-format
-#| msgid "spec %qs invalid"
 msgid "use %qs instead"
 msgstr "spec %qs が無効です"
 
 #: c-family/c-format.c:3173
 #, fuzzy, gcc-internal-format
-#| msgid "multiple function type attributes specified"
 msgid "unquoted attribute in format"
 msgstr "複数の関数型属性が指定されています"
 
 #: c-family/c-format.c:3186
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "unquoted name of built-in function %<%.*s%> in format"
 msgstr "組み込み関数への無効な引数です"
 
@@ -32813,7 +30245,6 @@ msgstr ""
 
 #: c-family/c-format.c:3228
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
 msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
 msgstr "%<-mcpu=%> は廃止されました。代わりに %<-mtune=%> または %<-march=%> を使用してください"
 
@@ -32829,13 +30260,11 @@ msgstr ""
 
 #: c-family/c-format.c:3319
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unquoted whitespace character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3332
 #, fuzzy, gcc-internal-format
-#| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing space in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
@@ -32846,31 +30275,26 @@ msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
 #: c-family/c-format.c:3360
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unquoted sequence of %i consecutive space characters in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3380
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control characters in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3387
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unquoted control character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3445
 #, fuzzy, gcc-internal-format
-#| msgid "spurious trailing %<%%%> in format"
 msgid "unquoted option name %<%.*s%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
 #: c-family/c-format.c:3505
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
@@ -32881,7 +30305,6 @@ msgstr ""
 
 #: c-family/c-format.c:3560
 #, fuzzy, gcc-internal-format
-#| msgid "repeated %s in format"
 msgid "bare apostrophe %<'%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
@@ -32892,7 +30315,6 @@ msgstr ""
 
 #: c-family/c-format.c:3574
 #, fuzzy, gcc-internal-format
-#| msgid "repeated %s in format"
 msgid "grave accent %<`%> in format"
 msgstr "書式内に %s の繰り返しがあります"
 
@@ -32908,7 +30330,6 @@ msgstr ""
 
 #: c-family/c-format.c:3599
 #, fuzzy, gcc-internal-format
-#| msgid "repeated %s in format"
 msgid "quoted %qs directive in format"
 msgstr "書式内に %s の繰り返しがあります"
 
@@ -32919,13 +30340,11 @@ msgstr ""
 
 #: c-family/c-format.c:3630
 #, fuzzy, gcc-internal-format
-#| msgid "spurious trailing %<%%%> in format"
 msgid "spurious leading punctuation sequence %<%.*s%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
 #: c-family/c-format.c:3670
 #, fuzzy, gcc-internal-format
-#| msgid "spurious trailing %<%%%> in format"
 msgid "spurious trailing punctuation sequence %<%.*s%> in format"
 msgstr "書式内に誤った %<%%%> が最後にあります"
 
@@ -32936,31 +30355,26 @@ msgstr ""
 
 #: c-family/c-format.c:3707
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph characters in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3714
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unquoted non-graph character %qc in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3746
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unbalanced punctuation character %<%c%> in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
 #: c-family/c-format.c:3753
 #, fuzzy, gcc-internal-format
-#| msgid "Do not generate #line directives"
 msgid "unterminated quoting directive"
 msgstr "#line 指示を生成しない"
 
 #: c-family/c-format.c:3762
 #, fuzzy, gcc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "unterminated quote character %<%c%> in format"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
@@ -32976,7 +30390,6 @@ msgstr "書式の最後に型変換がありません"
 
 #: c-family/c-format.c:3921
 #, fuzzy, gcc-internal-format
-#| msgid "Process #ident directives"
 msgid "nested quoting directive"
 msgstr "#ident 指示を処理する"
 
@@ -33007,7 +30420,6 @@ msgstr "書式内に %<\\0%> が組み込まれています"
 
 #: c-family/c-format.c:4021
 #, fuzzy, gcc-internal-format
-#| msgid "unterminated format string"
 msgid "unterminated color directive"
 msgstr "終端されていない書式文字列です"
 
@@ -33068,7 +30480,6 @@ msgstr "%<locus%> が型として定義されていません"
 
 #: c-family/c-format.c:4923
 #, fuzzy, gcc-internal-format
-#| msgid "%<locus%> is not defined as a type"
 msgid "%qs is not defined as a type"
 msgstr "%<locus%> が型として定義されていません"
 
@@ -33089,7 +30500,6 @@ msgstr "%<tree%> がポインタ型として定義されていません"
 
 #: c-family/c-format.c:5202
 #, fuzzy, gcc-internal-format
-#| msgid "args to be formatted is not %<...%>"
 msgid "argument to be formatted is not %<...%>"
 msgstr "書式解釈される引数が %<...%> ではありません"
 
@@ -33120,7 +30530,6 @@ msgstr "前処理から間違って入れ子になっている C ヘッダです
 
 #: c-family/c-lex.c:262
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring #pragma %s %s"
 msgid "ignoring %<#pragma %s %s%>"
 msgstr "#pragma %s %s を無視します"
 
@@ -33167,13 +30576,11 @@ msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
 #: c-family/c-lex.c:868
 #, fuzzy, gcc-internal-format
-#| msgid "unsuffixed float constant"
 msgid "unsuffixed floating constant"
 msgstr "接尾辞がない浮動小数定数です"
 
 #: c-family/c-lex.c:882
 #, fuzzy, gcc-internal-format
-#| msgid "fixed-point types not supported for this target"
 msgid "decimal floating-point not supported for this target"
 msgstr "固定小数点型はこのターゲットではサポートされていません"
 
@@ -33219,7 +30626,6 @@ msgstr ""
 
 #: c-family/c-omp.c:216
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "%<_Atomic%> expression in %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
@@ -33255,7 +30661,6 @@ msgstr ""
 
 #: c-family/c-omp.c:509
 #, fuzzy, gcc-internal-format
-#| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
@@ -33266,7 +30671,6 @@ msgstr ""
 
 #: c-family/c-omp.c:728
 #, fuzzy, gcc-internal-format
-#| msgid "%qs specified for auto variable %qE"
 msgid "%<_Atomic%> iteration variable %qE"
 msgstr "%qs が自動変数 %qE 用に指定されています"
 
@@ -33312,7 +30716,6 @@ msgstr ""
 
 #: c-family/c-omp.c:1088
 #, fuzzy, gcc-internal-format
-#| msgid "increment of read-only variable %qD"
 msgid "increment expression refers to iteration variable %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
@@ -33333,19 +30736,16 @@ msgstr ""
 
 #: c-family/c-omp.c:2016 c-family/c-omp.c:2031
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a function template"
 msgid "%qD is not a function argument"
 msgstr "%qD は関数テンプレートではありません"
 
 #: c-family/c-omp.c:2138
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
 msgid "selector set %qs specified more than once"
 msgstr "型名用に記憶域クラスが指定されました"
 
 #: c-family/c-omp.c:2152 c-family/c-omp.c:2165
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
 msgid "selector %qs specified more than once in set %qs"
 msgstr "型名用に記憶域クラスが指定されました"
 
@@ -33356,13 +30756,11 @@ msgstr ""
 
 #: c-family/c-omp.c:2213
 #, fuzzy, gcc-internal-format
-#| msgid "unknown operator %qs in %%:version-compare"
 msgid "unknown property %qs of %qs selector"
 msgstr "不明な演算子 %qs が %%:version-compare 内にあります"
 
 #: c-family/c-omp.c:2218
 #, fuzzy, gcc-internal-format
-#| msgid "unknown property attribute"
 msgid "unknown property %qE of %qs selector"
 msgstr "不明な property 属性です"
 
@@ -33373,19 +30771,16 @@ msgstr ""
 
 #: c-family/c-opts.c:330
 #, fuzzy, gcc-internal-format
-#| msgid "-I- specified twice"
 msgid "%<-I-%> specified twice"
 msgstr "-I- が二回指定されました"
 
 #: c-family/c-opts.c:333
 #, fuzzy, gcc-internal-format
-#| msgid "obsolete option -I- used, please use -iquote instead"
 msgid "obsolete option %<-I-%> used, please use %<-iquote%> instead"
 msgstr "廃止されたオプション -I- が使用されています。代わりに -iquote を使用してください"
 
 #: c-family/c-opts.c:412
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
@@ -33401,49 +30796,41 @@ msgstr ""
 
 #: c-family/c-opts.c:841
 #, fuzzy, gcc-internal-format
-#| msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgid "%<-fno-gnu89-inline%> is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline は GNU99 または C99 モードでのみサポートされます"
 
 #: c-family/c-opts.c:887
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-y2k ignored without -Wformat"
 msgid "%<-Wformat-y2k%> ignored without %<-Wformat%>"
 msgstr "-Wformat-y2k は無視されました (-Wformat がありません)"
 
 #: c-family/c-opts.c:889
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-extra-args ignored without -Wformat"
 msgid "%<-Wformat-extra-args%> ignored without %<-Wformat%>"
 msgstr "-Wformat-extra-args は無視されました (-Wformat がありません)"
 
 #: c-family/c-opts.c:891
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-zero-length ignored without -Wformat"
 msgid "%<-Wformat-zero-length%> ignored without %<-Wformat%>"
 msgstr "-Wformat-zero-length は無視されました (-Wformat がありません)"
 
 #: c-family/c-opts.c:893
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-nonliteral ignored without -Wformat"
 msgid "%<-Wformat-nonliteral%> ignored without %<-Wformat%>"
 msgstr "-Wformat-nonliteral は無視されました (-Wformat がありません)"
 
 #: c-family/c-opts.c:895
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-contains-nul ignored without -Wformat"
 msgid "%<-Wformat-contains-nul%> ignored without %<-Wformat%>"
 msgstr "-Wformat-contains-nul は無視されました (-Wformat がありません)"
 
 #: c-family/c-opts.c:897
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-security ignored without -Wformat"
 msgid "%<-Wformat-security%> ignored without %<-Wformat%>"
 msgstr "-Wformat-security は無視されました (-Wformat がありません)"
 
 #: c-family/c-opts.c:940
 #, fuzzy, gcc-internal-format
-#| msgid "-falign-loops=%d is not supported"
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "-falign-loops=%d はサポートされていません"
 
@@ -33464,13 +30851,11 @@ msgstr ""
 
 #: c-family/c-opts.c:1035
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "external TLS initialization functions not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: c-family/c-opts.c:1059
 #, fuzzy, gcc-internal-format
-#| msgid "too many filenames given.  Type %s --help for usage"
 msgid "too many filenames given; type %<%s %s%> for usage"
 msgstr "与えられたファイル名が多すぎます。使用法に関しては %s --help を参照してください"
 
@@ -33501,25 +30886,21 @@ msgstr "出力を %s へ書き込み中です: %m"
 
 #: c-family/c-opts.c:1339
 #, fuzzy, gcc-internal-format
-#| msgid "to generate dependencies you must specify either -M or -MM"
 msgid "to generate dependencies you must specify either %<-M%> or %<-MM%>"
 msgstr "依存関係を生成するためには -M または -MM のいずれかを指定しなければいけません"
 
 #: c-family/c-opts.c:1363
 #, fuzzy, gcc-internal-format
-#| msgid "-MG may only be used with -M or -MM"
 msgid "%<-MG%> may only be used with %<-M%> or %<-MM%>"
 msgstr "-MG は -M または -MM と併せてのみ使用できます"
 
 #: c-family/c-opts.c:1396
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgid "%<-fdirectives-only%> is incompatible with %<-Wunused-macros%>"
 msgstr "-fdirectives-only は -Wunused_macros と併用できません"
 
 #: c-family/c-opts.c:1399
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fdirectives-only%> is incompatible with %<-traditional%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
@@ -33530,31 +30911,26 @@ msgstr "デバッグディレクトリを設定する # 指示が遅すぎます
 
 #: c-family/c-pch.c:106
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t create precompiled header %s: %m"
 msgid "cannot create precompiled header %s: %m"
 msgstr "前処理済ヘッダ %s を作成できません: %m"
 
 #: c-family/c-pch.c:127
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t write to %s: %m"
 msgid "cannot write to %s: %m"
 msgstr "%s へ書き込めません: %m"
 
 #: c-family/c-pch.c:185
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t write %s: %m"
 msgid "cannot write %s: %m"
 msgstr "%s へ書き込めません: %m"
 
 #: c-family/c-pch.c:409
 #, fuzzy, gcc-internal-format
-#| msgid "pch_preprocess pragma should only be used with -fpreprocessed"
 msgid "%<pch_preprocess%> pragma should only be used with %<-fpreprocessed%>"
 msgstr "pch_preprocess pragma は -fpreprocessed と併せてのみ使用するべきです"
 
 #: c-family/c-pch.c:411
 #, fuzzy, gcc-internal-format
-#| msgid "use #include instead"
 msgid "use %<#include%> instead"
 msgstr "代わりに #include を使用してください"
 
@@ -33565,7 +30941,6 @@ msgstr "%s: PCH ファイルを開けませんでした: %m"
 
 #: c-family/c-pch.c:422
 #, fuzzy, gcc-internal-format
-#| msgid "use -Winvalid-pch for more information"
 msgid "use %<-Winvalid-pch%> for more information"
 msgstr "詳細については -Winvalid-pch を使用してください"
 
@@ -33576,13 +30951,11 @@ msgstr "%s: PCH ファイルが無効です"
 
 #: c-family/c-pragma.c:94
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma pack (pop) encountered without matching #pragma pack (push)"
 msgid "%<#pragma pack (pop)%> encountered without matching %<#pragma pack (push)%>"
 msgstr "#pragma pack (pop) で対応する #pragma pack (push) が無いものに遭遇しました"
 
 #: c-family/c-pragma.c:109
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma pack(pop, %E) encountered without matching #pragma pack(push, %E)"
 msgid "%<#pragma pack(pop, %E)%> encountered without matching %<#pragma pack(push, %E)%>"
 msgstr "#pragma pack(pop, %E) で対応する #pragma pack(push, %E) が無いものに遭遇しました"
 
@@ -33623,7 +30996,6 @@ msgstr "%<#pragma pack%> の末尾にゴミがあります"
 
 #: c-family/c-pragma.c:202
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma pack has no effect with -fpack-struct - ignored"
 msgid "%<#pragma pack%> has no effect with %<-fpack-struct%> - ignored"
 msgstr "#pragma pack は -fpack-struct と併せて使用しても効果がありません - 無視されました"
 
@@ -33634,13 +31006,11 @@ msgstr "整列は %d ではなく、小さな二の累乗の数でなければ
 
 #: c-family/c-pragma.c:262
 #, fuzzy, gcc-internal-format
-#| msgid "weak declaration of %q+D after first use results in unspecified behavior"
 msgid "applying %<#pragma weak %+D%> after first use results in unspecified behavior"
 msgstr "%q+D の弱い (weak) 宣言が最初に使用された後に行われていますが、この結果は不定です"
 
 #: c-family/c-pragma.c:359 c-family/c-pragma.c:364
 #, fuzzy, gcc-internal-format
-#| msgid "malformed #pragma weak, ignored"
 msgid "malformed %<#pragma weak%>, ignored"
 msgstr "間違った形式の #pragma weak です。無視されました"
 
@@ -33651,19 +31021,16 @@ msgstr "%<#pragma weak%> の末尾にゴミがあります"
 
 #: c-family/c-pragma.c:374
 #, fuzzy, gcc-internal-format
-#| msgid "weak declaration of %q+D not supported"
 msgid "%<#pragma weak%> declaration of %q+D not allowed, ignored"
 msgstr "%q+D の弱い (weak) 宣言はサポートされていません"
 
 #: c-family/c-pragma.c:422
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma STDC FLOAT_CONST_DECIMAL64%> is not supported for C++"
 msgid "%<scalar_storage_order%> is not supported because endianness is not uniform"
 msgstr "%<#pragma STDC FLOAT_CONST_DECIMAL64%> は C++ 用にはサポートされていません"
 
 #: c-family/c-pragma.c:431
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma STDC FLOAT_CONST_DECIMAL64%> is not supported for C++"
 msgid "%<#pragma scalar_storage_order%> is not supported for C++"
 msgstr "%<#pragma STDC FLOAT_CONST_DECIMAL64%> は C++ 用にはサポートされていません"
 
@@ -33679,7 +31046,6 @@ msgstr ""
 
 #: c-family/c-pragma.c:500 c-family/c-pragma.c:502
 #, fuzzy, gcc-internal-format
-#| msgid "malformed #pragma redefine_extname, ignored"
 msgid "malformed %<#pragma redefine_extname%>, ignored"
 msgstr "間違った形式の #pragma redefine_extname です。無視されました"
 
@@ -33690,37 +31056,31 @@ msgstr "%<#pragma redefine_extname%> の末尾にゴミがあります"
 
 #: c-family/c-pragma.c:533 c-family/c-pragma.c:606
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma redefine_extname ignored due to conflict with previous rename"
 msgid "%<#pragma redefine_extname%> ignored due to conflict with previous rename"
 msgstr "#pragma redefine_extname は前の名前変更と競合するため無視されました"
 
 #: c-family/c-pragma.c:561
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma redefine_extname ignored due to conflict with previous #pragma redefine_extname"
 msgid "%<#pragma redefine_extname%> ignored due to conflict with previous %<#pragma redefine_extname%>"
 msgstr "#pragma redefine_extname は前の #pragma redefine_extname と競合するため無視されました"
 
 #: c-family/c-pragma.c:597
 #, fuzzy, gcc-internal-format
-#| msgid "asm declaration ignored due to conflict with previous rename"
 msgid "%<asm%> declaration ignored due to conflict with previous rename"
 msgstr "アセンブラ宣言は前の名前変更と競合するため無視されました"
 
 #: c-family/c-pragma.c:628
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma redefine_extname ignored due to conflict with __asm__ declaration"
 msgid "%<#pragma redefine_extname%> ignored due to conflict with %<asm%> declaration"
 msgstr "#pragma redefine_extname は __asm__ 宣言と競合するため無視されました"
 
 #: c-family/c-pragma.c:689
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC visibility push() must specify default, internal, hidden or protected"
 msgid "%<#pragma GCC visibility push()%> must specify %<default%>, %<internal%>, %<hidden%> or %<protected%>"
 msgstr "#pragma GCC visibility push() は default、internal、hidden または protected を指定しなければいけません"
 
 #: c-family/c-pragma.c:732
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC visibility must be followed by push or pop"
 msgid "%<#pragma GCC visibility%> must be followed by %<push%> or %<pop%>"
 msgstr "#pragma GCC visibility には push または pop を続けなければいけません"
 
@@ -33736,7 +31096,6 @@ msgstr "%<#pragma GCC visibility push%> の後に %<(%> がありません - 無
 
 #: c-family/c-pragma.c:747
 #, fuzzy, gcc-internal-format
-#| msgid "malformed #pragma GCC visibility push"
 msgid "malformed %<#pragma GCC visibility push%>"
 msgstr "誤った形式の #pragma GCC visibility push です"
 
@@ -33747,7 +31106,6 @@ msgstr "%<#pragma GCC visibility%> の末尾にゴミがあります"
 
 #: c-family/c-pragma.c:767
 #, fuzzy, gcc-internal-format
-#| msgid "missing [error|warning|ignored] after %<#pragma GCC diagnostic%>"
 msgid "missing [error|warning|ignored|push|pop] after %<#pragma GCC diagnostic%>"
 msgstr "%<#pragma GCC diagnostic%> の後に [error|warning|ignored] がありません"
 
@@ -33763,7 +31121,6 @@ msgstr "%<#pragma GCC diagnostic%> 類の後にオプションがありません
 
 #: c-family/c-pragma.c:816
 #, fuzzy, gcc-internal-format
-#| msgid "unknown option after %<#pragma GCC diagnostic%> kind"
 msgid "unknown option after %<#pragma GCC diagnostic%> kind; did you mean %<-%s%>?"
 msgstr "%<#pragma GCC diagnostic%> の後に不明なオプションです"
 
@@ -33774,19 +31131,16 @@ msgstr "%<#pragma GCC diagnostic%> の後に不明なオプションです"
 
 #: c-family/c-pragma.c:827
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not an option that controls warnings"
 msgstr "%qs は前処理の有効なオプションではありません"
 
 #: c-family/c-pragma.c:835
 #, fuzzy, gcc-internal-format
-#| msgid "command line option %qs is valid for %s but not for %s"
 msgid "option %qs is valid for %s but not for %s"
 msgstr "コマンドラインオプション %qs は %s 用としては有効ですが、%s 用としては有効ではありません"
 
 #: c-family/c-pragma.c:867
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC option%> is not allowed inside functions"
 msgstr "#pragma GCC option は関数内では許可されていません"
 
@@ -33802,13 +31156,11 @@ msgstr "%<#pragma GCC target (string [,string]...)%> に最後の %<)%> があ
 
 #: c-family/c-pragma.c:913
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC target string... is badly formed"
 msgid "%<#pragma GCC target%> string is badly formed"
 msgstr "#pragma GCC target string... の形式に間違いがあります"
 
 #: c-family/c-pragma.c:936
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC optimize%> is not allowed inside functions"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
@@ -33824,7 +31176,6 @@ msgstr "%<#pragma GCC optimize (string [,string]...)%> に最後の %<)%> があ
 
 #: c-family/c-pragma.c:981
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC optimize string... is badly formed"
 msgid "%<#pragma GCC optimize%> string is badly formed"
 msgstr "#pragma GCC optimize string... の形式に間違いがあります"
 
@@ -33865,7 +31216,6 @@ msgstr "%<#pragma message%> の末尾にゴミがあります"
 
 #: c-family/c-pragma.c:1154
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma message: %s"
 msgid "%<#pragma message: %s%>"
 msgstr "#pragma message: %s"
 
@@ -33952,73 +31302,61 @@ msgstr "定数式内でオーバーフローしました"
 
 #: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
-#| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で整数がオーバーフローしました"
 
 #: c-family/c-warn.c:98
 #, fuzzy, gcc-internal-format
-#| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "式内で整数がオーバーフローしました"
 
 #: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
-#| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で浮動小数点数がオーバーフローしました"
 
 #: c-family/c-warn.c:106
 #, fuzzy, gcc-internal-format
-#| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "式内で浮動小数点数がオーバーフローしました"
 
 #: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
-#| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で固定小数点数がオーバーフローしました"
 
 #: c-family/c-warn.c:114
 #, fuzzy, gcc-internal-format
-#| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "式内で固定小数点数がオーバーフローしました"
 
 #: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
-#| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "式内でベクトルがオーバーフローしました"
 
 #: c-family/c-warn.c:122
 #, fuzzy, gcc-internal-format
-#| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "式内でベクトルがオーバーフローしました"
 
 #: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
-#| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で複素整数がオーバーフローしました"
 
 #: c-family/c-warn.c:131
 #, fuzzy, gcc-internal-format
-#| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "式内で複素整数がオーバーフローしました"
 
 #: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
-#| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で複素浮動小数点数がオーバーフローしました"
 
 #: c-family/c-warn.c:137
 #, fuzzy, gcc-internal-format
-#| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "式内で複素浮動小数点数がオーバーフローしました"
 
@@ -34044,13 +31382,11 @@ msgstr "相互に排他的な値の論理 %<and%> 演算は常に偽 (false) と
 
 #: c-family/c-warn.c:317
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand in unary expression"
 msgid "logical %<or%> of equal expressions"
 msgstr "単項演算式内で無効な被演算子です"
 
 #: c-family/c-warn.c:320
 #, fuzzy, gcc-internal-format
-#| msgid "logical %<and%> of mutually exclusive tests is always false"
 msgid "logical %<and%> of equal expressions"
 msgstr "相互に排他的な値の論理 %<and%> 演算は常に偽 (false) となります"
 
@@ -34061,7 +31397,6 @@ msgstr ""
 
 #: c-family/c-warn.c:409
 #, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "bitwise comparison always evaluates to true"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
@@ -34212,7 +31547,6 @@ msgstr "%q+D は 0 個または 2 個の引数のみとります"
 
 #: c-family/c-warn.c:1155
 #, fuzzy, gcc-internal-format
-#| msgid "field %qE declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "フィールド %qE が関数として宣言されています"
 
@@ -34223,37 +31557,31 @@ msgstr "真偽式から %qT への変換です"
 
 #: c-family/c-warn.c:1223 c-family/c-warn.c:1392
 #, fuzzy, gcc-internal-format
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
 #: c-family/c-warn.c:1228 c-family/c-warn.c:1400
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
 #: c-family/c-warn.c:1236
 #, fuzzy, gcc-internal-format
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "signed conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
 #: c-family/c-warn.c:1241
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "signed conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
 #: c-family/c-warn.c:1248 c-family/c-warn.c:1390
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
 #: c-family/c-warn.c:1252 c-family/c-warn.c:1398
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
@@ -34264,25 +31592,21 @@ msgstr "%qT への %qT からの変換は結果の符号が変更になるかも
 
 #: c-family/c-warn.c:1340
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "%qT から %qT への変換が曖昧です"
 
 #: c-family/c-warn.c:1344
 #, fuzzy, gcc-internal-format
-#| msgid "conversion to %qT from %qT may alter its value"
 msgid "conversion from %qT to %qT may change value"
 msgstr "%qT への %qT からの変換はその値が変更になるかもしれません"
 
 #: c-family/c-warn.c:1411 c-family/c-warn.c:1428 c-family/c-warn.c:1445
 #, fuzzy, gcc-internal-format
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
 #: c-family/c-warn.c:1416 c-family/c-warn.c:1433 c-family/c-warn.c:1450
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
@@ -34498,7 +31822,6 @@ msgstr "単項 %<&%> の被演算子として左辺値が必要です"
 
 #: c-family/c-warn.c:1876
 #, fuzzy, gcc-internal-format
-#| msgid "lvalue required in asm statement"
 msgid "lvalue required in %<asm%> statement"
 msgstr "アセンブラ文内に左辺値が必要です"
 
@@ -34524,7 +31847,6 @@ msgstr "%<->%> の無効な型の引数です (%qT 型です)"
 
 #: c-family/c-warn.c:1912
 #, fuzzy, gcc-internal-format
-#| msgid "invalid type argument of %<->%> (have %qT)"
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "%<->%> の無効な型の引数です (%qT 型です)"
 
@@ -34666,31 +31988,26 @@ msgstr ""
 
 #: c-family/c-warn.c:2350
 #, fuzzy, gcc-internal-format
-#| msgid "comparison of promoted ~unsigned with constant"
 msgid "comparison of promoted bitwise complement of an unsigned value with constant"
 msgstr "~で反転された格上げ符号無し型と定数との比較です"
 
 #: c-family/c-warn.c:2361
 #, fuzzy, gcc-internal-format
-#| msgid "comparison of promoted ~unsigned with unsigned"
 msgid "comparison of promoted bitwise complement of an unsigned value with unsigned"
 msgstr "~で反転された格上げ符号無し型と符号無し型との比較です"
 
 #: c-family/c-warn.c:2416
 #, fuzzy, gcc-internal-format
-#| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "仮引数 %q+D が未使用です"
 
 #: c-family/c-warn.c:2478
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "%q+D が定義されましたが使用されません"
 
 #: c-family/c-warn.c:2514
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "重複した %<const%> です"
 
@@ -34701,13 +32018,11 @@ msgstr ""
 
 #: c-family/c-warn.c:2551
 #, fuzzy, gcc-internal-format
-#| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %<noinline%>"
 msgstr "%qD のインライン宣言の後に非インライン属性の宣言があります"
 
 #: c-family/c-warn.c:2556
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %<noinline%> follows inline declaration"
 msgstr "%q+D の非インライン属性での宣言の後にインライン宣言があります"
 
@@ -34718,13 +32033,11 @@ msgstr ""
 
 #: c-family/c-warn.c:2643 c-family/c-warn.c:2667
 #, fuzzy, gcc-internal-format
-#| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "符号無しの式 < 0 という比較は常に false です"
 
 #: c-family/c-warn.c:2646 c-family/c-warn.c:2664
 #, fuzzy, gcc-internal-format
-#| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "符号無しの式 >= 0 という比較は常に true です"
 
@@ -34755,7 +32068,6 @@ msgstr ""
 
 #: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, fuzzy, gcc-internal-format
-#| msgid "union defined here"
 msgid "defined here"
 msgstr "共用体がここで定義されています"
 
@@ -34776,19 +32088,16 @@ msgstr "入力ファイルが多すぎます"
 
 #: common/config/aarch64/aarch64-common.c:516 config/aarch64/aarch64.c:14482
 #, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mcpu%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
 #: common/config/alpha/alpha-common.c:75
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mtls-size switch"
 msgid "bad value %qs for %<-mtls-size%> switch"
 msgstr "-mtls-size スイッチ用の間違った値 %qs です"
 
 #: common/config/arc/arc-common.c:87
 #, fuzzy, gcc-internal-format
-#| msgid "multiple function type attributes specified"
 msgid "multiple %<-mcpu=%> options specified."
 msgstr "複数の関数型属性が指定されています"
 
@@ -34811,32 +32120,27 @@ msgstr ""
 #: common/config/arm/arm-common.c:442 config/aarch64/aarch64.c:14414
 #: config/aarch64/aarch64.c:14452
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: common/config/arm/arm-common.c:334 common/config/arm/arm-common.c:398
 #: common/config/arm/arm-common.c:445 config/aarch64/aarch64.c:14417
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: common/config/arm/arm-common.c:371 common/config/arm/arm-common.c:425
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized address"
 msgid "unrecognized %s target: %s"
 msgstr "認識できないアドレス"
 
 #: common/config/arm/arm-common.c:461
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized address"
 msgid "unrecognized %<-mfpu%> target: %s"
 msgstr "認識できないアドレス"
 
 #: common/config/arm/arm-common.c:489
 #, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
 msgid "%qs does not support feature %qs"
 msgstr "%s は %s をサポートしません"
 
@@ -34847,7 +32151,6 @@ msgstr ""
 
 #: common/config/arm/arm-common.c:503
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid feature names are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -34863,13 +32166,11 @@ msgstr ""
 
 #: common/config/arm/arm-common.c:626
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized format specifier"
 msgid "unrecognized operand to %%:canon_for_mlib"
 msgstr "認識できない書式指定です"
 
 #: common/config/arm/arm-common.c:972
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized option %<-%s%>"
 msgid "unrecognized operand to %%:asm_auto_mfpu"
 msgstr "認識できないオプション %<-%s%> です"
 
@@ -34895,13 +32196,11 @@ msgstr ""
 
 #: common/config/bfin/bfin-common.c:304 common/config/m68k/m68k-common.c:60
 #, fuzzy, gcc-internal-format
-#| msgid "-mshared-library-id=%s is not between 0 and %d"
 msgid "%<-mshared-library-id=%s%> is not between 0 and %d"
 msgstr "-mshared-library-id=%s が 0 から %d の間ではありません"
 
 #: common/config/bfin/bfin-common.c:323
 #, fuzzy, gcc-internal-format
-#| msgid "-mcpu=%s is not valid"
 msgid "%<-mcpu=%s%> is not valid"
 msgstr "-mcpu=%s が無効です"
 
@@ -34912,43 +32211,36 @@ msgstr ""
 
 #: common/config/i386/i386-common.c:1398
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-loops%s is obsolete, use -falign-loops%s"
 msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
 msgstr "%salign-loops%s は廃止予定です。-falign-loops%s を使用してください"
 
 #: common/config/i386/i386-common.c:1401
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-malign-loops=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
 #: common/config/i386/i386-common.c:1408
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-jumps%s is obsolete, use -falign-jumps%s"
 msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
 msgstr "%salign-jumps%s は廃止予定です。-falign-jumps%s を使用してください"
 
 #: common/config/i386/i386-common.c:1411
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-malign-jumps=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
 #: common/config/i386/i386-common.c:1419
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-functions%s is obsolete, use -falign-functions%s"
 msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
 msgstr "%salign-functions%s は廃止予定です。-falign-functions%s を使用してください"
 
 #: common/config/i386/i386-common.c:1422
 #, fuzzy, gcc-internal-format
-#| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "%<-malign-functions=%d%> is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
 #: common/config/i386/i386-common.c:1431
 #, fuzzy, gcc-internal-format
-#| msgid "%sbranch-cost=%d%s is not between 0 and 5"
 msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s が 0 と 5 の間ではありません"
 
@@ -34964,7 +32256,6 @@ msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートして
 
 #: common/config/ia64/ia64-common.c:65
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %<%s%> for -mtls-size= switch"
 msgid "bad value %<%s%> for %<-mtls-size=%> switch"
 msgstr "-mtls-size= スイッチ用の間違った値 %<%s%> です"
 
@@ -34975,13 +32266,11 @@ msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
 #: common/config/nds32/nds32-common.c:49
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "%<-misr-vector-size=%d%> argument must be 4 or 16"
 msgstr "引数は定数でなければいけません"
 
 #: common/config/nds32/nds32-common.c:59
 #, fuzzy, gcc-internal-format
-#| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "%<-misr-secure=%d%> argument not in between 0 and 3"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
@@ -34992,7 +32281,6 @@ msgstr ""
 
 #: common/config/riscv/riscv-common.c:253
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%<-march=%s%>: Expect number after %<%dp%>."
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
@@ -35018,7 +32306,6 @@ msgstr ""
 
 #: common/config/riscv/riscv-common.c:458
 #, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with _"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
@@ -35034,19 +32321,16 @@ msgstr ""
 
 #: common/config/rs6000/rs6000-common.c:184 config/sparc/sparc.c:1736
 #, fuzzy, gcc-internal-format
-#| msgid "unknown -mdebug-%s switch"
 msgid "unknown %<-mdebug-%s%> switch"
 msgstr "不明な -mdebug-%s スイッチです"
 
 #: common/config/rs6000/rs6000-common.c:223
 #, fuzzy, gcc-internal-format
-#| msgid "unknown switch -mlong-double-%s"
 msgid "unknown switch %<-mlong-double-%s%>"
 msgstr "不明なスイッチ -mlong-double-%s です"
 
 #: common/config/rs6000/rs6000-common.c:258
 #, fuzzy, gcc-internal-format
-#| msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "%<-fsplit-stack%> は現在のところ GNU/Linux 上でのみサポートされています"
 
@@ -35057,7 +32341,6 @@ msgstr "RX200 CPU は FPU ハードウェアを持っていません"
 
 #: common/config/rx/rx-common.c:63
 #, fuzzy, gcc-internal-format
-#| msgid "the RX200 cpu does not have FPU hardware"
 msgid "the RX100 cpu does not have FPU hardware"
 msgstr "RX200 CPU は FPU ハードウェアを持っていません"
 
@@ -35073,68 +32356,57 @@ msgstr "スタックサイズは 2 の累乗でなければいけません"
 
 #: common/config/v850/v850-common.c:47
 #, fuzzy, gcc-internal-format
-#| msgid "value passed to %<-m%s%> is too large"
 msgid "value passed in %qs is too large"
 msgstr "%<-m%s%> へ渡された値が大きすぎます"
 
 #: config/darwin-c.c:82
 #, fuzzy, gcc-internal-format
-#| msgid "too many #pragma options align=reset"
 msgid "too many %<#pragma options align=reset%>"
 msgstr "#pragma options align=reset が多すぎます"
 
 #: config/darwin-c.c:102 config/darwin-c.c:105 config/darwin-c.c:107
 #: config/darwin-c.c:109
 #, fuzzy, gcc-internal-format
-#| msgid "malformed '#pragma options', ignoring"
 msgid "malformed %<#pragma options%>, ignoring"
 msgstr "間違った形式の '#pragma options' です。無視されました"
 
 #: config/darwin-c.c:112
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of %<#pragma pop_options%>"
 msgid "junk at end of %<#pragma options%>"
 msgstr "%<#pragma pop_options%> の末尾にゴミがあります"
 
 #: config/darwin-c.c:122
 #, fuzzy, gcc-internal-format
-#| msgid "malformed '#pragma options align={mac68k|power|reset}', ignoring"
 msgid "malformed %<#pragma options align={mac68k|power|reset}%>, ignoring"
 msgstr "間違った形式の '#pragma options align={mac68k|power|reset}' です。無視されました"
 
 #: config/darwin-c.c:134
 #, fuzzy, gcc-internal-format
-#| msgid "missing '(' after '#pragma unused', ignoring"
 msgid "missing %<(%> after %<#pragma unused%>, ignoring"
 msgstr "'#pragma unused' の後に '(' がありません。無視されました"
 
 #: config/darwin-c.c:155
 #, fuzzy, gcc-internal-format
-#| msgid "missing ')' after '#pragma unused', ignoring"
 msgid "missing %<)%> after %<#pragma unused%>, ignoring"
 msgstr "'#pragma unused' の後に ')' がありません。無視されました"
 
 #: config/darwin-c.c:158
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of '#pragma unused'"
 msgid "junk at end of %<#pragma unused%>"
 msgstr "'#pragma unused' の末尾にゴミがあります"
 
 #: config/darwin-c.c:169
 #, fuzzy, gcc-internal-format
-#| msgid "malformed '#pragma ms_struct', ignoring"
 msgid "malformed %<#pragma ms_struct%>, ignoring"
 msgstr "間違った形式の '#pragma ms_struct' です。無視されました"
 
 #: config/darwin-c.c:177
 #, fuzzy, gcc-internal-format
-#| msgid "malformed '#pragma ms_struct {on|off|reset}', ignoring"
 msgid "malformed %<#pragma ms_struct {on|off|reset}%>, ignoring"
 msgstr "間違った形式の '#pragma ms_struct {on|off|reset}' です。無視されました"
 
 #: config/darwin-c.c:180
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of '#pragma ms_struct'"
 msgid "junk at end of %<#pragma ms_struct%>"
 msgstr "'#pragma ms_struct' の末尾にゴミがあります"
 
@@ -35145,7 +32417,6 @@ msgstr ""
 
 #: config/darwin-c.c:709
 #, fuzzy, gcc-internal-format
-#| msgid "unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs of %<-mmacosx-version-min%>"
 msgstr "-mmacosx-version-min の不明な値 %qs です"
 
@@ -35161,19 +32432,16 @@ msgstr "kern.osversion %q.*s を解釈できません"
 
 #: config/darwin-driver.c:205
 #, fuzzy, gcc-internal-format
-#| msgid "couldn%'t understand kern.osversion %q.*s"
 msgid "couldn%'t understand version %s"
 msgstr "kern.osversion %q.*s を解釈できません"
 
 #: config/darwin-driver.c:281
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "this target does not support %qs"
 msgid "this compiler does not support %s"
 msgstr "このターゲットでは %qs はサポートされていません"
 
 #: config/darwin-driver.c:324
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "%qs is not valid for %<mmacosx-version-min%>"
 msgstr "%qs は %qs 用には有効ではありません"
 
@@ -35184,7 +32452,6 @@ msgstr ""
 
 #: config/darwin-driver.c:362
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%s conflicts with i386 (arch flags ignored)"
 msgstr "-mcpu=%s が -march=%s と競合しています"
 
@@ -35200,7 +32467,6 @@ msgstr ""
 
 #: config/darwin-driver.c:381
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%s conflicts with ppc (arch flags ignored)"
 msgstr "-mcpu=%s が -march=%s と競合しています"
 
@@ -35226,7 +32492,6 @@ msgstr "%qE 2.95 vtable-compatibility 属性は C++ クラスへのみ適用さ
 
 #: config/darwin.c:2772
 #, fuzzy, gcc-internal-format
-#| msgid "visibility attribute not supported in this configuration; ignored"
 msgid "protected visibility attribute not supported in this configuration; ignored"
 msgstr "可視性属性はこの設定ではサポートされていません。無視されました"
 
@@ -35247,13 +32512,11 @@ msgstr ""
 
 #: config/darwin.c:3193
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
 #: config/darwin.c:3271
 #, fuzzy, gcc-internal-format
-#| msgid "-mdynamic-no-pic overrides -fpic or -fPIC"
 msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
 msgstr "-mdynamic-no-pic は -fpic または -fPIC を上書きします"
 
@@ -35284,13 +32547,11 @@ msgstr "CFString リテラル式が文字列定数ではありません"
 
 #: config/darwin.c:3622
 #, fuzzy, gcc-internal-format
-#| msgid "%s in CFString literal"
 msgid "non-ASCII character in CFString literal"
 msgstr "CFString リテラル内に %s があります"
 
 #: config/darwin.c:3623
 #, fuzzy, gcc-internal-format
-#| msgid "%s in CFString literal"
 msgid "embedded NUL in CFString literal"
 msgstr "CFString リテラル内に %s があります"
 
@@ -35311,7 +32572,6 @@ msgstr "%<#pragma align%> への無効な引数です。無視しています"
 
 #: config/sol2-c.c:115
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma align%> must appear before the declaration of %qD, ignoring"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
@@ -35384,13 +32644,11 @@ msgstr "VxWorks 用のプロファイルサポート"
 #: config/aarch64/aarch64-builtins.c:1445
 #: config/aarch64/aarch64-builtins.c:1675 config/arm/arm-builtins.c:3114
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引数は定数でなければいけません"
 
 #: config/aarch64/aarch64-builtins.c:1516 config/arm/arm-builtins.c:3459
 #, fuzzy, gcc-internal-format
-#| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
 msgstr "マスクは即値でなければなりません"
 
@@ -35401,68 +32659,57 @@ msgstr ""
 
 #: config/aarch64/aarch64-builtins.c:1764
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "%Kargument must be a 16-bit constant immediate"
 msgstr "引数は定数でなければいけません"
 
 #: config/aarch64/aarch64-builtins.c:1819
 #, fuzzy, gcc-internal-format
-#| msgid "does not support multilib"
 msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
 msgstr "multilib はサポートしません"
 
 #: config/aarch64/aarch64-builtins.c:1853
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate in range [0,15]"
 msgstr "引数は定数でなければいけません"
 
 #: config/aarch64/aarch64-builtins.c:2404
 #: config/aarch64/aarch64-builtins.c:2424
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected expression"
 msgid "expected 64-bit address but argument 1 is %d-bit"
 msgstr "式が予期されます"
 
 #: config/aarch64/aarch64-builtins.c:2408
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected expression"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "式が予期されます"
 
 #: config/aarch64/aarch64-c.c:291
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> が文字列または番号ではありません"
 
 #: config/aarch64/aarch64-c.c:299
 #, fuzzy, gcc-internal-format
-#| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明な #pragma GCC coprocessor %E です"
 
 #: config/aarch64/aarch64.c:1410
 #, fuzzy, gcc-internal-format
-#| msgid "new cannot be applied to a function type"
 msgid "the %qE attribute cannot be applied to an SVE function type"
 msgstr "関数型に対して new を適用できません"
 
 #: config/aarch64/aarch64.c:1485 config/aarch64/aarch64.c:1499
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
 msgid "unexpected %<%s%> after %<%s%>"
 msgstr "%<operator%> が予期されます"
 
 #: config/aarch64/aarch64.c:1929
 #, fuzzy, gcc-internal-format
-#| msgid "RTP PIC is incompatible with Thumb"
 msgid "%qs is incompatible with the use of floating-point types"
 msgstr "RTP PIC は Thumb では使用できません"
 
 #: config/aarch64/aarch64.c:1932
 #, fuzzy, gcc-internal-format
-#| msgid "RTP PIC is incompatible with Thumb"
 msgid "%qs is incompatible with the use of vector types"
 msgstr "RTP PIC は Thumb では使用できません"
 
@@ -35478,7 +32725,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:1955
 #, fuzzy, gcc-internal-format
-#| msgid "Do not use the bit-field instructions"
 msgid "this operation requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
@@ -35496,7 +32742,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:5747
 #, fuzzy, gcc-internal-format
-#| msgid "AltiVec argument passed to unprototyped function"
 msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
@@ -35509,13 +32754,11 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:6001
 #, fuzzy, gcc-internal-format
-#| msgid "Do not use the bit-field instructions"
 msgid "%qE requires the SVE ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
 #: config/aarch64/aarch64.c:6004
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "calls to functions of type %qT require the SVE ISA extension"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
@@ -35536,13 +32779,11 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14059
 #, fuzzy, gcc-internal-format
-#| msgid "invalid #pragma %s"
 msgid "invalid format for sve_width"
 msgstr "無効な #pragma %s です"
 
 #: config/aarch64/aarch64.c:14071
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid %%h value"
 msgid "invalid sve_width value: %d"
 msgstr "無効な %%h 値"
 
@@ -35553,7 +32794,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14109
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unknown spec function %qs"
 msgid "unknown tuning option (%s)"
 msgstr "不明な spec 関数 %qs です"
 
@@ -35574,7 +32814,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14289 config/rs6000/rs6000.c:4385
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
@@ -35590,7 +32829,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14455
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s;"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -35601,19 +32839,16 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14486
 #, fuzzy, gcc-internal-format
-#| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
 #: config/aarch64/aarch64.c:14594
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
 msgstr "組み込み関数への無効な引数です"
 
 #: config/aarch64/aarch64.c:14596
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "missing argument for %<-mbranch-protection=%>"
 msgstr "組み込み関数への無効な引数です"
 
@@ -35624,13 +32859,11 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14623
 #, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-march%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
 #: config/aarch64/aarch64.c:14627
 #, fuzzy, gcc-internal-format
-#| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier %qs in %<-march=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
@@ -35641,19 +32874,16 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14658
 #, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
 #: config/aarch64/aarch64.c:14789 config/arm/arm.c:3252
 #, fuzzy, gcc-internal-format
-#| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
 
 #: config/aarch64/aarch64.c:14845
 #, fuzzy, gcc-internal-format
-#| msgid "does not support multilib"
 msgid "assembler does not support %<-mabi=ilp32%>"
 msgstr "multilib はサポートしません"
 
@@ -35669,7 +32899,6 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:14927
 #, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in ilp32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
@@ -35721,7 +32950,6 @@ msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されまし
 
 #: config/aarch64/aarch64.c:15308 config/aarch64/aarch64.c:15481
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "間違った形式の %<#pragma init%> です"
 
@@ -35737,20 +32965,17 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:15414
 #, fuzzy, gcc-internal-format
-#| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
 #: config/aarch64/aarch64.c:15471 config/arm/arm.c:32390
 #: config/rs6000/rs6000.c:23428 config/s390/s390.c:15584
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
 #: config/aarch64/aarch64.c:15498
 #, fuzzy, gcc-internal-format
-#| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
@@ -35784,7 +33009,6 @@ msgstr ""
 #: config/aarch64/aarch64.c:22613 config/i386/i386.c:22138
 #: config/i386/i386.c:22265
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "サポートされていない組み合わせです: %s"
 
@@ -35800,43 +33024,36 @@ msgstr ""
 
 #: config/aarch64/aarch64.c:22631
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
 msgid "unsupported return type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
 #: config/aarch64/aarch64.c:22648
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
 msgid "GCC does not currently support argument type %qT for %<simd%> functions"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
 #: config/aarch64/aarch64.c:22670
 #, fuzzy, gcc-internal-format
-#| msgid "the -shared option is not currently supported for VAX ELF"
 msgid "GCC does not currently support simdlen %d for type %qT"
 msgstr "-shared オプションは VAX ELF 用には現在はサポートされていません"
 
 #: config/alpha/alpha.c:420
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mtrap-precision switch"
 msgid "bad value %qs for %<-mtrap-precision%> switch"
 msgstr "-mtrap-precision スイッチ用の間違った値 %qs です"
 
 #: config/alpha/alpha.c:435
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mfp-rounding-mode switch"
 msgid "bad value %qs for %<-mfp-rounding-mode%> switch"
 msgstr "-mfp-rounding-mode スイッチ用の間違った値 %qs です"
 
 #: config/alpha/alpha.c:450
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mfp-trap-mode switch"
 msgid "bad value %qs for %<-mfp-trap-mode%> switch"
 msgstr "-mfp-trap-mode スイッチ用の間違った値 %qs です"
 
 #: config/alpha/alpha.c:468
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mcpu switch"
 msgid "bad value %qs for %<-mcpu%> switch"
 msgstr "-mcpu スイッチ用の間違った値 %qs です"
 
@@ -35847,7 +33064,6 @@ msgstr "-mtune スイッチ用の間違った値 %qs です"
 
 #: config/alpha/alpha.c:501
 #, fuzzy, gcc-internal-format
-#| msgid "fp software completion requires -mtrap-precision=i"
 msgid "fp software completion requires %<-mtrap-precision=i%>"
 msgstr "浮動小数点ソフトウェア補完には -mtrap-precision=i が必要です"
 
@@ -35863,7 +33079,6 @@ msgstr "VAX 浮動小数ではトラップモードはサポートされてい
 
 #: config/alpha/alpha.c:526
 #, fuzzy, gcc-internal-format
-#| msgid "128-bit long double not supported for VAX floats"
 msgid "128-bit %<long double%> not supported for VAX floats"
 msgstr "128 ビット long double は VAX 浮動小数用にはサポートされていません"
 
@@ -35874,7 +33089,6 @@ msgstr "L%d キャッシュレイテンシは %s にとって不明です"
 
 #: config/alpha/alpha.c:569
 #, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mmemory-latency"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
@@ -35897,7 +33111,6 @@ msgstr ""
 
 #: config/arc/arc.c:1106
 #, fuzzy, gcc-internal-format
-#| msgid "-mcorea and -mcoreb can%'t be used together"
 msgid "FPX fast and compact options cannot be specified together"
 msgstr "-mcorea と -mcoreb は併用できません"
 
@@ -35913,25 +33126,21 @@ msgstr ""
 
 #: config/arc/arc.c:1120
 #, fuzzy, gcc-internal-format
-#| msgid "PIC is only supported for RTPs"
 msgid "PIC is not supported for %qs"
 msgstr "PIC は RTP 用にのみサポートされています"
 
 #: config/arc/arc.c:1159
 #, fuzzy, gcc-internal-format
-#| msgid "missing operand"
 msgid "missing dash"
 msgstr "被演算子がありません"
 
 #: config/arc/arc.c:1171
 #, fuzzy, gcc-internal-format
-#| msgid "PIC register isn't set up"
 msgid "first register must be R0"
 msgstr "PIC レジスタが設定されていません"
 
 #: config/arc/arc.c:1191
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "operand 1 must be a hard register"
 msgid "last register name %s must be an odd register"
 msgstr "被演算子 1 はハードレジスタでなければいけません"
 
@@ -35975,7 +33184,6 @@ msgstr ""
 
 #: config/arc/arc.c:1378
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "option %qs is not available for %qs CPU"
 msgstr "%qs は %qs 用には有効ではありません"
 
@@ -35986,7 +33194,6 @@ msgstr ""
 
 #: config/arc/arc.c:1950
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "multiple function type attributes specified"
 msgid "multiply option implies r%d is fixed"
 msgstr "複数の関数型属性が指定されています"
 
@@ -36003,7 +33210,6 @@ msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありま
 
 #: config/arc/arc.c:2116
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありません"
 
@@ -36028,19 +33234,16 @@ msgstr "%qE 属性は関数へのみ適用されます"
 
 #: config/arc/arc.c:6972
 #, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_arc_aligned%> with non-constant alignment"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
 #: config/arc/arc.c:6980
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for %<__builtin_arc_aligned%>"
 msgstr "%<__builtin_frame_address%> への無効な引数です"
 
 #: config/arc/arc.c:7143
 #, fuzzy, gcc-internal-format
-#| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea は -mmulticore と併せて使用するべきです"
 
@@ -36086,25 +33289,21 @@ msgstr ""
 
 #: config/arc/arc.c:7379
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "symbol used as immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "即値被演算子として使用されるシンボルです"
 
 #: config/arc/arc.c:7384
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/arc/arc.c:7388
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/arc/arc.c:7392
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
@@ -36120,25 +33319,21 @@ msgstr ""
 
 #: config/arc/arc.c:8442
 #, fuzzy, gcc-internal-format
-#| msgid "Bad address, not register:"
 msgid "insn addresses not set after shorten_branches"
 msgstr "誤ったアドレスです。レジスタではありません:"
 
 #: config/arc/arc.c:8656
 #, fuzzy, gcc-internal-format
-#| msgid "Bad address, not register:"
 msgid "insn addresses not freed"
 msgstr "誤ったアドレスです。レジスタではありません:"
 
 #: config/arc/arc.c:11135
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
 #: config/arc/arc.c:11143 config/arc/arc.c:11182
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
@@ -36150,19 +33345,16 @@ msgstr "%qE 属性は整数定数引数のみ許可されています"
 
 #: config/arc/arc.c:11174
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
 #: config/arc/arc.c:11229
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
 #: config/arc/arc.c:11235
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 属性は無視されました"
 
@@ -36173,19 +33365,16 @@ msgstr ""
 
 #: config/arm/aarch-common.c:610 config/i386/i386.c:21117
 #, fuzzy, gcc-internal-format
-#| msgid "unknown IRA algorithm %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
 #: config/arm/aarch-common.c:620 config/i386/i386.c:21146
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand output code"
 msgid "invalid type for %<asm%> flag output"
 msgstr "無効な被演算子出力コード"
 
 #: config/arm/arm-builtins.c:3096
 #, fuzzy, gcc-internal-format
-#| msgid "coprocessor not enabled"
 msgid "%Kcoprocessor %d is not enabled with +cdecp%d"
 msgstr "コプロセッサが有効ではありません"
 
@@ -36199,25 +33388,21 @@ msgstr ""
 #. a given argument index.
 #: config/arm/arm-builtins.c:3107
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "%Kargument %d to %qE must be a constant immediate in range [0-%d]"
 msgstr "引数は定数でなければいけません"
 
 #: config/arm/arm-builtins.c:3225
 #, fuzzy, gcc-internal-format
-#| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
 #: config/arm/arm-builtins.c:3332
 #, fuzzy, gcc-internal-format
-#| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
 #: config/arm/arm-builtins.c:3336
 #, fuzzy, gcc-internal-format
-#| msgid "mask must be an immediate"
 msgid "%Ksaturation bit range must be a constant immediate"
 msgstr "マスクは即値でなければなりません"
 
@@ -36270,7 +33455,6 @@ msgstr "マスクは即値でなければなりません"
 
 #: config/arm/arm-builtins.c:3754
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
@@ -36401,7 +33585,6 @@ msgstr ""
 
 #: config/arm/arm.c:2912
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC と -G は併用できません"
 
@@ -36422,7 +33605,6 @@ msgstr "呼び出し先 ARM/Thumb 相互利用有効化は Thumb 用にコンパ
 
 #: config/arm/arm.c:2933
 #, fuzzy, gcc-internal-format
-#| msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
 msgstr "-g に -mno-apcs-frame をつけると、きめ細かなデバッグはできないでしょう"
 
@@ -36433,7 +33615,6 @@ msgstr ""
 
 #: config/arm/arm.c:2941
 #, fuzzy, gcc-internal-format
-#| msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
 msgstr "-mtp=cp15 を 16 ビット Thumb で使用できません"
 
@@ -36465,19 +33646,16 @@ msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
 #: config/arm/arm.c:3133
 #, fuzzy, gcc-internal-format
-#| msgid "target CPU does not support ARM mode"
 msgid "target CPU does not support unaligned accesses"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
 #: config/arm/arm.c:3482
 #, fuzzy, gcc-internal-format
-#| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
 msgstr "-mapcs-stack-check と -mno-apcs-frame は併用できません"
 
 #: config/arm/arm.c:3491
 #, fuzzy, gcc-internal-format
-#| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
 msgstr "-fpic と -mapcs-reent は併用できません"
 
@@ -36493,49 +33671,41 @@ msgstr ""
 
 #: config/arm/arm.c:3525
 #, fuzzy, gcc-internal-format
-#| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
 #: config/arm/arm.c:3527
 #, fuzzy, gcc-internal-format
-#| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
 #: config/arm/arm.c:3552
 #, fuzzy, gcc-internal-format
-#| msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC は -msingle-pic-base と併用できません"
 
 #: config/arm/arm.c:3564 config/arm/arm.c:32404
 #, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
 #: config/arm/arm.c:3572
 #, fuzzy, gcc-internal-format
-#| msgid "-mpic-register= is useless without -fpic"
 msgid "%<-mpic-register=%> is useless without %<-fpic%>"
 msgstr "-mpic-register= は -fpic をつけないと役に立ちません"
 
 #: config/arm/arm.c:3581
 #, fuzzy, gcc-internal-format
-#| msgid "unable to use '%s' for PIC register"
 msgid "unable to use %qs for PIC register"
 msgstr "PIC レジスタ用に '%s' を使用できません"
 
 #: config/arm/arm.c:3603 config/pru/pru.c:643
 #, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上ではサポートされていません"
 
 #: config/arm/arm.c:3747
 #, fuzzy, gcc-internal-format
-#| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable と -msdata=%s は併用できません"
 
@@ -36556,13 +33726,11 @@ msgstr "ターゲット CPU は ARM/Thumb 相互利用をサポートしてい
 
 #: config/arm/arm.c:3823
 #, fuzzy, gcc-internal-format
-#| msgid "AAPCS does not support -mcaller-super-interworking"
 msgid "AAPCS does not support %<-mcaller-super-interworking%>"
 msgstr "AAPCS は -mcaller-super-interworking をサポートしません"
 
 #: config/arm/arm.c:3826
 #, fuzzy, gcc-internal-format
-#| msgid "AAPCS does not support -mcallee-super-interworking"
 msgid "AAPCS does not support %<-mcallee-super-interworking%>"
 msgstr "AAPCS は -mcallee-super-interworking をサポートしません"
 
@@ -36574,7 +33742,6 @@ msgstr "__fp16 かつ ldrh 無し"
 # 公式な名前は Thumb であり THUMB ではない
 #: config/arm/arm.c:3834
 #, fuzzy, gcc-internal-format
-#| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
@@ -36585,13 +33752,11 @@ msgstr ""
 
 #: config/arm/arm.c:3851
 #, fuzzy, gcc-internal-format
-#| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%>: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard および VFP"
 
 #: config/arm/arm.c:3859
 #, fuzzy, gcc-internal-format
-#| msgid "-mfloat-abi=hard and VFP"
 msgid "%<-mfloat-abi=hard%> and VFP"
 msgstr "-mfloat-abi=hard および VFP"
 
@@ -36628,37 +33793,31 @@ msgstr ""
 
 #: config/arm/arm.c:7357
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
 #: config/arm/arm.c:7369
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
 #: config/arm/arm.c:7378
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
 #: config/arm/arm.c:7400 config/arm/arm.c:7452
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mcmse%> option."
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
 #: config/arm/arm.c:7419
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect on unit local functions"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
 #: config/arm/arm.c:7468
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
@@ -36704,7 +33863,6 @@ msgstr ""
 
 #: config/arm/arm.c:32419
 #, fuzzy, gcc-internal-format
-#| msgid "invalid vector type for attribute %qs"
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
 
@@ -36718,43 +33876,36 @@ msgstr ""
 
 #: config/arm/arm.c:32440
 #, fuzzy, gcc-internal-format
-#| msgid "invalid vector type for attribute %qs"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
 
 #: config/arm/arm.c:32454
 #, fuzzy, gcc-internal-format
-#| msgid "target attribute or pragma changes SPE ABI"
 msgid "unknown target attribute or pragma %qs"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
 #: config/arm/arm.c:33432
 #, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
 msgid "asm flags not supported in thumb1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
 #: config/arm/freebsd.h:121
 #, fuzzy, gcc-internal-format
-#| msgid "target format does not support infinity"
 msgid "target OS does not support unaligned accesses"
 msgstr "ターゲット形式は無限大をサポートしません"
 
 #: config/avr/avr-c.c:65 config/avr/avr-c.c:190
 #, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
 msgid "%qs expects 1 argument but %d given"
 msgstr "%qs には定数引数が予期されます"
 
 #: config/avr/avr-c.c:76
 #, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
 msgid "%qs expects a fixed-point value as argument"
 msgstr "%qs には定数引数が予期されます"
 
 #: config/avr/avr-c.c:102
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect"
 msgid "using %qs with unsigned type has no effect"
 msgstr "%qE 属性は効果がありません"
 
@@ -36765,25 +33916,21 @@ msgstr ""
 
 #: config/avr/avr-c.c:124
 #, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
 msgid "%qs expects 2 arguments but %d given"
 msgstr "%qs には定数引数が予期されます"
 
 #: config/avr/avr-c.c:136 config/avr/avr-c.c:201
 #, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
 msgid "%qs expects a fixed-point value as first argument"
 msgstr "%qs には定数引数が予期されます"
 
 #: config/avr/avr-c.c:144
 #, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
 msgid "%qs expects an integer value as second argument"
 msgstr "%qs には定数引数が予期されます"
 
 #: config/avr/avr-devices.c:152
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unknown architecture %qs"
 msgid "supported core architectures:%s"
 msgstr "不明なアーキテクチャ %qs です"
 
@@ -36793,31 +33940,26 @@ msgstr "不明なアーキテクチャ %qs です"
 #. with -mmcu=<device>.
 #: config/avr/avr.c:706
 #, fuzzy, gcc-internal-format
-#| msgid "unknown architecture %qs"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
 #: config/avr/avr.c:755 config/pru/pru.c:632 config/visium/visium.c:421
 #, fuzzy, gcc-internal-format
-#| msgid "-fpic is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-fpic はサポートされていません"
 
 #: config/avr/avr.c:757 config/pru/pru.c:634 config/visium/visium.c:423
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
 #: config/avr/avr.c:759 config/pru/pru.c:636
 #, fuzzy, gcc-internal-format
-#| msgid "-fpic is not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-fpic はサポートされていません"
 
 #: config/avr/avr.c:761 config/pru/pru.c:638
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC is not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
@@ -36828,19 +33970,16 @@ msgstr "-pedantic と -traditional とは相互排他的です"
 
 #: config/avr/avr.c:1066 config/riscv/riscv.c:4963
 #, fuzzy, gcc-internal-format
-#| msgid "interrupt function must have no arguments"
 msgid "%qs function cannot have arguments"
 msgstr "割り込み関数は引数無しでなければいけません"
 
 #: config/avr/avr.c:1069 config/riscv/riscv.c:4960
 #, fuzzy, gcc-internal-format
-#| msgid "functions cannot return __fp16 type"
 msgid "%qs function cannot return a value"
 msgstr "関数が __fp16 型を返しません"
 
 #: config/avr/avr.c:1083
 #, fuzzy, gcc-internal-format
-#| msgid "%qs appears to be a misspelled signal handler"
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs は綴りが間違ったシグナルハンドラのように見えます"
 
@@ -36851,7 +33990,6 @@ msgstr ""
 
 #: config/avr/avr.c:1313
 #, fuzzy, gcc-internal-format
-#| msgid "'builtin_return_address' contains only 2 bytes of address"
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "'builtin_return_address' がアドレスの 2 バイトのみ含んでいます"
 
@@ -36867,37 +34005,31 @@ msgstr "プログラムメモリアドレスとしてデータメモリをアク
 
 #: config/avr/avr.c:2936
 #, fuzzy, gcc-internal-format
-#| msgid "accessing program  memory with data memory address"
 msgid "accessing program memory with data memory address"
 msgstr "データメモリアドレスとしてプログラムメモリをアクセスしています"
 
 #: config/avr/avr.c:3437
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "レジスタの数が整数を引数を渡すために使われる"
 
 #: config/avr/avr.c:3702
 #, fuzzy, gcc-internal-format
-#| msgid "conflicting named address spaces (%s vs %s)"
 msgid "writing to address space %qs not supported"
 msgstr "名前付きアドレス空間 (%s と %s) が競合しています"
 
 #: config/avr/avr.c:9730
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
 #: config/avr/avr.c:9737
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is not supported for R8C target"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
 #: config/avr/avr.c:9777
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect"
 msgid "%qE attribute address out of range"
 msgstr "%qE 属性は効果がありません"
 
@@ -36908,7 +34040,6 @@ msgstr ""
 
 #: config/avr/avr.c:9801
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE は変数にのみ適用できます"
 
@@ -36939,13 +34070,11 @@ msgstr ""
 
 #: config/avr/avr.c:10155
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
 #: config/avr/avr.c:10187
 #, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "前の %q+D の宣言はここです"
 
@@ -36957,25 +34086,21 @@ msgstr "初期化されていない変数のみ .noinit セクション内に配
 #. This might happen with C++ if stuff needs constructing.
 #: config/avr/avr.c:10381
 #, fuzzy, gcc-internal-format
-#| msgid "only initialized variables can be placed into program memory area"
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
 
 #: config/avr/avr.c:10392
 #, fuzzy, gcc-internal-format
-#| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
 
 #: config/avr/avr.c:10478
 #, fuzzy, gcc-internal-format
-#| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "互換性がない %qE 属性は無視されました"
 
 #: config/avr/avr.c:10541
 #, fuzzy, gcc-internal-format
-#| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs はアセンブラのみ用にサポートされています"
 
@@ -36991,7 +34116,6 @@ msgstr "文字列定数の中でファイルの終端を検出しました"
 
 #: config/avr/avr.c:14285
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs expects a constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs には定数引数が予期されます"
 
@@ -37007,7 +34131,6 @@ msgstr ""
 
 #: config/avr/driver-avr.c:58
 #, fuzzy, gcc-internal-format
-#| msgid "unknown spec function %qs"
 msgid "bad usage of spec function %qs"
 msgstr "不明な spec 関数 %qs です"
 
@@ -37018,19 +34141,16 @@ msgstr ""
 
 #: config/avr/driver-avr.c:100
 #, fuzzy, gcc-internal-format
-#| msgid "specs file malformed after %ld characters"
 msgid "strange device name %qs after %qs: bad character %qc"
 msgstr "%ld 文字の後におかしな spec ファイル"
 
 #: config/bfin/bfin.c:2367
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<-mfdpic%> is not supported, please use a bfin-linux-uclibc target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
 #: config/bfin/bfin.c:2373
 #, fuzzy, gcc-internal-format
-#| msgid "-mshared-library-id= specified without -mid-shared-library"
 msgid "%<-mshared-library-id=%> specified without %<-mid-shared-library%>"
 msgstr "-mshared-library-id= が -mid-shared-library 無しで指定されました"
 
@@ -37051,31 +34171,26 @@ msgstr ""
 
 #: config/bfin/bfin.c:2392 config/m68k/m68k.c:590
 #, fuzzy, gcc-internal-format
-#| msgid "cannot specify both -msep-data and -mid-shared-library"
 msgid "cannot specify both %<-msep-data%> and %<-mid-shared-library%>"
 msgstr "-msep-data と -mid-shared-library は併用できません"
 
 #: config/bfin/bfin.c:2412
 #, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
 msgid "%<-mmulticore%> can only be used with BF561"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
 #: config/bfin/bfin.c:2415
 #, fuzzy, gcc-internal-format
-#| msgid "-mcorea should be used with -mmulticore"
 msgid "%<-mcorea%> should be used with %<-mmulticore%>"
 msgstr "-mcorea は -mmulticore と併せて使用するべきです"
 
 #: config/bfin/bfin.c:2418
 #, fuzzy, gcc-internal-format
-#| msgid "-mcoreb should be used with -mmulticore"
 msgid "%<-mcoreb%> should be used with %<-mmulticore%>"
 msgstr "-mcoreb は -mmulticore と併せて使用するべきです"
 
 #: config/bfin/bfin.c:2421
 #, fuzzy, gcc-internal-format
-#| msgid "-mcorea and -mcoreb can%'t be used together"
 msgid "%<-mcorea%> and %<-mcoreb%> can%'t be used together"
 msgstr "-mcorea と -mcoreb は併用できません"
 
@@ -37096,31 +34211,26 @@ msgstr "%qE 属性は局所変数用には指定できません"
 
 #: config/bpf/bpf.c:288
 #, fuzzy, gcc-internal-format
-#| msgid "variable tracking size limit exceeded"
 msgid "eBPF stack limit exceeded"
 msgstr "変数追跡サイズ制限が超過しました"
 
 #: config/bpf/bpf.c:597
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments to %qE"
 msgid "too many function arguments for eBPF"
 msgstr "%qE への引数が多すぎます"
 
 #: config/bpf/bpf.c:615 config/bpf/bpf.c:617
 #, fuzzy, gcc-internal-format
-#| msgid "In constructor %qs"
 msgid "no constructors"
 msgstr "コンストラクタ %qs 内"
 
 #: config/bpf/bpf.c:633 config/bpf/bpf.c:635
 #, fuzzy, gcc-internal-format
-#| msgid "In destructor %qs"
 msgid "no destructors"
 msgstr "デストラクタ %qs 内"
 
 #: config/bpf/bpf.c:680
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "indirect call in function, which are not supported by eBPF"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
@@ -37132,7 +34242,6 @@ msgstr "組み込み関数への無効な引数です"
 
 #: config/c6x/c6x.c:243
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC and -fpic are not supported for this target"
 msgid "%<-fpic%> and %<-fPIC%> not supported without %<-mdsbt%> on this target"
 msgstr "-fPIC and -fpic はこのターゲットではサポートされていません"
 
@@ -37148,13 +34257,11 @@ msgstr ""
 
 #: config/cr16/cr16.c:309
 #, fuzzy, gcc-internal-format
-#| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid data model option %<-mdata-model=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
 #: config/cr16/cr16.h:408
 #, fuzzy, gcc-internal-format
-#| msgid "profiler support for CRX"
 msgid "profiler support for CR16"
 msgstr "CRX 用のプロファイルサポート"
 
@@ -37169,7 +34276,6 @@ msgstr ""
 
 #: config/cris/cris.c:906
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of ':' modifier"
 msgid "invalid use of %<:%> modifier"
 msgstr "':' 修飾子の無効な使用方法です"
 
@@ -37196,25 +34302,21 @@ msgstr "内部エラー: 間違った被演算子を持つ cris_side_effect_mode
 
 #: config/cris/cris.c:2654
 #, fuzzy, gcc-internal-format
-#| msgid "-max-stackframe=%d is not usable, not between 0 and %d"
 msgid "%<-max-stackframe=%d%> is not usable, not between 0 and %d"
 msgstr "-max-stackframe=%d が使用できません。 0 と %d の間ではありません"
 
 #: config/cris/cris.c:2683
 #, fuzzy, gcc-internal-format
-#| msgid "unknown CRIS version specification in -march= or -mcpu= : %s"
 msgid "unknown CRIS version specification in %<-march=%> or %<-mcpu=%> : %s"
 msgstr "-march= または -mcpu= 内で不明な CRIS バージョン指定があります: %s"
 
 #: config/cris/cris.c:2719
 #, fuzzy, gcc-internal-format
-#| msgid "unknown CRIS cpu version specification in -mtune= : %s"
 msgid "unknown CRIS cpu version specification in %<-mtune=%> : %s"
 msgstr "-mtune= 内に不明な CRIS CPU バージョン指定があります: %s"
 
 #: config/cris/cris.c:2740
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC and -fpic are not supported in this configuration"
 msgid "%<-fPIC%> and %<-fpic%> are not supported in this configuration"
 msgstr "-fPIC および -fpic はこの設定ではサポートされていません"
 
@@ -37304,19 +34406,16 @@ msgstr ""
 #: config/csky/csky.c:2453 config/csky/csky.c:2489 config/csky/csky.c:2542
 #: config/csky/csky.c:2565 config/csky/csky.c:2582
 #, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
 msgid "%qs is not supported by arch %s"
 msgstr "%s は %s をサポートしません"
 
 #: config/csky/csky.c:2492
 #, fuzzy, gcc-internal-format
-#| msgid "-mhard-float not supported"
 msgid "%<-mhard-float%> is not supported by the selected CPU"
 msgstr "-mhard-float はサポートされていません"
 
 #: config/csky/csky.c:2508
 #, fuzzy, gcc-internal-format
-#| msgid "-Wformat-y2k ignored without -Wformat"
 msgid "%<-mdouble-float%> ignored without %<-mhard-float%>"
 msgstr "-Wformat-y2k は無視されました (-Wformat がありません)"
 
@@ -37327,7 +34426,6 @@ msgstr ""
 
 #: config/csky/csky.c:2554
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-msmart%> is incompatible with %<-mhigh-registers%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
@@ -37345,19 +34443,16 @@ msgstr "-fdirectives-only は -traditional と併用できません"
 #. stack overflow, but punt for now.
 #: config/csky/csky.c:5819
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "Nested function trampolines not supported on CK801."
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: config/csky/csky.c:6024
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without %<-mistack%>"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
 #: config/epiphany/epiphany.c:499
 #, fuzzy, gcc-internal-format
-#| msgid "interrupt handlers cannot be MIPS16 functions"
 msgid "interrupt handlers cannot have arguments"
 msgstr "割り込みハンドラが MIPS16 関数ではいけません"
 
@@ -37368,13 +34463,11 @@ msgstr ""
 
 #: config/epiphany/epiphany.c:1541
 #, fuzzy, gcc-internal-format
-#| msgid "stack size must be an exact power of 2"
 msgid "stack_offset must be at least 4"
 msgstr "スタックサイズは 2 の累乗でなければいけません"
 
 #: config/epiphany/epiphany.c:1543
 #, fuzzy, gcc-internal-format
-#| msgid "stack size must be an exact power of 2"
 msgid "stack_offset must be a multiple of 4"
 msgstr "スタックサイズは 2 の累乗でなければいけません"
 
@@ -37410,7 +34503,6 @@ msgstr "%qs 用の定数引数が範囲外です"
 
 #: config/frv/frv.c:9089
 #, fuzzy, gcc-internal-format
-#| msgid "media functions are not available unless -mmedia is used"
 msgid "media functions are not available unless %<-mmedia%> is used"
 msgstr "メディア関数は -mmedia が使用されない限り利用できません"
 
@@ -37441,25 +34533,21 @@ msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
 #: config/ft32/ft32.c:181
 #, fuzzy, gcc-internal-format
-#| msgid "shift of non-integer operand"
 msgid "%<h%> applied to non-register operand"
 msgstr "被演算子が非整数型のシフト演算です"
 
 #: config/ft32/ft32.c:206
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "array assignment"
 msgid "bad alignment: %d"
 msgstr "配列代入"
 
 #: config/ft32/ft32.c:502
 #, fuzzy, gcc-internal-format
-#| msgid "stack size must not be greater than 64k"
 msgid "stack frame must be smaller than 64K"
 msgstr "スタックサイズは 64k より大きくてはいけません"
 
 #: config/gcn/gcn.c:237
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires a string constant argument"
 msgid "amdgpu_hsa_kernel attribute requires string constant arguments"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
@@ -37475,7 +34563,6 @@ msgstr ""
 
 #: config/gcn/gcn.c:308
 #, fuzzy, gcc-internal-format
-#| msgid "Pass FP arguments in FP registers"
 msgid "too many arguments passed in sgpr registers"
 msgstr "浮動小数点レジスタで浮動小数点引数を渡す"
 
@@ -37486,13 +34573,11 @@ msgstr ""
 
 #: config/gcn/gcn.c:2332
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong type argument to %s"
 msgid "wrong type of argument %s"
 msgstr "%s への間違った型の引数です"
 
 #: config/gcn/gcn.c:3115
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
@@ -37503,7 +34588,6 @@ msgstr "ret 命令は実装されていません"
 
 #: config/gcn/gcn.c:3835
 #, fuzzy, gcc-internal-format
-#| msgid "DW_LOC_OP %s not implemented"
 msgid "Builtin not implemented"
 msgstr "DW_LOC_OP %s は実装されていません"
 
@@ -37524,7 +34608,6 @@ msgstr ""
 
 #: config/gcn/gcn.c:4845 config/gcn/gcn.c:4872
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "operand number out of range"
 msgid "offload dimension out of range (%d)"
 msgstr "被演算子の数字が範囲外です"
 
@@ -37536,7 +34619,6 @@ msgstr ""
 #: config/gcn/mkoffload.c:76 config/i386/intelmic-mkoffload.c:73
 #: config/nvptx/mkoffload.c:87
 #, fuzzy, gcc-internal-format
-#| msgid "deleting LTRANS file %s"
 msgid "deleting file %s: %m"
 msgstr "LTRANS ファイル %s を削除しています"
 
@@ -37547,7 +34629,6 @@ msgstr "環境変数 COLLECT_GCC_OPTIONS が設定されていなければいけ
 
 #: config/gcn/mkoffload.c:537 config/nvptx/mkoffload.c:409
 #, fuzzy, gcc-internal-format
-#| msgid "COLLECT_LTO_WRAPPER must be set"
 msgid "COLLECT_GCC must be set."
 msgstr "COLLECT_LTO_WRAPPER が設定されなければいけません"
 
@@ -37559,7 +34640,6 @@ msgstr "フィールド `%s' が見つかりません"
 #: config/gcn/mkoffload.c:603 config/i386/intelmic-mkoffload.c:585
 #: config/nvptx/mkoffload.c:478
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument in option %qs"
 msgid "unrecognizable argument of option "
 msgstr "オプション %qs 内で認識できない引数です"
 
@@ -37570,7 +34650,6 @@ msgstr ""
 
 #: config/gcn/mkoffload.c:703
 #, fuzzy, gcc-internal-format
-#| msgid "%s:cannot open graph file\n"
 msgid "cannot open intermediate gcn asm file"
 msgstr "%s: グラフファイルを開けません\n"
 
@@ -37578,49 +34657,41 @@ msgstr "%s: グラフファイルを開けません\n"
 #: config/i386/intelmic-mkoffload.c:255 config/i386/intelmic-mkoffload.c:319
 #: config/i386/intelmic-mkoffload.c:360 config/nvptx/mkoffload.c:528
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
 msgid "cannot open '%s'"
 msgstr "%s を開けません"
 
 #: config/gcn/mkoffload.c:724
 #, fuzzy, gcc-internal-format
-#| msgid "%s:cannot open graph file\n"
 msgid "cannot open intermediate gcn obj file"
 msgstr "%s: グラフファイルを開けません\n"
 
 #: config/h8300/h8300.c:329
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s not supported: ignored"
 msgid "%<-msx%> is not supported in coff"
 msgstr "-f%s はサポートされていません: 無視されました"
 
 #: config/h8300/h8300.c:351
 #, fuzzy, gcc-internal-format
-#| msgid "-ms2600 is used without -ms"
 msgid "%<-ms2600%> is used without %<-ms%>"
 msgstr "-ms2600 が -ms 無しで使用されています"
 
 #: config/h8300/h8300.c:357
 #, fuzzy, gcc-internal-format
-#| msgid "-mn is used without -mh or -ms"
 msgid "%<-mn%> is used without %<-mh%> or %<-ms%> or %<-msx%>"
 msgstr "-mn が -mh または -ms 無しで使用されています"
 
 #: config/h8300/h8300.c:363
 #, fuzzy, gcc-internal-format
-#| msgid "-ms2600 is used without -ms"
 msgid "%<-mexr%> is used without %<-ms%>"
 msgstr "-ms2600 が -ms 無しで使用されています"
 
 #: config/h8300/h8300.c:369
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<-mint32%> is not supported for H8300 and H8300L targets"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
 #: config/h8300/h8300.c:375
 #, fuzzy, gcc-internal-format
-#| msgid "-mn is used without -mh or -ms"
 msgid "%<-mexr%> is used without %<-ms%> or %<-msx%>"
 msgstr "-mn が -mh または -ms 無しで使用されています"
 
@@ -37631,7 +34702,6 @@ msgstr ""
 
 #: config/h8300/h8300.c:388
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<-mn%> is not supported for linux targets"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
@@ -37657,7 +34727,6 @@ msgstr ""
 
 #: config/i386/i386-builtins.c:2318
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
 msgid "ISA %qs is not supported in %<target%> attribute, use %<arch=%> syntax"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
@@ -37668,19 +34737,16 @@ msgstr ""
 
 #: config/i386/i386-builtins.c:2430
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "parameter to builtin must be a string constant or literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
 #: config/i386/i386-builtins.c:2455 config/i386/i386-builtins.c:2505
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "parameter %qD set but not used"
 msgid "parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
 #: config/i386/i386-expand.c:7916
 #, fuzzy, gcc-internal-format
-#| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine cannot be called directly"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
@@ -37701,13 +34767,11 @@ msgstr "第三引数は 8 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:9714
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:9729
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
@@ -37738,37 +34802,31 @@ msgstr "最後の引数は 8 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:9970
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
 #: config/i386/i386-expand.c:9975
 #, fuzzy, gcc-internal-format
-#| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
 #: config/i386/i386-expand.c:9981 config/i386/i386-expand.c:10301
 #, fuzzy, gcc-internal-format
-#| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
 #: config/i386/i386-expand.c:10283
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:10289
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:10292
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
@@ -37779,7 +34837,6 @@ msgstr "最後の引数は 32 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:10816 config/rs6000/rs6000-call.c:10024
 #, fuzzy, gcc-internal-format
-#| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "selector must be an integer constant in the range [0, %wi]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
@@ -37800,7 +34857,6 @@ msgstr "最後の引数は即値でなければいけません"
 
 #: config/i386/i386-expand.c:12441 config/i386/i386-expand.c:12653
 #, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
@@ -37811,13 +34867,11 @@ msgstr "第五引数は 8 ビット即値でなければいけません"
 
 #: config/i386/i386-expand.c:12712
 #, fuzzy, gcc-internal-format
-#| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
 #: config/i386/i386-expand.c:12731
 #, fuzzy, gcc-internal-format
-#| msgid "the next to last argument must be an 8-bit immediate"
 msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
@@ -37828,13 +34882,11 @@ msgstr ""
 
 #: config/i386/i386-features.c:2600 config/i386/i386-features.c:2868
 #, fuzzy, gcc-internal-format
-#| msgid "static linking is not supported"
 msgid "virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
 #: config/i386/i386-features.c:2732
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
@@ -37846,19 +34898,16 @@ msgstr "コードモデル %s は PIC モードをサポートしません"
 
 #: config/i386/i386-options.c:1081
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "attribute %qs argument is not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
 #: config/i386/i386-options.c:1145
 #, fuzzy, gcc-internal-format
-#| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %qs argument %qs is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
 #: config/i386/i386-options.c:1174
 #, fuzzy, gcc-internal-format
-#| msgid "weakref attribute must appear before alias attribute"
 msgid "attribute value %qs was already specified in %qs attribute"
 msgstr "弱い参照属性は別名属性より前に出現しなければいけません"
 
@@ -37869,7 +34918,6 @@ msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
 #: config/i386/i386-options.c:1450
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument in option %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
@@ -37880,7 +34928,6 @@ msgstr ""
 
 #: config/i386/i386-options.c:1466
 #, fuzzy, gcc-internal-format
-#| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
@@ -37892,7 +34939,6 @@ msgstr ""
 
 #: config/i386/i386-options.c:1505
 #, fuzzy, gcc-internal-format
-#| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%q+D 用の整列が指定されていないようです"
 
@@ -37903,31 +34949,26 @@ msgstr ""
 
 #: config/i386/i386-options.c:1522
 #, fuzzy, gcc-internal-format
-#| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs にクラス名が指定されていません"
 
 #: config/i386/i386-options.c:1575
 #, fuzzy, gcc-internal-format
-#| msgid "unknown register name: %s"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "不明なレジスタ名です: %s"
 
 #: config/i386/i386-options.c:1759
 #, fuzzy, gcc-internal-format
-#| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
 #: config/i386/i386-options.c:1808
 #, fuzzy, gcc-internal-format
-#| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
 #: config/i386/i386-options.c:1810
 #, fuzzy, gcc-internal-format
-#| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
@@ -37939,31 +34980,26 @@ msgstr ""
 
 #: config/i386/i386-options.c:1853
 #, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
 #: config/i386/i386-options.c:1864
 #, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-mg でのプロファイルはサポートされていません"
 
 #: config/i386/i386-options.c:1870
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
 #: config/i386/i386-options.c:1873
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
 #: config/i386/i386-options.c:1877
 #, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
@@ -37976,13 +35012,11 @@ msgstr "コードモデル %qs は %s ビットモード内ではサポートさ
 
 #: config/i386/i386-options.c:1906 config/i386/i386-options.c:1918
 #, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
 #: config/i386/i386-options.c:1961
 #, fuzzy, gcc-internal-format
-#| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
@@ -38028,7 +35062,6 @@ msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
 #: config/i386/i386-options.c:2279
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -38039,13 +35072,11 @@ msgstr ""
 
 #: config/i386/i386-options.c:2286
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/i386/i386-options.c:2287
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -38061,7 +35092,6 @@ msgstr "-mtune スイッチ用の間違った値 %qs です"
 
 #: config/i386/i386-options.c:2356
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
@@ -38072,67 +35102,56 @@ msgstr ""
 
 #: config/i386/i386-options.c:2363
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/i386/i386-options.c:2364
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/i386/i386-options.c:2388
 #, fuzzy, gcc-internal-format
-#| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
 #: config/i386/i386-options.c:2390
 #, fuzzy, gcc-internal-format
-#| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
 #: config/i386/i386-options.c:2393
 #, fuzzy, gcc-internal-format
-#| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
 #: config/i386/i386-options.c:2421
 #, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
 #: config/i386/i386-options.c:2422
 #, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
 #: config/i386/i386-options.c:2501
 #, fuzzy, gcc-internal-format
-#| msgid "%spreferred-stack-boundary%s is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
 #: config/i386/i386-options.c:2504
 #, fuzzy, gcc-internal-format
-#| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
 #: config/i386/i386-options.c:2527
 #, fuzzy, gcc-internal-format
-#| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
 #: config/i386/i386-options.c:2540
 #, fuzzy, gcc-internal-format
-#| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
@@ -38143,13 +35162,11 @@ msgstr "ret 命令は実装されていません"
 
 #: config/i386/i386-options.c:2549
 #, fuzzy, gcc-internal-format
-#| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
 #: config/i386/i386-options.c:2550
 #, fuzzy, gcc-internal-format
-#| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
@@ -38190,43 +35207,36 @@ msgstr ""
 
 #: config/i386/i386-options.c:2692
 #, fuzzy, gcc-internal-format
-#| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
 #: config/i386/i386-options.c:2696
 #, fuzzy, gcc-internal-format
-#| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
 #: config/i386/i386-options.c:2761
 #, fuzzy, gcc-internal-format
-#| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
 #: config/i386/i386-options.c:2820
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
 #: config/i386/i386-options.c:2825
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
 #: config/i386/i386-options.c:2853
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
 #: config/i386/i386-options.c:3015
 #, fuzzy, gcc-internal-format
-#| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
@@ -38237,43 +35247,36 @@ msgstr ""
 
 #: config/i386/i386-options.c:3079
 #, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
 #: config/i386/i386-options.c:3089
 #, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
 #: config/i386/i386-options.c:3124
 #, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
 #: config/i386/i386-options.c:3134
 #, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
 #: config/i386/i386-options.c:3228
 #, fuzzy, gcc-internal-format
-#| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
 #: config/i386/i386-options.c:3230
 #, fuzzy, gcc-internal-format
-#| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
 #: config/i386/i386-options.c:3234
 #, fuzzy, gcc-internal-format
-#| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
@@ -38334,7 +35337,6 @@ msgstr "cdecl と thiscall 属性は併用できません"
 
 #: config/i386/i386-options.c:3377
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
@@ -38355,7 +35357,6 @@ msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
 #: config/i386/i386-options.c:3563 config/i386/i386-options.c:3573
 #, fuzzy, gcc-internal-format
-#| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
@@ -38368,7 +35369,6 @@ msgstr "%qE 属性は文字列定数引数を必要とします"
 #: config/i386/i386-options.c:3610 config/i386/i386-options.c:3632
 #: config/s390/s390.c:1180
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
@@ -38379,7 +35379,6 @@ msgstr ""
 
 #: config/i386/i386-options.c:3671
 #, fuzzy, gcc-internal-format
-#| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
@@ -38390,7 +35389,6 @@ msgstr ""
 
 #: config/i386/i386-options.c:3685
 #, fuzzy, gcc-internal-format
-#| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
@@ -38406,25 +35404,21 @@ msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qT を
 
 #: config/i386/i386.c:1508
 #, fuzzy, gcc-internal-format
-#| msgid "does not support multilib"
 msgid "X32 does not support %<ms_abi%> attribute"
 msgstr "multilib はサポートしません"
 
 #: config/i386/i386.c:1542
 #, fuzzy, gcc-internal-format
-#| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
 #: config/i386/i386.c:1882
 #, fuzzy, gcc-internal-format
-#| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
 #: config/i386/i386.c:1888
 #, fuzzy, gcc-internal-format
-#| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
@@ -38435,7 +35429,6 @@ msgstr ""
 
 #: config/i386/i386.c:1908
 #, fuzzy, gcc-internal-format
-#| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
@@ -38466,13 +35459,11 @@ msgstr "可変長配列メンバを持つ構造体を渡す ABI は GCC 4.4 で
 
 #: config/i386/i386.c:2254
 #, fuzzy, gcc-internal-format
-#| msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
 msgstr "long double を持つ共用体を渡す ABI は GCC 4.4 で変更になっています"
 
 #: config/i386/i386.c:2372
 #, fuzzy, gcc-internal-format
-#| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
@@ -38493,7 +35484,6 @@ msgstr "x87 が無効な状態で x87 レジスタを戻して (return) いま
 
 #: config/i386/i386.c:2867 config/i386/i386.c:3104 config/i386/i386.c:3599
 #, fuzzy, gcc-internal-format
-#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
@@ -38504,19 +35494,16 @@ msgstr ""
 
 #: config/i386/i386.c:3505
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
 #: config/i386/i386.c:6015
 #, fuzzy, gcc-internal-format
-#| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
 #: config/i386/i386.c:8021
 #, fuzzy, gcc-internal-format
-#| msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
 msgstr "ms_hook_prologue 属性は 32 ビット用の -mfentry と併用できません"
 
@@ -38527,13 +35514,11 @@ msgstr ""
 
 #: config/i386/i386.c:9401
 #, fuzzy, gcc-internal-format
-#| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "%<-fsplit-stack%> does not support fastcall with nested function"
 msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートされていません"
 
 #: config/i386/i386.c:9421
 #, fuzzy, gcc-internal-format
-#| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
 msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートされていません"
 
@@ -38541,7 +35526,6 @@ msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートさ
 #. around the addition and comparison.
 #: config/i386/i386.c:9432
 #, fuzzy, gcc-internal-format
-#| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "%<-fsplit-stack%> does not support 3 register parameters"
 msgstr "このコンパイラ設定では %<-fsplit-stack%> はサポートされていません"
 
@@ -38567,7 +35551,6 @@ msgstr ""
 
 #: config/i386/i386.c:12647
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand type used with operand code '%c'"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
@@ -38578,7 +35561,6 @@ msgstr ""
 
 #: config/i386/i386.c:22099
 #, fuzzy, gcc-internal-format
-#| msgid "unknown architecture %qs"
 msgid "unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
@@ -38599,19 +35581,16 @@ msgstr ""
 
 #: config/i386/i386.c:22189
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
 #: config/i386/intelmic-mkoffload.c:465
 #, fuzzy, gcc-internal-format
-#| msgid "no input file specified"
 msgid "output file not specified"
 msgstr "入力ファイルが指定されていません"
 
 #: config/i386/intelmic-mkoffload.c:561
 #, fuzzy, gcc-internal-format
-#| msgid "COLLECT_LTO_WRAPPER must be set"
 msgid "COLLECT_GCC must be set"
 msgstr "COLLECT_LTO_WRAPPER が設定されなければいけません"
 
@@ -38634,13 +35613,11 @@ msgstr "環境変数 DJGPP が定義されていません"
 
 #: config/i386/xm-djgpp.h:87
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable DJGPP points to missing file '%s'"
 msgid "environment variable DJGPP points to missing file %qs"
 msgstr "環境変数 DJGPP が存在しないファイル '%s' を指しています"
 
 #: config/i386/xm-djgpp.h:90
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable DJGPP points to corrupt file '%s'"
 msgid "environment variable DJGPP points to corrupt file %qs"
 msgstr "環境変数 DJGPP が壊れたファイル '%s' を示しています。"
 
@@ -38671,7 +35648,6 @@ msgstr "アドレス領域属性は関数用には指定できません"
 
 #: config/ia64/ia64.c:6024 config/pa/pa.c:453 config/sh/sh.c:8266
 #, fuzzy, gcc-internal-format
-#| msgid "value of -mfixed-range must have form REG1-REG2"
 msgid "value of %<-mfixed-range%> must have form REG1-REG2"
 msgstr "-mfixed-range の値は REG1-REG2 形式でなければいけません"
 
@@ -38697,7 +35673,6 @@ msgstr "PRINT_OPERAND_ADDRESS, null ポインタ"
 
 #: config/iq2000/iq2000.c:3048
 #, fuzzy, gcc-internal-format
-#| msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgid "PRINT_OPERAND: Unknown punctuation %<%c%>"
 msgstr "PRINT_OPERAND: 不明な句読点 '%c'"
 
@@ -38733,7 +35708,6 @@ msgstr ""
 
 #: config/m32c/m32c.c:418
 #, fuzzy, gcc-internal-format
-#| msgid "invalid --param value %qs"
 msgid "invalid target memregs value %<%d%>"
 msgstr "無効な --param の値 %qs です"
 
@@ -38770,31 +35744,26 @@ msgstr "%qs 属性の引数が無効です"
 
 #: config/m68k/m68k.c:531
 #, fuzzy, gcc-internal-format
-#| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-mcpu=%s%> conflicts with %<-march=%s%>"
 msgstr "-mcpu=%s が -march=%s と競合しています"
 
 #: config/m68k/m68k.c:602
 #, fuzzy, gcc-internal-format
-#| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "%<-mpcrel%> %<-fPIC%> is not currently supported on selected cpu"
 msgstr "-mpcrel -fPIC は選択した CPU 上では現在のところサポートされていません"
 
 #: config/m68k/m68k.c:666
 #, fuzzy, gcc-internal-format
-#| msgid "-falign-labels=%d is not supported"
 msgid "%<-falign-labels=%d%> is not supported"
 msgstr "-falign-labels=%d はサポートされていません"
 
 #: config/m68k/m68k.c:673
 #, fuzzy, gcc-internal-format
-#| msgid "-falign-loops=%d is not supported"
 msgid "%<-falign-loops=%d%> is not supported"
 msgstr "-falign-loops=%d はサポートされていません"
 
 #: config/m68k/m68k.c:681
 #, fuzzy, gcc-internal-format
-#| msgid "stack limits not supported on this target"
 msgid "%<-fstack-limit-%> options are not supported on this cpu"
 msgstr "スタック制限はこのターゲットでは実装されていません"
 
@@ -38820,25 +35789,21 @@ msgstr "初期化された変数 %q+D は dllimport とマークされていま
 
 #: config/microblaze/microblaze.c:1754
 #, fuzzy, gcc-internal-format
-#| msgid "-fPIC and -fpic are not supported for this target"
 msgid "%<-fPIC%>/%<-fpic%> not supported for this target"
 msgstr "-fPIC and -fpic はこのターゲットではサポートされていません"
 
 #: config/microblaze/microblaze.c:1766
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
 msgid "%qs is an invalid argument to %<-mcpu=%>"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
 #: config/microblaze/microblaze.c:1815
 #, fuzzy, gcc-internal-format
-#| msgid "-mxl-multiply-high can be used only with -mcpu=v6.00.a or greater"
 msgid "%<-mxl-multiply-high%> can be used only with %<-mcpu=v6.00.a%> or greater"
 msgstr "-mxl-multiply-high は -mcpu=v6.00.a またはそれ以上でのみ使用出来ます"
 
 #: config/microblaze/microblaze.c:1832
 #, fuzzy, gcc-internal-format
-#| msgid "-mxl-multiply-high can be used only with -mcpu=v6.00.a or greater"
 msgid "%<-mxl-reorder%> can be used only with %<-mcpu=v8.30.a%> or greater"
 msgstr "-mxl-multiply-high は -mcpu=v6.00.a またはそれ以上でのみ使用出来ます"
 
@@ -38849,7 +35814,6 @@ msgstr ""
 
 #: config/microblaze/microblaze.c:1845
 #, fuzzy, gcc-internal-format
-#| msgid "-mxl-multiply-high requires -mno-xl-soft-mul"
 msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high は -mno-xl-soft-mul が必要です"
 
@@ -38860,7 +35824,6 @@ msgstr "%qs 属性は関数へのみ適用出来ます"
 
 #: config/mips/mips.c:1438 config/mips/mips.c:1444
 #, fuzzy, gcc-internal-format
-#| msgid "%qE cannot have both %<mips16%> and %<nomips16%> attributes"
 msgid "%qE cannot have both %qs and %qs attributes"
 msgstr "%qE は %<mips16%> と %<nomips16%> 属性の両方を持つことは出来ません"
 
@@ -38871,13 +35834,11 @@ msgstr "%qE が競合する %qs 属性付きで再宣言されました"
 
 #: config/mips/mips.c:1511 config/mips/mips.c:1565 config/riscv/riscv.c:2960
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
 #: config/mips/mips.c:1519
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is neither eic, nor vector=<line>"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
@@ -38888,7 +35849,6 @@ msgstr ""
 
 #: config/mips/mips.c:1572
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not intstack"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
@@ -38899,7 +35859,6 @@ msgstr "一貫していない %qs への呼び出しを取り扱えません"
 
 #: config/mips/mips.c:10992
 #, fuzzy, gcc-internal-format
-#| msgid "the %<interrupt%> attribute requires a MIPS32r2 processor"
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "%<interrupt%> 属性は MIPS32r2 プロセッサが必要です"
 
@@ -38915,13 +35874,11 @@ msgstr ""
 
 #: config/mips/mips.c:17019
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
 #: config/mips/mips.c:17139
 #, fuzzy, gcc-internal-format
-#| msgid "Recognize built-in functions"
 msgid "failed to expand built-in function"
 msgstr "組み込み関数を認識する"
 
@@ -38952,7 +35909,6 @@ msgstr ""
 
 #: config/mips/mips.c:19694
 #, fuzzy, gcc-internal-format
-#| msgid "Generate MIPS16 code"
 msgid "MSA MIPS16 code"
 msgstr "MIPS16 コードを生成する"
 
@@ -38990,7 +35946,6 @@ msgstr "%<-mgp64%> が 32 ビット ABI で使用されています"
 
 #: config/mips/mips.c:19953
 #, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
@@ -39006,25 +35961,21 @@ msgstr "%<-mgp32%> と %<-mfp64%> は o32 ABI を使用している時のみ組
 
 #: config/mips/mips.c:19986
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mgp32%> と %<-mfp64%> は o32 ABI を使用している時のみ組み合わせることができます"
 
 #: config/mips/mips.c:19990
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
 #: config/mips/mips.c:19992
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
 #: config/mips/mips.c:20008 config/mips/mips.c:20010 config/mips/mips.c:20023
 #, fuzzy, gcc-internal-format
-#| msgid "RTP PIC is incompatible with Thumb"
 msgid "%qs is incompatible with %qs"
 msgstr "RTP PIC は Thumb では使用できません"
 
@@ -39045,37 +35996,31 @@ msgstr "%qs アーキテクチャは branch-likely 命令をサポートして
 
 #: config/mips/mips.c:20085
 #, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
 #: config/mips/mips.c:20099
 #, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support paired-single instructions"
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "%qs アーキテクチャは paired-single 命令をサポートしていません"
 
 #: config/mips/mips.c:20112 config/mips/mips.c:20118
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "サポートされていない組み合わせです: %s"
 
 #: config/mips/mips.c:20127
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "サポートされていない組み合わせです: %s"
 
 #: config/mips/mips.c:20142
 #, fuzzy, gcc-internal-format
-#| msgid "Generate position-independent code if possible (large mode)"
 msgid "cannot generate position-independent code for %qs"
 msgstr "可能であれば位置非依存コードを生成する (large モード)"
 
 #: config/mips/mips.c:20145
 #, fuzzy, gcc-internal-format
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
 msgid "position-independent code requires %qs"
 msgstr "OS カーネルコード内で使用するために位置非依存コード (PIC) を無効にする"
 
@@ -39091,13 +36036,11 @@ msgstr ""
 
 #: config/mips/mips.c:20204
 #, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support paired-single instructions"
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "%qs アーキテクチャは paired-single 命令をサポートしていません"
 
 #: config/mips/mips.c:20211
 #, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
@@ -39128,7 +36071,6 @@ msgstr "%qs はターゲットが %qs 命令を提供していることが必要
 
 #: config/mips/mips.c:20276
 #, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
@@ -39159,7 +36101,6 @@ msgstr "mips16 関数プロファイル"
 
 #: config/mmix/mmix.c:317
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s not supported: ignored"
 msgid "%<-f%s%> not supported: ignored"
 msgstr "-f%s はサポートされていません: 無視されました"
 
@@ -39211,7 +36152,6 @@ msgstr "MMIX 内部: %s はシフト演算可能な int ではありません"
 
 #: config/mn10300/mn10300.c:107
 #, fuzzy, gcc-internal-format
-#| msgid "-mtune= expects mn10300, am33, am33-2, or am34"
 msgid "%<-mtune=%> expects mn10300, am33, am33-2, or am34"
 msgstr "-mtune= は mn10300、am33、am33-2 または am34 が予期されます"
 
@@ -39348,7 +36288,6 @@ msgstr ""
 
 #: config/msp430/msp430.c:252
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized register name %qs"
 msgid "Unrecognized MCU name %qs."
 msgstr "認識できないレジスタ名 %qs です"
 
@@ -39379,7 +36318,6 @@ msgstr ""
 
 #: config/msp430/msp430.c:298
 #, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
 msgid "%<-fuse-cxa-atexit%> is not supported for msp430-elf"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
 
@@ -39390,37 +36328,31 @@ msgstr ""
 
 #: config/msp430/msp430.c:1306
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qE attribute"
 msgid "unrecognized interrupt vector argument of %qE attribute"
 msgstr "%qE 属性の無効な引数です"
 
 #: config/msp430/msp430.c:1315
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "numeric argument of %qE attribute must be in range 0..63"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
 #: config/msp430/msp430.c:1321
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
 msgid "argument of %qE attribute is not a string constant or number"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: config/msp430/msp430.c:1350
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect on unit local functions"
 msgid "critical attribute has no effect on interrupt functions"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
 #: config/msp430/msp430.c:1386 config/msp430/msp430.c:1435
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %<noinit%>"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: config/msp430/msp430.c:1389 config/msp430/msp430.c:1427
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %<section%>"
 msgstr "%qE 属性は %s 属性と競合します"
 
@@ -39431,7 +36363,6 @@ msgstr ""
 
 #: config/msp430/msp430.c:1441
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect on unit local functions"
 msgid "%qE attribute has no effect on automatic variables"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
@@ -39442,37 +36373,31 @@ msgstr "可変長オブジェクトは初期化されないことになるでし
 
 #: config/msp430/msp430.c:1574
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %<lower%>"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: config/msp430/msp430.c:1577
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %<upper%>"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: config/msp430/msp430.c:1580
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %<either%>"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: config/msp430/msp430.c:1583
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %qE because it conflicts with attribute %<persistent%>"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: config/msp430/msp430.c:1743
 #, fuzzy, gcc-internal-format
-#| msgid "cannot set interrupt attribute: no current function"
 msgid "argument to interrupt attribute is unsupported for weak functions"
 msgstr "interrupt 属性を設定できません: 現在の関数がありません"
 
 #: config/msp430/msp430.c:2242
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute allows only an integer constant argument"
 msgid "__delay_cycles() only takes constant arguments"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
 
@@ -39499,97 +36424,81 @@ msgstr "間違った組み込みコードです"
 
 #: config/nds32/nds32-intrinsic.c:126 config/nios2/nios2.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "invalid argument to built-in function %s"
 msgstr "組み込み関数への無効な引数です"
 
 #: config/nds32/nds32-intrinsic.c:131
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "constant argument out of range for %s"
 msgstr "%qs 用の定数引数が範囲外です"
 
 #: config/nds32/nds32-intrinsic.c:1003
 #, fuzzy, gcc-internal-format
-#| msgid "Enable sign extend instructions"
 msgid "don%'t support DSP extension instructions"
 msgstr "符号付き拡張命令を有効にする"
 
 #: config/nds32/nds32-intrinsic.c:1016
 #, fuzzy, gcc-internal-format
-#| msgid "this builtin function is only available on the fr450"
 msgid "this builtin function is only available on the v3s or v3f toolchain"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
 #: config/nds32/nds32-intrinsic.c:1028
 #, fuzzy, gcc-internal-format
-#| msgid "this builtin function is only available on the fr450"
 msgid "this builtin function is only available on the v3f toolchain"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
 #: config/nds32/nds32-intrinsic.c:1043
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "this builtin function not support on the v3m toolchain"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: config/nds32/nds32-intrinsic.c:1062
 #, fuzzy, gcc-internal-format
-#| msgid "Support code generation of crc32 instruction."
 msgid "don%'t support performance extension instructions"
 msgstr "crc32 命令のコード生成をサポートする。"
 
 #: config/nds32/nds32-intrinsic.c:1074
 #, fuzzy, gcc-internal-format
-#| msgid "Support code generation of crc32 instruction."
 msgid "don%'t support performance extension version 2 instructions"
 msgstr "crc32 命令のコード生成をサポートする。"
 
 #: config/nds32/nds32-intrinsic.c:1086
 #, fuzzy, gcc-internal-format
-#| msgid "Enable sign extend instructions"
 msgid "don%'t support string extension instructions"
 msgstr "符号付き拡張命令を有効にする"
 
 #: config/nds32/nds32-isr.c:116 config/nds32/nds32-isr.c:207
 #, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
 msgid "require id argument in the string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
 #: config/nds32/nds32-isr.c:131
 #, fuzzy, gcc-internal-format
-#| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt attribute"
 msgstr "%qE 属性用としては無効なベクトル型です"
 
 #: config/nds32/nds32-isr.c:221
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for exception attribute"
 msgstr "%qs 属性の引数が無効です"
 
 #: config/nds32/nds32-isr.c:617
 #, fuzzy, gcc-internal-format
-#| msgid "not enough arguments to function %qE"
 msgid "multiple save reg attributes to function %qD"
 msgstr "関数 %qE へ十分な引数がありません"
 
 #: config/nds32/nds32-isr.c:630
 #, fuzzy, gcc-internal-format
-#| msgid "multiple function type attributes specified"
 msgid "multiple nested types attributes to function %qD"
 msgstr "複数の関数型属性が指定されています"
 
 #: config/nds32/nds32-isr.c:642
 #, fuzzy, gcc-internal-format
-#| msgid "multiple interrupt attributes not allowed"
 msgid "multiple interrupt attributes to function %qD"
 msgstr "複数の割り込み属性は許可されていません"
 
 #: config/nds32/nds32-isr.c:646
 #, fuzzy, gcc-internal-format
-#| msgid "multiple interrupt attributes not allowed"
 msgid "cannot use interrupt attributes to function %qD under linux toolchain"
 msgstr "複数の割り込み属性は許可されていません"
 
@@ -39600,7 +36509,6 @@ msgstr ""
 
 #: config/nds32/nds32-isr.c:652
 #, fuzzy, gcc-internal-format
-#| msgid "not enough arguments to function %qE"
 msgid "cannot use reset attributes to function %qD under linux toolchain"
 msgstr "関数 %qE へ十分な引数がありません"
 
@@ -39611,14 +36519,12 @@ msgstr "関数 %qE へ十分な引数がありません"
 #: config/nds32/nds32.c:3766 config/nds32/nds32.c:3772
 #: config/nds32/nds32.c:3804
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "a nested function is not supported for reduced registers"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #. The enum index value for array size is out of range.
 #: config/nds32/nds32.c:3463
 #, fuzzy, gcc-internal-format
-#| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "命令に対して無効なレジスタです"
 
@@ -39631,37 +36537,31 @@ msgstr "言語 %s は認識できません"
 
 #: config/nds32/nds32.c:3944
 #, fuzzy, gcc-internal-format
-#| msgid "cannot set interrupt attribute: no such identifier"
 msgid "cannot use indirect_call attribute under linux toolchain"
 msgstr "interrupt 属性を設定できません: そのような識別子はありません"
 
 #: config/nds32/nds32.c:3952
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
 msgid "indirect_call attribute can%'t apply for static function"
 msgstr "%qE 属性は関数へのみ適用されます"
 
 #: config/nds32/nds32.c:4041
 #, fuzzy, gcc-internal-format
-#| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "%qE 属性用としては無効なベクトル型です"
 
 #: config/nds32/nds32.c:4069
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
 #: config/nds32/nds32.c:4085
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
 #: config/nds32/nds32.c:4098
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
@@ -39687,7 +36587,6 @@ msgstr ""
 
 #: config/nios2/nios2.c:1182
 #, fuzzy, gcc-internal-format
-#| msgid "target attribute or pragma changes double precision floating point"
 msgid "switch %<-mcustom-%s%> is required for double precision floating point"
 msgstr "target 属性または pragma が倍精度浮動小数点を変更します"
 
@@ -39723,7 +36622,6 @@ msgstr ""
 
 #: config/nios2/nios2.c:1363
 #, fuzzy, gcc-internal-format
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
 msgid "position-independent code requires the Linux ABI"
 msgstr "OS カーネルコード内で使用するために位置非依存コード (PIC) を無効にする"
 
@@ -39734,19 +36632,16 @@ msgstr ""
 
 #: config/nios2/nios2.c:1388
 #, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
 msgid "%<-mgpopt%> not supported with PIC."
 msgstr "-mg でのプロファイルはサポートされていません"
 
 #: config/nios2/nios2.c:1390
 #, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
 msgid "%<-mgprel-sec=%> not supported with PIC."
 msgstr "-mg でのプロファイルはサポートされていません"
 
 #: config/nios2/nios2.c:1392
 #, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
 msgid "%<-mr0rel-sec=%> not supported with PIC."
 msgstr "-mg でのプロファイルはサポートされていません"
 
@@ -39762,19 +36657,16 @@ msgstr ""
 
 #: config/nios2/nios2.c:1417
 #, fuzzy, gcc-internal-format
-#| msgid "instruction scheduling not supported on this target machine"
 msgid "BMX instructions are only supported with R2 architecture"
 msgstr "命令スケジューリングはこのターゲットマシンではサポートされません"
 
 #: config/nios2/nios2.c:1419
 #, fuzzy, gcc-internal-format
-#| msgid "instruction scheduling not supported on this target machine"
 msgid "CDX instructions are only supported with R2 architecture"
 msgstr "命令スケジューリングはこのターゲットマシンではサポートされません"
 
 #: config/nios2/nios2.c:1424
 #, fuzzy, gcc-internal-format
-#| msgid "Generate code in little endian mode"
 msgid "R2 architecture is little-endian only"
 msgstr "リトルエンディアンモードでコードを生成する"
 
@@ -39795,7 +36687,6 @@ msgstr ""
 
 #: config/nios2/nios2.c:3925
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "number must be 0 or 1"
 msgid "Register number must be in range 0-31 for %s"
 msgstr "数値は 0 または 1 でなければいけません"
 
@@ -39816,7 +36707,6 @@ msgstr "%s: オプション `%s' には引数が必要です\n"
 
 #: config/nios2/nios2.c:4090
 #, fuzzy, gcc-internal-format
-#| msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgid "switch %<-mcustom-%s%> conflicts with switch %<-mcustom-%s%>"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
 
@@ -39837,7 +36727,6 @@ msgstr ""
 
 #: config/nios2/nios2.c:4246
 #, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 2 arguments"
 msgid "%<no-custom-%s%> does not accept arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
@@ -39848,7 +36737,6 @@ msgstr ""
 
 #: config/nios2/nios2.c:4271
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qs should be a non-negative integer"
 msgid "%<custom-%s=%> argument should be a non-negative integer"
 msgstr "%qs への引数は非負整数であるべきです"
 
@@ -39864,7 +36752,6 @@ msgstr "レジスタ '%c' が不明です"
 
 #: config/nvptx/mkoffload.c:109
 #, fuzzy, gcc-internal-format
-#| msgid "malformed spec function name"
 msgid "malformed ptx file"
 msgstr "間違った形式の spec 関数名です"
 
@@ -39880,19 +36767,16 @@ msgstr ""
 
 #: config/nvptx/mkoffload.c:556
 #, fuzzy, gcc-internal-format
-#| msgid "%s:cannot open graph file\n"
 msgid "cannot open intermediate ptx file"
 msgstr "%s: グラフファイルを開けません\n"
 
 #: config/nvptx/nvptx.c:197
 #, fuzzy, gcc-internal-format
-#| msgid "command line option %qs is not supported by this configuration"
 msgid "option %s is not supported together with %<-fopenacc%>"
 msgstr "コマンドラインオプション %qs はこの設定ではサポートされていません"
 
 #: config/nvptx/nvptx.c:223
 #, fuzzy, gcc-internal-format
-#| msgid "optimization options not supported yet"
 msgid "not generating patch area, nops not supported"
 msgstr "最適化オプションはまだサポートされていません"
 
@@ -39913,13 +36797,11 @@ msgstr ""
 
 #: config/nvptx/nvptx.c:5058
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE 属性は型に関しては無視されます"
 
 #: config/nvptx/nvptx.c:5081
 #, fuzzy, gcc-internal-format
-#| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 属性は自動記憶域クラスでのみ許可されています"
 
@@ -39940,7 +36822,6 @@ msgstr ""
 
 #: config/or1k/or1k.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unexpected operand"
 msgid "unexpected operand: %d"
 msgstr "予期しない演算子"
 
@@ -39956,13 +36837,11 @@ msgstr "PIC コード生成は高速間接呼び出しと併用できません"
 
 #: config/pa/pa.c:539
 #, fuzzy, gcc-internal-format
-#| msgid "-g is only supported when using GAS on this processor,"
 msgid "%<-g%> is only supported when using GAS on this processor"
 msgstr "-g はこのプロセッサでは GAS を使用する時だけサポートされます。"
 
 #: config/pa/pa.c:540
 #, fuzzy, gcc-internal-format
-#| msgid "-g option disabled"
 msgid "%<-g%> option disabled"
 msgstr "-g オプションが無効になりました"
 
@@ -39973,7 +36852,6 @@ msgstr ""
 
 #: config/pa/som.h:337
 #, fuzzy, gcc-internal-format
-#| msgid "-fpic is not supported"
 msgid "weak aliases are not supported"
 msgstr "-fpic はサポートされていません"
 
@@ -39985,13 +36863,11 @@ msgstr ""
 #: config/pru/pru-passes.c:119 config/pru/pru-passes.c:163
 #: config/pru/pru-passes.c:176
 #, fuzzy, gcc-internal-format
-#| msgid "ifunc is not supported in this configuration"
 msgid "function pointers not supported with %<-mabi=ti%> option"
 msgstr "ifunc はこの設定ではサポートされていません"
 
 #: config/pru/pru-pragma.c:59
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of %<#pragma %s%>"
 msgid "junk at end of %<#pragma CTABLE_ENTRY%>"
 msgstr "%<#pragma %s%> の末尾にゴミがあります"
 
@@ -40001,7 +36877,6 @@ msgstr ""
 
 #: config/pru/pru-pragma.c:64
 #, fuzzy
-#| msgid "redefinition of %q#T"
 msgid "redefinition of %<CTABLE_ENTRY %"
 msgstr "%q#T が再定義されています"
 
@@ -40012,19 +36887,16 @@ msgstr ""
 
 #: config/pru/pru-pragma.c:77
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma %s%>, ignored"
 msgid "malformed %<#pragma CTABLE_ENTRY%> variable address"
 msgstr "間違った形式の %<#pragma %s%> です。無視されました"
 
 #: config/pru/pru.c:2802
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute allows only an integer constant argument"
 msgid "%<__delay_cycles%> only takes constant arguments"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
 
 #: config/pru/pru.c:2811
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute allows only an integer constant argument"
 msgid "%<__delay_cycles%> only takes non-negative cycle counts"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
 
@@ -40035,19 +36907,16 @@ msgstr ""
 
 #: config/riscv/riscv.c:362
 #, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
 #: config/riscv/riscv.c:2580 config/riscv/riscv.c:2622
 #, fuzzy, gcc-internal-format
-#| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
 #: config/riscv/riscv.c:2971
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not \"user\", \"supervisor\", or \"machine\""
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
@@ -40073,7 +36942,6 @@ msgstr ""
 
 #: config/riscv/riscv.c:4684
 #, fuzzy, gcc-internal-format
-#| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
@@ -40084,14 +36952,12 @@ msgstr ""
 
 #: config/riscv/riscv.c:4989
 #, fuzzy, gcc-internal-format
-#| msgid "interrupt function must have no arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "割り込み関数は引数無しでなければいけません"
 
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:375
 #, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
 msgid "%<-mes0%> can only be used with C"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
@@ -40102,20 +36968,17 @@ msgstr ""
 
 #: config/rl78/rl78.c:393
 #, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
 msgid "%<-mmul=g13%> cannot be used with %<-mcpu=g10%>"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
 #: config/rl78/rl78.c:395
 #, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
 msgid "%<-mmul=g14%> cannot be used with %<-mcpu=g10%>"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
 #. The S2 core does not have mul/div instructions.
 #: config/rl78/rl78.c:407
 #, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
 msgid "%<-mmul=g14%> cannot be used with %<-mcpu=g13%>"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
@@ -40123,19 +36986,16 @@ msgstr "-mmulticore は BF561 でのみ使用できます"
 #. G13 core, hence you cannot use G13 multipliy routines on G14 hardware.
 #: config/rl78/rl78.c:420
 #, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
 msgid "%<-mmul=g13%> cannot be used with %<-mcpu=g14%>"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
 #: config/rl78/rl78.c:843
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
 msgid "naked attribute only applies to functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
 #: config/rl78/rl78.c:867
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute doesn%'t apply to functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
@@ -40143,7 +37003,6 @@ msgstr "%qE 属性は関数へのみ適用されます"
 #. bits.
 #: config/rl78/rl78.c:1233
 #, fuzzy, gcc-internal-format
-#| msgid "ordered comparison of pointer with null pointer"
 msgid "converting far pointer to near pointer"
 msgstr "NULL ポインタがあるポインタの順序比較です"
 
@@ -40179,7 +37038,6 @@ msgstr "シグナルハンドラをセットアップ中: %m"
 
 #: config/rs6000/rs6000-c.c:55
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring malformed #pragma longcall"
 msgid "ignoring malformed %<#pragma longcall%>"
 msgstr "間違った形式の #pragma longcall を無視しています"
 
@@ -40205,7 +37063,6 @@ msgstr "数値は 0 または 1 でなければいけません"
 
 #: config/rs6000/rs6000-c.c:77
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of #pragma longcall"
 msgid "junk at end of %<#pragma longcall%>"
 msgstr "#pragma longcall の末尾にゴミがあります"
 
@@ -40223,26 +37080,22 @@ msgstr ""
 #: config/rs6000/rs6000-c.c:1269 config/rs6000/rs6000-c.c:1335
 #: config/rs6000/rs6000-c.c:1701 config/rs6000/rs6000-c.c:1748
 #, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
 #: config/rs6000/rs6000-c.c:1072 config/rs6000/rs6000-c.c:1155
 #: config/rs6000/rs6000-c.c:1513
 #, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
 #: config/rs6000/rs6000-c.c:1264
 #, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
 #: config/rs6000/rs6000-c.c:1640
 #, fuzzy, gcc-internal-format
-#| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
@@ -40253,7 +37106,6 @@ msgstr ""
 
 #: config/rs6000/rs6000-c.c:1843
 #, fuzzy, gcc-internal-format
-#| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s はこの設定ではサポートされていません"
 
@@ -40274,7 +37126,6 @@ msgstr ""
 
 #: config/rs6000/rs6000-call.c:6240
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
@@ -40285,7 +37136,6 @@ msgstr ""
 
 #: config/rs6000/rs6000-call.c:7250
 #, fuzzy, gcc-internal-format
-#| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous %<float%> aggregates has changed in GCC 5"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
@@ -40296,19 +37146,16 @@ msgstr ""
 
 #: config/rs6000/rs6000-call.c:8217
 #, fuzzy, gcc-internal-format
-#| msgid "internal error: builtin function to %s already processed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
 #: config/rs6000/rs6000-call.c:8588
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_mffsl%> not supported with %<-msoft-float%>"
 msgstr "__builtin_saveregs はこのターゲットではサポートされていません"
 
 #: config/rs6000/rs6000-call.c:8629
 #, fuzzy, gcc-internal-format
-#| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
@@ -40319,37 +37166,31 @@ msgstr ""
 
 #: config/rs6000/rs6000-call.c:8672
 #, fuzzy, gcc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a constant between 0 and 31."
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
 #: config/rs6000/rs6000-call.c:8698
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_rn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: config/rs6000/rs6000-call.c:8713
 #, fuzzy, gcc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a value between 0 and 3."
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
 #: config/rs6000/rs6000-call.c:8738
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> is not supported in 32-bit mode"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: config/rs6000/rs6000-call.c:8743
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
 msgid "%<__builtin_set_fpscr_drn%> not supported with %<-msoft-float%>"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: config/rs6000/rs6000-call.c:8762
 #, fuzzy, gcc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument must be a value between 0 and 7."
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
@@ -40360,25 +37201,21 @@ msgstr "第一引数は 5 ビット符号付きリテラルでなければいけ
 
 #: config/rs6000/rs6000-call.c:8887
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:8898
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 2-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:8909
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 3-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:8920
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 4-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
@@ -40389,63 +37226,53 @@ msgstr "第二引数は 5 ビット符号無しリテラルでなければいけ
 
 #: config/rs6000/rs6000-call.c:8952
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:8968
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:9007
 #, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "引数は定数でなければいけません"
 
 #: config/rs6000/rs6000-call.c:9065
 #, fuzzy, gcc-internal-format
-#| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
 #: config/rs6000/rs6000-call.c:9354 config/rs6000/rs6000-call.c:9514
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:9356 config/rs6000/rs6000-call.c:9516
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
 #: config/rs6000/rs6000-call.c:9465
 #, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
 #: config/rs6000/rs6000-call.c:9661
 #, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
 #. Invalid CPU argument.
 #: config/rs6000/rs6000-call.c:9680
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
 #. Invalid HWCAP argument.
 #: config/rs6000/rs6000-call.c:9708
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
@@ -40471,31 +37298,26 @@ msgstr "第三引数は 1 ビット符号無しリテラルでなければいけ
 
 #: config/rs6000/rs6000-call.c:9844
 #, fuzzy, gcc-internal-format
-#| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "数値は 0 または 1 でなければいけません"
 
 #: config/rs6000/rs6000-call.c:9856
 #, fuzzy, gcc-internal-format
-#| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:9870
 #, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
 #: config/rs6000/rs6000-call.c:9882
 #, fuzzy, gcc-internal-format
-#| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "数値は 0 または 1 でなければいけません"
 
 #: config/rs6000/rs6000-call.c:9890
 #, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range [0, 15]"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
@@ -40511,19 +37333,16 @@ msgstr ""
 
 #: config/rs6000/rs6000-call.c:10344
 #, fuzzy, gcc-internal-format
-#| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be [0, 12]"
 msgstr "%q+D の第二引数は %<char **%> であるべきです"
 
 #: config/rs6000/rs6000-call.c:10359
 #, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
 msgid "third argument to %qs must be [0, 12]"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: config/rs6000/rs6000-call.c:10553
 #, fuzzy, gcc-internal-format
-#| msgid "this builtin function is only available on the fr450"
 msgid "%qs is only valid for the cell processor"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
@@ -40535,44 +37354,37 @@ msgstr "この組み込み関数は fr450 上でのみ利用できます"
 #: config/rs6000/rs6000-call.c:10589 config/rs6000/rs6000-call.c:10593
 #: config/rs6000/rs6000-call.c:10597
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "%qs requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
 #: config/rs6000/rs6000-call.c:10562 config/rs6000/rs6000-call.c:10570
 #: config/rs6000/rs6000-call.c:10576
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "%qs requires the %qs and %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
 #: config/rs6000/rs6000-call.c:10595
 #, fuzzy, gcc-internal-format
-#| msgid "Enable 32-bit multiply instructions"
 msgid "%qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "32 ビット乗算命令を有効にする"
 
 #: config/rs6000/rs6000-call.c:10600
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "%qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
 #: config/rs6000/rs6000-call.c:10603
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qE not supported for MIPS16"
 msgid "%qs is not supported with the current options"
 msgstr "組み込み関数 %qE は MIPS16 用にはサポートされていません"
 
 #: config/rs6000/rs6000-call.c:13544
 #, fuzzy, gcc-internal-format
-#| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
 
 #: config/rs6000/rs6000-call.c:13566
 #, fuzzy, gcc-internal-format
-#| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
@@ -40583,32 +37395,27 @@ msgstr "スタックフレームが大きすぎます"
 
 #: config/rs6000/rs6000-logue.c:5486
 #, fuzzy, gcc-internal-format
-#| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "レジスタ r2 と r5 を使用する"
 
 #: config/rs6000/rs6000-logue.c:5494
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
 #: config/rs6000/rs6000.c:3217 config/rs6000/rs6000.c:3220
 #: config/rs6000/rs6000.c:3223
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
 #: config/rs6000/rs6000.c:3324
 #, fuzzy, gcc-internal-format
-#| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 は PowerPC64 アーキテクチャが有効のまま残されていることが必要です"
 
 #: config/rs6000/rs6000.c:3519
 #, fuzzy, gcc-internal-format
-#| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power は 64 ビット Darwin ではサポートされていません。インストールされている C および C++ ライブラリと互換性がありません"
 
@@ -40619,7 +37426,6 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:3675
 #, fuzzy, gcc-internal-format
-#| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring はリトルエンディアンシステム上ではサポートされていません"
 
@@ -40632,7 +37438,6 @@ msgstr ""
 #. were explicitly cleared.
 #: config/rs6000/rs6000.c:3762
 #, fuzzy, gcc-internal-format
-#| msgid "-mcmodel incompatible with other toc options"
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
@@ -40652,31 +37457,26 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:3995
 #, fuzzy, gcc-internal-format
-#| msgid "target attribute or pragma changes long double size"
 msgid "target attribute or pragma changes %<long double%> size"
 msgstr "target 属性または pragma が long double のサイズを変更します"
 
 #: config/rs6000/rs6000.c:4021
 #, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
 msgid "%qs requires full ISA 2.06 support"
 msgstr "%s は %s をサポートしません"
 
 #: config/rs6000/rs6000.c:4030
 #, fuzzy, gcc-internal-format
-#| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision %<long double%>"
 msgstr "IEEE 拡張精度 long double を使用しています"
 
 #: config/rs6000/rs6000.c:4033
 #, fuzzy, gcc-internal-format
-#| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision %<long double%>"
 msgstr "IBM 拡張精度 long double を使用しています"
 
 #: config/rs6000/rs6000.c:4052
 #, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s は %s をサポートしません"
 
@@ -40692,7 +37492,6 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:4171
 #, fuzzy, gcc-internal-format
-#| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
@@ -40708,25 +37507,21 @@ msgstr "target 属性または pragma が darwin64 ABI を変更します"
 
 #: config/rs6000/rs6000.c:4380
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
 #: config/rs6000/rs6000.c:4397
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
 #: config/rs6000/rs6000.c:4405
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t use %qs as a call-used register"
 msgid "%qs needs a valid base register"
 msgstr "%qs を呼び出しで使用されるレジスタとして使用できません"
 
 #: config/rs6000/rs6000.c:4706
 #, fuzzy, gcc-internal-format
-#| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
@@ -40737,7 +37532,6 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:7267
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
@@ -40778,7 +37572,6 @@ msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
 #: config/rs6000/rs6000.c:19374
 #, fuzzy, gcc-internal-format
-#| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
@@ -40789,31 +37582,26 @@ msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%
 
 #: config/rs6000/rs6000.c:19382
 #, fuzzy, gcc-internal-format
-#| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
 #: config/rs6000/rs6000.c:19385
 #, fuzzy, gcc-internal-format
-#| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
 #: config/rs6000/rs6000.c:23400
 #, fuzzy, gcc-internal-format
-#| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
 #: config/rs6000/rs6000.c:23403
 #, fuzzy, gcc-internal-format
-#| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
 #: config/rs6000/rs6000.c:23405
 #, fuzzy, gcc-internal-format
-#| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
@@ -40829,13 +37617,11 @@ msgstr ""
 
 #: config/rs6000/rs6000.c:24133
 #, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: config/rs6000/rs6000.c:24389
 #, fuzzy, gcc-internal-format
-#| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
@@ -40907,7 +37693,6 @@ msgstr "静的リンクはサポートされていません"
 #. get control in TARGET_OPTION_OVERRIDE.
 #: config/rs6000/aix61.h:30 config/rs6000/aix71.h:30 config/rs6000/aix72.h:30
 #, fuzzy, gcc-internal-format
-#| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%<-maix64%> requires PowerPC64 architecture remain enabled"
 msgstr "-maix64 は PowerPC64 アーキテクチャが有効のまま残されていることが必要です"
 
@@ -40918,39 +37703,33 @@ msgstr "soft-float と long-double-128 は互換性がありません"
 
 #: config/rs6000/aix61.h:40 config/rs6000/aix71.h:40 config/rs6000/aix72.h:40
 #, fuzzy, gcc-internal-format
-#| msgid "-maix64 required: 64-bit computation with 32-bit addressing not yet supported"
 msgid "%<-maix64%> required: 64-bit computation with 32-bit addressing not yet supported"
 msgstr "-maix64 が必要です: 32 ビットアドレスでの 64 ビット計算はまだサポートされていません"
 
 #: config/rs6000/aix61.h:47 config/rs6000/aix71.h:47 config/rs6000/aix72.h:47
 #: config/rs6000/freebsd64.h:124 config/rs6000/rtems.h:121
 #, fuzzy, gcc-internal-format
-#| msgid "-mcmodel incompatible with other toc options"
 msgid "%<-mcmodel%> incompatible with other toc options"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
 #: config/rs6000/freebsd64.h:102 config/rs6000/linux64.h:115
 #, fuzzy, gcc-internal-format
-#| msgid "-mas100-syntax is incompatible with -gdwarf"
 msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
 msgstr "-mas100-syntax と -gdwarf は併用できません"
 
 #: config/rs6000/freebsd64.h:117 config/rs6000/linux64.h:135
 #: config/rs6000/rtems.h:114
 #, fuzzy, gcc-internal-format
-#| msgid "-m64 requires a PowerPC64 cpu"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "-m64 は PowerPC64 CPU が必要です"
 
 #: config/rs6000/linux64.h:142
 #, fuzzy, gcc-internal-format
-#| msgid "-mcmodel incompatible with other toc options"
 msgid "%<-mcmodel incompatible with other toc options%>"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
 #: config/rs6000/linux64.h:161
 #, fuzzy, gcc-internal-format
-#| msgid "FPA is unsupported in the AAPCS"
 msgid "%qs unsupported for this ABI"
 msgstr "FPA は AAPCS 内ではサポートされていません"
 
@@ -40958,73 +37737,61 @@ msgstr "FPA は AAPCS 内ではサポートされていません"
 #. get control in TARGET_OPTION_OVERRIDE.
 #: config/rs6000/sysv4.h:116
 #, fuzzy, gcc-internal-format
-#| msgid "bad value for -mcall-%s"
 msgid "bad value for %<%s-%s%>"
 msgstr "-mcall-%s 用の間違った値です"
 
 #: config/rs6000/sysv4.h:132
 #, fuzzy, gcc-internal-format
-#| msgid "bad value for -msdata=%s"
 msgid "bad value for %<%s=%s%>"
 msgstr "-msdata=%s 用の間違った値です"
 
 #: config/rs6000/sysv4.h:149
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
 msgid "%qs and %<%s=%s%> are incompatible"
 msgstr "-f%s と -msdata=%s は併用できません"
 
 #: config/rs6000/sysv4.h:158
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
 msgid "%<-f%s%> and %<%s=%s%> are incompatible"
 msgstr "-f%s と -msdata=%s は併用できません"
 
 #: config/rs6000/sysv4.h:167
 #, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<%s=%s%> and %<%s-%s%> are incompatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
 #: config/rs6000/sysv4.h:176 config/rs6000/sysv4.h:210
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
 msgid "%qs and %qs are incompatible"
 msgstr "-f%s と -msdata=%s は併用できません"
 
 #: config/rs6000/sysv4.h:183 config/rs6000/sysv4.h:190
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
 msgid "%qs and %<%s-%s%> are incompatible"
 msgstr "-f%s と -msdata=%s は併用できません"
 
 #: config/rs6000/sysv4.h:196 config/rs6000/sysv4.h:202
 #, fuzzy, gcc-internal-format
-#| msgid "-msecure-plt not supported by your assembler"
 msgid "%qs not supported by your assembler"
 msgstr "-msecure-plt は使用するアセンブラでサポートされていません"
 
 #: config/rs6000/sysv4.h:244
 #, fuzzy, gcc-internal-format
-#| msgid "-m%s not supported in this configuration"
 msgid "%<-m%s%> not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
 #: config/rx/rx.c:650
 #, fuzzy, gcc-internal-format
-#| msgid "unreocgnized control register number: %d - using 'psw'"
 msgid "unrecognized control register number: %d - using %<psw%>"
 msgstr "認識出来ない制御レジスタ番号です: %d - 'psw' を使用します"
 
 #: config/rx/rx.c:1383
 #, fuzzy, gcc-internal-format
-#| msgid "multiple interrupt attributes not allowed"
 msgid "multiple fast interrupt routines seen: %qE and %qE"
 msgstr "複数の割り込み属性は許可されていません"
 
 #: config/rx/rx.c:2594
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_rx_%s takes 'C', 'Z', 'S', 'O', 'I', or 'U'"
 msgid "%<__builtin_rx_%s%> takes %<C%>, %<Z%>, %<S%>, %<O%>, %<I%>, or %<U%>"
 msgstr "__builtin_rx_%s は 'C'、'Z'、'S'、'O'、'I' または 'U' をとります"
 
@@ -41065,13 +37832,11 @@ msgstr ""
 
 #: config/s390/s390-c.c:894
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
 msgid "builtin %qF is deprecated."
 msgstr "%qE は廃止されました"
 
 #: config/s390/s390-c.c:898
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%qF requires %<-mvx%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
@@ -41082,7 +37847,6 @@ msgstr ""
 
 #: config/s390/s390-c.c:910
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is predetermined %qs for %qs"
 msgid "%qF requires z15 or higher"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
@@ -41093,13 +37857,11 @@ msgstr ""
 
 #: config/s390/s390-c.c:973
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "invalid parameter combination for intrinsic %qs"
 msgstr "組み込み関数への無効な引数です"
 
 #: config/s390/s390-c.c:979
 #, fuzzy, gcc-internal-format
-#| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for intrinsic %qs"
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
@@ -41110,31 +37872,26 @@ msgstr ""
 
 #: config/s390/s390-c.c:996
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
 msgid "%qs matching variant requires z15 or higher"
 msgstr "%qE は廃止されました"
 
 #: config/s390/s390-c.c:1002
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
 msgid "%qs matching variant is deprecated."
 msgstr "%qE は廃止されました"
 
 #: config/s390/s390-c.c:1042
 #, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "%qs 用の定数引数が範囲外です"
 
 #: config/s390/s390.c:732
 #, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0..%wu)"
 msgstr "%qs 用の定数引数が範囲外です"
 
 #: config/s390/s390.c:748
 #, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd..%wd)"
 msgstr "%qs 用の定数引数が範囲外です"
 
@@ -41160,20 +37917,17 @@ msgstr ""
 
 #: config/s390/s390.c:835
 #, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<未解決オーバーロードされた関数型>"
 
 #: config/s390/s390.c:842 config/tilegx/tilegx.c:3539
 #: config/tilepro/tilepro.c:3103
 #, fuzzy, gcc-internal-format
-#| msgid "bad builtin code"
 msgid "bad builtin icode"
 msgstr "間違った組み込みコードです"
 
 #: config/s390/s390.c:976
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "組み込み関数への無効な引数です"
 
@@ -41184,7 +37938,6 @@ msgstr ""
 
 #: config/s390/s390.c:1167
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
@@ -41205,7 +37958,6 @@ msgstr ""
 
 #: config/s390/s390.c:11252
 #, fuzzy, gcc-internal-format
-#| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs のフレームサイズ: "
 
@@ -41231,13 +37983,11 @@ msgstr ""
 
 #: config/s390/s390.c:15266
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
 #: config/s390/s390.c:15269
 #, fuzzy, gcc-internal-format
-#| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
@@ -41253,13 +38003,11 @@ msgstr "ハードウェア十進浮動小数点命令は ESA/390 モードでは
 
 #: config/s390/s390.c:15314
 #, fuzzy, gcc-internal-format
-#| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> can%'t be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp は -msoft-float と併用できません"
 
 #: config/s390/s390.c:15323
 #, fuzzy, gcc-internal-format
-#| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float の組み合わせはサポートされていません"
 
@@ -41275,7 +38023,6 @@ msgstr "スタックサイズは 64k より大きくてはいけません"
 
 #: config/s390/s390.c:15334
 #, fuzzy, gcc-internal-format
-#| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard は -mstack-size を暗黙的に使用します"
 
@@ -41301,20 +38048,17 @@ msgstr ""
 
 #: config/s390/s390.c:15416
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 属性は SH2A 用にのみサポートされています"
 
 #. argument is not a plain number
 #: config/s390/s390.c:15452
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%qs への引数は非負整数であるべきです"
 
 #: config/s390/s390.c:15459
 #, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE 属性への引数が %d より大きいです"
 
@@ -41331,7 +38075,6 @@ msgstr "attribute(target(\"%s\")) が不明です"
 #. Value is not allowed for the target attribute.
 #: config/s390/s390.c:15656
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
@@ -41342,13 +38085,11 @@ msgstr ""
 
 #: config/sh/sh.c:953
 #, fuzzy, gcc-internal-format
-#| msgid "unwind tables currently require a frame pointer for correctness"
 msgid "unwind tables currently require either a frame pointer or %<-maccumulate-outgoing-args%> for correctness"
 msgstr "巻き戻し (unwind) 表は現在のところ訂正用のフレームポインタを必要とします"
 
 #: config/sh/sh.c:7416
 #, fuzzy, gcc-internal-format
-#| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__builtin_saveregs%> not supported by this subtarget"
 msgstr "__builtin_saveregs はこのターゲットではサポートされていません"
 
@@ -41386,7 +38127,6 @@ msgstr "r0 は呼び出しによって上書きされるレジスタとして利
 #. The kernel loader cannot handle the relaxation			 relocations, so it cannot load kernel modules			 (which are ET_REL) or RTP executables (which are		 linked with --emit-relocs).  No relaxation relocations		 appear in shared libraries, so relaxation is OK		 for RTP PIC.
 #: config/sh/vxworks.h:43
 #, fuzzy, gcc-internal-format
-#| msgid "-mrelax is only supported for RTP PIC"
 msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax は RTP PIC 用にのみサポートされています"
 
@@ -41397,19 +38137,16 @@ msgstr "%s はこの設定ではサポートされていません"
 
 #: config/sparc/sparc.c:1770
 #, fuzzy, gcc-internal-format
-#| msgid "-mlong-double-64 not allowed with -m64"
 msgid "%<-mlong-double-64%> not allowed with %<-m64%>"
 msgstr "-mlong-double-64 は -m64 と併用することは許可されていません"
 
 #: config/sparc/sparc.c:1778
 #, fuzzy, gcc-internal-format
-#| msgid "-fdata-sections not supported for this target"
 msgid "%<-fcall-saved-REG%> is not supported for out registers"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
 #: config/sparc/sparc.c:1902
 #, fuzzy, gcc-internal-format
-#| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mcmodel=%> is not supported in 32-bit mode"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
@@ -41445,7 +38182,6 @@ msgstr "__BELOW100__ 属性は自動記憶域クラスでのみ許可されて
 
 #: config/tilegx/tilegx.c:3580 config/tilepro/tilepro.c:3129
 #, fuzzy, gcc-internal-format
-#| msgid "mask must be an immediate"
 msgid "operand must be an immediate of the right size"
 msgstr "マスクは即値でなければなりません"
 
@@ -41566,55 +38302,46 @@ msgstr "準備するスタック空間が多すぎます: %d"
 
 #: config/visium/visium.c:729
 #, fuzzy, gcc-internal-format
-#| msgid "attribute interrupt_handler is not compatible with -m5-compact"
 msgid "an interrupt handler cannot be compiled with %<-muser-mode%>"
 msgstr "interrupt_handler 属性は -m5-compact と併用できません"
 
 #: config/vms/vms-c.c:44
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of #pragma ghs starttda"
 msgid "junk at end of #pragma __nostandard"
 msgstr "#pragma ghs starttda の末尾にゴミがあります"
 
 #: config/vms/vms-c.c:55
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of #pragma %s"
 msgid "junk at end of #pragma __standard"
 msgstr "#pragma %s の末尾にゴミ"
 
 #: config/vms/vms-c.c:81
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma align%>, ignoring"
 msgid "malformed %<#pragma member_alignment%>, ignoring"
 msgstr "間違った形式の %<#pragma align%> です。無視しています"
 
 #: config/vms/vms-c.c:96
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma align%>"
 msgid "unknown %<#pragma member_alignment%> name %s"
 msgstr "間違った形式の %<#pragma align%> です"
 
 #: config/vms/vms-c.c:101
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma align%>"
 msgid "malformed %<#pragma member_alignment%>"
 msgstr "間違った形式の %<#pragma align%> です"
 
 #: config/vms/vms-c.c:135
 #, fuzzy, gcc-internal-format
-#| msgid "invalid alignment for %<#pragma align%>, ignoring"
 msgid "unhandled alignment for %<#pragma nomember_alignment%>"
 msgstr "%<#pragma align%> への無効な引数です。無視しています"
 
 #: config/vms/vms-c.c:148
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of '#pragma options'"
 msgid "garbage at end of %<#pragma nomember_alignment%>"
 msgstr "'#pragma options' の末尾にゴミがあります"
 
 #: config/vms/vms-c.c:203
 #, fuzzy, gcc-internal-format
-#| msgid "malformed '#pragma options', ignoring"
 msgid "malformed %<#pragma extern_model%>, ignoring"
 msgstr "間違った形式の '#pragma options' です。無視されました"
 
@@ -41625,37 +38352,31 @@ msgstr ""
 
 #: config/vms/vms-c.c:229
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of %<#pragma extern_prefix%>"
 msgid "unknown %<#pragma extern_model%> model %qs"
 msgstr "%<#pragma extern_prefix%> の末尾にゴミがあります"
 
 #: config/vms/vms-c.c:235
 #, fuzzy, gcc-internal-format
-#| msgid "junk at end of %<#pragma extern_prefix%>"
 msgid "junk at end of '#pragma extern_model'"
 msgstr "%<#pragma extern_prefix%> の末尾にゴミがあります"
 
 #: config/vms/vms-c.c:249
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma message%>, ignored"
 msgid "vms '#pragma __message' is ignored"
 msgstr "間違った形式の %<#pragma message%> です。無視されました"
 
 #: config/vms/vms-c.c:274 config/vms/vms-c.c:280
 #, fuzzy, gcc-internal-format
-#| msgid "malformed #pragma extern_prefix, ignored"
 msgid "malformed '#pragma __extern_prefix', ignoring"
 msgstr "間違った形式の #pragma extern_prefix です。無視されました"
 
 #: config/vms/vms-c.c:313 config/vms/vms-c.c:333
 #, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma %s%>, ignored"
 msgid "malformed %<#pragma %s%>, ignoring"
 msgstr "間違った形式の %<#pragma %s%> です。無視されました"
 
 #: config/vms/vms-c.c:329
 #, fuzzy, gcc-internal-format
-#| msgid "invalid constant in %<#pragma pack%> - ignored"
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "%<#pragma pack%> 内で無効な定数です - 無視されました"
 
@@ -41666,7 +38387,6 @@ msgstr ""
 
 #: config/xtensa/xtensa.c:2255
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s is not supported with CONST16 instructions"
 msgid "%<-f%s%> is not supported with CONST16 instructions"
 msgstr "-f%s は CONST16 命令ではサポートされていません"
 
@@ -41707,7 +38427,6 @@ msgstr "複雑なパラメタをもつ関数は inline にできません"
 
 #: ada/gcc-interface/trans.c:2082
 #, fuzzy, gcc-internal-format
-#| msgid "parameter %q+D declared %<inline%>"
 msgid "subprogram %q+F not marked %<Inline%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
@@ -41718,7 +38437,6 @@ msgstr "%qs 属性用の無効なエレメント型です"
 
 #: ada/gcc-interface/utils.c:4046
 #, fuzzy, gcc-internal-format
-#| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "ベクトルの要素の数が 2 の累乗ではありません"
 
@@ -41730,13 +38448,11 @@ msgstr "%qs 属性が無視されました"
 
 #: ada/gcc-interface/utils.c:6296
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "%qs attribute without arguments on a non-prototype"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: ada/gcc-interface/utils.c:6311
 #, fuzzy, gcc-internal-format
-#| msgid "format string has invalid operand number"
 msgid "%qs argument has invalid operand number (argument %lu)"
 msgstr "書式文字列が無効な被演算子数を持っています"
 
@@ -41772,7 +38488,6 @@ msgstr "%qs 属性は配列型のみに適用できます"
 
 #: brig/brig-lang.c:212
 #, fuzzy, gcc-internal-format
-#| msgid "could not write to response file %s"
 msgid "could not read the BRIG file"
 msgstr "応答ファイル %s を書き込めませんでした"
 
@@ -41911,25 +38626,21 @@ msgstr "列挙型 %q+D の再宣言です"
 
 #: c/c-decl.c:2008
 #, fuzzy, gcc-internal-format
-#| msgid "conflicting types for built-in function %q+D"
 msgid "conflicting types for built-in function %q+D; expected %qT"
 msgstr "組み込み関数 %q+D と型が競合しています"
 
 #: c/c-decl.c:2018 c/c-decl.c:2043
 #, fuzzy, gcc-internal-format
-#| msgid "%qD was declared here"
 msgid "%qD is declared in header %qs"
 msgstr "%qD はここで定義されています"
 
 #: c/c-decl.c:2029
 #, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "mismatch in argument %u type of built-in function %qD; expected %qT"
 msgstr "組み込み関数への無効な引数です"
 
 #: c/c-decl.c:2034
 #, fuzzy, gcc-internal-format
-#| msgid "conflicting types for built-in function %q+D"
 msgid "mismatch in return type of built-in function %qD; expected %qT"
 msgstr "組み込み関数 %q+D と型が競合しています"
 
@@ -41975,7 +38686,6 @@ msgstr "typedef %q+D が再定義されました"
 
 #: c/c-decl.c:2184
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a built-in function"
 msgid "declaration of %qD shadows a built-in function"
 msgstr "%q+D の宣言が組み込み関数を隠します"
 
@@ -42056,7 +38766,6 @@ msgstr "%q+D の宣言は前の非変数を隠します"
 
 #: c/c-decl.c:3011
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
@@ -42082,7 +38791,6 @@ msgstr "入れ子になった外部宣言 %qD です"
 
 #: c/c-decl.c:3350 c/c-decl.c:3364
 #, fuzzy, gcc-internal-format
-#| msgid "implicit declaration of function %qE"
 msgid "implicit declaration of function %qE; did you mean %qs?"
 msgstr "関数 %qE の暗黙的な宣言です"
 
@@ -42108,7 +38816,6 @@ msgstr "関数 %qD の互換性がない暗黙的な宣言です"
 
 #: c/c-decl.c:3716
 #, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared here (not in a function)"
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
@@ -42119,7 +38826,6 @@ msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
 #: c/c-decl.c:3734
 #, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared (first use in this function)"
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
@@ -42210,7 +38916,6 @@ msgstr ""
 
 #: c/c-decl.c:4669
 #, fuzzy, gcc-internal-format
-#| msgid "declaration %qD does not declare anything"
 msgid "empty declaration with %<_Alignas%> does not redeclare tag"
 msgstr "宣言 %qD が何も宣言していません"
 
@@ -42226,7 +38931,6 @@ msgstr "空の宣言内に %<inline%> があります"
 
 #: c/c-decl.c:4713
 #, fuzzy, gcc-internal-format
-#| msgid "%<inline%> in empty declaration"
 msgid "%<_Noreturn%> in empty declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
@@ -42247,7 +38951,6 @@ msgstr "空の宣言内に無意味な記憶域クラス指定があります"
 
 #: c/c-decl.c:4738
 #, fuzzy, gcc-internal-format
-#| msgid "useless type name in empty declaration"
 msgid "useless %qs in empty declaration"
 msgstr "空の宣言内に無意味な型名があります"
 
@@ -42258,7 +38961,6 @@ msgstr "空の宣言内に無意味な型修飾子があります"
 
 #: c/c-decl.c:4758
 #, fuzzy, gcc-internal-format
-#| msgid "useless %<__thread%> in empty declaration"
 msgid "useless %<_Alignas%> in empty declaration"
 msgstr "空の宣言内に無意味な %<__thread%> があります"
 
@@ -42297,7 +38999,6 @@ msgstr "%q+D は通常は関数です"
 
 #: c/c-decl.c:5031
 #, fuzzy, gcc-internal-format
-#| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
 msgstr "typedef %qD が初期化されました (代わりに __typeof__ を使用してください)"
 
@@ -42328,7 +39029,6 @@ msgstr "変数 %qD には初期化子がありますが不完全型です"
 
 #: c/c-decl.c:5156
 #, fuzzy, gcc-internal-format
-#| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %q+D given attribute %qs"
 msgstr "noinline 属性が与えられたインライン関数 %q+D です"
 
@@ -42364,7 +39064,6 @@ msgstr "%q+D の記憶域サイズが一定ではありません"
 
 #: c/c-decl.c:5437
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring asm-specifier for non-static local variable %q+D"
 msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
 msgstr "非静的変数 %q+D 用のアセンブラ指定を無視しています"
 
@@ -42375,7 +39074,6 @@ msgstr "volatile フィールドがあるオブジェクトをレジスタに配
 
 #: c/c-decl.c:5553
 #, fuzzy, gcc-internal-format
-#| msgid "uninitialized const %qD is invalid in C++"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
@@ -42421,7 +39119,6 @@ msgstr "ビットフィールド %qs が無効な型を持っています"
 
 #: c/c-decl.c:5806
 #, fuzzy, gcc-internal-format
-#| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
@@ -42442,13 +39139,11 @@ msgstr "%qs の幅はその型の値より狭いです"
 
 #: c/c-decl.c:5851
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
 msgstr "ISO C90 はサイズを評価できない配列 %qE を禁止しています"
 
 #: c/c-decl.c:5854
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size cannot be evaluated"
 msgstr "ISO C90 はサイズが評価できない配列を禁止しています"
 
@@ -42499,7 +39194,6 @@ msgstr "重複した %<volatile%> です"
 
 #: c/c-decl.c:6138
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "重複した %<restrict%> です"
 
@@ -42530,7 +39224,6 @@ msgstr "関数定義が %<typedef%> と宣言されています"
 
 #: c/c-decl.c:6184
 #, fuzzy, gcc-internal-format
-#| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "関数定義が %<auto%> と宣言されています"
 
@@ -42586,7 +39279,6 @@ msgstr "入れ子になった関数 %qE が %<extern%> と宣言されていま
 
 #: c/c-decl.c:6253
 #, fuzzy, gcc-internal-format
-#| msgid "function-scope %qE implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "関数スコープの %qE は暗黙的に auto となり %<__thread%> と宣言されます"
 
@@ -42635,13 +39327,11 @@ msgstr "無名配列のサイズが非整数型です"
 
 #: c/c-decl.c:6425
 #, fuzzy, gcc-internal-format
-#| msgid "size of array %qE has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "配列 %qE のサイズが非整数型です"
 
 #: c/c-decl.c:6428
 #, fuzzy, gcc-internal-format
-#| msgid "size of unnamed array has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "無名配列のサイズが非整数型です"
 
@@ -42688,7 +39378,6 @@ msgstr "宣言内にない %<[*]%> です"
 
 #: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
-#| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "配列の型が不完全要素型を持っています"
 
@@ -42735,7 +39424,6 @@ msgstr "関数戻り値の型修飾子は無視されました"
 #: c/c-decl.c:6826 c/c-decl.c:7036 c/c-decl.c:7090 c/c-decl.c:7174
 #: c/c-decl.c:7299 c/c-parser.c:3016
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
@@ -42781,55 +39469,46 @@ msgstr "%qs が構造体フィールド用に指定されています"
 
 #: c/c-decl.c:6980
 #, fuzzy, gcc-internal-format
-#| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
 #: c/c-decl.c:6982
 #, fuzzy, gcc-internal-format
-#| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
 #: c/c-decl.c:6991
 #, fuzzy, gcc-internal-format
-#| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
 #: c/c-decl.c:6993
 #, fuzzy, gcc-internal-format
-#| msgid "%qs specified for parameter %qE"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
 #: c/c-decl.c:6998
 #, fuzzy, gcc-internal-format
-#| msgid "%qs specified for parameter %qE"
 msgid "alignment specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
 #: c/c-decl.c:7000
 #, fuzzy, gcc-internal-format
-#| msgid "%qs specified for unnamed parameter"
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
 #: c/c-decl.c:7005
 #, fuzzy, gcc-internal-format
-#| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
 #: c/c-decl.c:7007
 #, fuzzy, gcc-internal-format
-#| msgid "%qs specified for unnamed parameter"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%qs が無名仮引数用に指定されました"
 
 #: c/c-decl.c:7010
 #, fuzzy, gcc-internal-format
-#| msgid "assignment of function %qD"
 msgid "alignment specified for function %qE"
 msgstr "関数 %qD への代入です"
 
@@ -42850,7 +39529,6 @@ msgstr "typedef %q+D が %<inline%> と宣言されています"
 
 #: c/c-decl.c:7053
 #, fuzzy, gcc-internal-format
-#| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
@@ -42882,7 +39560,6 @@ msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
 #: c/c-decl.c:7208
 #, fuzzy, gcc-internal-format
-#| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
@@ -42913,19 +39590,16 @@ msgstr "関数 %<main%> をインラインに出来ません"
 
 #: c/c-decl.c:7343
 #, fuzzy, gcc-internal-format
-#| msgid "%qE initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
 #: c/c-decl.c:7354
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
 #: c/c-decl.c:7357
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
@@ -42941,7 +39615,6 @@ msgstr "変数 %q+D が %<inline%> と宣言されています"
 
 #: c/c-decl.c:7398
 #, fuzzy, gcc-internal-format
-#| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
@@ -43112,13 +39785,11 @@ msgstr "構造体の最後ではない所に可変配列メンバがあります
 
 #: c/c-decl.c:8500
 #, fuzzy, gcc-internal-format
-#| msgid "flexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "共用体に可変配列メンバがあります"
 
 #: c/c-decl.c:8531
 #, fuzzy, gcc-internal-format
-#| msgid "size of array %qE is too large"
 msgid "type %qT is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
@@ -43140,7 +39811,6 @@ msgstr "%<enum %E%> の再定義です"
 
 #: c/c-decl.c:8862 cp/decl.c:15545
 #, fuzzy, gcc-internal-format
-#| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "指定したモードは列挙値用には小さすぎます"
 
@@ -43171,7 +39841,6 @@ msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
 #: c/c-decl.c:9159 cp/decl.c:5298 cp/decl.c:16104
 #, fuzzy, gcc-internal-format
-#| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
@@ -43187,7 +39856,6 @@ msgstr "戻り値の型をデフォルトの %<int%> にします"
 
 #: c/c-decl.c:9212
 #, fuzzy, gcc-internal-format
-#| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "プロトタイプ無しの大域関数に関して警告する"
 
@@ -43331,19 +39999,16 @@ msgstr "仮引数 %qD が設定されましたが使用されません"
 #. allow it.
 #: c/c-decl.c:10043
 #, fuzzy, gcc-internal-format
-#| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
 #: c/c-decl.c:10048
 #, fuzzy, gcc-internal-format
-#| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "オプション -std=c99 または -std=gnu99 をコードコンパイル時に使用してください"
 
 #: c/c-decl.c:10055
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
@@ -43384,7 +40049,6 @@ msgstr "互換性のないアドレス空間修飾子 %qs と %qs です"
 
 #: c/c-decl.c:10464 c/c-decl.c:10471
 #, fuzzy, gcc-internal-format
-#| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "宣言指定が予期されます"
 
@@ -43420,37 +40084,31 @@ msgstr "%qE が重複しています"
 
 #: c/c-decl.c:10930
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
 #: c/c-decl.c:10952
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
 #: c/c-decl.c:10995
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
 #: c/c-decl.c:11114
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
 #: c/c-decl.c:11164
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
 #: c/c-decl.c:11235
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C2X"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
@@ -43481,31 +40139,26 @@ msgstr "%qE は宣言の開始ではありません"
 
 #: c/c-decl.c:11379
 #, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
 #: c/c-decl.c:11381
 #, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
 #: c/c-decl.c:11383
 #, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
 #: c/c-decl.c:11397 c/c-parser.c:8374
 #, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s は %s をサポートしません"
 
 #: c/c-decl.c:11400 c/c-parser.c:8377
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
@@ -43531,7 +40184,6 @@ msgstr "宣言指定内に複数の記憶域クラスがあります"
 
 #: c/c-decl.c:11450
 #, fuzzy, gcc-internal-format
-#| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
@@ -43567,7 +40219,6 @@ msgstr ""
 
 #: c/c-fold.c:387 c/c-typeck.c:11920 cp/typeck.c:4964
 #, fuzzy, gcc-internal-format
-#| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左シフト回数が負です"
 
@@ -43593,13 +40244,11 @@ msgstr "右シフト回数 >= 型の幅となっています"
 
 #: c/c-fold.c:414 c/c-typeck.c:11940
 #, fuzzy, gcc-internal-format
-#| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左シフト回数 >= 型の幅となっています"
 
 #: c/c-fold.c:415 c/c-typeck.c:11869
 #, fuzzy, gcc-internal-format
-#| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
 msgstr "右シフト回数 >= 型の幅となっています"
 
@@ -43630,7 +40279,6 @@ msgstr ""
 
 #: c/c-parser.c:1633 cp/semantics.c:3059
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp declare target%> without corresponding %<#pragma omp end declare target%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
@@ -43656,7 +40304,6 @@ msgstr ""
 
 #: c/c-parser.c:1938 c/c-parser.c:4347
 #, fuzzy, gcc-internal-format
-#| msgid "unknown type name %qE"
 msgid "unknown type name %qE; did you mean %qs?"
 msgstr "不明な型名 %qE です"
 
@@ -43673,13 +40320,11 @@ msgstr "宣言指定が予期されます"
 
 #: c/c-parser.c:1979
 #, fuzzy, gcc-internal-format
-#| msgid "%<inline%> in empty declaration"
 msgid "%<__auto_type%> in empty declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
 #: c/c-parser.c:1993
 #, fuzzy, gcc-internal-format
-#| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute at top level"
 msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
 
@@ -43706,7 +40351,6 @@ msgstr "packed 属性は必要ありません"
 #: c/c-parser.c:2100 c/c-parser.c:5948 c/c-parser.c:6272 cp/parser.c:11508
 #: cp/parser.c:11715
 #, fuzzy, gcc-internal-format
-#| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
 
@@ -43730,13 +40374,11 @@ msgstr "大域 register 変数が関数定義の後ろにあります"
 
 #: c/c-parser.c:2191
 #, fuzzy, gcc-internal-format
-#| msgid "%<typeof%> applied to a bit-field"
 msgid "%<__auto_type%> used with a bit-field initializer"
 msgstr "%<typeof%> がビットフィールドに適用されています"
 
 #: c/c-parser.c:2266 c/c-parser.c:2389
 #, fuzzy, gcc-internal-format
-#| msgid "%<auto%> in file-scope empty declaration"
 msgid "%<__auto_type%> requires an initialized data declaration"
 msgstr "ファイルスコープの空の宣言内に %<auto%> があります"
 
@@ -43780,7 +40422,6 @@ msgstr "文字列リテラルが予期されます"
 
 #: c/c-parser.c:2620
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C11 does not support omitting the string in %<_Static_assert%>"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
@@ -43806,7 +40447,6 @@ msgstr "静的アサーションに失敗しました: %E"
 
 #: c/c-parser.c:2649 cp/semantics.c:9702
 #, fuzzy, gcc-internal-format
-#| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静的アサーションに失敗しました: %E"
 
@@ -43817,19 +40457,16 @@ msgstr ""
 
 #: c/c-parser.c:2988
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C99 does not support the %<_Atomic%> qualifier"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
 #: c/c-parser.c:2991
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<_Static_assert%>"
 msgid "ISO C90 does not support the %<_Atomic%> qualifier"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
 #: c/c-parser.c:3018
 #, fuzzy, gcc-internal-format
-#| msgid "%<typeof%> applied to a bit-field"
 msgid "%<_Atomic%> applied to a qualified type"
 msgstr "%<typeof%> がビットフィールドに適用されています"
 
@@ -43917,13 +40554,11 @@ msgstr "%<typeof%> がビットフィールドに適用されています"
 
 #: c/c-parser.c:3736
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Alignas%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
 #: c/c-parser.c:3739
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Alignas%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
@@ -43949,13 +40584,11 @@ msgstr ""
 
 #: c/c-parser.c:4903 cp/parser.c:26887
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not take any arguments"
 msgstr "%qE 属性は型に適用できません"
 
 #: c/c-parser.c:4955
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C does not support %<[[]]%> attributes before C2X"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
@@ -44106,26 +40739,22 @@ msgstr ""
 
 #: c/c-parser.c:7098 c/c-parser.c:7109 c/c-parser.c:7120
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %<volatile%>"
 msgid "duplicate %<asm%> qualifier %qE"
 msgstr "重複した %<volatile%> です"
 
 #: c/c-parser.c:7099 c/c-parser.c:7110 c/c-parser.c:7121 cp/parser.c:20219
 #: cp/parser.c:20236 cp/parser.c:20250
 #, fuzzy, gcc-internal-format
-#| msgid "struct defined here"
 msgid "first seen here"
 msgstr "構造体がここで定義されています"
 
 #: c/c-parser.c:7130
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a valid %<asm%> qualifier"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-parser.c:7180
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<,%> or %<)%>"
 msgid "expected %<:%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
 
@@ -44136,7 +40765,6 @@ msgstr ""
 
 #: c/c-parser.c:7669
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids omitting the middle term of a ?: expression"
 msgid "ISO C forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C は中間項が省略された ?: 式を禁じます"
 
@@ -44149,13 +40777,11 @@ msgstr ""
 
 #: c/c-parser.c:7883 cp/typeck.c:4752
 #, fuzzy, gcc-internal-format
-#| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
 msgstr "フィールドの型はここで宣言されました"
 
 #: c/c-parser.c:8101
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
 msgid "alignment specified for type name in cast"
 msgstr "型名用に記憶域クラスが指定されました"
 
@@ -44166,7 +40792,6 @@ msgstr "伝統的な C では単項プラス演算子を拒否します"
 
 #: c/c-parser.c:8331
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
 msgid "alignment specified for type name in %<sizeof%>"
 msgstr "型名用に記憶域クラスが指定されました"
 
@@ -44177,7 +40802,6 @@ msgstr "%<sizeof%> がビットフィールドに適用されています"
 
 #: c/c-parser.c:8417
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
 msgid "alignment specified for type name in %qE"
 msgstr "型名用に記憶域クラスが指定されました"
 
@@ -44188,31 +40812,26 @@ msgstr "ISO C++ は名前つき戻り値を許可しません"
 
 #: c/c-parser.c:8588
 #, fuzzy, gcc-internal-format
-#| msgid "cannot take address of bit-field %qD"
 msgid "cannot take address of %qs"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
 #: c/c-parser.c:8671
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C99 does not support %<_Generic%>"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
 #: c/c-parser.c:8674
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<_Static_assert%>"
 msgid "ISO C90 does not support %<_Generic%>"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
 #: c/c-parser.c:8742
 #, fuzzy, gcc-internal-format
-#| msgid "cast specifies function type"
 msgid "%<_Generic%> association has function type"
 msgstr "キャストは関数型を指定しています"
 
 #: c/c-parser.c:8745
 #, fuzzy, gcc-internal-format
-#| msgid "expression statement has incomplete type"
 msgid "%<_Generic%> association has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
@@ -44228,7 +40847,6 @@ msgstr ""
 
 #: c/c-parser.c:8774
 #, fuzzy, gcc-internal-format
-#| msgid "originally defined here"
 msgid "original %<default%> is here"
 msgstr "元々はここで定義されました"
 
@@ -44239,13 +40857,11 @@ msgstr ""
 
 #: c/c-parser.c:8783
 #, fuzzy, gcc-internal-format
-#| msgid "incompatible types in PHI argument %u"
 msgid "compatible type is here"
 msgstr "PHI 引数 %u 内で互換性のない型です"
 
 #: c/c-parser.c:8806
 #, fuzzy, gcc-internal-format
-#| msgid "Generate load/store multiple instructions"
 msgid "%<_Generic%> selector matches multiple associations"
 msgstr "複数命令のロード/ストアを生成する"
 
@@ -44261,37 +40877,31 @@ msgstr ""
 
 #: c/c-parser.c:8848
 #, fuzzy, gcc-internal-format
-#| msgid "first argument to %<__builtin_choose_expr%> not a constant"
 msgid "argument %u of %<__builtin_tgmath%> is not a function pointer"
 msgstr "%<__builtin_choose_expr%> の第一引数が定数ではありません"
 
 #: c/c-parser.c:8856
 #, fuzzy, gcc-internal-format
-#| msgid "argument %qD doesn%'t match prototype"
 msgid "argument %u of %<__builtin_tgmath%> is unprototyped"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
 #: c/c-parser.c:8862
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %<__builtin_eh_return_regno%> must be constant"
 msgid "argument %u of %<__builtin_tgmath%> has variable arguments"
 msgstr "%<__builtin_eh_return_regno%> の引数は定数でなければいけません"
 
 #: c/c-parser.c:8878
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %<__builtin_eh_return_regno%> must be constant"
 msgid "argument %u of %<__builtin_tgmath%> has no arguments"
 msgstr "%<__builtin_eh_return_regno%> の引数は定数でなければいけません"
 
 #: c/c-parser.c:8901 c/c-parser.c:8905
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %qs predefined identifier"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
 #: c/c-parser.c:8909
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C90 does not support %<__func__%> predefined identifier"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
@@ -44313,7 +40923,6 @@ msgstr "ISO C は式内を中括弧で括ることを禁止しています"
 
 #: c/c-parser.c:9305
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
@@ -44324,13 +40933,11 @@ msgstr "%<__builtin_choose_expr%> の第一引数が定数ではありません"
 
 #: c/c-parser.c:9391 c/c-parser.c:9408 c/c-parser.c:9415
 #, fuzzy, gcc-internal-format
-#| msgid "too few arguments to function %<va_start%>"
 msgid "too few arguments to %<__builtin_tgmath%>"
 msgstr "関数 %<va_start%> への引数が少なすぎます"
 
 #: c/c-parser.c:9436
 #, fuzzy, gcc-internal-format
-#| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %u of %<__builtin_tgmath%> has wrong number of arguments"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
@@ -44346,7 +40953,6 @@ msgstr ""
 
 #: c/c-parser.c:9555
 #, fuzzy, gcc-internal-format
-#| msgid "second argument to %<__builtin_prefetch%> must be a constant"
 msgid "function arguments of %<__builtin_tgmath%> all have the same type"
 msgstr "%<__builtin_prefetch%> への第二引数は定数でなければいけません"
 
@@ -44367,7 +40973,6 @@ msgstr ""
 
 #: c/c-parser.c:9662
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "bad type for argument %u of function argument %u of %<__builtin_tgmath%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
@@ -44378,25 +40983,21 @@ msgstr "関数 `%s' に対して不適切な保存クラス"
 
 #: c/c-parser.c:9711
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "non-floating-point argument in call to function %qE"
 msgid "decimal floating-point argument %u to complex-only type-generic function"
 msgstr "関数 %qE の呼び出し内に非浮動小数点引数があります"
 
 #: c/c-parser.c:9719
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "non-floating-point argument in call to function %qE"
 msgid "decimal floating-point argument %u to binary-only type-generic function"
 msgstr "関数 %qE の呼び出し内に非浮動小数点引数があります"
 
 #: c/c-parser.c:9727 c/c-parser.c:9757
 #, fuzzy, gcc-internal-format
-#| msgid "non-floating-point arguments in call to function %qE"
 msgid "both complex and decimal floating-point arguments to type-generic function"
 msgstr "関数 %qE の呼び出し内に非浮動小数点引数があります"
 
 #: c/c-parser.c:9735 c/c-parser.c:9777
 #, fuzzy, gcc-internal-format
-#| msgid "non-floating-point arguments in call to function %qE"
 msgid "both binary and decimal floating-point arguments to type-generic function"
 msgstr "関数 %qE の呼び出し内に非浮動小数点引数があります"
 
@@ -44407,37 +41008,31 @@ msgstr "引数は複素数型でなければいけません"
 
 #: c/c-parser.c:9769
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid argument to built-in function"
 msgid "binary argument %u to decimal-only type-generic function"
 msgstr "組み込み関数への無効な引数です"
 
 #: c/c-parser.c:9875
 #, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for type-generic call"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
 #: c/c-parser.c:9916
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_call_with_static_chain%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
 #: c/c-parser.c:9929
 #, fuzzy, gcc-internal-format
-#| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "first argument to %<__builtin_call_with_static_chain%> must be a call expression"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
 #: c/c-parser.c:9933
 #, fuzzy, gcc-internal-format
-#| msgid "second argument to %<__builtin_prefetch%> must be a constant"
 msgid "second argument to %<__builtin_call_with_static_chain%> must be a pointer type"
 msgstr "%<__builtin_prefetch%> への第二引数は定数でなければいけません"
 
 #: c/c-parser.c:9959
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_complex%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
@@ -44448,13 +41043,11 @@ msgstr ""
 
 #: c/c-parser.c:9990
 #, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_longjmp%> second argument must be 1"
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
 #: c/c-parser.c:10035 cp/parser.c:7127
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
@@ -44490,7 +41083,6 @@ msgstr ""
 
 #: c/c-parser.c:10323
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect"
 msgid "taking the absolute value of unsigned type %qT has no effect"
 msgstr "%qE 属性は効果がありません"
 
@@ -44615,19 +41207,16 @@ msgstr ""
 #: cp/parser.c:43690 cp/parser.c:43706 cp/parser.c:43722 cp/parser.c:43749
 #: cp/parser.c:43762 cp/parser.c:43785 cp/parser.c:43798
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
 #: c/c-parser.c:12314 cp/parser.c:43775
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
 #: c/c-parser.c:12401 cp/parser.c:43868
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
@@ -44638,13 +41227,11 @@ msgstr ""
 
 #: c/c-parser.c:12421
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma omp requires%> may only be used at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
 #: c/c-parser.c:12443 c/c-parser.c:12467 cp/parser.c:43903 cp/parser.c:43936
 #, fuzzy, gcc-internal-format
-#| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
@@ -44661,13 +41248,11 @@ msgstr "%qs 句が多すぎます"
 
 #: c/c-parser.c:12844
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
 #: c/c-parser.c:13088 c/c-parser.c:13100
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<,%> or %<)%>"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<,%> または %<)%> が予期されます"
 
@@ -44678,7 +41263,6 @@ msgstr "%qD は変数ではありません"
 
 #: c/c-parser.c:13255 cp/semantics.c:7482
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
@@ -44689,7 +41273,6 @@ msgstr ""
 
 #: c/c-parser.c:13374 cp/parser.c:34934
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
@@ -44700,14 +41283,12 @@ msgstr "%<none%> または %<shared%> が予期されます"
 
 #: c/c-parser.c:13496 cp/parser.c:35047
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:13516 c/c-parser.c:19510 c/c-parser.c:19594 cp/parser.c:35065
 #: cp/parser.c:40436 cp/parser.c:40524
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
@@ -44718,13 +41299,11 @@ msgstr ""
 
 #: c/c-parser.c:13576 cp/parser.c:35127
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
 #: c/c-parser.c:13578 cp/parser.c:35129
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
@@ -44747,67 +41326,56 @@ msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:13746
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:13792 cp/semantics.c:7685
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:13839 cp/semantics.c:7715
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:13875
 #, fuzzy, gcc-internal-format
-#| msgid "expected integer expression"
 msgid "expected constant integer expression"
 msgstr "整数式が予期されます"
 
 #: c/c-parser.c:13914 cp/parser.c:35360
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:13975 cp/parser.c:35425
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
 #: c/c-parser.c:14041 cp/parser.c:35494
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%qs 句が多すぎます"
 
 #: c/c-parser.c:14044 cp/parser.c:35497
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "%qs 句が多すぎます"
 
 #: c/c-parser.c:14118 cp/semantics.c:6836
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%qs expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
 #: c/c-parser.c:14130 c/c-parser.c:14253 cp/semantics.c:6868
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:14192 cp/parser.c:34642
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
@@ -44818,31 +41386,26 @@ msgstr "packed 属性は必要ありません"
 
 #: c/c-parser.c:14393 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: c/c-parser.c:14451 c/c-parser.c:14457 cp/parser.c:35529 cp/parser.c:35539
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<using%>"
 msgid "expected %<concurrent%>"
 msgstr "%<using%> が予期されます"
 
 #: c/c-parser.c:14491 cp/parser.c:35577
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
 #: c/c-parser.c:14544 cp/parser.c:35645
 #, fuzzy, gcc-internal-format
-#| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
 #: c/c-parser.c:14669 c/c-parser.c:20764 cp/parser.c:42372
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
@@ -44863,7 +41426,6 @@ msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりませ
 
 #: c/c-parser.c:14852 cp/semantics.c:6903
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
@@ -44874,13 +41436,11 @@ msgstr "`無効なスケジュールの種類です"
 
 #: c/c-parser.c:14996
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:15041 cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
@@ -44906,43 +41466,36 @@ msgstr ""
 
 #: c/c-parser.c:15506 cp/parser.c:36577
 #, fuzzy, gcc-internal-format
-#| msgid "RTP PIC is incompatible with Thumb"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "RTP PIC は Thumb では使用できません"
 
 #: c/c-parser.c:15553 cp/parser.c:36625 cp/parser.c:36854 cp/parser.c:36904
 #, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
 #: c/c-parser.c:15640 cp/parser.c:36700
 #, fuzzy, gcc-internal-format
-#| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
 #: c/c-parser.c:15738 cp/parser.c:36801
 #, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
 msgstr "`無効なスケジュールの種類です"
 
 #: c/c-parser.c:15814
 #, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind"
 msgid "invalid proc_bind kind"
 msgstr "`無効なスケジュールの種類です"
 
 #: c/c-parser.c:15858
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:16082 cp/parser.c:37135
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
@@ -44958,7 +41511,6 @@ msgstr ""
 
 #: c/c-parser.c:16278 cp/parser.c:37371
 #, fuzzy, gcc-internal-format
-#| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
@@ -44984,13 +41536,11 @@ msgstr ""
 
 #: c/c-parser.c:16580 cp/parser.c:40992
 #, fuzzy, gcc-internal-format
-#| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
 #: c/c-parser.c:16587 cp/parser.c:40999
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
@@ -45011,7 +41561,6 @@ msgstr ""
 
 #: c/c-parser.c:16709 cp/parser.c:41122
 #, fuzzy, gcc-internal-format
-#| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
@@ -45027,7 +41576,6 @@ msgstr ""
 
 #: c/c-parser.c:16978
 #, fuzzy, gcc-internal-format
-#| msgid "expected function"
 msgid "expected function name"
 msgstr "関数が予期されます"
 
@@ -45053,7 +41601,6 @@ msgstr ""
 
 #: c/c-parser.c:17091 cp/parser.c:43086
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
@@ -45064,19 +41611,16 @@ msgstr ""
 
 #: c/c-parser.c:17287 cp/parser.c:37676
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
 #: c/c-parser.c:17296 cp/parser.c:37685
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "%qs 句が多すぎます"
 
 #: c/c-parser.c:17303 cp/parser.c:37692
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "%qs 句が多すぎます"
 
@@ -45097,7 +41641,6 @@ msgstr ""
 
 #: c/c-parser.c:17642 cp/parser.c:37970 cp/parser.c:37996
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
@@ -45123,19 +41666,16 @@ msgstr "初期化子の要素が定数式ではありません"
 
 #: c/c-parser.c:17861 cp/parser.c:38228
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%> or %<mutexinoutset%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:17873 cp/parser.c:38244
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:17909 cp/parser.c:38277
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
@@ -45146,13 +41686,11 @@ msgstr ""
 
 #: c/c-parser.c:17975 cp/parser.c:38889
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<none%> または %<shared%> が予期されます"
 
 #: c/c-parser.c:17980 cp/parser.c:38895
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp%> 句が予期されます"
 
@@ -45193,25 +41731,21 @@ msgstr ""
 
 #: c/c-parser.c:18465 cp/parser.c:39418
 #, fuzzy, gcc-internal-format
-#| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
 #: c/c-parser.c:18678 cp/parser.c:39635
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
 #: c/c-parser.c:18886 cp/parser.c:39834
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
 #: c/c-parser.c:19158 cp/parser.c:40105
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
@@ -45257,19 +41791,16 @@ msgstr ""
 
 #: c/c-parser.c:19917
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
 #: c/c-parser.c:19968 c/c-parser.c:19996
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
 #: c/c-parser.c:20035 cp/parser.c:41491
 #, fuzzy, gcc-internal-format
-#| msgid "expected class name"
 msgid "expected trait selector name"
 msgstr "クラス名が予期されます"
 
@@ -45280,37 +41811,31 @@ msgstr ""
 
 #: c/c-parser.c:20113 cp/parser.c:41567
 #, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 2 arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%s は 2 この引数のみ受け付けます"
 
 #: c/c-parser.c:20140 cp/parser.c:41606 cp/pt.c:11339
 #, fuzzy, gcc-internal-format
-#| msgid "ordered comparison of pointer with integer zero"
 msgid "score argument must be constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
 #: c/c-parser.c:20143 cp/parser.c:41609 cp/pt.c:11356
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "score argument must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: c/c-parser.c:20167 cp/parser.c:41637 cp/pt.c:11342
 #, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
 #: c/c-parser.c:20212 cp/parser.c:41681
 #, fuzzy, gcc-internal-format
-#| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "文字列リテラルが予期されます"
 
 #: c/c-parser.c:20234 cp/parser.c:41703 cp/pt.c:11346
 #, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
 msgid "property must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
@@ -45321,13 +41846,11 @@ msgstr ""
 
 #: c/c-parser.c:20332 cp/parser.c:41800
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:20407 cp/parser.c:41908
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<catch%>"
 msgid "expected %<match%>"
 msgstr "%<catch%> が予期されます"
 
@@ -45338,7 +41861,6 @@ msgstr "呼び出されたオブジェクトは関数ではありません"
 
 #: c/c-parser.c:20433 cp/decl.c:7312
 #, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s と -msdata=%s は併用できません"
 
@@ -45349,13 +41871,11 @@ msgstr ""
 
 #: c/c-parser.c:20488
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
 #: c/c-parser.c:20496 cp/parser.c:41953
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
@@ -45371,19 +41891,16 @@ msgstr ""
 
 #: c/c-parser.c:20673 cp/parser.c:42132
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
 #: c/c-parser.c:20680 cp/parser.c:42139
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
 #: c/c-parser.c:20686 cp/parser.c:42146
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
@@ -45424,13 +41941,11 @@ msgstr "前方での `%s' の宣言"
 
 #: c/c-parser.c:20935
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
 #: c/c-parser.c:20946
 #, fuzzy, gcc-internal-format
-#| msgid "expected function"
 msgid "expected function-name %<(%>"
 msgstr "関数が予期されます"
 
@@ -45441,13 +41956,11 @@ msgstr ""
 
 #: c/c-parser.c:21096 cp/parser.c:42606
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
 #: c/c-parser.c:21160 cp/parser.c:42669
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
@@ -45458,7 +41971,6 @@ msgstr ""
 
 #: c/c-parser.c:21189 cp/parser.c:42704
 #, fuzzy, gcc-internal-format
-#| msgid "switch %qs is no longer supported"
 msgid "%qs clause on %<requires%> directive not supported yet"
 msgstr "%qs スイッチは既にサポートされていません"
 
@@ -45484,13 +41996,11 @@ msgstr ""
 
 #: c/c-parser.c:21255
 #, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
 #: c/c-parser.c:21261
 #, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
@@ -45536,7 +42046,6 @@ msgstr ""
 
 #: c/c-typeck.c:224
 #, fuzzy, gcc-internal-format
-#| msgid "%qD has an incomplete type"
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD は不完全型を持っています"
 
@@ -45557,14 +42066,12 @@ msgstr "境界が指定されていない配列の無効な使用法です"
 
 #: c/c-typeck.c:260
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of undefined type %qT"
 msgstr "未定義の型 %<%s %E%> の無効な使用法です"
 
 #. If this type has a typedef-name, the TYPE_NAME is a TYPE_DECL.
 #: c/c-typeck.c:263
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of incomplete typedef %qD"
 msgid "invalid use of incomplete typedef %qT"
 msgstr "不完全な typedef %qD の無効な使用法です"
 
@@ -45575,7 +42082,6 @@ msgstr ""
 
 #: c/c-typeck.c:371
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute cannot be applied to a function that does not take variable arguments"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
@@ -45586,25 +42092,21 @@ msgstr "関数型が ISO C と完全互換ではありません"
 
 #: c/c-typeck.c:767
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t mix operands of decimal float and vector types"
 msgid "cannot mix operands of decimal floating and vector types"
 msgstr "十進浮動小数型とベクトル型の被演算子を混ぜることは出来ません"
 
 #: c/c-typeck.c:772
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t mix operands of decimal float and complex types"
 msgid "cannot mix operands of decimal floating and complex types"
 msgstr "十進浮動小数型と複素数型の被演算子を混ぜることは出来ません"
 
 #: c/c-typeck.c:777
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t mix operands of decimal float and other float types"
 msgid "cannot mix operands of decimal floating and other floating types"
 msgstr "十進浮動小数型と他の浮動小数型の被演算子を混ぜることは出来ません"
 
 #: c/c-typeck.c:1318
 #, fuzzy, gcc-internal-format
-#| msgid "pointer target types incompatible in C++"
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
 msgstr "ポインタターゲット型は C++ では互換性がありません"
 
@@ -45625,13 +42127,11 @@ msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
 #: c/c-typeck.c:1917
 #, fuzzy, gcc-internal-format
-#| msgid "defining a type in a compound literal is invalid in C++"
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "複合リテラル内での型定義は C++ では無効です"
 
 #: c/c-typeck.c:2447 c/c-typeck.c:9045
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
@@ -45702,19 +42202,16 @@ msgstr ""
 
 #: c/c-typeck.c:3078
 #, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
 msgid "called object %qE is not a function or function pointer"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
 #: c/c-typeck.c:3083
 #, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
 msgid "called object %qD is not a function or function pointer"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
 #: c/c-typeck.c:3089
 #, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
 msgid "called object is not a function or function pointer"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
@@ -45798,7 +42295,6 @@ msgstr "メソッド %qE への引数が多すぎます"
 
 #: c/c-typeck.c:3532
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments to function %qE"
 msgid "too many arguments to built-in function %qE expecting %d"
 msgstr "関数 %qE への引数が多すぎます"
 
@@ -45809,7 +42305,6 @@ msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換
 
 #: c/c-typeck.c:3672
 #, fuzzy, gcc-internal-format
-#| msgid "too few arguments to function %qE"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
@@ -45820,7 +42315,6 @@ msgstr "文字列リテラルの比較結果は不定です"
 
 #: c/c-typeck.c:3855 c/c-typeck.c:3866 cp/typeck.c:5037 cp/typeck.c:5061
 #, fuzzy, gcc-internal-format
-#| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "ポインタと整数との比較を行なっています"
 
@@ -45851,13 +42345,11 @@ msgstr "不完全型へのポインタに関する計算です"
 
 #: c/c-typeck.c:3987 cp/typeck.c:5965
 #, fuzzy, gcc-internal-format
-#| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "不完全型へのポインタに関する計算です"
 
 #: c/c-typeck.c:4420
 #, fuzzy, gcc-internal-format
-#| msgid "expected boolean expression"
 msgid "%<~%> on a boolean expression"
 msgstr "真偽式が予期されます"
 
@@ -45873,7 +42365,6 @@ msgstr "ISO C は複素共役用の `~' を受け付けません"
 
 #: c/c-typeck.c:4458
 #, fuzzy, gcc-internal-format
-#| msgid "wrong type argument to abs"
 msgid "wrong type argument to absu"
 msgstr "abs への引数の型が間違っています"
 
@@ -45894,13 +42385,11 @@ msgstr "列挙値の減分は C++ では無効です"
 
 #: c/c-typeck.c:4551
 #, fuzzy, gcc-internal-format
-#| msgid "expected boolean expression"
 msgid "increment of a boolean expression"
 msgstr "真偽式が予期されます"
 
 #: c/c-typeck.c:4554
 #, fuzzy, gcc-internal-format
-#| msgid "expected boolean expression"
 msgid "decrement of a boolean expression"
 msgstr "真偽式が予期されます"
 
@@ -45946,7 +42435,6 @@ msgstr "`this' は右辺値式であり、そのアドレスを取ることは
 
 #: c/c-typeck.c:4809
 #, fuzzy, gcc-internal-format
-#| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "レジスタ変数 %qD のアドレスが要求されました"
 
@@ -45997,7 +42485,6 @@ msgstr ""
 
 #: c/c-typeck.c:5335 c/c-typeck.c:5352
 #, fuzzy, gcc-internal-format
-#| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
@@ -46008,7 +42495,6 @@ msgstr "ISO C は %<void *%> と関数ポインタ間の比較式を禁止して
 
 #: c/c-typeck.c:5370
 #, fuzzy, gcc-internal-format
-#| msgid "pointer type mismatch in conditional expression"
 msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
@@ -46034,7 +42520,6 @@ msgstr "カンマ演算子の左側の式に効力がありません"
 
 #: c/c-typeck.c:5551 c/c-typeck.c:11110
 #, fuzzy, gcc-internal-format
-#| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
@@ -46123,7 +42608,6 @@ msgstr "ISO C はオブジェクトのポインタから関数のポインタ型
 
 #: c/c-typeck.c:5929
 #, fuzzy, gcc-internal-format
-#| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "不完全型 %qT から %qT へ変換できません"
 
@@ -46134,7 +42618,6 @@ msgstr "キャスト内での型定義は C++ 内では無効です"
 
 #: c/c-typeck.c:6065
 #, fuzzy, gcc-internal-format
-#| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "代入の抑制"
 
@@ -46170,7 +42653,6 @@ msgstr ""
 
 #: c/c-typeck.c:6543
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "built-in %qD declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -46181,25 +42663,21 @@ msgstr "%d 番目の %qE の引数を渡すときの列挙型の変換は C++ 
 
 #: c/c-typeck.c:6751
 #, fuzzy, gcc-internal-format
-#| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "代入内での列挙型の変換は C++ 内では無効です"
 
 #: c/c-typeck.c:6755
 #, fuzzy, gcc-internal-format
-#| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "初期化内での列挙型の変換は C++ では無効です"
 
 #: c/c-typeck.c:6760
 #, fuzzy, gcc-internal-format
-#| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "return 内での列挙型の変換は C++ では無効です"
 
 #: c/c-typeck.c:6778
 #, fuzzy, gcc-internal-format
-#| msgid "conversion from %q#T to %q#T"
 msgid "implicit conversion from %qT to %qT"
 msgstr "%q#T から %q#T への変換です"
 
@@ -46312,19 +42790,16 @@ msgstr "%d 番目の %qE の引数を渡すときのポインタの先の符号
 
 #: c/c-typeck.c:7246
 #, fuzzy, gcc-internal-format
-#| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "代入でのポインタの先の符号が異なります"
 
 #: c/c-typeck.c:7251
 #, fuzzy, gcc-internal-format
-#| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初期化でのポインタの先の符号が異なります"
 
 #: c/c-typeck.c:7256
 #, fuzzy, gcc-internal-format
-#| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "%d 番目の %qE の引数を渡すときのポインタの先の符号が異なります"
 
@@ -46335,37 +42810,31 @@ msgstr "互換性のないポインタ型から %d 番目の %qE の引数に渡
 
 #: c/c-typeck.c:7306
 #, fuzzy, gcc-internal-format
-#| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
 msgstr "互換性のないポインタ型からの代入です"
 
 #: c/c-typeck.c:7311
 #, fuzzy, gcc-internal-format
-#| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "互換性のないポインタ型からの代入です"
 
 #: c/c-typeck.c:7317
 #, fuzzy, gcc-internal-format
-#| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
 #: c/c-typeck.c:7322
 #, fuzzy, gcc-internal-format
-#| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
 #: c/c-typeck.c:7329
 #, fuzzy, gcc-internal-format
-#| msgid "return from incompatible pointer type"
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
 msgstr "互換性のないポインタ型からの戻りです"
 
 #: c/c-typeck.c:7334
 #, fuzzy, gcc-internal-format
-#| msgid "return from incompatible pointer type"
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "互換性のないポインタ型からの戻りです"
 
@@ -46376,19 +42845,16 @@ msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無
 
 #: c/c-typeck.c:7380
 #, fuzzy, gcc-internal-format
-#| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "代入で整数からキャスト無しにポインタを作成しています"
 
 #: c/c-typeck.c:7385
 #, fuzzy, gcc-internal-format
-#| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初期化で整数からキャスト無しにポインタを作成しています"
 
 #: c/c-typeck.c:7389
 #, fuzzy, gcc-internal-format
-#| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
@@ -46399,19 +42865,16 @@ msgstr "passing argument %d 番目の %qE の引数を渡すときにポイン
 
 #: c/c-typeck.c:7416
 #, fuzzy, gcc-internal-format
-#| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "代入でポインタからキャスト無しに整数を作成しています"
 
 #: c/c-typeck.c:7421
 #, fuzzy, gcc-internal-format
-#| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初期化でポインタからキャスト無しに整数を作成しています"
 
 #: c/c-typeck.c:7425
 #, fuzzy, gcc-internal-format
-#| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
@@ -46447,7 +42910,6 @@ msgstr "可変配列メンバを初期化しています"
 
 #: c/c-typeck.c:7804 cp/typeck2.c:1196
 #, fuzzy, gcc-internal-format
-#| msgid "initialization from incompatible pointer type"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
@@ -46584,7 +43046,6 @@ msgstr "初期化内での列挙型の変換は C++ では無効です"
 
 #: c/c-typeck.c:9952
 #, fuzzy, gcc-internal-format
-#| msgid "excess elements in char array initializer"
 msgid "excess elements in %<char%> array initializer"
 msgstr "char 配列初期化子内の要素が多すぎます"
 
@@ -46655,7 +43116,6 @@ msgstr "ISO C は void を戻す関数内で、式をがある %<return%> を禁
 
 #: c/c-typeck.c:10705
 #, fuzzy, gcc-internal-format
-#| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "関数が局所変数のアドレスを返します"
 
@@ -46701,13 +43161,11 @@ msgstr "OpenMP のループ用に break 文が使用されています"
 
 #: c/c-typeck.c:11064
 #, fuzzy, gcc-internal-format
-#| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "ループまたは switch 文の外にある break 文です"
 
 #: c/c-typeck.c:11066
 #, fuzzy, gcc-internal-format
-#| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "ループの外にある continue 文です"
 
@@ -46723,13 +43181,11 @@ msgstr "式の中の文に不完全型があります"
 
 #: c/c-typeck.c:11970 c/c-typeck.c:12138 cp/typeck.c:5293
 #, fuzzy, gcc-internal-format
-#| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
 #: c/c-typeck.c:11978 c/c-typeck.c:12146 cp/typeck.c:5306
 #, fuzzy, gcc-internal-format
-#| msgid "different number of results"
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
@@ -46740,7 +43196,6 @@ msgstr ""
 
 #: c/c-typeck.c:12017 cp/typeck.c:4999
 #, fuzzy, gcc-internal-format
-#| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "浮動小数点の比較で == や != を使うのは安全ではありません"
 
@@ -46817,7 +43272,6 @@ msgstr "スカラーが必要な場所で共用体型の値が使用されてい
 
 #: c/c-typeck.c:12650
 #, fuzzy, gcc-internal-format
-#| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
@@ -46829,7 +43283,6 @@ msgstr ""
 #: c/c-typeck.c:12851 c/c-typeck.c:12861 cp/semantics.c:9497
 #: cp/semantics.c:9507
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%qs 句が多すぎます"
 
@@ -46840,7 +43293,6 @@ msgstr ""
 
 #: c/c-typeck.c:12940 c/c-typeck.c:14498 c/c-typeck.c:14585 c/c-typeck.c:14656
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%qs 句が多すぎます"
 
@@ -46869,13 +43321,11 @@ msgstr "インスタンス変数 `%s' は %s と宣言されています"
 #: c/c-typeck.c:12984 c/c-typeck.c:14621 cp/semantics.c:4796
 #: cp/semantics.c:7434
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-typeck.c:12991
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%qs 句が多すぎます"
 
@@ -46887,13 +43337,11 @@ msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
 #: c/c-typeck.c:13036 cp/semantics.c:4848
 #, fuzzy, gcc-internal-format
-#| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
 #: c/c-typeck.c:13043 cp/semantics.c:4855
 #, fuzzy, gcc-internal-format
-#| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
@@ -46921,7 +43369,6 @@ msgstr ""
 #: c/c-typeck.c:13119 c/c-typeck.c:13235 cp/semantics.c:4941
 #: cp/semantics.c:5057
 #, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
@@ -46953,31 +43400,26 @@ msgstr ""
 
 #: c/c-typeck.c:13253 cp/semantics.c:5075
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
 #: c/c-typeck.c:13643 cp/semantics.c:6148
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
 #: c/c-typeck.c:13650
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids qualified function types"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
 #: c/c-typeck.c:13656 cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
-#| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
 #: c/c-typeck.c:13669 cp/semantics.c:6171
 #, fuzzy, gcc-internal-format
-#| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "非整数型のビットフィールド %qD です"
 
@@ -46993,13 +43435,11 @@ msgstr ""
 
 #: c/c-typeck.c:13723 cp/semantics.c:6241
 #, fuzzy, gcc-internal-format
-#| msgid "increment of read-only variable %qD"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
 #: c/c-typeck.c:13729 cp/semantics.c:6247
 #, fuzzy, gcc-internal-format
-#| msgid "increment of read-only variable %qD"
 msgid "end expression refers to outer iterator %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
@@ -47010,7 +43450,6 @@ msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
 #: c/c-typeck.c:13772 cp/semantics.c:6301
 #, fuzzy, gcc-internal-format
-#| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "ポインタが予期されます"
 
@@ -47041,7 +43480,6 @@ msgstr "セクション属性は `%s' には使えません"
 
 #: c/c-typeck.c:13947
 #, fuzzy, gcc-internal-format
-#| msgid "variable length array %qE is used"
 msgid "variable sized type %qT in %qs clause"
 msgstr "可変長配列 %qE が使用されています"
 
@@ -47057,7 +43495,6 @@ msgstr ""
 
 #: c/c-typeck.c:14094
 #, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
@@ -47099,7 +43536,6 @@ msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-typeck.c:14218 cp/semantics.c:6610
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -47122,7 +43558,6 @@ msgstr ""
 #: cp/semantics.c:6634 cp/semantics.c:6698 cp/semantics.c:7502
 #: cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -47138,13 +43573,11 @@ msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
 #: c/c-typeck.c:14306 cp/semantics.c:7070
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-typeck.c:14313
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
@@ -47155,19 +43588,16 @@ msgstr ""
 
 #: c/c-typeck.c:14327
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
 #: c/c-typeck.c:14340 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-typeck.c:14346
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -47178,7 +43608,6 @@ msgstr ""
 
 #: c/c-typeck.c:14422 cp/semantics.c:7217
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not lvalue expression nor array section in %<depend%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
@@ -47200,20 +43629,17 @@ msgstr ""
 #: c/c-typeck.c:14515 c/c-typeck.c:14687 cp/semantics.c:7313
 #: cp/semantics.c:7514
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
 #: c/c-typeck.c:14523 c/c-typeck.c:14693 cp/semantics.c:7321
 #: cp/semantics.c:7520
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
 #: c/c-typeck.c:14578 cp/semantics.c:7391
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
@@ -47225,13 +43651,11 @@ msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
 #: c/c-typeck.c:14726 cp/semantics.c:7607
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-typeck.c:14754 cp/semantics.c:7637
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -47242,19 +43666,16 @@ msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
 #: c/c-typeck.c:14771 cp/semantics.c:7656
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
 #: c/c-typeck.c:14788
 #, fuzzy, gcc-internal-format
-#| msgid "source is not a pointer"
 msgid "%qs variable is not a pointer"
 msgstr "ソースはポインタではありません"
 
 #: c/c-typeck.c:14795
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
@@ -47311,7 +43732,6 @@ msgstr ""
 
 #: c/c-typeck.c:15250
 #, fuzzy, gcc-internal-format
-#| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%> の第一引数が %<va_list%> 型ではありません"
 
@@ -47322,19 +43742,16 @@ msgstr ""
 
 #: c/gimple-parser.c:166
 #, fuzzy, gcc-internal-format
-#| msgid "expected function"
 msgid "expected frequency quality"
 msgstr "関数が予期されます"
 
 #: c/gimple-parser.c:175
 #, fuzzy, gcc-internal-format
-#| msgid "unknown type name %qE"
 msgid "unknown profile quality"
 msgstr "不明な型名 %qE です"
 
 #: c/gimple-parser.c:187
 #, fuzzy, gcc-internal-format
-#| msgid "expected function"
 msgid "expected frequency value"
 msgstr "関数が予期されます"
 
@@ -47345,37 +43762,31 @@ msgstr ""
 
 #: c/gimple-parser.c:478 c/gimple-parser.c:484
 #, fuzzy, gcc-internal-format
-#| msgid "expected pointer"
 msgid "expected block index"
 msgstr "ポインタが予期されます"
 
 #: c/gimple-parser.c:492
 #, fuzzy, gcc-internal-format
-#| msgid "invalid mask"
 msgid "invalid block index"
 msgstr "無効なマスクです"
 
 #: c/gimple-parser.c:503
 #, fuzzy, gcc-internal-format
-#| msgid "expected type specifier"
 msgid "expected block specifier"
 msgstr "型指定が予期されます"
 
 #: c/gimple-parser.c:521
 #, fuzzy, gcc-internal-format
-#| msgid "expected class name"
 msgid "expected loop number"
 msgstr "クラス名が予期されます"
 
 #: c/gimple-parser.c:539
 #, fuzzy, gcc-internal-format
-#| msgid "unknown ABI specified: '%s'"
 msgid "unknown block specifier"
 msgstr "不明な ABI が指定されました: '%s'"
 
 #: c/gimple-parser.c:552 c/gimple-parser.c:1942
 #, fuzzy, gcc-internal-format
-#| msgid "expected pointer"
 msgid "expected count value"
 msgstr "ポインタが予期されます"
 
@@ -47386,7 +43797,6 @@ msgstr ""
 
 #: c/gimple-parser.c:612
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate label %qD"
 msgid "duplicate loop header"
 msgstr "重複したラベル %qD です"
 
@@ -47407,7 +43817,6 @@ msgstr ""
 
 #: c/gimple-parser.c:1097
 #, fuzzy, gcc-internal-format
-#| msgid "expected identifier or %<*%>"
 msgid "expected pointer as argument of unary %<*%>"
 msgstr "識別子または %<*%> が予期されます"
 
@@ -47418,7 +43827,6 @@ msgstr ""
 
 #: c/gimple-parser.c:1182 c/gimple-parser.c:1522
 #, fuzzy, gcc-internal-format
-#| msgid "expected statement"
 msgid "expected constant offset"
 msgstr "文が予期されます"
 
@@ -47429,7 +43837,6 @@ msgstr ""
 
 #: c/gimple-parser.c:1265
 #, fuzzy, gcc-internal-format
-#| msgid "unnamed variable or field declared void"
 msgid "base variable or SSA name undeclared"
 msgstr "無名変数やフィールドが void と宣言されました"
 
@@ -47440,38 +43847,32 @@ msgstr "new に対して無効な型である `void'"
 
 #: c/gimple-parser.c:1303
 #, fuzzy, gcc-internal-format
-#| msgid "expected function"
 msgid "expecting internal function name"
 msgstr "関数が予期されます"
 
 #: c/gimple-parser.c:1316
 #, fuzzy, gcc-internal-format
-#| msgid "call to non-function %qD"
 msgid "unknown internal function %qE"
 msgstr "非関数 %qD の呼び出しです"
 
 #: c/gimple-parser.c:1454
 #, fuzzy, gcc-internal-format
-#| msgid "invalid %%P operand"
 msgid "invalid type of %<__MEM%> operand"
 msgstr "無効な %%P 被演算子です"
 
 #: c/gimple-parser.c:1516
 #, fuzzy, gcc-internal-format
-#| msgid "expected statement"
 msgid "expected constant size"
 msgstr "文が予期されます"
 
 #: c/gimple-parser.c:1554 c/gimple-parser.c:1584 c/gimple-parser.c:1627
 #: c/gimple-parser.c:1637
 #, fuzzy, gcc-internal-format
-#| msgid "invalid shift operand"
 msgid "invalid _Literal"
 msgstr "無効なシフト被演算子"
 
 #: c/gimple-parser.c:1563
 #, fuzzy, gcc-internal-format
-#| msgid "initializer invalid for static member with constructor"
 msgid "invalid type for _Literal with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
@@ -47482,43 +43883,36 @@ msgstr "無名共用体にメンバがありません"
 
 #: c/gimple-parser.c:1923
 #, fuzzy, gcc-internal-format
-#| msgid "expected class name"
 msgid "expected pass name"
 msgstr "クラス名が予期されます"
 
 #: c/gimple-parser.c:1962
 #, fuzzy, gcc-internal-format
-#| msgid "invalid %%d operand"
 msgid "invalid operation"
 msgstr "無効な %%d 被演算子です"
 
 #: c/gimple-parser.c:2152
 #, fuzzy, gcc-internal-format
-#| msgid "-fpic is not supported"
 msgid "%<catch%> is not supported"
 msgstr "-fpic はサポートされていません"
 
 #: c/gimple-parser.c:2154
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<,%> or %<)%>"
 msgid "expected %<finally%> or %<catch%>"
 msgstr "%<,%> または %<)%> が予期されます"
 
 #: c/gimple-parser.c:2198 c/gimple-parser.c:2235
 #, fuzzy, gcc-internal-format
-#| msgid "expected expression"
 msgid "expected goto expression"
 msgstr "式が予期されます"
 
 #: c/gimple-parser.c:2206
 #, fuzzy, gcc-internal-format
-#| msgid "expected statement"
 msgid "expected else statement"
 msgstr "文が予期されます"
 
 #: c/gimple-parser.c:2349
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<__label__%>"
 msgid "expected case label"
 msgstr "%<__label__%> が予期されます"
 
@@ -47530,26 +43924,22 @@ msgstr ""
 
 #: cp/call.c:3658
 #, fuzzy
-#| msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
 msgstr "  %qT から %qT へ %<this%> パラメータを暗黙的に変換する方法が不明です"
 
 #: cp/call.c:3665
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  conversion of argument %d would be ill-formed:"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
 #. Conversion of conversion function return value failed.
 #: cp/call.c:3672
 #, fuzzy
-#| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
 #: cp/call.c:3678
 #, fuzzy
-#| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
@@ -47561,25 +43951,21 @@ msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引
 
 #: cp/call.c:3718
 #, fuzzy, gcc-internal-format
-#| msgid "%s%D(%T, %T, %T) <built-in>"
 msgid "%s%<%D(%T, %T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T, %T) <組み込み>"
 
 #: cp/call.c:3723
 #, fuzzy, gcc-internal-format
-#| msgid "%s%D(%T, %T) <built-in>"
 msgid "%s%<%D(%T, %T)%> (built-in)"
 msgstr "%s%D(%T, %T) <組み込み>"
 
 #: cp/call.c:3727
 #, fuzzy, gcc-internal-format
-#| msgid "%s%D(%T) <built-in>"
 msgid "%s%<%D(%T)%> (built-in)"
 msgstr "%s%D(%T) <組み込み>"
 
 #: cp/call.c:3731
 #, fuzzy, gcc-internal-format
-#| msgid "%s%T <conversion>"
 msgid "%s%qT (conversion)"
 msgstr "%s%T <変換>"
 
@@ -47590,13 +43976,11 @@ msgstr ""
 
 #: cp/call.c:3735
 #, fuzzy, gcc-internal-format
-#| msgid "%s%#D <deleted>"
 msgid "%s%#qD (deleted)"
 msgstr "%s%#D <削除済み>"
 
 #: cp/call.c:3737
 #, fuzzy, gcc-internal-format
-#| msgid "%s%#D <deleted>"
 msgid "%s%#qD (reversed)"
 msgstr "%s%#D <削除済み>"
 
@@ -47648,7 +44032,6 @@ msgstr ""
 
 #: cp/call.c:4201
 #, fuzzy
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "%qT から %qT への変換が曖昧です"
 
@@ -47658,7 +44041,6 @@ msgstr ""
 
 #: cp/call.c:4368
 #, fuzzy
-#| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
@@ -47696,25 +44078,21 @@ msgstr "%<(%T) (%A)%> の呼び出しが曖昧です"
 
 #: cp/call.c:4915
 #, fuzzy, gcc-internal-format
-#| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
 #: cp/call.c:4916
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
 #: cp/call.c:4919
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
 #: cp/call.c:4921
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
@@ -47725,79 +44103,66 @@ msgstr ""
 
 #: cp/call.c:4940
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "%<operator%> が予期されます"
 
 #: cp/call.c:4944
 #, fuzzy, gcc-internal-format
-#| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E ? %E : %E%> 内にある三項演算子 %<operator?:%> が適合しません "
 
 #: cp/call.c:4953 cp/call.c:4997 cp/call.c:5007
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "%<operator%> が予期されます"
 
 #: cp/call.c:4956
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> で %<%E%s%> 内にあるものが適合しません"
 
 #: cp/call.c:4963
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "%<operator%> が予期されます"
 
 #: cp/call.c:4966
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E[%E]%> 内の %<operator[]%> が適合しません"
 
 #: cp/call.c:4974
 #, fuzzy, gcc-internal-format
-#| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
 #: cp/call.c:4977
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
 #: cp/call.c:4983
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
 msgid "%<operator %s%>"
 msgstr "%<operator%> が予期されます"
 
 #: cp/call.c:4986
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator %s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
 #: cp/call.c:5001
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> で %<%E %s %E%> 内にあるものが適合しません"
 
 #: cp/call.c:5010
 #, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
 #: cp/call.c:5120
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
 msgstr "ISO C++ は中間項が省略された ?: 式を禁止しています"
 
@@ -47827,7 +44192,6 @@ msgstr ""
 
 #: cp/call.c:5401 cp/call.c:5518 cp/call.c:5666
 #, fuzzy, gcc-internal-format
-#| msgid "operands to ?: have different types %qT and %qT"
 msgid "operands to %<?:%> have different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
@@ -47838,19 +44202,16 @@ msgstr ""
 
 #: cp/call.c:5594
 #, fuzzy
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
 #: cp/call.c:5610
 #, fuzzy, gcc-internal-format
-#| msgid "type mismatch in conditional expression"
 msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "条件式での型の組合わせが適合しません"
 
 #: cp/call.c:5622
 #, fuzzy, gcc-internal-format
-#| msgid "pointer/integer type mismatch in conditional expression"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
@@ -47871,7 +44232,6 @@ msgstr ""
 
 #: cp/call.c:6361
 #, fuzzy, gcc-internal-format
-#| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
@@ -47892,13 +44252,11 @@ msgstr ""
 
 #: cp/call.c:6821
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD は通常は非静的関数です。"
 
 #: cp/call.c:6860
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD は通常は非静的関数です。"
 
@@ -47919,7 +44277,6 @@ msgstr "マクロ引数内でディレクトリを使うことはできません
 
 #: cp/call.c:7050 cp/decl.c:7978
 #, fuzzy, gcc-internal-format
-#| msgid "declared here"
 msgid "declared private here"
 msgstr "ここで宣言されています"
 
@@ -47930,13 +44287,11 @@ msgstr "マクロ引数内でディレクトリを使うことはできません
 
 #: cp/call.c:7057 cp/decl.c:7979
 #, fuzzy, gcc-internal-format
-#| msgid "declared here"
 msgid "declared protected here"
 msgstr "ここで宣言されています"
 
 #: cp/call.c:7062
 #, fuzzy, gcc-internal-format
-#| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D はアクセス出来ません"
 
@@ -47947,7 +44302,6 @@ msgstr ""
 
 #: cp/call.c:7174 cp/call.c:7193 cp/decl.c:9647 cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
-#| msgid "declared here"
 msgid "  declared here"
 msgstr "ここで宣言されています"
 
@@ -47963,7 +44317,6 @@ msgstr ""
 
 #: cp/call.c:7197
 #, fuzzy, gcc-internal-format
-#| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL から非ポインタ型へ変換しています"
 
@@ -47974,7 +44327,6 @@ msgstr ""
 
 #: cp/call.c:7284
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -47989,13 +44341,11 @@ msgstr ""
 
 #: cp/call.c:7383
 #, fuzzy
-#| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
 #: cp/call.c:7423 cp/cvt.c:227
 #, fuzzy
-#| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
@@ -48030,7 +44380,6 @@ msgstr ""
 
 #: cp/call.c:7795
 #, fuzzy, gcc-internal-format
-#| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
@@ -48046,7 +44395,6 @@ msgstr ""
 
 #: cp/call.c:7920
 #, fuzzy
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
@@ -48137,13 +44485,11 @@ msgstr ""
 
 #: cp/call.c:9473
 #, fuzzy, gcc-internal-format
-#| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
 #: cp/call.c:9475
 #, fuzzy, gcc-internal-format
-#| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "代わりに #include を使用してください"
 
@@ -48169,13 +44515,11 @@ msgstr ""
 
 #: cp/call.c:9506
 #, fuzzy, gcc-internal-format
-#| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
 #: cp/call.c:9508
 #, fuzzy, gcc-internal-format
-#| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "代わりに #include を使用してください"
 
@@ -48241,19 +44585,16 @@ msgstr ""
 
 #: cp/call.c:9609
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD はここで宣言されています"
 
 #: cp/call.c:9709
 #, fuzzy, gcc-internal-format
-#| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
 #: cp/call.c:9983 cp/typeck.c:9344
 #, fuzzy
-#| msgid "cannot convert type %qT to type %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "型 %qT から型 %qT へ変換できません"
 
@@ -48264,7 +44605,6 @@ msgstr ""
 
 #: cp/call.c:10037
 #, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
@@ -48285,7 +44625,6 @@ msgstr ""
 
 #: cp/call.c:10316
 #, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
@@ -48301,13 +44640,11 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/call.c:10345
 #, fuzzy, gcc-internal-format
-#| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #: cp/call.c:10346
 #, fuzzy, gcc-internal-format
-#| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "デストラクタから値を返そうとしています"
 
@@ -48328,7 +44665,6 @@ msgstr ""
 
 #: cp/call.c:11406
 #, fuzzy
-#| msgid "conversion from %q#T to %q#T"
 msgid "  for conversion from %qH to %qI"
 msgstr "%q#T から %q#T への変換です"
 
@@ -48344,13 +44680,11 @@ msgstr ""
 
 #: cp/call.c:11663
 #, fuzzy, gcc-internal-format
-#| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " 候補 1: %q+#F"
 
 #: cp/call.c:11665
 #, fuzzy, gcc-internal-format
-#| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " 候補 2: %q+#F"
 
@@ -48395,7 +44729,6 @@ msgstr ""
 
 #: cp/class.c:372
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert to a pointer type"
 msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
 msgstr "ポインタ型へ変換できません"
 
@@ -48411,7 +44744,6 @@ msgstr ""
 
 #: cp/class.c:1179
 #, fuzzy, gcc-internal-format
-#| msgid "%q+#D cannot be overloaded"
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
@@ -48459,7 +44791,6 @@ msgstr ""
 #: cp/class.c:1369 cp/class.c:1376 cp/class.c:1383 cp/class.c:1395
 #: cp/cvt.c:1091
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%qT declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -48510,7 +44841,6 @@ msgstr ""
 
 #: cp/class.c:2866
 #, fuzzy, gcc-internal-format
-#| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
@@ -48526,19 +44856,16 @@ msgstr ""
 
 #: cp/class.c:2947
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D は隠されています"
 
 #: cp/class.c:2948
 #, fuzzy, gcc-internal-format
-#| msgid "        %qD"
 msgid "  by %qD"
 msgstr "        %qD"
 
 #: cp/class.c:2983
 #, fuzzy, gcc-internal-format
-#| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
@@ -48554,7 +44881,6 @@ msgstr ""
 
 #: cp/class.c:3377
 #, fuzzy, gcc-internal-format
-#| msgid "bit-field %q+#D with non-integral type"
 msgid "bit-field %q#D with non-integral type %qT"
 msgstr "ビットフィールド %q+#D が非整数型です"
 
@@ -48575,13 +44901,11 @@ msgstr "ビットフィールド %q+D の幅が 0 です"
 
 #: cp/class.c:3413
 #, fuzzy, gcc-internal-format
-#| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D の幅が型の大きさを超えています"
 
 #: cp/class.c:3419
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D は %q#T の全ての値を持つには小さすぎます"
 
@@ -48602,25 +44926,21 @@ msgstr "コピー代入演算子を持つメンバ %q+#D は共用体内では
 
 #: cp/class.c:3489
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/class.c:3605
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D は共用体のメンバのため静的ではありません"
 
 #: cp/class.c:3618
 #, fuzzy, gcc-internal-format
-#| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
 #: cp/class.c:3631
 #, fuzzy, gcc-internal-format
-#| msgid "field %q+D invalidly declared function type"
 msgid "data member %q+D invalidly declared function type"
 msgstr "フィールド %q+D はが関数型として無効な宣言をされました"
 
@@ -48656,7 +44976,6 @@ msgstr "`%s' は前にここで宣言されました"
 
 #: cp/class.c:3839
 #, fuzzy, gcc-internal-format
-#| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "フィールド %q+#D がクラス名と同じです"
 
@@ -48687,13 +45006,11 @@ msgstr "`%s' は前にここで宣言されました"
 
 #: cp/class.c:4318
 #, fuzzy, gcc-internal-format
-#| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
 msgstr "%qD の整列は元の宣言より大きいです"
 
 #: cp/class.c:4321
 #, fuzzy, gcc-internal-format
-#| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in %<-fabi-version=9%>"
 msgstr "%qD の整列は元の宣言より大きいです"
 
@@ -48734,13 +45051,11 @@ msgstr ""
 
 #: cp/class.c:5900
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
 #: cp/class.c:5903
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T does not have %<constexpr%> destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
@@ -48751,7 +45066,6 @@ msgstr ""
 
 #: cp/class.c:5944
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
@@ -48767,19 +45081,16 @@ msgstr "メンバへのポインタでの無効な `%s' の使用"
 
 #: cp/class.c:6087
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
 #: cp/class.c:6116
 #, fuzzy, gcc-internal-format
-#| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
 #: cp/class.c:6122
 #, fuzzy, gcc-internal-format
-#| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
@@ -48795,13 +45106,11 @@ msgstr "仮想基底 %qT は曖昧なため %qT 内ではアクセスできま
 
 #: cp/class.c:6703
 #, fuzzy, gcc-internal-format
-#| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
 
 #: cp/class.c:6873
 #, fuzzy, gcc-internal-format
-#| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "配列 %qE のサイズが大きすぎます"
 
@@ -48812,7 +45121,6 @@ msgstr ""
 
 #: cp/class.c:7161
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "可変配列メンバの無効な使用法です"
 
@@ -48823,31 +45131,26 @@ msgstr "`%s' は前にここで宣言されました"
 
 #: cp/class.c:7194
 #, fuzzy, gcc-internal-format
-#| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
 #: cp/class.c:7196
 #, fuzzy, gcc-internal-format
-#| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
 #: cp/class.c:7205 cp/class.c:7236
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T が再定義されています"
 
 #: cp/class.c:7213
 #, fuzzy, gcc-internal-format
-#| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
 #: cp/class.c:7215
 #, fuzzy, gcc-internal-format
-#| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
@@ -48868,7 +45171,6 @@ msgstr "%q#T は仮想関数を持っており非仮想デストラクタから
 
 #: cp/class.c:7516
 #, fuzzy, gcc-internal-format
-#| msgid "prototype for %q#D does not match any in class %qT"
 msgid "type transparent %q#T does not have any fields"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
@@ -48944,7 +45246,6 @@ msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
 #: cp/class.c:8876
 #, fuzzy, gcc-internal-format
-#| msgid "redeclared here as %q#D"
 msgid "%qD declared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
 
@@ -49025,7 +45326,6 @@ msgstr ""
 
 #: cp/constexpr.c:1660 cp/constexpr.c:7401
 #, fuzzy, gcc-internal-format
-#| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "非関数 %qD の呼び出しです"
 
@@ -49036,7 +45336,6 @@ msgstr "初期化子の要素が定数式ではありません"
 
 #: cp/constexpr.c:1717
 #, fuzzy, gcc-internal-format
-#| msgid "originally defined here"
 msgid "originally declared %<const%> here"
 msgstr "元々はここで定義されました"
 
@@ -49083,7 +45382,6 @@ msgstr "`%s' の宣言は前方のローカルシンボルを覆い隠します"
 
 #: cp/constexpr.c:2250 cp/constexpr.c:7433
 #, fuzzy, gcc-internal-format
-#| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
@@ -49114,19 +45412,16 @@ msgstr ""
 
 #: cp/constexpr.c:2769
 #, fuzzy, gcc-internal-format
-#| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右シフト回数が負です"
 
 #: cp/constexpr.c:2776
 #, fuzzy, gcc-internal-format
-#| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
 msgstr "右シフト回数が負です"
 
 #: cp/constexpr.c:2799
 #, fuzzy, gcc-internal-format
-#| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
@@ -49142,25 +45437,21 @@ msgstr ""
 
 #: cp/constexpr.c:3348
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: cp/constexpr.c:3351
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: cp/constexpr.c:3356
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
 #: cp/constexpr.c:3359
 #, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
@@ -49171,7 +45462,6 @@ msgstr "初期化子を欠いています"
 
 #: cp/constexpr.c:3582
 #, fuzzy, gcc-internal-format
-#| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
@@ -49183,7 +45473,6 @@ msgstr ""
 
 #: cp/constexpr.c:3605
 #, fuzzy, gcc-internal-format
-#| msgid "%qD was not initialized with a constant expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
@@ -49199,7 +45488,6 @@ msgstr ""
 
 #: cp/constexpr.c:4408 cp/constexpr.c:6178
 #, fuzzy, gcc-internal-format
-#| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
@@ -49210,13 +45498,11 @@ msgstr ""
 
 #: cp/constexpr.c:4471
 #, fuzzy, gcc-internal-format
-#| msgid "%qD was not initialized with a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
 #: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, fuzzy, gcc-internal-format
-#| msgid "declared here"
 msgid "allocated here"
 msgstr "ここで宣言されています"
 
@@ -49272,13 +45558,11 @@ msgstr "NaN から整数への変換です"
 
 #: cp/constexpr.c:4839
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert to a pointer type"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ポインタ型へ変換できません"
 
 #: cp/constexpr.c:5231 cp/constexpr.c:6433
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -49289,7 +45573,6 @@ msgstr ""
 
 #: cp/constexpr.c:5439
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -49315,7 +45598,6 @@ msgstr "定数式がオーバーフローしました"
 
 #: cp/constexpr.c:6138 cp/constexpr.c:7553
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -49326,7 +45608,6 @@ msgstr "初期化子の要素が定数式ではありません"
 
 #: cp/constexpr.c:6204
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -49337,13 +45618,11 @@ msgstr "初期化子の要素が定数式ではありません"
 
 #: cp/constexpr.c:6400
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<template%>"
 msgid "unexpected template-id %qE"
 msgstr "%<template%> が予期されます"
 
 #: cp/constexpr.c:6406
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD takes one argument only"
 msgid "function concept must be called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
@@ -49389,7 +45668,6 @@ msgstr ""
 
 #: cp/constexpr.c:7523
 #, fuzzy, gcc-internal-format
-#| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
@@ -49400,7 +45678,6 @@ msgstr ""
 
 #: cp/constexpr.c:7573
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -49416,19 +45693,16 @@ msgstr "定数式がオーバーフローしました"
 
 #: cp/constexpr.c:7776
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "初期化子の要素が定数式ではありません"
 
 #: cp/constexpr.c:7843
 #, fuzzy, gcc-internal-format
-#| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++2a"
 msgstr "仮想関数は friend にできません"
 
 #: cp/constexpr.c:7858
 #, fuzzy, gcc-internal-format
-#| msgid "overflow in constant expression"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "定数式内でオーバーフローしました"
 
@@ -49439,13 +45713,11 @@ msgstr "定数式がオーバーフローしました"
 
 #: cp/constexpr.c:7972
 #, fuzzy, gcc-internal-format
-#| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
 #: cp/constexpr.c:7979
 #, fuzzy, gcc-internal-format
-#| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
@@ -49456,7 +45728,6 @@ msgstr "初期化子の要素が定数式ではありません"
 
 #: cp/constexpr.c:8150
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -49467,7 +45738,6 @@ msgstr "初期化子内に非定数の配列インデックスがあります"
 
 #: cp/constexpr.c:8212
 #, fuzzy, gcc-internal-format
-#| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
@@ -49483,7 +45753,6 @@ msgstr ""
 
 #: cp/cp-gimplify.c:1596
 #, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
@@ -49499,7 +45768,6 @@ msgstr ""
 
 #: cp/cp-gimplify.c:3056
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
@@ -49515,13 +45783,11 @@ msgstr "クラスタイプ項を欠いています"
 
 #: cp/cp-gimplify.c:3113
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
 #: cp/cp-gimplify.c:3124
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have integral type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
@@ -49532,25 +45798,21 @@ msgstr ""
 
 #: cp/cp-gimplify.c:3225
 #, fuzzy, gcc-internal-format
-#| msgid "error closing %s: %m"
 msgid "evaluating %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
 #: cp/cvt.c:92
 #, fuzzy
-#| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cannot convert from incomplete type %qH to %qI"
 msgstr "不完全型 %qT から %qT へ変換できません"
 
 #: cp/cvt.c:102
 #, fuzzy
-#| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "conversion of %qE from %qH to %qI is ambiguous"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
 #: cp/cvt.c:174 cp/cvt.c:201 cp/cvt.c:255
 #, fuzzy
-#| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "cannot convert %qE from type %qH to type %qI"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
 
@@ -49576,7 +45838,6 @@ msgstr ""
 
 #: cp/cvt.c:476
 #, fuzzy
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT から %qT への変換が曖昧です"
 
@@ -49587,7 +45848,6 @@ msgstr ""
 
 #: cp/cvt.c:526
 #, fuzzy
-#| msgid "cannot convert type %qT to type %qT"
 msgid "cannot convert type %qH to type %qI"
 msgstr "型 %qT から型 %qT へ変換できません"
 
@@ -49613,37 +45873,31 @@ msgstr "%qE から %qT へ変換できません"
 
 #: cp/cvt.c:909
 #, fuzzy, gcc-internal-format
-#| msgid "%q#T used where a floating point value was expected"
 msgid "%q#T used where a floating-point value was expected"
 msgstr "%q#T が浮動小数点値が予期される場所で使用されました"
 
 #: cp/cvt.c:967
 #, fuzzy
-#| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "%qT から非スカラ型 %qT への変換が要求されました"
 
 #: cp/cvt.c:1061
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
 #: cp/cvt.c:1063
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
 #: cp/cvt.c:1079
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
 #: cp/cvt.c:1081
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
@@ -49654,7 +45908,6 @@ msgstr "`%s' は前にここで宣言されました"
 
 #: cp/cvt.c:1103
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
@@ -49905,7 +46158,6 @@ msgstr "NULL から非ポインタ型へ変換しています"
 
 #: cp/cvt.c:1877
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of default argument for %q#D"
 msgid "default type conversion cannot deduce template argument for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
@@ -49941,7 +46193,6 @@ msgstr "無効な宣言です"
 
 #: cp/decl.c:672
 #, fuzzy, gcc-internal-format
-#| msgid "unused variable %q+D"
 msgid "unused variable %qD"
 msgstr "使用されない変数 %q+D です"
 
@@ -49952,13 +46203,11 @@ msgstr ""
 
 #: cp/decl.c:829
 #, fuzzy, gcc-internal-format
-#| msgid "%q+F declared %<static%> but never defined"
 msgid "%qF declared %<static%> but never defined"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
 #: cp/decl.c:836
 #, fuzzy, gcc-internal-format
-#| msgid "environment variable %qs not defined"
 msgid "odr-used inline variable %qD is not defined"
 msgstr "環境変数 %qs が定義されていません"
 
@@ -49981,7 +46230,6 @@ msgstr "前方での `%s' の宣言"
 
 #: cp/decl.c:1260
 #, fuzzy, gcc-internal-format
-#| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
@@ -50022,7 +46270,6 @@ msgstr "無効な宣言です"
 
 #: cp/decl.c:1468
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
@@ -50043,7 +46290,6 @@ msgstr "ライブラリ関数 %q#D は非関数 %q#D として再宣言されて
 
 #: cp/decl.c:1494 cp/decl.c:1564
 #, fuzzy, gcc-internal-format
-#| msgid "section of %q+D conflicts with previous declaration"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
@@ -50059,13 +46305,11 @@ msgstr "前方での `%s' の暗黙的な宣言"
 
 #: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a built-in function"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "%q+D の宣言が組み込み関数を隠します"
 
 #: cp/decl.c:1598 cp/decl.c:1612
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a built-in function"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "%q+D の宣言が組み込み関数を隠します"
 
@@ -50076,7 +46320,6 @@ msgstr "空の宣言です"
 
 #: cp/decl.c:1696
 #, fuzzy, gcc-internal-format
-#| msgid "data area of %q+D conflicts with previous declaration"
 msgid "literal operator %q#D conflicts with raw literal operator"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
@@ -50087,7 +46330,6 @@ msgstr ""
 
 #: cp/decl.c:1713
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D redeclared as different kind of symbol"
 msgid "%q#D redeclared as different kind of entity"
 msgstr "%q+D が異なる種類のシンボルとして再宣言されました"
 
@@ -50098,13 +46340,11 @@ msgstr "インラインテンプレートの明示的な実体化のみを生成
 
 #: cp/decl.c:1759
 #, fuzzy, gcc-internal-format
-#| msgid "implicit declaration of function %qE"
 msgid "conflicting declaration of C function %q#D"
 msgstr "関数 %qE の暗黙的な宣言です"
 
 #: cp/decl.c:1776
 #, fuzzy, gcc-internal-format
-#| msgid "template declaration of %q#D"
 msgid "ambiguating new declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
 
@@ -50120,14 +46360,12 @@ msgstr "前方での `%s' の宣言"
 
 #: cp/decl.c:1847 cp/decl2.c:923
 #, fuzzy, gcc-internal-format
-#| msgid "previously defined here"
 msgid "%q#D previously defined here"
 msgstr "前はここで定義されました"
 
 #: cp/decl.c:1848 cp/name-lookup.c:2691 cp/name-lookup.c:2720
 #: cp/name-lookup.c:2744
 #, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
 msgid "%q#D previously declared here"
 msgstr "前はここで宣言されました"
 
@@ -50143,7 +46381,6 @@ msgstr "`%s' は前にここで定義されました"
 
 #: cp/decl.c:1901
 #, fuzzy, gcc-internal-format
-#| msgid "redeclaration of %q+D with no linkage"
 msgid "conflicting declaration of %q#D with %qL linkage"
 msgstr "リンク無し %q+D の再定義です"
 
@@ -50159,19 +46396,16 @@ msgstr ""
 
 #: cp/decl.c:1942 cp/decl.c:1952
 #, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+D was here"
 msgid "previous specification in %q#D here"
 msgstr "前の %q+D の宣言はここです"
 
 #: cp/decl.c:2002
 #, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "前の %q+D の宣言はここです"
 
 #: cp/decl.c:2003
 #, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "前の %q+D の宣言はここです"
 
@@ -50187,7 +46421,6 @@ msgstr ""
 
 #: cp/decl.c:2073
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD"
 msgstr "%q+D が再定義されました"
 
@@ -50206,7 +46439,6 @@ msgstr ""
 
 #: cp/decl.c:2675
 #, fuzzy, gcc-internal-format
-#| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
@@ -50268,7 +46500,6 @@ msgstr ""
 
 #: cp/decl.c:3102
 #, fuzzy, gcc-internal-format
-#| msgid "redundant redeclaration of %q+D"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%q+D の冗長な再宣言です"
 
@@ -50299,19 +46530,16 @@ msgstr "(`%s' の初期化は不完全です)"
 
 #: cp/decl.c:3317
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
 #: cp/decl.c:3331 cp/decl.c:3485
 #, fuzzy, gcc-internal-format
-#| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  try ブロックに入ります"
 
 #: cp/decl.c:3337 cp/decl.c:3467 cp/decl.c:3487
 #, fuzzy, gcc-internal-format
-#| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  catch ブロックに入ります"
 
@@ -50327,7 +46555,6 @@ msgstr ""
 
 #: cp/decl.c:3356 cp/decl.c:3491
 #, fuzzy, gcc-internal-format
-#| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "文が予期されます"
 
@@ -50338,7 +46565,6 @@ msgstr "(`%s' の初期化は不完全です)"
 
 #: cp/decl.c:3477
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
@@ -50349,7 +46575,6 @@ msgstr ""
 
 #: cp/decl.c:3935 cp/parser.c:6581
 #, fuzzy, gcc-internal-format
-#| msgid "non-template %qD used as template"
 msgid "%qD used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
@@ -50365,7 +46590,6 @@ msgstr ""
 
 #: cp/decl.c:3975
 #, fuzzy, gcc-internal-format
-#| msgid "unknown type name %qE"
 msgid "no type named %q#T in %q#T"
 msgstr "不明な型名 %qE です"
 
@@ -50391,7 +46615,6 @@ msgstr "仮引数 `%s' の型が宣言されていません"
 
 #: cp/decl.c:4400
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求された整列が 2 の累乗ではありません"
 
@@ -50543,7 +46766,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/decl.c:5317
 #, fuzzy, gcc-internal-format
-#| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
@@ -50569,13 +46791,11 @@ msgstr "friend 宣言がクラス定義の中にありません"
 
 #: cp/decl.c:5433
 #, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %qs function"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
 #: cp/decl.c:5438
 #, fuzzy, gcc-internal-format
-#| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %qs function"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
@@ -50666,13 +46886,11 @@ msgstr "未初期化定数を ROM に置かない"
 
 #: cp/decl.c:5929
 #, fuzzy, gcc-internal-format
-#| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
 #: cp/decl.c:5938
 #, fuzzy, gcc-internal-format
-#| msgid "initialized variable %q+D is marked dllimport"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "初期化された変数 %q+D は dllimport とマークされています"
 
@@ -50713,7 +46931,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/decl.c:6227
 #, fuzzy, gcc-internal-format
-#| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
@@ -50795,13 +47012,11 @@ msgstr "(クラス外での初期化を必要とします)"
 
 #: cp/decl.c:7077
 #, fuzzy, gcc-internal-format
-#| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
 #: cp/decl.c:7335
 #, fuzzy, gcc-internal-format
-#| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "宣言内にない %<[*]%> です"
 
@@ -50842,7 +47057,6 @@ msgstr "ISO C++ は名前つき戻り値を許可しません"
 
 #: cp/decl.c:7451 cp/decl.c:13730
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
@@ -50853,7 +47067,6 @@ msgstr "非メンバ関数での `this' の使用は無効です"
 
 #: cp/decl.c:7610
 #, fuzzy, gcc-internal-format
-#| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可変長オブジェクトが初期化されないようです"
 
@@ -50864,7 +47077,6 @@ msgstr "前方での `%s' の宣言"
 
 #: cp/decl.c:7706
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables and functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
@@ -50900,19 +47112,16 @@ msgstr ""
 
 #: cp/decl.c:8219
 #, fuzzy, gcc-internal-format
-#| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
 #: cp/decl.c:8235
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
 #: cp/decl.c:8244 cp/decl.c:8329
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
@@ -50966,13 +47175,11 @@ msgstr "不完全型のポインタへの間接参照"
 
 #: cp/decl.c:8397
 #, fuzzy, gcc-internal-format
-#| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
 #: cp/decl.c:8406
 #, fuzzy, gcc-internal-format
-#| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
@@ -51093,37 +47300,31 @@ msgstr ""
 
 #: cp/decl.c:9273
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
 #: cp/decl.c:9280
 #, fuzzy, gcc-internal-format
-#| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
 #: cp/decl.c:9283
 #, fuzzy, gcc-internal-format
-#| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java メソッド %qD が非 Java 戻り型 %qT を持ちます"
 
 #: cp/decl.c:9360
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
 #: cp/decl.c:9379
 #, fuzzy, gcc-internal-format
-#| msgid "union cannot be made transparent"
 msgid "a function concept cannot be constrained"
 msgstr "共用体を透過的にできません"
 
 #: cp/decl.c:9387
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD はテンプレート関数ではありません"
 
@@ -51189,7 +47390,6 @@ msgstr ""
 
 #: cp/decl.c:9626
 #, fuzzy, gcc-internal-format
-#| msgid "static member %qD cannot be a bit-field"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
@@ -51220,7 +47420,6 @@ msgstr ""
 
 #: cp/decl.c:9675
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
@@ -51256,13 +47455,11 @@ msgstr ""
 
 #: cp/decl.c:9827
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of typedef %q+D"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
 #: cp/decl.c:9829
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%qD はここで宣言されています"
 
@@ -51278,7 +47475,6 @@ msgstr "`::main' を template としては宣言できません"
 
 #: cp/decl.c:10046
 #, fuzzy, gcc-internal-format
-#| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
@@ -51289,7 +47485,6 @@ msgstr ""
 
 #: cp/decl.c:10056
 #, fuzzy, gcc-internal-format
-#| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可変長オブジェクトが初期化されないようです"
 
@@ -51480,7 +47675,6 @@ msgstr "大域 register 変数が関数定義の後ろにあります"
 
 #: cp/decl.c:10751
 #, fuzzy, gcc-internal-format
-#| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
@@ -51506,7 +47700,6 @@ msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline'
 
 #: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -51562,7 +47755,6 @@ msgstr "`%s' の extern 宣言がネストしています"
 
 #: cp/decl.c:11215
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
@@ -51573,7 +47765,6 @@ msgstr ""
 
 #: cp/decl.c:11257 cp/decl.c:11264 cp/decl.c:11271 cp/decl.c:11278
 #, fuzzy, gcc-internal-format
-#| msgid "%<[*]%> not in a declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "宣言内にない %<[*]%> です"
 
@@ -51594,7 +47785,6 @@ msgstr "`%s' の宣言が矛盾しています"
 
 #: cp/decl.c:11343
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
@@ -51605,43 +47795,36 @@ msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
 #: cp/decl.c:11416
 #, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
 #: cp/decl.c:11424
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
 #: cp/decl.c:11478
 #, fuzzy, gcc-internal-format
-#| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
 #: cp/decl.c:11484
 #, fuzzy, gcc-internal-format
-#| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
 #: cp/decl.c:11492 cp/decl.c:11498
 #, fuzzy, gcc-internal-format
-#| msgid "%qs must be used with %qs"
 msgid "%qs specified with %qT"
 msgstr "%qs は %qs と併用しなければいけません"
 
 #: cp/decl.c:11503
 #, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
 #: cp/decl.c:11505
 #, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
@@ -51682,7 +47865,6 @@ msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
 #: cp/decl.c:11679 cp/decl.c:11688 cp/decl.c:11694 cp/decl.c:11700
 #, fuzzy, gcc-internal-format
-#| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
@@ -51699,7 +47881,6 @@ msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
 #: cp/decl.c:11732 cp/decl.c:11754
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "structured binding declaration can be %qs only in %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -51755,7 +47936,6 @@ msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
 #: cp/decl.c:11913
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE 属性は無視されました"
 
@@ -51766,7 +47946,6 @@ msgstr ""
 
 #: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
-#| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
@@ -51782,13 +47961,11 @@ msgstr ""
 
 #: cp/decl.c:12050
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/decl.c:12055
 #, fuzzy, gcc-internal-format
-#| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
@@ -51804,13 +47981,11 @@ msgstr ""
 
 #: cp/decl.c:12076
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<restrict%> の誤った使用法です"
 
 #: cp/decl.c:12087
 #, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
@@ -51826,7 +48001,6 @@ msgstr ""
 
 #: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -51867,7 +48041,6 @@ msgstr "デストラクタを静的メンバ関数とすることはできませ
 
 #: cp/decl.c:12218
 #, fuzzy, gcc-internal-format
-#| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
@@ -51893,7 +48066,6 @@ msgstr "コンストラクタは virtual 宣言できません"
 
 #: cp/decl.c:12251
 #, fuzzy, gcc-internal-format
-#| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "コンストラクタは virtual 宣言できません"
 
@@ -51909,7 +48081,6 @@ msgstr "friend 宣言がクラス定義の中にありません"
 
 #: cp/decl.c:12277
 #, fuzzy, gcc-internal-format
-#| msgid "friend declaration not in class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
@@ -51980,7 +48151,6 @@ msgstr ""
 
 #: cp/decl.c:12628
 #, fuzzy, gcc-internal-format
-#| msgid "cannot call member function %qD without object"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
@@ -52011,13 +48181,11 @@ msgstr ""
 
 #: cp/decl.c:12701
 #, fuzzy, gcc-internal-format
-#| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
 #: cp/decl.c:12704
 #, fuzzy, gcc-internal-format
-#| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
@@ -52063,13 +48231,11 @@ msgstr "大域 register 変数が関数定義の後ろにあります"
 
 #: cp/decl.c:12767
 #, fuzzy, gcc-internal-format
-#| msgid "destructor cannot be static member function"
 msgid "typedef may not be a member function definition"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
 #: cp/decl.c:12793
 #, fuzzy, gcc-internal-format
-#| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "宣言内にない %<[*]%> です"
 
@@ -52216,7 +48382,6 @@ msgstr "デストラクタを静的メンバ関数とすることはできませ
 
 #: cp/decl.c:13198
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> destructors only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -52232,25 +48397,21 @@ msgstr "デストラクタを静的メンバ関数とすることはできませ
 
 #: cp/decl.c:13226
 #, fuzzy, gcc-internal-format
-#| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
 #: cp/decl.c:13234 cp/decl.c:13562
 #, fuzzy, gcc-internal-format
-#| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "%s を開けません"
 
 #: cp/decl.c:13243
 #, fuzzy, gcc-internal-format
-#| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
 #: cp/decl.c:13246
 #, fuzzy, gcc-internal-format
-#| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
@@ -52276,7 +48437,6 @@ msgstr "`%s' は関数でもメンバ関数でもありません -- friend と
 
 #: cp/decl.c:13387 cp/decl.c:13398
 #, fuzzy, gcc-internal-format
-#| msgid "parameter %q+D declared %<inline%>"
 msgid "static data member %qE declared %qs"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
@@ -52367,13 +48527,11 @@ msgstr ""
 
 #: cp/decl.c:13666
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
 #: cp/decl.c:13673
 #, fuzzy, gcc-internal-format
-#| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
@@ -52566,7 +48724,6 @@ msgstr ""
 
 #: cp/decl.c:14699
 #, fuzzy, gcc-internal-format
-#| msgid "invalid template declaration of %qD"
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
@@ -52716,13 +48873,11 @@ msgstr "`%s' の列挙値が整数定数ではありません"
 
 #: cp/decl.c:15796
 #, fuzzy, gcc-internal-format
-#| msgid "integer constant is too large for %<unsigned long%> type"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
 #: cp/decl.c:15797
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
@@ -52733,7 +48888,6 @@ msgstr "列挙値がオーバーフロー"
 
 #: cp/decl.c:15828
 #, fuzzy, gcc-internal-format
-#| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
@@ -52754,13 +48908,11 @@ msgstr ""
 
 #: cp/decl.c:17011
 #, fuzzy, gcc-internal-format
-#| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
 #: cp/decl.c:17013 cp/typeck.c:9911
 #, fuzzy, gcc-internal-format
-#| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
@@ -52771,7 +48923,6 @@ msgstr ""
 
 #: cp/decl.c:17628
 #, fuzzy, gcc-internal-format
-#| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
 
@@ -52792,7 +48943,6 @@ msgstr ""
 
 #: cp/decl2.c:502
 #, fuzzy, gcc-internal-format
-#| msgid "deleting array %q#D"
 msgid "deleting array %q#E"
 msgstr "配列 %q#D を削除しています"
 
@@ -52828,7 +48978,6 @@ msgstr "デストラクタ %qD がメンバテンプレートとして宣言さ
 
 #: cp/decl2.c:712
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q#D"
 msgid "no declaration matches %q#D"
 msgstr "%q#D が宣言されています"
 
@@ -52839,13 +48988,11 @@ msgstr ""
 
 #: cp/decl2.c:720
 #, fuzzy, gcc-internal-format
-#| msgid "In function %qs"
 msgid "no functions named %qD"
 msgstr "関数 %qs 内"
 
 #: cp/decl2.c:722
 #, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
 msgid "%#qT defined here"
 msgstr "ラベル %qD はここで定義されています"
 
@@ -52861,7 +49008,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/decl2.c:793
 #, fuzzy, gcc-internal-format
-#| msgid "union defined here"
 msgid "unnamed class defined here"
 msgstr "共用体がここで定義されています"
 
@@ -52882,7 +49028,6 @@ msgstr "メンバ関数 %qD 用の無効な初期化子です"
 
 #: cp/decl2.c:959
 #, fuzzy, gcc-internal-format
-#| msgid "initializer specified for static member function %qD"
 msgid "initializer specified for friend function %qD"
 msgstr "静的メンバ関数 %qD 用の初期化子が指定されています"
 
@@ -52898,7 +49043,6 @@ msgstr "%<asm%> 指定は非静的データメンバに関しては許可され
 
 #: cp/decl2.c:1066
 #, fuzzy, gcc-internal-format
-#| msgid "bit-field %qD with non-integral type"
 msgid "bit-field %qD with non-integral type %qT"
 msgstr "非整数型のビットフィールド %qD です"
 
@@ -52914,7 +49058,6 @@ msgstr "ビットフィールド %qD を関数型として宣言できません"
 
 #: cp/decl2.c:1091
 #, fuzzy, gcc-internal-format
-#| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qD with %<warn_if_not_aligned%> type"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
@@ -52960,19 +49103,16 @@ msgstr "無名構造体が名前つき型の中にありません"
 
 #: cp/decl2.c:1644
 #, fuzzy, gcc-internal-format
-#| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
 #: cp/decl2.c:1651
 #, fuzzy, gcc-internal-format
-#| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "無名共用体内に非公開メンバ %q+#D があります"
 
 #: cp/decl2.c:1654
 #, fuzzy, gcc-internal-format
-#| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
@@ -53012,7 +49152,6 @@ msgstr "`operator delete' の戻り型は `void' でなければなりません"
 
 #: cp/decl2.c:1838
 #, fuzzy, gcc-internal-format
-#| msgid "destructor cannot be static member function"
 msgid "destroying %<operator delete%> must be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
@@ -53112,7 +49251,6 @@ msgstr ""
 
 #: cp/decl2.c:4694
 #, fuzzy, gcc-internal-format
-#| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
@@ -53148,7 +49286,6 @@ msgstr "strftime フォーマットは引数をフォーマットできません
 
 #: cp/decl2.c:5419
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "%qE は廃止されました"
 
@@ -53181,7 +49318,6 @@ msgstr ""
 
 #: cp/error.c:3868
 #, fuzzy, gcc-internal-format
-#| msgid "no arguments"
 msgid "(no argument)"
 msgstr "引数がありません"
 
@@ -53192,91 +49328,76 @@ msgstr ""
 
 #: cp/error.c:4311
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4316
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4321
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4326
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4331
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4336
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4341
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4346
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4351
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4356
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4361
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4366
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4371
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4376
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "c++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/error.c:4381
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -53292,7 +49413,6 @@ msgstr ""
 
 #: cp/error.c:4449
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
@@ -53303,7 +49423,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/error.c:4475
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
@@ -53314,7 +49433,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/error.c:4490
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not declared in %qD"
 msgid "%<::%D%> has not been declared; did you mean %qs?"
 msgstr "%qD は %qD 内では宣言されていません"
 
@@ -53325,13 +49443,11 @@ msgstr ""
 
 #: cp/except.c:147
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%qs declared incorrectly"
 msgstr "%qD はここで宣言されています"
 
 #: cp/except.c:419
 #, fuzzy, gcc-internal-format
-#| msgid "exception handling disabled, use -fexceptions to enable"
 msgid "exception handling disabled, use %<-fexceptions%> to enable"
 msgstr "例外処理を無効にしました. 有効にするには -fexceptions を使ってください"
 
@@ -53478,7 +49594,6 @@ msgstr "（もしこれがあなたの意図したものでなければ、関数
 
 #: cp/init.c:393
 #, fuzzy, gcc-internal-format
-#| msgid "invalid application of %qs to incomplete type %qT "
 msgid "value-initialization of incomplete type %qT"
 msgstr "%qs を不完全型 %qT へ適用することは無効です "
 
@@ -53499,7 +49614,6 @@ msgstr "可変配列メンバを初期化しています"
 
 #: cp/init.c:574
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of default argument for %q#D"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
@@ -53510,7 +49624,6 @@ msgstr ""
 
 #: cp/init.c:697
 #, fuzzy, gcc-internal-format
-#| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "可変配列メンバを初期化しています"
 
@@ -53526,7 +49639,6 @@ msgstr ""
 
 #: cp/init.c:802
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD はこの関数内で初期化されずに使用されています"
 
@@ -53543,7 +49655,6 @@ msgstr ""
 #: cp/init.c:923 cp/init.c:941 cp/init.c:949 cp/init.c:2470 cp/init.c:2498
 #: cp/method.c:2079 cp/method.c:2090
 #, fuzzy, gcc-internal-format
-#| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD は初期化されるべきです"
 
@@ -53554,7 +49665,6 @@ msgstr ""
 
 #: cp/init.c:1116
 #, fuzzy, gcc-internal-format
-#| msgid "%qD should be initialized"
 msgid "%qD will be initialized after"
 msgstr "%qD は初期化されるべきです"
 
@@ -53690,7 +49800,6 @@ msgstr ""
 
 #: cp/init.c:2490
 #, fuzzy, gcc-internal-format
-#| msgid "uninitialized const member in %qT is invalid in C++"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
@@ -53716,7 +49825,6 @@ msgstr ""
 
 #: cp/init.c:3035
 #, fuzzy, gcc-internal-format
-#| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "式内で整数がオーバーフローしました"
 
@@ -53727,7 +49835,6 @@ msgstr ""
 
 #: cp/init.c:3063
 #, fuzzy, gcc-internal-format
-#| msgid "variably modified field at file scope"
 msgid "variably modified type not allowed in new-expression"
 msgstr "ファイルスコープの可変フィールドです"
 
@@ -53858,7 +49965,6 @@ msgstr ""
 
 #: cp/lambda.c:548
 #, fuzzy, gcc-internal-format
-#| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "複合リテラルが可変サイズを持っています"
 
@@ -53894,7 +50000,6 @@ msgstr ""
 
 #: cp/lex.c:402
 #, fuzzy, gcc-internal-format
-#| msgid "invalid #pragma %s"
 msgid "invalid %<#pragma %s%>"
 msgstr "無効な #pragma %s です"
 
@@ -53915,7 +50020,6 @@ msgstr "\"%s\" は定義されていません"
 
 #: cp/lex.c:522
 #, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared (first use in this function)"
 msgid "%qD was not declared in this scope; did you mean %qs?"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
@@ -54006,13 +50110,11 @@ msgstr ""
 
 #: cp/method.c:832 cp/method.c:2029
 #, fuzzy, gcc-internal-format
-#| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D, cannot use default assignment operator"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
 #: cp/method.c:838 cp/method.c:2035
 #, fuzzy, gcc-internal-format
-#| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference member %q#D, cannot use default assignment operator"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
@@ -54023,19 +50125,16 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/method.c:929
 #, fuzzy, gcc-internal-format
-#| msgid "missing argument to %qs"
 msgid "determining value of %qs"
 msgstr "%qs への引数がありません"
 
 #: cp/method.c:956
 #, fuzzy, gcc-internal-format
-#| msgid "conflicting types for %q+D"
 msgid "forming type of %qs"
 msgstr "%q+D と型が競合しています"
 
 #: cp/method.c:1100
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "defaulted %qD only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -54046,7 +50145,6 @@ msgstr ""
 
 #: cp/method.c:1123
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %<const%>"
 msgid "defaulted %qD must be %<const%>"
 msgstr "重複した %<const%> です"
 
@@ -54087,7 +50185,6 @@ msgstr "ポインタを参照として宣言できません"
 
 #: cp/method.c:1370
 #, fuzzy, gcc-internal-format
-#| msgid "protected member %q+#D in anonymous union"
 msgid "cannot default compare anonymous union member"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
@@ -54118,7 +50215,6 @@ msgstr "デストラクタを静的メンバ関数とすることはできませ
 
 #: cp/method.c:2052
 #, fuzzy, gcc-internal-format
-#| msgid "uninitialized const %qD is invalid in C++"
 msgid "initializer for %q#D is invalid"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
@@ -54204,7 +50300,6 @@ msgstr ""
 
 #: cp/name-lookup.c:2272
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
@@ -54250,7 +50345,6 @@ msgstr "無効な宣言です"
 
 #: cp/name-lookup.c:2978
 #, fuzzy, gcc-internal-format
-#| msgid "no previous declaration for %qD"
 msgid "does not match previous declaration %q#D"
 msgstr "前に %qD 用の定義がありません"
 
@@ -54276,7 +50370,6 @@ msgstr ""
 
 #: cp/name-lookup.c:4625
 #, fuzzy, gcc-internal-format
-#| msgid "redeclaration of enumerator %q+D"
 msgid "using-declaration may not name enumerator %<%E::%D%>"
 msgstr "列挙型 %q+D の再宣言です"
 
@@ -54302,13 +50395,11 @@ msgstr ""
 
 #: cp/name-lookup.c:4713
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qE"
 msgstr "%qD は %qD 内では宣言されていません"
 
 #: cp/name-lookup.c:4729
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q#D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D が宣言されています"
 
@@ -54324,7 +50415,6 @@ msgstr "`%s' の宣言が矛盾しています"
 
 #: cp/name-lookup.c:4904
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
@@ -54355,7 +50445,6 @@ msgstr ""
 
 #: cp/name-lookup.c:4986
 #, fuzzy, gcc-internal-format
-#| msgid "inline function %qD given attribute noinline"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
@@ -54392,13 +50481,11 @@ msgstr "`this' は静的メンバ関数から使用できません"
 
 #: cp/name-lookup.c:6169
 #, fuzzy, gcc-internal-format
-#| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "弱い %q+D は %qE として定義できません"
 
 #: cp/name-lookup.c:6172
 #, fuzzy, gcc-internal-format
-#| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "構造体がここで定義されています"
 
@@ -54409,7 +50496,6 @@ msgstr "初期化された変数 `%s' は dllimport マークされています"
 
 #: cp/name-lookup.c:7305
 #, fuzzy, gcc-internal-format
-#| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
@@ -54436,13 +50522,11 @@ msgstr ""
 
 #: cp/name-lookup.c:7482
 #, fuzzy, gcc-internal-format
-#| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "メソッド属性を指定するのは最後のみでなければいけません"
 
 #: cp/name-lookup.c:7483
 #, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
@@ -54463,13 +50547,11 @@ msgstr ""
 
 #: cp/parser.c:842
 #, fuzzy, gcc-internal-format
-#| msgid "identifier %qE conflicts with C++ keyword"
 msgid "identifier %qE is a keyword in C++11"
 msgstr "識別子 %qE は C++ 予約語と競合しています"
 
 #: cp/parser.c:856
 #, fuzzy, gcc-internal-format
-#| msgid "identifier %qE conflicts with C++ keyword"
 msgid "identifier %qE is a keyword in C++20"
 msgstr "識別子 %qE は C++ 予約語と競合しています"
 
@@ -54480,7 +50562,6 @@ msgstr ""
 
 #: cp/parser.c:1363 cp/parser.c:41453
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
@@ -54581,7 +50662,6 @@ msgstr "無効な型: `void &'"
 
 #: cp/parser.c:3196
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
@@ -54657,7 +50737,6 @@ msgstr ""
 
 #: cp/parser.c:3331
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "class template argument deduction is only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -54684,37 +50763,31 @@ msgstr ""
 
 #: cp/parser.c:3365
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<constexpr%> only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:3368
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<noexcept%> only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:3373
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<thread_local%> only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:3376
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++20 %<constinit%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:3379
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<concept%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:3382 cp/parser.c:27723
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<requires%> only available with %<-std=c++2a%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -54790,19 +50863,16 @@ msgstr ""
 
 #: cp/parser.c:4503
 #, fuzzy, gcc-internal-format
-#| msgid "floating constant exceeds range of %qT"
 msgid "integer literal exceeds range of %qT type"
 msgstr "浮動小数定数が %qT の範囲を超えています"
 
 #: cp/parser.c:4510
 #, fuzzy, gcc-internal-format
-#| msgid "floating constant exceeds range of %qT"
 msgid "floating literal exceeds range of %qT type"
 msgstr "浮動小数定数が %qT の範囲を超えています"
 
 #: cp/parser.c:4514
 #, fuzzy, gcc-internal-format
-#| msgid "floating constant truncated to zero"
 msgid "floating literal truncated to zero"
 msgstr "浮動小数定数が 0 に切り詰められました"
 
@@ -54843,13 +50913,11 @@ msgstr ""
 
 #: cp/parser.c:5086 cp/parser.c:5101
 #, fuzzy, gcc-internal-format
-#| msgid "expected operator"
 msgid "expected binary operator"
 msgstr "演算子が予期されます"
 
 #: cp/parser.c:5107
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<...%>"
 msgid "expected ..."
 msgstr "%<...%> が予期されます"
 
@@ -54865,7 +50933,6 @@ msgstr "初期化子リストは複合式として取り扱われました"
 
 #: cp/parser.c:5132
 #, fuzzy, gcc-internal-format
-#| msgid "type mismatch in comparison expression"
 msgid "mismatched operator in fold-expression"
 msgstr "比較式内で型不一致です"
 
@@ -54886,7 +50953,6 @@ msgstr ""
 
 #: cp/parser.c:5370
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -54927,7 +50993,6 @@ msgstr "マクロ引数内でディレクトリを使うことはできません
 
 #: cp/parser.c:6114 cp/parser.c:8087
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -54993,13 +51058,11 @@ msgstr ""
 
 #: cp/parser.c:7098
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
 #: cp/parser.c:7110 cp/pt.c:19975
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
@@ -55020,7 +51083,6 @@ msgstr "無効な %qD の使用です"
 
 #: cp/parser.c:7834
 #, fuzzy, gcc-internal-format
-#| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
@@ -55045,9 +51107,9 @@ msgid "types may not be defined in %qs expressions"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
 #: cp/parser.c:8683
-#, gcc-internal-format
+#, fuzzy, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
-msgstr ""
+msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
 #: cp/parser.c:8769
 #, fuzzy, gcc-internal-format
@@ -55071,7 +51133,6 @@ msgstr ""
 
 #: cp/parser.c:8864
 #, fuzzy, gcc-internal-format
-#| msgid "expected expression"
 msgid "expected expression-list or type-id"
 msgstr "式が予期されます"
 
@@ -55087,7 +51148,6 @@ msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
 #: cp/parser.c:9429
 #, fuzzy, gcc-internal-format
-#| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "古いスタイルのキャストを使用しています"
 
@@ -55118,13 +51178,11 @@ msgstr "一つの空の宣言中に、二つの型が指定されています"
 
 #: cp/parser.c:10517
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in unevaluated context only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:10527
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda-expression in template-argument only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55145,13 +51203,11 @@ msgstr ""
 
 #: cp/parser.c:10721 cp/parser.c:10742 cp/parser.c:10934
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operand in unary expression"
 msgid "already captured %qD in lambda expression"
 msgstr "単項演算式内で無効な被演算子です"
 
 #: cp/parser.c:10736
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55162,7 +51218,6 @@ msgstr "%s を参照として宣言できません"
 
 #: cp/parser.c:10775
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack init-capture only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55173,7 +51228,6 @@ msgstr ""
 
 #: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55184,13 +51238,11 @@ msgstr ""
 
 #: cp/parser.c:10848
 #, fuzzy, gcc-internal-format
-#| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "読み取り専用変数 %qD の増分です"
 
 #: cp/parser.c:10852 cp/parser.c:10862 cp/semantics.c:3633 cp/semantics.c:3645
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%q#D declared here"
 msgstr "%qD はここで宣言されています"
 
@@ -55201,7 +51253,6 @@ msgstr ""
 
 #: cp/parser.c:10896
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "too many %<...%> in lambda capture"
 msgstr "%qs 句が多すぎます"
 
@@ -55217,13 +51268,11 @@ msgstr ""
 
 #: cp/parser.c:10991
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:10995
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55234,19 +51283,16 @@ msgstr "仮引数 `%s' で指定された記憶クラス"
 
 #: cp/parser.c:11081
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複した %<volatile%> です"
 
 #: cp/parser.c:11133
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:11521 cp/parser.c:11722
 #, fuzzy, gcc-internal-format
-#| msgid "attributes in parameter array declarator ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
@@ -55277,13 +51323,11 @@ msgstr ""
 
 #: cp/parser.c:11951
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:11978
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55299,7 +51343,6 @@ msgstr "関数が集合体を返しています"
 
 #: cp/parser.c:12198
 #, fuzzy, gcc-internal-format
-#| msgid "field %qE declared as a function"
 msgid "condition declares a function"
 msgstr "フィールド %qE が関数として宣言されています"
 
@@ -55316,7 +51359,6 @@ msgstr ""
 
 #: cp/parser.c:12701
 #, fuzzy, gcc-internal-format
-#| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
@@ -55332,13 +51374,11 @@ msgstr ""
 
 #: cp/parser.c:12974
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops with initializer only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:12998
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55400,19 +51440,16 @@ msgstr ""
 
 #: cp/parser.c:13943
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:13995
 #, fuzzy, gcc-internal-format
-#| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "空の宣言です"
 
 #: cp/parser.c:14013
 #, fuzzy, gcc-internal-format
-#| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "メンバ関数 %qD 用の無効な初期化子です"
 
@@ -55433,25 +51470,21 @@ msgstr ""
 
 #: cp/parser.c:14294
 #, fuzzy, gcc-internal-format
-#| msgid "%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> は C++0x で意味が変更になります。削除してください"
 
 #: cp/parser.c:14330
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specifiers invalid in friend function declarations"
 msgid "%<decl-specifier%> invalid in condition"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
 #: cp/parser.c:14337
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
 #: cp/parser.c:14418
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D invalid in %q#T"
 msgid "type-specifier invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
@@ -55472,7 +51505,6 @@ msgstr "例外仕様の検査をするコードを生成しない"
 
 #: cp/parser.c:14533
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<explicit(bool)%> only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55483,7 +51515,6 @@ msgstr "無効なリンク指定です"
 
 #: cp/parser.c:14701
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55519,7 +51550,6 @@ msgstr "メンバ `%s' に対する無効な初期値"
 
 #: cp/parser.c:15225 cp/pt.c:26036
 #, fuzzy, gcc-internal-format
-#| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
@@ -55545,19 +51575,16 @@ msgstr ""
 
 #: cp/parser.c:15768
 #, fuzzy, gcc-internal-format
-#| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "識別子が予期されます"
 
 #: cp/parser.c:15777
 #, fuzzy, gcc-internal-format
-#| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
 #: cp/parser.c:15783
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "二進演算内で無効な被演算子です"
 
@@ -55579,7 +51606,6 @@ msgstr "不完全な typedef `%s' の使用は不適切です"
 
 #: cp/parser.c:16050
 #, fuzzy, gcc-internal-format
-#| msgid "invalid parameter %qs"
 msgid "cv-qualified type parameter"
 msgstr "無効なパラメータ %qs です"
 
@@ -55630,7 +51656,6 @@ msgstr ""
 
 #: cp/parser.c:16694
 #, fuzzy, gcc-internal-format
-#| msgid "expected template-argument"
 msgid "expected %<(%> after template-argument-list"
 msgstr "テンプレート引数が予期されます"
 
@@ -55698,19 +51723,16 @@ msgstr "型指定が予期されます"
 
 #: cp/parser.c:17993
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:17999
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:18004
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with %<-fconcepts-ts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55731,13 +51753,11 @@ msgstr "クラスタイプ項を欠いています"
 
 #: cp/parser.c:18402
 #, fuzzy, gcc-internal-format
-#| msgid "union defined here"
 msgid "concept defined here"
 msgstr "共用体がここで定義されています"
 
 #: cp/parser.c:18424
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
@@ -55788,7 +51808,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/parser.c:19174
 #, fuzzy, gcc-internal-format
-#| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
@@ -55854,7 +51873,6 @@ msgstr "名前空間名が予期されます"
 
 #: cp/parser.c:19639
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested inline namespace definitions only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55865,13 +51883,11 @@ msgstr ""
 
 #: cp/parser.c:19669
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
-#| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "名前空間名が予期されます"
 
@@ -55882,13 +51898,11 @@ msgstr ""
 
 #: cp/parser.c:19688
 #, fuzzy, gcc-internal-format
-#| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
 #: cp/parser.c:19691
 #, fuzzy, gcc-internal-format
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
@@ -55904,7 +51918,6 @@ msgstr "ここでは %<namespace%> 定義は許可されていません"
 
 #: cp/parser.c:19907
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55915,7 +51928,6 @@ msgstr ""
 
 #: cp/parser.c:19952
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -55931,19 +51943,16 @@ msgstr "一つの空の宣言中に、二つの型が指定されています"
 
 #: cp/parser.c:20198
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:20217 cp/parser.c:20234 cp/parser.c:20248
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %<volatile%>"
 msgid "duplicate %<asm%> qualifier %qT"
 msgstr "重複した %<volatile%> です"
 
 #: cp/parser.c:20224
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not defined outside of function scope"
 msgid "%<asm%> qualifier %qT ignored outside of function body"
 msgstr "%qD は関数スコープの外側で定義されていません"
 
@@ -55954,7 +51963,6 @@ msgstr "%s=%s は数値ではありません"
 
 #: cp/parser.c:20277
 #, fuzzy, gcc-internal-format
-#| msgid "alloc_size parameter outside range"
 msgid "%<asm%> qualifier outside of function body"
 msgstr "alloc_size パラメータが範囲外です"
 
@@ -55990,7 +51998,6 @@ msgstr ""
 
 #: cp/parser.c:20893
 #, fuzzy, gcc-internal-format
-#| msgid "function template %qD redeclared as a class template"
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
@@ -56072,7 +52079,6 @@ msgstr ""
 
 #: cp/parser.c:22025
 #, fuzzy, gcc-internal-format
-#| msgid "expected type-specifier"
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
@@ -56133,19 +52139,16 @@ msgstr "strftime フォーマットは引数をフォーマットできません
 
 #: cp/parser.c:23104
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:23108
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:23432
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -56241,7 +52244,6 @@ msgstr ""
 
 #: cp/parser.c:24622
 #, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T の前の定義"
 
@@ -56257,7 +52259,6 @@ msgstr ""
 
 #: cp/parser.c:24740
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
@@ -56278,7 +52279,6 @@ msgstr ""
 
 #: cp/parser.c:25121
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -56294,7 +52294,6 @@ msgstr ""
 
 #: cp/parser.c:25291
 #, fuzzy, gcc-internal-format
-#| msgid "width of bit-field %qD has non-integral type %qT"
 msgid "bit-field %qD has non-integral type %qT"
 msgstr "ビットフィールドの幅が %qD 非整数型 %qT です"
 
@@ -56305,13 +52304,11 @@ msgstr ""
 
 #: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
 #: cp/parser.c:25386
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
@@ -56372,7 +52369,6 @@ msgstr "void 式の不適切な使用"
 
 #: cp/parser.c:26098
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<try%> in %<constexpr%> function only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -56388,7 +52384,6 @@ msgstr ""
 
 #: cp/parser.c:26831
 #, fuzzy, gcc-internal-format
-#| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
@@ -56410,19 +52405,16 @@ msgstr ""
 
 #: cp/parser.c:26994
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<:%> または %<...%> が予期されます"
 
 #: cp/parser.c:27054
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/parser.c:27394 cp/parser.c:27403
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "expression must be enclosed in parentheses"
 msgstr "添え字は整数でなければいけません"
 
@@ -56433,13 +52425,11 @@ msgstr ""
 
 #: cp/parser.c:28073
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not a constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求された整列が定数ではありません"
 
 #: cp/parser.c:28081
 #, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求された整列が定数ではありません"
 
@@ -56519,7 +52509,6 @@ msgstr "`%s' の extern 宣言がネストしています"
 
 #: cp/parser.c:29484
 #, fuzzy, gcc-internal-format
-#| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
@@ -56565,7 +52554,6 @@ msgstr ""
 
 #: cp/parser.c:30460
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
@@ -56651,7 +52639,6 @@ msgstr "%<throw%> が予期されます"
 
 #: cp/parser.c:30586
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "%<catch%> が予期されます"
 
@@ -56677,19 +52664,16 @@ msgstr "%<@throw%> が予期されます"
 
 #: cp/parser.c:30601
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
 #: cp/parser.c:30604
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
 #: cp/parser.c:30607
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> が予期されます"
 
@@ -56735,7 +52719,6 @@ msgstr ""
 
 #: cp/parser.c:31148
 #, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
@@ -56756,19 +52739,16 @@ msgstr ""
 
 #: cp/parser.c:31416 cp/parser.c:31449
 #, fuzzy, gcc-internal-format
-#| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "名前無しテンプレートクラスです"
 
 #: cp/parser.c:31423
 #, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "ラベル %qD はここで定義されています"
 
 #: cp/parser.c:31424
 #, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qD はここで宣言されています"
 
@@ -56794,7 +52774,6 @@ msgstr ""
 
 #: cp/parser.c:32085
 #, fuzzy, gcc-internal-format
-#| msgid "objective-c method declaration is expected"
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
@@ -56855,19 +52834,16 @@ msgstr ""
 
 #: cp/parser.c:34785
 #, fuzzy, gcc-internal-format
-#| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "整数式が予期されます"
 
 #: cp/parser.c:34802
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
 #: cp/parser.c:35776
 #, fuzzy, gcc-internal-format
-#| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
@@ -56883,7 +52859,6 @@ msgstr ""
 
 #: cp/parser.c:39056
 #, fuzzy, gcc-internal-format
-#| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
@@ -56899,19 +52874,16 @@ msgstr "不十分な型情報"
 
 #: cp/parser.c:41412
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
 #: cp/parser.c:42246
 #, fuzzy, gcc-internal-format
-#| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
 #: cp/parser.c:42276
 #, fuzzy, gcc-internal-format
-#| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
@@ -56988,19 +52960,16 @@ msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
 #: cp/parser.c:43840
 #, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
 #: cp/parser.c:43883
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
 #: cp/parser.c:43915
 #, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option は関数内では許可されていません"
 
@@ -57108,7 +53077,6 @@ msgstr ""
 
 #: cp/pt.c:2034 cp/semantics.c:5550
 #, fuzzy, gcc-internal-format
-#| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
@@ -57119,7 +53087,6 @@ msgstr "%qD は関数テンプレートではありません"
 
 #: cp/pt.c:2175
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD は変数ではありません"
 
@@ -57140,7 +53107,6 @@ msgstr ""
 
 #: cp/pt.c:2667
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -57172,13 +53138,11 @@ msgstr "宣言の中に代入(初期化ではなく)があります"
 
 #: cp/pt.c:2752
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "Code 属性を欠いています"
 
 #: cp/pt.c:2753
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "Code 属性を欠いています"
 
@@ -57262,7 +53226,6 @@ msgstr "friend 宣言がクラス定義の中にありません"
 
 #: cp/pt.c:3101
 #, fuzzy, gcc-internal-format
-#| msgid "shadowed declaration is here"
 msgid "friend declaration here"
 msgstr "隠された宣言はここです"
 
@@ -57273,7 +53236,6 @@ msgstr "インラインテンプレートの明示的な実体化のみを生成
 
 #: cp/pt.c:3790
 #, fuzzy, gcc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
@@ -57304,19 +53266,16 @@ msgstr "        %qD"
 
 #: cp/pt.c:4246
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
 #: cp/pt.c:4372
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
 #: cp/pt.c:4375
 #, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
@@ -57347,7 +53306,6 @@ msgstr ""
 
 #: cp/pt.c:5067 cp/pt.c:5078 cp/pt.c:5086
 #, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
@@ -57358,7 +53316,6 @@ msgstr ""
 
 #: cp/pt.c:5085
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "関数 %qE への引数が多すぎます"
 
@@ -57369,7 +53326,6 @@ msgstr ""
 
 #: cp/pt.c:5101
 #, fuzzy, gcc-internal-format
-#| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "重複したラベル %qD です"
 
@@ -57541,7 +53497,6 @@ msgstr "`%s' が別のシンボル種として再宣言されました"
 
 #: cp/pt.c:6195 cp/pt.c:6244
 #, fuzzy, gcc-internal-format
-#| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "元の定義はここに出現しています"
 
@@ -57597,7 +53552,6 @@ msgstr "%s に `%s' という名前のメンバはありません"
 
 #: cp/pt.c:6704
 #, fuzzy, gcc-internal-format
-#| msgid "template parameter %q+#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
@@ -57608,7 +53562,6 @@ msgstr ""
 
 #: cp/pt.c:6722
 #, fuzzy, gcc-internal-format
-#| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
@@ -57619,13 +53572,11 @@ msgstr "strftime フォーマットは引数をフォーマットできません
 
 #: cp/pt.c:6742
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
 #: cp/pt.c:6752
 #, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
@@ -57656,15 +53607,12 @@ msgstr ""
 
 #: cp/pt.c:6811
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "  candidate expects %d argument, %d provided"
-#| msgid_plural "  candidate expects %d arguments, %d provided"
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
 #: cp/pt.c:6842
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
@@ -57690,7 +53638,6 @@ msgstr "不完全型のポインタへの間接参照"
 
 #: cp/pt.c:6890
 #, fuzzy, gcc-internal-format
-#| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "型 %qT の引数が %qT と一致しません"
 
@@ -57711,7 +53658,6 @@ msgstr ""
 
 #: cp/pt.c:6970
 #, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
@@ -57787,7 +53733,6 @@ msgstr "不完全な typedef `%s' の使用は不適切です"
 
 #: cp/pt.c:8085
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
@@ -57873,7 +53818,6 @@ msgstr ""
 
 #: cp/pt.c:8722
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
@@ -57899,7 +53843,6 @@ msgstr ""
 
 #: cp/pt.c:9505
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
@@ -57915,7 +53858,6 @@ msgstr "空の宣言です"
 
 #: cp/pt.c:9796 cp/pt.c:20894
 #, fuzzy, gcc-internal-format
-#| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "内部一貫性がありません"
 
@@ -57931,7 +53873,6 @@ msgstr ""
 
 #: cp/pt.c:11922
 #, fuzzy, gcc-internal-format
-#| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "共用体に可変配列メンバがあります"
 
@@ -57942,7 +53883,6 @@ msgstr ""
 
 #: cp/pt.c:12822
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE は宣言の開始ではありません"
 
@@ -57958,7 +53898,6 @@ msgstr ""
 
 #: cp/pt.c:13481
 #, fuzzy, gcc-internal-format
-#| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
@@ -58087,7 +54026,6 @@ msgstr ""
 
 #: cp/pt.c:16291
 #, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -58133,13 +54071,11 @@ msgstr ""
 
 #: cp/pt.c:19941
 #, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
 #: cp/pt.c:19989
 #, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
@@ -58155,7 +54091,6 @@ msgstr ""
 
 #: cp/pt.c:20618
 #, fuzzy, gcc-internal-format
-#| msgid "%qT is not a template type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
@@ -58293,13 +54228,11 @@ msgstr ""
 
 #: cp/pt.c:26187
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
 #: cp/pt.c:26209
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of class type only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -58325,7 +54258,6 @@ msgstr ""
 
 #: cp/pt.c:27850
 #, fuzzy, gcc-internal-format
-#| msgid "destructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
@@ -58341,13 +54273,11 @@ msgstr ""
 
 #: cp/pt.c:28794
 #, fuzzy, gcc-internal-format
-#| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
 #: cp/pt.c:28801
 #, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "alias template deduction only available with %<-std=c++2a%> or %<-std=gnu++2a%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
@@ -58368,7 +54298,6 @@ msgstr "マクロ引数 \"%s\" は文字列化されます"
 
 #: cp/pt.c:28931
 #, fuzzy, gcc-internal-format
-#| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
@@ -58399,19 +54328,16 @@ msgstr ""
 
 #: cp/pt.c:29120
 #, fuzzy, gcc-internal-format
-#| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
 #: cp/pt.c:29124
 #, fuzzy, gcc-internal-format
-#| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
 #: cp/pt.c:29128
 #, fuzzy, gcc-internal-format
-#| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
@@ -58422,13 +54348,11 @@ msgstr "不完全な typedef `%s' の使用は不適切です"
 
 #: cp/rtti.c:313
 #, fuzzy, gcc-internal-format
-#| msgid "cannot use typeid with -fno-rtti"
 msgid "cannot use %<typeid%> with %<-fno-rtti%>"
 msgstr "-fno-rtti が指定されると typeid を使えません"
 
 #: cp/rtti.c:322
 #, fuzzy, gcc-internal-format
-#| msgid "must #include <typeinfo> before using typeid"
 msgid "must %<#include <typeinfo>%> before using %<typeid%>"
 msgstr "typeid を使う前に #include <typeinfo> としないといけません"
 
@@ -58454,7 +54378,6 @@ msgstr "-fno-rtti が指定されると typeid を使えません"
 
 #: cp/rtti.c:804
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert type %qT to type %qT"
 msgid "cannot %<dynamic_cast%> %qE (of type %q#T) to type %q#T (%s)"
 msgstr "型 %qT から型 %qT へ変換できません"
 
@@ -58475,7 +54398,6 @@ msgstr ""
 
 #: cp/search.c:1893
 #, fuzzy, gcc-internal-format
-#| msgid "In function %qs"
 msgid "overridden function is %q#F"
 msgstr "関数 %qs 内"
 
@@ -58486,7 +54408,6 @@ msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
 #: cp/search.c:1964 cp/search.c:1980 cp/search.c:1987 cp/search.c:2005
 #, fuzzy, gcc-internal-format
-#| msgid "decrement of function %qD"
 msgid "overridden function is %q#D"
 msgstr "関数 %qD の減分です"
 
@@ -58512,31 +54433,26 @@ msgstr ""
 
 #: cp/search.c:2023
 #, fuzzy, gcc-internal-format
-#| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
 #: cp/search.c:2031
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %q+D declared as non-function"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
 #: cp/search.c:2034 cp/search.c:2043 cp/search.c:2052
 #, fuzzy, gcc-internal-format
-#| msgid "decrement of function %qD"
 msgid "overridden function is %qD"
 msgstr "関数 %qD の減分です"
 
 #: cp/search.c:2040
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %q+D declared as non-function"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
 #: cp/search.c:2050
 #, fuzzy, gcc-internal-format
-#| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
@@ -58552,7 +54468,6 @@ msgstr ""
 
 #: cp/semantics.c:777
 #, fuzzy, gcc-internal-format
-#| msgid "Warn when a logical operator is suspiciously always evaluating to true or false"
 msgid "%qs always evaluates to true in %<if constexpr%>"
 msgstr "論理演算子が常に true または false と評価されるように思われる場合に警告する"
 
@@ -58583,7 +54498,6 @@ msgstr ""
 
 #: cp/semantics.c:1740
 #, fuzzy, gcc-internal-format
-#| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
@@ -58594,7 +54508,6 @@ msgstr "非メンバ関数での `this' の使用は無効です"
 
 #: cp/semantics.c:2198
 #, fuzzy, gcc-internal-format
-#| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "合っていない引数です"
 
@@ -58680,7 +54593,6 @@ msgstr "無効な宣言です"
 
 #: cp/semantics.c:3607
 #, fuzzy, gcc-internal-format
-#| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
@@ -58711,13 +54623,11 @@ msgstr ""
 
 #: cp/semantics.c:3771
 #, fuzzy, gcc-internal-format
-#| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size パラメータが範囲外です"
 
 #: cp/semantics.c:3781
 #, fuzzy, gcc-internal-format
-#| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "合っていない引数です"
 
@@ -58749,14 +54659,12 @@ msgstr "レジスタ '%c' が不明です"
 
 #: cp/semantics.c:4081
 #, fuzzy, gcc-internal-format
-#| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT はテンプレート型ではありません"
 
 #. Parameter packs can only be used in templates
 #: cp/semantics.c:4215
 #, fuzzy, gcc-internal-format
-#| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
@@ -58804,7 +54712,6 @@ msgstr ""
 
 #: cp/semantics.c:5870
 #, fuzzy, gcc-internal-format
-#| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
@@ -58825,7 +54732,6 @@ msgstr ""
 
 #: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
@@ -58851,7 +54757,6 @@ msgstr ""
 
 #: cp/semantics.c:6791
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
@@ -58872,19 +54777,16 @@ msgstr ""
 
 #: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
 #: cp/semantics.c:6863
 #, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
@@ -58895,19 +54797,16 @@ msgstr ""
 
 #: cp/semantics.c:6923
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
 #: cp/semantics.c:6937
 #, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
 #: cp/semantics.c:6957
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
@@ -58918,7 +54817,6 @@ msgstr ""
 
 #: cp/semantics.c:7016
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
@@ -58939,7 +54837,6 @@ msgstr ""
 
 #: cp/semantics.c:7089
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -58955,7 +54852,6 @@ msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
 #: cp/semantics.c:7148
 #, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
@@ -58966,7 +54862,6 @@ msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
 #: cp/semantics.c:7599
 #, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
@@ -58977,7 +54872,6 @@ msgstr ""
 
 #: cp/semantics.c:7672
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
@@ -58988,19 +54882,16 @@ msgstr ""
 
 #: cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
-#| msgid "index must be integer"
 msgid "%<hint%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
 #: cp/semantics.c:7745
 #, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
 #: cp/semantics.c:7768
 #, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
@@ -59011,7 +54902,6 @@ msgstr ""
 
 #: cp/semantics.c:7832
 #, fuzzy, gcc-internal-format
-#| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
@@ -59047,7 +54937,6 @@ msgstr ""
 
 #: cp/semantics.c:9704
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
@@ -59058,19 +54947,16 @@ msgstr ""
 
 #: cp/semantics.c:9745
 #, fuzzy, gcc-internal-format
-#| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
 #: cp/semantics.c:9773
 #, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
 #: cp/semantics.c:10316
 #, fuzzy, gcc-internal-format
-#| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
@@ -59086,7 +54972,6 @@ msgstr ""
 
 #: cp/semantics.c:10389
 #, fuzzy, gcc-internal-format
-#| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%> へのサポートされていない引数です"
 
@@ -59112,7 +54997,6 @@ msgstr ""
 
 #: cp/tree.c:4115
 #, fuzzy, gcc-internal-format
-#| msgid "declared here"
 msgid " declared here"
 msgstr "ここで宣言されています"
 
@@ -59133,13 +55017,11 @@ msgstr "メンバ関数の名前を欠いています"
 
 #: cp/tree.c:4540
 #, fuzzy, gcc-internal-format
-#| msgid "%q#T has pointer data members"
 msgid "%qT has a mutable member"
 msgstr "%q#T がポインタデータメンバを持っています"
 
 #: cp/tree.c:4551
 #, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %qT is not public"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
@@ -59155,13 +55037,11 @@ msgstr "%s は型 %s ではありません (引数 %d)"
 
 #: cp/tree.c:4580
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: cp/tree.c:4588
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
@@ -59177,7 +55057,6 @@ msgstr "`java_interface' 属性は Java クラス定義に対してのみ用い
 
 #: cp/tree.c:4619
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
@@ -59188,13 +55067,11 @@ msgstr "%s: オプション `%s' には引数が必要です\n"
 
 #: cp/tree.c:4643
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute does not apply to types"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE 属性は型に適用できません"
 
 #: cp/tree.c:4706
 #, fuzzy, gcc-internal-format
-#| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "要求された init_priority は整数型の定数ではありません"
 
@@ -59205,13 +55082,11 @@ msgstr "init_priority 属性はクラス型オブジェクトのファイルス
 
 #: cp/tree.c:4736
 #, fuzzy, gcc-internal-format
-#| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "要求された init_priority が範囲外です"
 
 #: cp/tree.c:4747
 #, fuzzy, gcc-internal-format
-#| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "要求された init_priority は内部で使用するために予約されています"
 
@@ -59232,55 +55107,46 @@ msgstr "%s: オプション `%s' には引数が必要です\n"
 
 #: cp/tree.c:4817
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: cp/tree.c:4830 cp/tree.c:4843
 #, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: cp/tree.c:4832
 #, fuzzy, gcc-internal-format
-#| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
 #: cp/tree.c:4845
 #, fuzzy, gcc-internal-format
-#| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
 #: cp/tree.c:4869
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
 #: cp/tree.c:4875
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
 #: cp/tree.c:4882
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
 #: cp/tree.c:4889
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
 #: cp/tree.c:4911
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
@@ -59346,13 +55212,11 @@ msgstr "型が全く異なるポインタの比較でキャストを欠いてい
 
 #: cp/typeck.c:1561
 #, fuzzy, gcc-internal-format
-#| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
 #: cp/typeck.c:1568
 #, fuzzy, gcc-internal-format
-#| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
@@ -59393,7 +55257,6 @@ msgstr "非メンバ関数での `this' の使用は無効です"
 
 #: cp/typeck.c:2200
 #, fuzzy, gcc-internal-format
-#| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
@@ -59445,25 +55308,21 @@ msgstr ""
 #. No hint.
 #: cp/typeck.c:2956
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
 #: cp/typeck.c:2979
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
 #: cp/typeck.c:2990
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
 #: cp/typeck.c:3004
 #, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
@@ -59639,7 +55498,6 @@ msgstr "ISO C++ はポインタと整数との比較を禁じます"
 
 #: cp/typeck.c:5295 cp/typeck.c:5308
 #, fuzzy, gcc-internal-format
-#| msgid "comparison between %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
@@ -59650,13 +55508,11 @@ msgstr ""
 
 #: cp/typeck.c:5419
 #, fuzzy, gcc-internal-format
-#| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮動小数点引数での順序付けられない比較です"
 
 #: cp/typeck.c:5464
 #, fuzzy
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
@@ -59723,7 +55579,6 @@ msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取るこ
 #. Make this a permerror because we used to accept it.
 #: cp/typeck.c:6289
 #, fuzzy, gcc-internal-format
-#| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
@@ -59739,7 +55594,6 @@ msgstr "ポインタを参照として宣言できません"
 
 #: cp/typeck.c:6384
 #, fuzzy, gcc-internal-format
-#| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
@@ -59750,7 +55604,6 @@ msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
 #: cp/typeck.c:6547
 #, fuzzy, gcc-internal-format
-#| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
@@ -59876,7 +55729,6 @@ msgstr "関数 `%s' に対して不適切な保存クラス"
 
 #: cp/typeck.c:7285
 #, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
@@ -59921,7 +55773,6 @@ msgstr "キャストによってポインタが示す型の要求アラインメ
 
 #: cp/typeck.c:7965
 #, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ は関数ポインタとオブジェクトポインタの間でのキャストを禁じます"
 
@@ -60012,31 +55863,26 @@ msgstr "無効なバージョン番号形式"
 
 #: cp/typeck.c:9335
 #, fuzzy
-#| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ポインタ型へ変換できません"
 
 #: cp/typeck.c:9340
 #, fuzzy
-#| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ポインタ型へ変換できません"
 
 #: cp/typeck.c:9349
 #, fuzzy
-#| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ポインタ型へ変換できません"
 
 #: cp/typeck.c:9353
 #, fuzzy
-#| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in return"
 msgstr "ポインタ型へ変換できません"
 
 #: cp/typeck.c:9358
 #, fuzzy
-#| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ポインタ型へ変換できません"
 
@@ -60112,7 +55958,6 @@ msgstr ""
 
 #: cp/typeck.c:9824
 #, fuzzy, gcc-internal-format
-#| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "return 文に十分な値がありません"
 
@@ -60142,7 +55987,6 @@ msgstr "戻り型が関数で、`return' に値がありません"
 
 #: cp/typeck.c:9917
 #, fuzzy, gcc-internal-format
-#| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
@@ -60168,7 +56012,6 @@ msgstr ""
 
 #: cp/typeck.c:10639
 #, fuzzy, gcc-internal-format
-#| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
 msgstr "無効な %%s 値"
 
@@ -60285,7 +56128,6 @@ msgstr "仮引数 `%s' は無効です"
 
 #: cp/typeck2.c:360
 #, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
 msgid "expression of abstract class type %qT cannot be used in throw-expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
@@ -60306,7 +56148,6 @@ msgstr "  以下の仮想関数が抽象であるためです:"
 
 #: cp/typeck2.c:384
 #, fuzzy, gcc-internal-format
-#| msgid "        %qD"
 msgid "    %#qD"
 msgstr "        %qD"
 
@@ -60367,7 +56208,6 @@ msgstr "未定義の型 `%s %s' の使用は不適切です"
 
 #: cp/typeck2.c:565
 #, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<restrict%>"
 msgid "invalid use of brace-enclosed initializer list"
 msgstr "%<restrict%> の誤った使用法です"
 
@@ -60398,25 +56238,21 @@ msgstr "関数を inline にできません"
 
 #: cp/typeck2.c:1061
 #, fuzzy
-#| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
 #: cp/typeck2.c:1073 cp/typeck2.c:1086
 #, fuzzy
-#| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
 #: cp/typeck2.c:1076
 #, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
 #: cp/typeck2.c:1235
 #, fuzzy, gcc-internal-format
-#| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "char の配列にとって初期化子文字列が長すぎます"
 
@@ -60427,7 +56263,6 @@ msgstr ""
 
 #: cp/typeck2.c:1298
 #, fuzzy, gcc-internal-format
-#| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
@@ -60453,7 +56288,6 @@ msgstr "仮引数 `%s' が初期化されました"
 
 #: cp/typeck2.c:1801
 #, fuzzy, gcc-internal-format
-#| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
@@ -60504,13 +56338,11 @@ msgstr ""
 
 #: cp/typeck2.c:2241
 #, fuzzy, gcc-internal-format
-#| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
 #: cp/typeck2.c:2252
 #, fuzzy, gcc-internal-format
-#| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
@@ -60621,7 +56453,6 @@ msgstr ""
 
 #: fortran/arith.c:903
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "floating constant exceeds range of %qT"
 msgid "Result of exponentiation at %L exceeds the range of %s"
 msgstr "浮動小数定数が %qT の範囲を超えています"
 
@@ -60637,7 +56468,6 @@ msgstr ""
 
 #: fortran/arith.c:979
 #, fuzzy, gcc-internal-format
-#| msgid "ia64_print_operand: unknown code"
 msgid "arith_power(): unknown type"
 msgstr "ia64_print_operand: 不明なコードです"
 
@@ -60782,7 +56612,6 @@ msgstr ""
 
 #: fortran/array.c:269
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE attribute ignored"
 msgid "TEAM= attribute in %C misplaced"
 msgstr "%qE 属性は無視されました"
 
@@ -60803,7 +56632,6 @@ msgstr ""
 
 #: fortran/array.c:306 fortran/array.c:314
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<(%> or end of line"
 msgid "Unexpected %<*%> for codimension %d of %d at %C"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
@@ -60954,7 +56782,6 @@ msgstr ""
 
 #: fortran/array.c:1318 fortran/array.c:1328
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
@@ -61010,14 +56837,12 @@ msgstr ""
 
 #: fortran/array.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "overflow in array dimension"
 msgid "Bad array dimension at %L"
 msgstr "配列の次元がオーバーフローしました"
 
 #: fortran/array.c:2394 fortran/data.c:563 fortran/data.c:582
 #: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
-#| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimplification に失敗しました"
 
@@ -61164,7 +56989,6 @@ msgstr ""
 
 #: fortran/check.c:841
 #, fuzzy, gcc-internal-format
-#| msgid "%qs must be used with %qs"
 msgid "%qs at %L must be less than BIT_SIZE(%qs)"
 msgstr "%qs は %qs と併用しなければいけません"
 
@@ -61335,7 +57159,6 @@ msgstr ""
 
 #: fortran/check.c:1878
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong type argument to %s"
 msgid "Negative argument N at %L"
 msgstr "%s への間違った型の引数です"
 
@@ -61366,7 +57189,6 @@ msgstr ""
 
 #: fortran/check.c:2178
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "the last argument must be a 2-bit immediate"
 msgid "The stat= argument at %L must be a kind=4 integer variable"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
@@ -61518,7 +57340,6 @@ msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
 #: fortran/check.c:3063
 #, fuzzy, gcc-internal-format
-#| msgid "arguments 1 and 2 have different types"
 msgid "Arguments of %qs have different kind type parameters at %L"
 msgstr "引数1と引数2が異なる型を持っています"
 
@@ -61979,7 +57800,6 @@ msgstr ""
 
 #: fortran/check.c:6052
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
@@ -62227,7 +58047,6 @@ msgstr ""
 
 #: fortran/decl.c:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "empty scalar initializer"
 msgid "Empty old style initializer list at %C"
 msgstr "空のスカラー初期化子です"
 
@@ -62238,7 +58057,6 @@ msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
 #: fortran/decl.c:829
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "スカラー初期化子内に余分な要素があります"
 
@@ -62259,13 +58077,11 @@ msgstr "長さ 0 の初期化は推奨されません"
 
 #: fortran/decl.c:908
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "配列初期化子内の要素が多すぎます"
 
 #: fortran/decl.c:910
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "配列初期化子内の要素が多すぎます"
 
@@ -62291,7 +58107,6 @@ msgstr ""
 
 #: fortran/decl.c:1064
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "different parameter types"
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
@@ -62312,7 +58127,6 @@ msgstr "メソッド仕様内での構文解析エラー"
 
 #: fortran/decl.c:1361 fortran/decl.c:1368 fortran/decl.c:1432
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is already defined in %qT"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "%qD は既に %qT 内で定義されています"
 
@@ -62398,7 +58212,6 @@ msgstr ""
 
 #: fortran/decl.c:1774
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "引数は定数でなければいけません"
 
@@ -62434,7 +58247,6 @@ msgstr ""
 
 #: fortran/decl.c:2028
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize implied-shape array at %L with scalar"
 msgstr "多次元配列は初期化子で初期化することができません"
 
@@ -62530,7 +58342,6 @@ msgstr ""
 
 #: fortran/decl.c:2493
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qE 属性は %s 属性と競合します"
 
@@ -62571,7 +58382,6 @@ msgstr ""
 
 #: fortran/decl.c:2745
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert to a pointer type"
 msgid "Cannot set pointee array spec."
 msgstr "ポインタ型へ変換できません"
 
@@ -62717,7 +58527,6 @@ msgstr ""
 
 #: fortran/decl.c:3719
 #, fuzzy, gcc-internal-format
-#| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
@@ -62891,19 +58700,16 @@ msgstr ""
 
 #: fortran/decl.c:5447
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "can%'t set %qE attribute after definition"
 msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
 #: fortran/decl.c:5457
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
 #: fortran/decl.c:5459
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
 msgid "KIND attribute at %C in a STRUCTURE definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
@@ -62919,13 +58725,11 @@ msgstr ""
 
 #: fortran/decl.c:5484
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "can%'t set %qE attribute after definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
 #: fortran/decl.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "can%'t set %qE attribute after definition"
 msgid "LEN attribute at %C in a STRUCTURE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
@@ -63068,7 +58872,6 @@ msgstr ""
 
 #: fortran/decl.c:6048
 #, fuzzy, gcc-internal-format
-#| msgid "missing number"
 msgid "Missing symbol"
 msgstr "数値がありません"
 
@@ -63129,7 +58932,6 @@ msgstr ""
 
 #: fortran/decl.c:6475
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "parameter name omitted"
 msgid "A type parameter list is required at %C"
 msgstr "仮引数名が省略されています"
 
@@ -63140,7 +58942,6 @@ msgstr "ファイル \"%s\" に戻るはずでした"
 
 #: fortran/decl.c:6495 fortran/decl.c:6503
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "parameter name omitted"
 msgid "A parameter name is required at %C"
 msgstr "仮引数名が省略されています"
 
@@ -63161,7 +58962,6 @@ msgstr ""
 
 #: fortran/decl.c:6577
 #, fuzzy, gcc-internal-format
-#| msgid "parameter name missing from parameter list"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "仮引数リストに仮引数名がありません"
 
@@ -63273,7 +59073,6 @@ msgstr ""
 
 #: fortran/decl.c:7540
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in statement"
 msgid "ENTRY statement at %C"
 msgstr "式内"
 
@@ -63344,7 +59143,6 @@ msgstr ""
 
 #: fortran/decl.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected statement"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "文が予期されます"
 
@@ -63380,7 +59178,6 @@ msgstr ""
 
 #: fortran/decl.c:8047
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -63477,7 +59274,6 @@ msgstr ""
 
 #: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> が予期されます"
 
@@ -63503,7 +59299,6 @@ msgstr ""
 
 #: fortran/decl.c:8796
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert to a pointer type"
 msgid "Cannot set Cray pointee array spec."
 msgstr "ポインタ型へ変換できません"
 
@@ -63645,7 +59440,6 @@ msgstr ""
 
 #: fortran/decl.c:9549
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in statement"
 msgid "VALUE statement at %C"
 msgstr "式内"
 
@@ -63736,7 +59530,6 @@ msgstr ""
 
 #: fortran/decl.c:10070
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to close read state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "読み込んだ状態ファイル %s を閉じるのに失敗しました [%s]"
 
@@ -63807,7 +59600,6 @@ msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
 #: fortran/decl.c:10473
 #, fuzzy, gcc-internal-format
-#| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD は既に定義されています"
 
@@ -63958,7 +59750,6 @@ msgstr ""
 
 #: fortran/decl.c:11260
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<::%>"
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> が予期されます"
 
@@ -63974,7 +59765,6 @@ msgstr ""
 
 #: fortran/decl.c:11304
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "%<=%> が予期されます"
 
@@ -64025,7 +59815,6 @@ msgstr ""
 
 #: fortran/decl.c:11509
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> が予期されます"
 
@@ -64126,7 +59915,6 @@ msgstr ""
 
 #: fortran/dump-parse-tree.c:3403 fortran/dump-parse-tree.c:3508
 #, fuzzy, gcc-internal-format
-#| msgid "cannot convert to a pointer type"
 msgid "Cannot convert %qs to interoperable type at %L"
 msgstr "ポインタ型へ変換できません"
 
@@ -64771,7 +60559,6 @@ msgstr "入力ファイル %s を close できません"
 
 #: fortran/frontend-passes.c:195
 #, fuzzy, gcc-internal-format
-#| msgid "in statement"
 msgid "Inconsistent internal state: No location in statement"
 msgstr "式内"
 
@@ -64804,19 +60591,16 @@ msgstr "FPU レジスタ内の機能の値を返す"
 
 #: fortran/frontend-passes.c:1356 fortran/frontend-passes.c:1395
 #, fuzzy, gcc-internal-format
-#| msgid "expected expression"
 msgid "bad expression"
 msgstr "式が予期されます"
 
 #: fortran/frontend-passes.c:1391
 #, fuzzy, gcc-internal-format
-#| msgid "bad move"
 msgid "bad op"
 msgstr "誤った move です"
 
 #: fortran/frontend-passes.c:2175
 #, fuzzy, gcc-internal-format
-#| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
@@ -64867,7 +60651,6 @@ msgstr ""
 
 #: fortran/gfortranspec.c:146
 #, fuzzy, gcc-internal-format
-#| msgid "no default argument for %qD"
 msgid "overflowed output argument list for %qs"
 msgstr "%qD 用のデフォルト引数がありません"
 
@@ -65493,7 +61276,6 @@ msgstr ""
 
 #: fortran/interface.c:4158
 #, fuzzy, gcc-internal-format
-#| msgid "%q+D aliased to undefined symbol %qE"
 msgid "Unable to find symbol %qs"
 msgstr "%q+D が未定義シンボル %qE の別名となっています"
 
@@ -65599,7 +61381,6 @@ msgstr "`%s' オプションに対する引数がありません"
 
 #: fortran/interface.c:4936
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument must be a constant"
 msgid "DTIO dummy argument at %L must be a scalar"
 msgstr "引数は定数でなければいけません"
 
@@ -65665,7 +61446,6 @@ msgstr ""
 
 #: fortran/intrinsic.c:286
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
 msgid "do_check(): too many args"
 msgstr "引数が多すぎます"
 
@@ -65691,13 +61471,11 @@ msgstr ""
 
 #: fortran/intrinsic.c:4280
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "parameter name omitted"
 msgid "Scalar entity required at %L"
 msgstr "仮引数名が省略されています"
 
 #: fortran/intrinsic.c:4291
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "parameter name omitted"
 msgid "Array entity required at %L"
 msgstr "仮引数名が省略されています"
 
@@ -65753,7 +61531,6 @@ msgstr ""
 
 #: fortran/intrinsic.c:4699
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
 msgid "init_arglist(): too many arguments"
 msgstr "引数が多すぎます"
 
@@ -65843,7 +61620,6 @@ msgstr ""
 
 #: fortran/io.c:210
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unknown conversion type character %qc in format"
 msgid "Nonconforming tab character in format at %C"
 msgstr "書式内に不明な型変換文字 %qc があります"
 
@@ -65869,43 +61645,36 @@ msgstr "認識できないフォーマット指定子"
 
 #: fortran/io.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Nonnegative width required"
 msgid "Nonnegative width required in format string at %L"
 msgstr "非負の幅が必要です"
 
 #: fortran/io.c:600
 #, fuzzy, gcc-internal-format
-#| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
 #: fortran/io.c:602
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected end of format string in format string at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
 #: fortran/io.c:604
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Zero width in format descriptor"
 msgid "Zero width in format descriptor in format string at %L"
 msgstr "幅 0 の書式記述子です"
 
 #: fortran/io.c:624
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Missing leading left parenthesis"
 msgid "Missing leading left parenthesis in format string at %L"
 msgstr "前に左小括弧がありません"
 
 #: fortran/io.c:653
 #, fuzzy, gcc-internal-format
-#| msgid "Left parenthesis required after '*'"
 msgid "Left parenthesis required after %<*%> in format string at %L"
 msgstr "'*' の後には左小括弧が必要です"
 
 #: fortran/io.c:685
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected element '%c' in format string at %L"
 msgid "Expected P edit descriptor in format string at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
@@ -65922,7 +61691,6 @@ msgstr ""
 
 #: fortran/io.c:730
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "no description yet"
 msgid "$ descriptor at %L"
 msgstr "説明はまだありません"
 
@@ -65938,7 +61706,6 @@ msgstr "フォーマット文字列が null です"
 
 #: fortran/io.c:797 fortran/io.c:812
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Generate run time type descriptor information"
 msgid "Comma required after P descriptor in format string at %L"
 msgstr "実行時型記述子情報を生成する"
 
@@ -65949,7 +61716,6 @@ msgstr "認識できないフォーマット指定子"
 
 #: fortran/io.c:846 fortran/io.c:850
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Zero width in format descriptor"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "幅 0 の書式記述子です"
 
@@ -65965,7 +61731,6 @@ msgstr "フォーマット文字列が null です"
 
 #: fortran/io.c:911
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected element '%c' in format string at %L"
 msgid "E specifier not allowed with g0 descriptor in format string at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
@@ -65976,7 +61741,6 @@ msgstr ""
 
 #: fortran/io.c:941
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Positive width required"
 msgid "positive width required at %L"
 msgstr "正の幅が必要です"
 
@@ -66057,7 +61821,6 @@ msgstr ""
 
 #: fortran/io.c:1527
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qD is not a variable"
 msgid "Expecting a variable at %L"
 msgstr "%qD は変数ではありません"
 
@@ -66615,7 +62378,6 @@ msgstr ""
 
 #: fortran/match.c:1365
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "initializer element is not a constant expression"
 msgid "Assignment to a constant expression at %C"
 msgstr "初期化子の要素が定数式ではありません"
 
@@ -66736,7 +62498,6 @@ msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
 #: fortran/match.c:2000
 #, fuzzy, gcc-internal-format
-#| msgid "expected %<,%> or %<)%>"
 msgid "Expected %<)%> or %<,%> at %C"
 msgstr "%<,%> または %<)%> が予期されます"
 
@@ -66848,7 +62609,6 @@ msgstr ""
 
 #: fortran/match.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "lvalue required in asm statement"
 msgid "Blank required in %s statement near %C"
 msgstr "アセンブラ文内に左辺値が必要です"
 
@@ -67006,7 +62766,6 @@ msgstr ""
 
 #: fortran/match.c:3762
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in statement"
 msgid "LOCK statement at %C"
 msgstr "式内"
 
@@ -67072,7 +62831,6 @@ msgstr ""
 
 #: fortran/match.c:4291 fortran/match.c:4728
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected statement"
 msgid "Unexpected constant at %C"
 msgstr "文が予期されます"
 
@@ -67296,7 +63054,6 @@ msgstr ""
 
 #: fortran/match.c:5425
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "In constructor %qs"
 msgid "BLOCK DATA construct at %L"
 msgstr "コンストラクタ %qs 内"
 
@@ -67342,7 +63099,6 @@ msgstr ""
 
 #: fortran/match.c:5759
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in statement"
 msgid "EQUIVALENCE statement at %C"
 msgstr "式内"
 
@@ -67398,7 +63154,6 @@ msgstr ""
 
 #: fortran/match.c:6623
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in statement"
 msgid "SELECT RANK statement at %C"
 msgstr "式内"
 
@@ -67449,7 +63204,6 @@ msgstr "メソッド仕様内での構文解析エラー"
 
 #: fortran/match.c:6971
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected statement"
 msgid "Unexpected RANK statement at %C"
 msgstr "文が予期されます"
 
@@ -67826,7 +63580,6 @@ msgstr "')' が必要です"
 
 #: fortran/openmp.c:279
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "environment variable %qs not defined"
 msgid "List item shall not be coindexed at %C"
 msgstr "環境変数 %qs が定義されていません"
 
@@ -67878,7 +63631,6 @@ msgstr ""
 
 #: fortran/openmp.c:1553
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "ORDERED clause argument not constant positive integer at %C"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
@@ -67889,7 +63641,6 @@ msgstr ""
 
 #: fortran/openmp.c:1990
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to close read state file %s [%s]"
 msgid "Failed to match clause at %C"
 msgstr "読み込んだ状態ファイル %s を閉じるのに失敗しました [%s]"
 
@@ -67955,7 +63706,6 @@ msgstr ""
 
 #: fortran/openmp.c:2459
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine at %C"
 msgstr "型名用に記憶域クラスが指定されました"
 
@@ -68257,19 +64007,16 @@ msgstr ""
 
 #: fortran/openmp.c:4303
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
 msgid "Object %qs is not a variable at %L; parameters cannot be and need not be copied"
 msgstr "%qD は変数ではありません"
 
 #: fortran/openmp.c:4307
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
 msgid "Object %qs is not a variable at %L; parameters cannot be and need not be mapped"
 msgstr "%qD は変数ではありません"
 
 #: fortran/openmp.c:4312 fortran/openmp.c:6313
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
 msgid "Object %qs is not a variable at %L"
 msgstr "%qD は変数ではありません"
 
@@ -68493,7 +64240,6 @@ msgstr ""
 
 #: fortran/openmp.c:5137
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected expression"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "式が予期されます"
 
@@ -68799,13 +64545,11 @@ msgstr ""
 
 #: fortran/options.c:479
 #, fuzzy, gcc-internal-format
-#| msgid "alignment for %q+D must be at least %d"
 msgid "Fixed line length must be at least seven"
 msgstr "%q+D 用の整列は最低 %d でなければいけません"
 
 #: fortran/options.c:482
 #, fuzzy, gcc-internal-format
-#| msgid "alignment for %q+D must be at least %d"
 msgid "Free line length must be at least three"
 msgstr "%q+D 用の整列は最低 %d でなければいけません"
 
@@ -69066,13 +64810,11 @@ msgstr ""
 
 #: fortran/parse.c:3180
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to open %s"
 msgid "failed to create map component '%s'"
 msgstr "%s を開くのに失敗しました"
 
 #: fortran/parse.c:3213
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to open %s"
 msgid "failed to create union component '%s'"
 msgstr "%s を開くのに失敗しました"
 
@@ -69243,13 +64985,11 @@ msgstr ""
 
 #: fortran/parse.c:4611
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "In constructor %qs"
 msgid "BLOCK construct at %C"
 msgstr "コンストラクタ %qs 内"
 
 #: fortran/parse.c:4645
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "In constructor %qs"
 msgid "ASSOCIATE construct at %C"
 msgstr "コンストラクタ %qs 内"
 
@@ -69698,7 +65438,6 @@ msgstr "値をベクトルには変換できません"
 
 #: fortran/primary.c:3091
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs attribute requires prototypes with named arguments"
 msgid "Structure constructor with named arguments at %C"
 msgstr "%qs 属性は名前付き引数を持つプロトタイプが必要です"
 
@@ -69844,7 +65583,6 @@ msgstr "FPU レジスタ内の機能の値を返す"
 
 #: fortran/resolve.c:315
 #, fuzzy, gcc-internal-format
-#| msgid "explicit template argument list not allowed"
 msgid "Self-referential argument %qs at %L is not allowed"
 msgstr "明示的なテンプレート引数リストは許可されていません"
 
@@ -70247,7 +65985,6 @@ msgstr ""
 
 #: fortran/resolve.c:2837
 #, fuzzy, gcc-internal-format
-#| msgid "error in args to spec function %qs"
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
@@ -70278,7 +66015,6 @@ msgstr ""
 
 #: fortran/resolve.c:3142
 #, fuzzy, gcc-internal-format
-#| msgid "expected numeric type"
 msgid "Unexpected junk after %qs at %L"
 msgstr "数値型が予期されます"
 
@@ -70305,7 +66041,6 @@ msgstr ""
 
 #: fortran/resolve.c:3250
 #, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
 msgid "resolve_function(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
@@ -70381,7 +66116,6 @@ msgstr ""
 
 #: fortran/resolve.c:3712
 #, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
 msgid "resolve_subroutine(): bad function type"
 msgstr "<未解決オーバーロードされた関数型>"
 
@@ -70402,7 +66136,6 @@ msgstr "関数を inline にできません"
 
 #: fortran/resolve.c:3909
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Impure function at %L might not be evaluated"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
@@ -70473,7 +66206,6 @@ msgstr ""
 
 #: fortran/resolve.c:4683
 #, fuzzy, gcc-internal-format
-#| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
@@ -70723,7 +66455,6 @@ msgstr ""
 
 #: fortran/resolve.c:7150
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "index must be integer"
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
@@ -71008,7 +66739,6 @@ msgstr ""
 
 #: fortran/resolve.c:8943
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
@@ -71049,7 +66779,6 @@ msgstr ""
 
 #: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format
-#| msgid "expected numeric type"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
@@ -71240,7 +66969,6 @@ msgstr ""
 
 #: fortran/resolve.c:10553
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "In constructor %qs"
 msgid "FORALL construct at %L"
 msgstr "コンストラクタ %qs 内"
 
@@ -71501,7 +67229,6 @@ msgstr "`%s' に `extern' と初期化子の両方があります"
 
 #: fortran/resolve.c:12959
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
@@ -71582,25 +67309,21 @@ msgstr ""
 
 #: fortran/resolve.c:13214
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: fortran/resolve.c:13220
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: fortran/resolve.c:13226
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
 #: fortran/resolve.c:13234
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
@@ -71876,7 +67599,6 @@ msgstr ""
 
 #: fortran/resolve.c:14863
 #, fuzzy, gcc-internal-format
-#| msgid "%qD has already been defined"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD は既に定義されています"
 
@@ -71917,7 +67639,6 @@ msgstr ""
 
 #: fortran/resolve.c:15025
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
@@ -72353,13 +68074,11 @@ msgstr ""
 
 #: fortran/scanner.c:332
 #, fuzzy, gcc-internal-format
-#| msgid "In destructor %qs"
 msgid "Include directory %qs: %s"
 msgstr "デストラクタ %qs 内"
 
 #: fortran/scanner.c:336
 #, fuzzy, gcc-internal-format
-#| msgid "ignoring nonexistent directory \"%s\"\n"
 msgid "Nonexistent include directory %qs"
 msgstr "存在しないディレクトリ \"%s\" を無視します\n"
 
@@ -72520,13 +68239,11 @@ msgstr ""
 
 #: fortran/simplify.c:1138
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument of ACOSD at %L must be between -1 and 1"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
 #: fortran/simplify.c:1164
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "Argument of ASIND at %L must be between -1 and 1"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
@@ -72733,7 +68450,6 @@ msgstr ""
 
 #: fortran/simplify.c:6861
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "size of array is too large"
 msgid "Reshaped array too large at %C"
 msgstr "配列のサイズが大きすぎます"
 
@@ -73119,7 +68835,6 @@ msgstr "行番号 %u に戻るはずでした"
 
 #: fortran/symbol.c:2819
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in statement"
 msgid "Labeled DO statement at %L"
 msgstr "式内"
 
@@ -73191,7 +68906,6 @@ msgstr ""
 
 #: fortran/target-memory.c:137
 #, fuzzy, gcc-internal-format
-#| msgid "invalid expression as operand"
 msgid "Invalid expression in gfc_element_size."
 msgstr "被演算子として無効な式です"
 
@@ -73239,7 +68953,6 @@ msgstr ""
 
 #: fortran/trans-common.c:790
 #, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
 msgid "get_mpz(): Not an integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
@@ -73391,7 +69104,6 @@ msgstr ""
 
 #: fortran/trans-expr.c:957
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ISO C90 forbids variable length array %qE"
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
@@ -73443,7 +69155,6 @@ msgstr ""
 
 #: fortran/trans-intrinsic.c:11673
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "environment variable %qs not defined"
 msgid "The event variable at %L shall not be coindexed"
 msgstr "環境変数 %qs が定義されていません"
 
@@ -73464,7 +69175,6 @@ msgstr ""
 
 #: fortran/trans-openmp.c:2474
 #, fuzzy, gcc-internal-format
-#| msgid "invalid PHI argument"
 msgid "optional class parameter"
 msgstr "無効な PHI 引数です"
 
@@ -73570,19 +69280,16 @@ msgstr ""
 
 #: jit/docs/examples/tut05-bf.c:242
 #, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
 msgid "too many open parens"
 msgstr "引数が多すぎます"
 
 #: jit/docs/examples/tut05-bf.c:275
 #, fuzzy, gcc-internal-format
-#| msgid "mismatched arguments"
 msgid "mismatching parens"
 msgstr "合っていない引数です"
 
 #: jit/docs/examples/tut05-bf.c:310
 #, fuzzy, gcc-internal-format
-#| msgid "failed to open %s"
 msgid "unable to open file"
 msgstr "%s を開くのに失敗しました"
 
@@ -73638,19 +69345,16 @@ msgstr "friend 関数 `%s' を初期化できません"
 
 #: lto/lto-common.c:2346
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "%s を開けません"
 
 #: lto/lto-common.c:2367
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "%s を開けません"
 
 #: lto/lto-common.c:2378
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "%s を開けません"
 
@@ -73676,7 +69380,6 @@ msgstr ""
 
 #: lto/lto-dump.c:273
 #, fuzzy, gcc-internal-format
-#| msgid "function not inlinable"
 msgid "Function not found."
 msgstr "inline にできない関数です"
 
@@ -73727,13 +69430,11 @@ msgstr ""
 
 #: lto/lto-symtab.c:169
 #, fuzzy, gcc-internal-format
-#| msgid "%qD is already defined in the class %qT"
 msgid "%qD is defined with tls model %s"
 msgstr "%qD は既にクラス %qT 内で定義されています"
 
 #: lto/lto-symtab.c:171
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "previously defined here"
 msgid "previously defined here as %s"
 msgstr "前はここで定義されました"
 
@@ -73769,13 +69470,11 @@ msgstr "%qD の整列は元の宣言より大きいです"
 
 #: lto/lto-symtab.c:752
 #, fuzzy, gcc-internal-format
-#| msgid "type of %qD does not match original declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "%qD の型は元の宣言と一致しません"
 
 #: lto/lto-symtab.c:757
 #, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
 msgid "%qD was previously declared here"
 msgstr "前はここで宣言されました"
 
@@ -73806,13 +69505,11 @@ msgstr ""
 
 #: lto/lto.c:199
 #, fuzzy, gcc-internal-format
-#| msgid "atexit failed"
 msgid "waitpid failed"
 msgstr "atexit に失敗しました"
 
 #: lto/lto.c:202
 #, fuzzy, gcc-internal-format
-#| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr ".rpo ファイルの名前を変更しています"
 
@@ -74004,19 +69701,16 @@ msgstr ""
 
 #: objc/objc-act.c:1093
 #, fuzzy, gcc-internal-format
-#| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%<nonatomic%> attribute of property %qD conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
 #: objc/objc-act.c:1104
 #, fuzzy, gcc-internal-format
-#| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%<getter%> attribute of property %qD conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
 #: objc/objc-act.c:1118
 #, fuzzy, gcc-internal-format
-#| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%<setter%> attribute of property %qD conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
@@ -74027,7 +69721,6 @@ msgstr ""
 
 #: objc/objc-act.c:1141
 #, fuzzy, gcc-internal-format
-#| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%<readonly%> attribute of property %qD conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
@@ -74232,7 +69925,6 @@ msgstr ""
 
 #: objc/objc-act.c:3992 objc/objc-act.c:4020 objc/objc-act.c:4075
 #, fuzzy, gcc-internal-format
-#| msgid "unused variable %q+D"
 msgid "duplicate instance variable %q+D"
 msgstr "使用されない変数 %q+D です"
 
@@ -74558,7 +70250,6 @@ msgstr "クラス `%s' のインターフェイス宣言が重複しています
 
 #: objc/objc-act.c:7240 objc/objc-act.c:7436
 #, fuzzy, gcc-internal-format
-#| msgid "inconsistent instance variable specification"
 msgid "cannot find instance variable associated with property"
 msgstr "インスタンス変数の仕様が一貫していません"
 
@@ -74686,7 +70377,6 @@ msgstr "`%s' へのインターフェイスに基底クラスが宣言されて
 
 #: objc/objc-act.c:8859
 #, fuzzy, gcc-internal-format
-#| msgid "[super ...] must appear in a method context"
 msgid "%<[super ...]%> must appear in a method context"
 msgstr "[super ...] はメソッドコンテキストに現れなければなりません"
 
@@ -74787,7 +70477,6 @@ msgstr "認識不能なオプション `%s'"
 
 #: fortran/lang.opt:767
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized option %<-%s%>"
 msgid "Unrecognized option: %qs"
 msgstr "認識できないオプション %<-%s%> です"
 
@@ -74824,7 +70513,6 @@ msgstr "%qs の後に makefile ターゲットがありません"
 
 #: c-family/c.opt:283
 #, fuzzy, gcc-internal-format
-#| msgid "argument %qs to %<-Wnormalized%> not recognized"
 msgid "argument %qs to %<-Waligned-new%> not recognized"
 msgstr "%<-Wnormalized%> への引数 %qs が認識できません"
 
@@ -74840,31 +70528,26 @@ msgstr "%qs にクラス名が指定されていません"
 
 #: c-family/c.opt:1588
 #, fuzzy, gcc-internal-format
-#| msgid "-fhandle-exceptions has been renamed -fexceptions (and is now on by default)"
 msgid "%<-fhandle-exceptions%> has been renamed %<-fexceptions%> (and is now on by default)"
 msgstr "-fhandle-exceptions は -fexceptions に名前が変更されました (またデフォルトで有効になっています)"
 
 #: c-family/c.opt:1675
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized visibility value %qs"
 msgid "unrecognized ivar visibility value %qs"
 msgstr "認識できない可視性の値 %qs です"
 
 #: c-family/c.opt:1835
 #, fuzzy, gcc-internal-format
-#| msgid "unrecognized register name %qs"
 msgid "unrecognized scalar storage order value %qs"
 msgstr "認識できないレジスタ名 %qs です"
 
 #: d/lang.opt:189
 #, fuzzy, gcc-internal-format
-#| msgid "unknown IRA algorithm %qs"
 msgid "unknown array bounds setting %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
 #: config/vms/vms.opt:42
 #, fuzzy, gcc-internal-format
-#| msgid "unknown TLS model %qs"
 msgid "unknown pointer size model %qs"
 msgstr "不明な TLS モデル %qs です"
 
@@ -74885,19 +70568,16 @@ msgstr "%<-msse5%> は削除されました"
 
 #: config/avr/avr.opt:26
 #, fuzzy, gcc-internal-format
-#| msgid "missing makefile target after %qs"
 msgid "missing device or architecture after %qs"
 msgstr "%qs の後に makefile ターゲットがありません"
 
 #: config/rs6000/rs6000.opt:316
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
 msgid "%<-mvrsave=no%> is deprecated; use %<-mno-vrsave%> instead"
 msgstr "%<-mcpu=%> は廃止されました。代わりに %<-mtune=%> または %<-march=%> を使用してください"
 
 #: config/rs6000/rs6000.opt:320
 #, fuzzy, gcc-internal-format
-#| msgid "%<-mfused-madd%> is deprecated; use %<-ffp-contract=%> instead"
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mfused-madd%> は廃止されました。代わりに %<-ffp-contract=%> を使用してください"
 
@@ -74918,13 +70598,11 @@ msgstr "%<-mfused-madd%> は廃止されました。代わりに %<-ffp-contract
 
 #: config/microblaze/microblaze.opt:87
 #, fuzzy, gcc-internal-format
-#| msgid "-mxl_stack_check is deprecated; use -fstack-check"
 msgid "%qs is deprecated; use -fstack-check"
 msgstr "-mxl_stack_check は廃止されました。-fstack-check を使用してください"
 
 #: config/microblaze/microblaze.opt:95
 #, fuzzy, gcc-internal-format
-#| msgid "-mno-clearbss is deprecated; use -fno-zero-initialized-in-bss"
 msgid "%qs is deprecated; use -fno-zero-initialized-in-bss"
 msgstr "-mno-clearbss は廃止されました。-fno-zero-initialized-in-bss を使用してください"
 
@@ -74933,13 +70611,11 @@ msgstr "-mno-clearbss は廃止されました。-fno-zero-initialized-in-bss 
 #: config/arc/arc.opt:357 config/arc/arc.opt:361 config/arc/arc.opt:364
 #: config/arc/arc.opt:367 config/arc/arc.opt:384
 #, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
 msgid "%qs is deprecated"
 msgstr "%qE は廃止されました"
 
 #: lto/lang.opt:31
 #, fuzzy, gcc-internal-format
-#| msgid "unknown architecture %qs"
 msgid "unknown linker output %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
@@ -74960,7 +70636,6 @@ msgstr "不明な浮動小数短縮形 %qs です"
 
 #: common.opt:1681
 #, fuzzy, gcc-internal-format
-#| msgid "unknown architecture %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
@@ -74981,43 +70656,36 @@ msgstr "不明な IRA 範囲 %qs です"
 
 #: common.opt:1932
 #, fuzzy, gcc-internal-format
-#| msgid "unknown TLS model %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明な TLS モデル %qs です"
 
 #: common.opt:2034
 #, fuzzy, gcc-internal-format
-#| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs の後にアサーションがありません"
 
 #: common.opt:2042
 #, fuzzy, gcc-internal-format
-#| msgid "unknown TLS model %qs"
 msgid "unknown offload ABI %qs"
 msgstr "不明な TLS モデル %qs です"
 
 #: common.opt:2184
 #, fuzzy, gcc-internal-format
-#| msgid "unknown type name %qE"
 msgid "unknown profile reproducibility method %qs"
 msgstr "不明な型名 %qE です"
 
 #: common.opt:2200
 #, fuzzy, gcc-internal-format
-#| msgid "unknown type name %qE"
 msgid "unknown profile update method %qs"
 msgstr "不明な型名 %qE です"
 
 #: common.opt:2294
 #, fuzzy, gcc-internal-format
-#| msgid "unknown architecture %qs"
 msgid "unknown Live-Patching Level %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
 #: common.opt:2327
 #, fuzzy, gcc-internal-format
-#| msgid "unknown IRA algorithm %qs"
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
@@ -75028,7 +70696,6 @@ msgstr "不明な TLS モデル %qs です"
 
 #: common.opt:2970
 #, fuzzy, gcc-internal-format
-#| msgid "unknown TLS model %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明な TLS モデル %qs です"
 
@@ -75039,2830 +70706,5 @@ msgstr "認識できない可視性の値 %qs です"
 
 #: common.opt:3027
 #, fuzzy, gcc-internal-format
-#| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs 用の初期化付近)"
-
-#, fuzzy
-#~| msgid "%s: Cannot open output file: %s\n"
-#~ msgid "Cannot open intermediate output file %s\n"
-#~ msgstr "%s: 出力ファイルを開けません: %s\n"
-
-#~ msgid "The --param option recognizes the following as parameters"
-#~ msgstr "--param オプションは以降をパラメータとして認識します"
-
-#~ msgid "collect: reading %s\n"
-#~ msgstr "collect: %s を読み込んでいます\n"
-
-#~ msgid "collect: recompiling %s\n"
-#~ msgstr "collect: %s を再コンパイルしています\n"
-
-#~ msgid "collect: tweaking %s in %s\n"
-#~ msgstr "collect: %s を引っ張ります(%s 内)\n"
-
-#~ msgid "collect: relinking\n"
-#~ msgstr "collect: 再リンクしています\n"
-
-#~ msgid "mismatched arguments"
-#~ msgstr "合っていない引数です"
-
-#, fuzzy
-#~| msgid "The maximum number of instructions when automatically inlining"
-#~ msgid "The maximum number of insns of a peeled loop that rolls only once."
-#~ msgstr "自動インライン化が行われる最大命令数"
-
-#~ msgid "-mvsx and -mpaired are incompatible"
-#~ msgstr "-mvsx と -mpaired は併用できません"
-
-#, fuzzy
-#~| msgid "invalid %%P operand"
-#~ msgid "invalid %%t operand '"
-#~ msgstr "無効な %%P 被演算子です"
-
-#, fuzzy
-#~| msgid "  enters try block"
-#~ msgid "enters try block"
-#~ msgstr "  try ブロックに入ります"
-
-#, fuzzy
-#~| msgid "  enters catch block"
-#~ msgid "enters catch block"
-#~ msgstr "  catch ブロックに入ります"
-
-#, fuzzy
-#~ msgid "enters OpenMP structured block"
-#~ msgstr "  try ブロックに入ります"
-
-#, fuzzy
-#~| msgid "Generate code for huge switch statements"
-#~ msgid "enters synchronized or atomic statement"
-#~ msgstr "巨大な swich 文用コードを生成する"
-
-#~ msgid "Unexpected end of format string"
-#~ msgstr "予期しない書式文字列終了です"
-
-#, fuzzy
-#~ msgid "Period required in format specifier"
-#~ msgstr "認識できないフォーマット指定子"
-
-#, fuzzy
-#~| msgid "Generate checks for references to NULL"
-#~ msgid "Generate checks for all read accesses to memory."
-#~ msgstr "NULL への参照を検査する"
-
-#, fuzzy
-#~| msgid "Generate checks for references to NULL"
-#~ msgid "Generate checks for all write accesses to memory."
-#~ msgstr "NULL への参照を検査する"
-
-#, fuzzy
-#~| msgid "Generate code for GNU as"
-#~ msgid "Generate bounds passing for calls."
-#~ msgstr "GNU as 用のコードを生成する"
-
-#, fuzzy
-#~| msgid "Scope of for-init-statement variables is local to the loop"
-#~ msgid "Scope of for-init-statement variables is local to the loop."
-#~ msgstr "for 文内で初期化した (for-init-statement) 変数のスコープをループ局所にする"
-
-#, fuzzy
-#~| msgid "Inject friend functions into enclosing namespace"
-#~ msgid "Inject friend functions into enclosing namespace."
-#~ msgstr "フレンド関数を囲まれた名前空間内に入れる"
-
-#, fuzzy
-#~| msgid "only initialized variables can be placed into program memory area"
-#~ msgid "Specify whether variables should be placed into low or high memory."
-#~ msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
-
-#, fuzzy
-#~| msgid "Emit warnings when run-time relocations are generated"
-#~ msgid "Emit warnings when run-time relocations are generated."
-#~ msgstr "実行時再配置が生成されたときに警告を発行する"
-
-#, fuzzy
-#~| msgid "Emit errors when run-time relocations are generated"
-#~ msgid "Emit errors when run-time relocations are generated."
-#~ msgstr "実行時再配置が生成されたときにエラーを発行する"
-
-#, fuzzy
-#~| msgid "Specify cost of branches (Default 20)"
-#~ msgid "Specify cost of branches (Default 20)."
-#~ msgstr "分岐のコストを指定する (デフォルト: 20)"
-
-#, fuzzy
-#~| msgid "volatile must be specified on any memory that is effected by DMA"
-#~ msgid "volatile must be specified on any memory that is effected by DMA."
-#~ msgstr "DMA によって影響を受けるすべてのメモリで volatile 指定を必須とする"
-
-#, fuzzy
-#~| msgid "Use standard main function as entry for startup"
-#~ msgid "Use standard main function as entry for startup."
-#~ msgstr "開始時のエントリとして標準の main 関数を使用する"
-
-#, fuzzy
-#~| msgid "Generate branch hints for branches"
-#~ msgid "Generate branch hints for branches."
-#~ msgstr "分岐用に分岐ヒントを生成する"
-
-#, fuzzy
-#~| msgid "Maximum number of nops to insert for a hint (Default 2)"
-#~ msgid "Maximum number of nops to insert for a hint (Default 2)."
-#~ msgstr "ヒント用に挿入される nops の最大数 (デフォルト: 2)"
-
-#, fuzzy
-#~| msgid "Approximate maximum number of instructions to allow between a hint and its branch [125]"
-#~ msgid "Approximate maximum number of instructions to allow between a hint and its branch [125]."
-#~ msgstr "ヒントと分岐間に許可される命令数のおおよその最大値 [125]"
-
-#, fuzzy
-#~| msgid "Generate code for 18 bit addressing"
-#~ msgid "Generate code for 18 bit addressing."
-#~ msgstr "18 ビットアドレス用のコードを生成する"
-
-#, fuzzy
-#~| msgid "Generate code for 32 bit addressing"
-#~ msgid "Generate code for 32 bit addressing."
-#~ msgstr "32 ビットアドレス用のコードを生成する"
-
-#, fuzzy
-#~| msgid "Insert hbrp instructions after hinted branch targets to avoid the SPU hang issue"
-#~ msgid "Insert hbrp instructions after hinted branch targets to avoid the SPU hang issue."
-#~ msgstr "SPU のハングアップ問題を回避するためにヒント付き分岐ターゲットの後に hbrp 命令を挿入する"
-
-#, fuzzy
-#~| msgid "Access variables in 32-bit PPU objects (default)"
-#~ msgid "Access variables in 32-bit PPU objects (default)."
-#~ msgstr "32 ビット PPU オブジェクト内で変数にアクセスする (デフォルト)"
-
-#, fuzzy
-#~| msgid "Access variables in 64-bit PPU objects"
-#~ msgid "Access variables in 64-bit PPU objects."
-#~ msgstr "64 ビット PPU オブジェクト内で変数にアクセスする"
-
-#, fuzzy
-#~| msgid "Allow conversions between __ea and generic pointers (default)"
-#~ msgid "Allow conversions between __ea and generic pointers (default)."
-#~ msgstr "__ea と一般ポインタ間の変換を許可する (デフォルト)"
-
-#, fuzzy
-#~| msgid "Size (in KB) of software data cache"
-#~ msgid "Size (in KB) of software data cache."
-#~ msgstr "ソフトウェアデータキャッシュのサイズ (KB 単位)"
-
-#, fuzzy
-#~| msgid "Do not use inline patterns for copying memory"
-#~ msgid "Do not use inline patterns for copying memory."
-#~ msgstr "メモリコピー用にインラインパターンを使用しない"
-
-#, fuzzy
-#~| msgid "Use inline patterns for copying memory"
-#~ msgid "Use inline patterns for copying memory."
-#~ msgstr "メモリコピー用にインラインパターンを使用する"
-
-#, fuzzy
-#~| msgid "Do not pretend that branches are expensive"
-#~ msgid "Do not pretend that branches are expensive."
-#~ msgstr "分岐が高コストであると見なさない"
-
-#, fuzzy
-#~| msgid "Pretend that branches are expensive"
-#~ msgid "Pretend that branches are expensive."
-#~ msgstr "分岐が高コストであると見なす"
-
-#, fuzzy
-#~| msgid "Use 32 bit float"
-#~ msgid "Use 32 bit float."
-#~ msgstr "32 ビット浮動小数を使用する"
-
-#, fuzzy
-#~| msgid "Use 64 bit float"
-#~ msgid "Use 64 bit float."
-#~ msgstr "64 ビット浮動小数を使用する"
-
-#, fuzzy
-#~| msgid "%qE is deprecated"
-#~ msgid "%<-mpcommit%> was deprecated"
-#~ msgstr "%qE は廃止されました"
-
-#, fuzzy
-#~| msgid "Support code generation of movbe instruction."
-#~ msgid "Support MPX code generation."
-#~ msgstr "movbe 命令のコード生成をサポートする。"
-
-#, fuzzy
-#~| msgid "Use extended PowerPC V2.05 move floating point to/from GPR instructions"
-#~ msgid "Use extended PowerPC V2.05 move floating point to/from GPR instructions."
-#~ msgstr "汎用レジスタ (GPR) へまたは汎用レジスタからの拡張 PowerPC V2.05 浮動小数点 move 命令を使用する"
-
-#, fuzzy
-#~| msgid "Generate code in little endian mode"
-#~ msgid "Generate AltiVec instructions using little-endian element order."
-#~ msgstr "リトルエンディアンモードでコードを生成する"
-
-#, fuzzy
-#~| msgid "Generate VRSAVE instructions when generating AltiVec code"
-#~ msgid "Generate AltiVec instructions using big-endian element order."
-#~ msgstr "AltiVec コードを生成しているときに VRSAVE 命令を生成する"
-
-#, fuzzy
-#~| msgid "Generate string instructions for block moves"
-#~ msgid "Generate string instructions for block moves."
-#~ msgstr "ブロック移動用の string 命令を生成する"
-
-#, fuzzy
-#~| msgid "-misel=yes/no\tDeprecated option.  Use -misel/-mno-isel instead"
-#~ msgid "Deprecated option.  Use -mno-isel instead."
-#~ msgstr "-misel=yes/no\t廃止されたオプションです。代わりに -misel/-mno-isel を使用してください"
-
-#, fuzzy
-#~| msgid "Deprecated.  Use -Os instead"
-#~ msgid "Deprecated option.  Use -misel instead."
-#~ msgstr "廃止されました。代わりに -Os を使用してください"
-
-#, fuzzy
-#~| msgid "Generate SPE SIMD instructions on E500"
-#~ msgid "Generate SPE SIMD instructions on E500."
-#~ msgstr "E500 上で SPE SIMD 命令を生成する"
-
-#, fuzzy
-#~| msgid "Generate isel instructions"
-#~ msgid "Generate PPC750CL paired-single instructions."
-#~ msgstr "isel 命令を生成する"
-
-#, fuzzy
-#~| msgid "-mspe=yes/no\tDeprecated option.  Use -mspe/-mno-spe instead"
-#~ msgid "Deprecated option.  Use -mno-spe instead."
-#~ msgstr "-mspe=yes/no\t廃止されたオプションです。代わりに -mspe/-mno-spe を使用してください"
-
-#, fuzzy
-#~| msgid "Deprecated.  Use -Os instead"
-#~ msgid "Deprecated option.  Use -mspe instead."
-#~ msgstr "廃止されました。代わりに -Os を使用してください"
-
-#~ msgid "using IEEE extended precision long double"
-#~ msgstr "IEEE 拡張精度 long double を使用しています"
-
-#~ msgid "using IBM extended precision long double"
-#~ msgstr "IBM 拡張精度 long double を使用しています"
-
-#, fuzzy
-#~| msgid "-mtraceback=\tSelect full, part, or no traceback table"
-#~ msgid "-mtraceback=\tSelect full, part, or no traceback table."
-#~ msgstr "-mtraceback=\tトレースバック表を full、part、または no のいずれかにする"
-
-#, fuzzy
-#~| msgid "Warn when a Cell microcoded instruction is emitted"
-#~ msgid "Warn when a Cell microcoded instruction is emitted."
-#~ msgstr "Cell マイクロコード命令が発行されたときに警告する"
-
-#, fuzzy
-#~| msgid "-mfloat-gprs=\tSelect GPR floating point method"
-#~ msgid "-mfloat-gprs=\tSelect GPR floating point method."
-#~ msgstr "-mfloat-gprs=\t汎用レジスタ GPR の浮動小数点使用法を選択する"
-
-#, fuzzy
-#~| msgid "valid arguments to %qs are: %s"
-#~ msgid "Valid arguments to -mfloat-gprs=:"
-#~ msgstr "%qs への有効な引数は次の通りです: %s"
-
-#, fuzzy
-#~| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
-#~ msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
-#~ msgstr "-mlong-double-<n>\tlong double のサイズを指定する (64 または 128 ビット)"
-
-#, fuzzy
-#~| msgid "Single-precision floating point unit"
-#~ msgid "Single-precision floating point unit."
-#~ msgstr "単精度浮動小数点ユニット"
-
-#, fuzzy
-#~| msgid "Double-precision floating point unit"
-#~ msgid "Double-precision floating point unit."
-#~ msgstr "倍精度浮動小数点ユニット"
-
-#, fuzzy
-#~| msgid "Floating point unit does not support divide & sqrt"
-#~ msgid "Floating point unit does not support divide & sqrt."
-#~ msgstr "浮動小数点ユニットが divide および sqrt をサポートしません"
-
-#, fuzzy
-#~| msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
-#~ msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)."
-#~ msgstr "-mfpu=\t浮動小数点 (FP) を指定する (sp, dp, sp-lite, dp-lite) (暗黙的に -mxilinx-fpu も指定される)"
-
-#~ msgid "Specify Xilinx FPU."
-#~ msgstr "Xilinx FPU を指定する。"
-
-#, fuzzy
-#~| msgid "Return small aggregates in registers"
-#~ msgid "Enable small integers to be in VSX registers."
-#~ msgstr "小さな集合体をレジスタで返す"
-
-#, fuzzy
-#~| msgid "Select ABI calling convention"
-#~ msgid "Select ABI calling convention."
-#~ msgstr "ABI 呼び出し規約を選択する"
-
-#, fuzzy
-#~| msgid "-msim\tUse simulator runtime"
-#~ msgid "-msim   Use simulator runtime."
-#~ msgstr "-msim\tシミュレータランタイムを使用する"
-
-#, fuzzy
-#~| msgid "%qE is deprecated"
-#~ msgid "%<-mstring%> is deprecated"
-#~ msgstr "%qE は廃止されました"
-
-#, fuzzy
-#~| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
-#~ msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
-#~ msgstr "%<-mcpu=%> は廃止されました。代わりに %<-mtune=%> または %<-march=%> を使用してください"
-
-#, fuzzy
-#~| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
-#~ msgid "-mlong-double-[64,128]\tSpecify size of long double."
-#~ msgstr "-mlong-double-<n>\tlong double のサイズを指定する (64 または 128 ビット)"
-
-#, fuzzy
-#~| msgid "Enable linker relaxation."
-#~ msgid "Enable lra."
-#~ msgstr "リンカの緩和を有効にする。"
-
-#, fuzzy
-#~| msgid "--param <param>=<value>\tSet parameter <param> to value.  See below for a complete list of parameters"
-#~ msgid "--param <param>=<value>\tSet parameter <param> to value.  See below for a complete list of parameters."
-#~ msgstr "--param <param>=<value>\tパラメータ <param> を<value> に設定する。パラメータの完全な一覧は下記を参照"
-
-#, fuzzy
-#~| msgid "switch %qs is no longer supported"
-#~ msgid "switch %qs no longer supported"
-#~ msgstr "%qs スイッチは既にサポートされていません"
-
-#, fuzzy
-#~| msgid "Reading specs from %s\n"
-#~ msgid "cannot read working set from %s"
-#~ msgstr "%s から spec を読み込んでいます\n"
-
-#, fuzzy
-#~| msgid "target format does not support infinity"
-#~ msgid "Your target platform does not support -fcheck-pointer-bounds"
-#~ msgstr "ターゲット形式は無限大をサポートしません"
-
-#, fuzzy
-#~| msgid "alignment of %qD is bigger than original declaration"
-#~ msgid "Not instrumented node has non-NULL original declaration"
-#~ msgstr "%qD の整列は元の宣言より大きいです"
-
-#, fuzzy
-#~| msgid "alignment of %qD is bigger than original declaration"
-#~ msgid "Instrumented node has wrong original declaration"
-#~ msgstr "%qD の整列は元の宣言より大きいです"
-
-#, fuzzy
-#~ msgid "Wrong node is referenced with chkp reference"
-#~ msgstr "参照を参照として宣言できません"
-
-#~ msgid "cannot find '%s'"
-#~ msgstr "'%s' が見つかりません"
-
-#~ msgid "COLLECT_LTO_WRAPPER must be set"
-#~ msgstr "COLLECT_LTO_WRAPPER が設定されなければいけません"
-
-#, fuzzy
-#~| msgid "can%'t open %s: %m"
-#~ msgid "can't open %s: %m"
-#~ msgstr "%s を開けません: %m"
-
-#~ msgid "aggregate value used where a float was expected"
-#~ msgstr "浮動小数点型があるべき箇所で、集合体の値が使われました"
-
-#~ msgid "-fdbg-cnt=%s"
-#~ msgstr "-fdbg-cnt=%s"
-
-#~ msgid "verify_eh_tree failed"
-#~ msgstr "verify_eh_tree に失敗しました"
-
-#, fuzzy
-#~ msgid "iteration variable %qE should not be lastprivate"
-#~ msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
-
-#, fuzzy
-#~ msgid "iteration variable %qE should not be private"
-#~ msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
-
-#~ msgid "can%'t open %s: %m"
-#~ msgstr "%s を開けません: %m"
-
-#, fuzzy
-#~| msgid "%s: %s"
-#~ msgid "%s: %s\n"
-#~ msgstr "%s: %s"
-
-#, fuzzy
-#~| msgid "storage class specified for typename"
-#~ msgid "multiple loop axes specified for routine"
-#~ msgstr "型名用に記憶域クラスが指定されました"
-
-#, fuzzy
-#~| msgid "%salign-loops=%d%s is not between 0 and %d"
-#~ msgid "-falign-jumps=%d is not between 0 and %d"
-#~ msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
-
-#, fuzzy
-#~| msgid "%salign-loops=%d%s is not between 0 and %d"
-#~ msgid "-falign-functions=%d is not between 0 and %d"
-#~ msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
-
-#, fuzzy
-#~| msgid "%salign-loops=%d%s is not between 0 and %d"
-#~ msgid "-falign-labels=%d is not between 0 and %d"
-#~ msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
-
-#, fuzzy
-#~| msgid "%qE attribute directive ignored"
-#~ msgid "%<%s%> attribute directive ignored"
-#~ msgstr "%qE 属性指示が無視されました"
-
-#~ msgid "%s: --param arguments should be of the form NAME=VALUE"
-#~ msgstr "%s: --param 引数は NAME=VALUE の形式であるべきです"
-
-#, fuzzy
-#~| msgid "invalid --param value %qs"
-#~ msgid "invalid --param name %qs; did you mean %qs?"
-#~ msgstr "無効な --param の値 %qs です"
-
-#, fuzzy
-#~| msgid "invalid --param value %qs"
-#~ msgid "invalid --param name %qs"
-#~ msgstr "無効な --param の値 %qs です"
-
-#~ msgid "invalid parameter %qs"
-#~ msgstr "無効なパラメータ %qs です"
-
-#~ msgid "minimum value of parameter %qs is %u"
-#~ msgstr "パラメータ %qs の最小値は %u です"
-
-#~ msgid "maximum value of parameter %qs is %u"
-#~ msgstr "パラメータ %qs の最大値は %u です"
-
-#~ msgid "corrupted profile info: sum_all is smaller than sum_max"
-#~ msgstr "破損したプロファイル情報: sum_all が sum_max より小さいです"
-
-#~ msgid "size of %q+D is %d bytes"
-#~ msgstr "%q+D のサイズは %d バイトです"
-
-#~ msgid "size of %q+D is larger than %wd bytes"
-#~ msgstr "%q+D のサイズは %wd バイトより大きいです"
-
-#, fuzzy
-#~| msgid "removing .rpo file"
-#~ msgid "removing .rpo file: %m"
-#~ msgstr ".rpo ファイルを削除しています"
-
-#, fuzzy
-#~| msgid "renaming .rpo file"
-#~ msgid "renaming .rpo file: %m"
-#~ msgstr ".rpo ファイルの名前を変更しています"
-
-#, fuzzy
-#~| msgid "%<__int128%> is not supported for this target"
-#~ msgid "%<-fcheck-pointer-bounds%> is not supported for this target"
-#~ msgstr "%<__int128%> はこのターゲットではサポートされていません"
-
-#, fuzzy
-#~| msgid "-fdata-sections not supported for this target"
-#~ msgid "-fsanitize=address not supported for this target"
-#~ msgstr "-fdata-sections はこのターゲットではサポートされていません"
-
-#, fuzzy
-#~ msgid "asm not allowed in %<transaction_safe%> function"
-#~ msgstr "大域 register 変数が関数定義の後ろにあります"
-
-#~ msgid "invalid first operand of MEM_REF"
-#~ msgstr "MEM_REF の無効な第一被演算子です"
-
-#~ msgid "invalid offset operand of MEM_REF"
-#~ msgstr "MEM_REF の無効なオフセット被演算子です"
-
-#~ msgid "non-integral used in condition"
-#~ msgstr "条件内で非整数が使用されました"
-
-#~ msgid "invalid conditional operand"
-#~ msgstr "無効な条件被演算子です"
-
-#~ msgid "invalid reference prefix"
-#~ msgstr "無効な参照接頭辞です"
-
-#~ msgid "invalid operand to plus/minus, type is a pointer"
-#~ msgstr "プラス/マイナスへの無効な被演算子です。型がポインタです"
-
-#, fuzzy
-#~| msgid "invalid operand to pointer plus, first operand is not a pointer"
-#~ msgid "invalid operand to pointer diff, operand is not a pointer"
-#~ msgstr "ポインタ加算への無効な被演算子です。第一被演算子がポインタではありません"
-
-#, fuzzy
-#~| msgid "invalid types in nop conversion"
-#~ msgid "invalid type for pointer diff"
-#~ msgstr "nop 変換内で無効な型です"
-
-#~ msgid "invalid operand to pointer plus, first operand is not a pointer"
-#~ msgstr "ポインタ加算への無効な被演算子です。第一被演算子がポインタではありません"
-
-#, fuzzy
-#~| msgid "invalid operand to pointer plus, second operand is not an integer with type of sizetype"
-#~ msgid "invalid operand to pointer plus, second operand is not an integer type of appropriate width"
-#~ msgstr "ポインタ加算への無効な被演算子です。第二被演算子が整数でも型サイズでもありません"
-
-#~ msgid "invalid operands to array reference"
-#~ msgstr "配列参照への無効な被演算子です"
-
-#~ msgid "type mismatch in array range reference"
-#~ msgstr "配列範囲参照内で型不一致です"
-
-#~ msgid "type mismatch in real/imagpart reference"
-#~ msgstr "実部/虚部参照内で型不一致です"
-
-#, fuzzy
-#~| msgid "invalid address operand in in TARGET_MEM_REF"
-#~ msgid "invalid address operand in TARGET_MEM_REF"
-#~ msgstr "TARGET_MEM_REF 内で無効なアドレス被演算子です"
-
-#~ msgid "invalid offset operand in TARGET_MEM_REF"
-#~ msgstr "TARGET_MEM_REF 内で無効なオフセット被演算子です"
-
-#~ msgid "type mismatch in complex expression"
-#~ msgstr "複素数式内で型不一致です"
-
-#~ msgid "type mismatch in shift expression"
-#~ msgstr "シフト式内で型不一致です"
-
-#, fuzzy
-#~| msgid "type mismatch in vector shift expression"
-#~ msgid "type mismatch in widening vector shift expression"
-#~ msgstr "ベクトルシフト式内で型不一致です"
-
-#~ msgid "invalid (pointer) operands to plus/minus"
-#~ msgstr "プラス/マイナスへの無効な (ポインタ) 被演算子です"
-
-#~ msgid "type mismatch in pointer plus expression"
-#~ msgstr "ポインタ加算式内で型不一致です"
-
-#, fuzzy
-#~| msgid "type mismatch in pointer plus expression"
-#~ msgid "type mismatch in pointer diff expression"
-#~ msgstr "ポインタ加算式内で型不一致です"
-
-#, fuzzy
-#~| msgid "type mismatch in address expression"
-#~ msgid "type mismatch in widening sum reduction"
-#~ msgstr "アドレス式内で型不一致です"
-
-#, fuzzy
-#~| msgid "type mismatch in vector shift expression"
-#~ msgid "type mismatch in vector widening multiplication"
-#~ msgstr "ベクトルシフト式内で型不一致です"
-
-#, fuzzy
-#~| msgid "type mismatch in vector shift expression"
-#~ msgid "type mismatch in vector pack expression"
-#~ msgstr "ベクトルシフト式内で型不一致です"
-
-#, fuzzy
-#~| msgid "type mismatch in address expression"
-#~ msgid "type mismatch in series expression"
-#~ msgstr "アドレス式内で型不一致です"
-
-#, fuzzy
-#~| msgid "expected integer expression"
-#~ msgid "vector type expected in series expression"
-#~ msgstr "整数式が予期されます"
-
-#, fuzzy
-#~| msgid "type mismatch in vector shift expression"
-#~ msgid "type mismatch in vector permute expression"
-#~ msgstr "ベクトルシフト式内で型不一致です"
-
-#, fuzzy
-#~| msgid "expected integer expression"
-#~ msgid "vector types expected in vector permute expression"
-#~ msgstr "整数式が予期されます"
-
-#, fuzzy
-#~| msgid "invalid increment expression"
-#~ msgid "invalid mask type in vector permute expression"
-#~ msgstr "無効な増分式です"
-
-#, fuzzy
-#~| msgid "type mismatch in pointer plus expression"
-#~ msgid "type mismatch in dot product reduction"
-#~ msgstr "ポインタ加算式内で型不一致です"
-
-#~ msgid "invalid operand in unary expression"
-#~ msgstr "単項演算式内で無効な被演算子です"
-
-#~ msgid "type mismatch in address expression"
-#~ msgstr "アドレス式内で型不一致です"
-
-#, fuzzy
-#~| msgid "verify_gimple failed"
-#~ msgid "verify_type failed"
-#~ msgstr "verify_gimple に失敗しました"
-
-#~ msgid "verify_histograms failed"
-#~ msgstr "verify_histograms に失敗しました"
-
-#~ msgid "ifunc is not supported in this configuration"
-#~ msgstr "ifunc はこの設定ではサポートされていません"
-
-#, fuzzy
-#~| msgid "visibility argument not a string"
-#~ msgid "no_sanitize argument not a string"
-#~ msgstr "可視性の引数が文字列ではありません"
-
-#~ msgid "alignment for %q+D must be at least %d"
-#~ msgstr "%q+D 用の整列は最低 %d でなければいけません"
-
-#, fuzzy
-#~ msgid "%+qD declared ifunc after being used"
-#~ msgstr "領域 `%s' は関数として宣言されています"
-
-#~ msgid "indirect function %q+D cannot be declared weakref"
-#~ msgstr "間接関数 %q+D は弱い参照として宣言できません"
-
-#, fuzzy
-#~| msgid "%qE declared %<threadprivate%> after first use"
-#~ msgid "%+qD declared weakref after being used"
-#~ msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
-
-#~ msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
-#~ msgstr "可視性の引数は \"default\"、\"hidden\"、\"protected\" または \"internal\" のうち一つでなければいけません"
-
-#~ msgid "tls_model argument not a string"
-#~ msgstr "tls_model の引数が文字列ではありません"
-
-#~ msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
-#~ msgstr "tls_model の引数は \"local-exec\"、\"initial-exec\"、\"local-dynamic\" または \"global-dynamic\" のうちの一つでなければいけません"
-
-#~ msgid "alloc_size parameter outside range"
-#~ msgstr "alloc_size パラメータが範囲外です"
-
-#, fuzzy
-#~| msgid "alloc_size parameter outside range"
-#~ msgid "alloc_align parameter outside range"
-#~ msgstr "alloc_size パラメータが範囲外です"
-
-#, fuzzy
-#~| msgid "%qE attribute argument not an integer constant"
-#~ msgid "assume_aligned parameter not integer constant"
-#~ msgstr "%qE 属性の引数が整数定数ではありません"
-
-#~ msgid "requested alignment is too large"
-#~ msgstr "要求された整列が大きすぎます"
-
-#~ msgid "%<...%> has invalid operand number"
-#~ msgstr "%<...%> に無効な被演算子数があります"
-
-#, fuzzy
-#~| msgid "%<locus%> is not defined as a type"
-#~ msgid "%<gcall%> is not defined as a type"
-#~ msgstr "%<locus%> が型として定義されていません"
-
-#~ msgid "can%'t read %s: %m"
-#~ msgstr "%s を読み込めません: %m"
-
-#~ msgid "-msingle-float option equivalent to -mhard-float"
-#~ msgstr "-msingle-float オプションは -mhard-float と等価です"
-
-#~ msgid "-msimple-fpu option ignored"
-#~ msgstr "-msimple-fpu オプションは無視されました"
-
-#~ msgid "junk at end of '#pragma options'"
-#~ msgstr "'#pragma options' の末尾にゴミがあります"
-
-#~ msgid "bad value %qs for -mtune switch"
-#~ msgstr "-mtune スイッチ用の間違った値 %qs です"
-
-#, fuzzy
-#~| msgid "value of -mfixed-range must have form REG1-REG2"
-#~ msgid "value of -mirq-ctrl-saved must have form R0-REGx"
-#~ msgstr "-mfixed-range の値は REG1-REG2 形式でなければいけません"
-
-#, fuzzy
-#~| msgid "%qs is not valid for %qs"
-#~ msgid "%s is not available for %s architecture"
-#~ msgstr "%qs は %qs 用には有効ではありません"
-
-#, fuzzy
-#~| msgid "%s does not support %s"
-#~ msgid "Intel MPX does not support x32"
-#~ msgstr "%s は %s をサポートしません"
-
-#~ msgid "option(\"%s\") was already specified"
-#~ msgstr "option(\"%s\") は既に指定されています"
-
-#, fuzzy
-#~| msgid "the last argument must be an 8-bit immediate"
-#~ msgid "the xabort's argument must be an 8-bit immediate"
-#~ msgstr "最後の引数は 8 ビット即値でなければいけません"
-
-#, fuzzy
-#~| msgid "Generate position-independent code if possible (large mode)"
-#~ msgid "position-independent code not supported"
-#~ msgstr "可能であれば位置非依存コードを生成する (large モード)"
-
-#~ msgid "-freorder-blocks-and-partition does not work on this architecture"
-#~ msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上では動作しません"
-
-#, fuzzy
-#~| msgid "vec_extract only accepts 2 arguments"
-#~ msgid "vec_mul only accepts 2 arguments"
-#~ msgstr "vec_extract は 2 個の引数のみ受け付けます"
-
-#, fuzzy
-#~| msgid "vec_insert only accepts 3 arguments"
-#~ msgid "vec_cmpne only accepts 2 arguments"
-#~ msgstr "vec_insert は 3 個の引数のみ受け付けます"
-
-#, fuzzy
-#~| msgid "vec_insert only accepts 3 arguments"
-#~ msgid "vec_adde only accepts 3 arguments"
-#~ msgstr "vec_insert は 3 個の引数のみ受け付けます"
-
-#, fuzzy
-#~| msgid "vec_insert only accepts 3 arguments"
-#~ msgid "vec_addec only accepts 3 arguments"
-#~ msgstr "vec_insert は 3 個の引数のみ受け付けます"
-
-#~ msgid "%s only accepts %d arguments"
-#~ msgstr "%s は %d 個の引数のみ受け付けます"
-
-#~ msgid "%s only accepts 1 argument"
-#~ msgstr "%s は 1 個の引数のみ受け付けます"
-
-#~ msgid "%s only accepts 2 arguments"
-#~ msgstr "%s は 2 この引数のみ受け付けます"
-
-#~ msgid "vec_extract only accepts 2 arguments"
-#~ msgstr "vec_extract は 2 個の引数のみ受け付けます"
-
-#~ msgid "vec_insert only accepts 3 arguments"
-#~ msgstr "vec_insert は 3 個の引数のみ受け付けます"
-
-#, fuzzy
-#~| msgid "%s only accepts 2 arguments"
-#~ msgid "__builtin_cmpb only accepts 2 arguments"
-#~ msgstr "%s は 2 この引数のみ受け付けます"
-
-#, fuzzy
-#~| msgid "ifunc is not supported in this configuration"
-#~ msgid "Builtin function %s not supported in this compiler configuration"
-#~ msgstr "ifunc はこの設定ではサポートされていません"
-
-#~ msgid "-mrecip requires -ffinite-math or -ffast-math"
-#~ msgstr "-mrecip は -ffinite-math または -ffast-math が必要となります"
-
-#~ msgid "-mrecip requires -fno-trapping-math or -ffast-math"
-#~ msgstr "-mrecip は -fno-trapping-math または -ffast-math が必要となります"
-
-#~ msgid "-mrecip requires -freciprocal-math or -ffast-math"
-#~ msgstr "-mrecip は -freciprocal-math または -ffast-math が必要となります"
-
-#~ msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
-#~ msgstr "-malign-power は 64 ビット Darwin ではサポートされていません。インストールされている C および C++ ライブラリと互換性がありません"
-
-#, fuzzy
-#~| msgid "Do not use PowerPC instruction set"
-#~ msgid "not configured for SPE instruction set"
-#~ msgstr "PowerPC 命令セットを使用しない"
-
-#~ msgid "target attribute or pragma changes SPE ABI"
-#~ msgstr "target 属性または pragma が SPE ABI を変更します"
-
-#~ msgid "-mmultiple is not supported on little endian systems"
-#~ msgstr "-mmultiple はリトルエンディアンシステム上ではサポートされていません"
-
-#~ msgid "-mstring is not supported on little endian systems"
-#~ msgstr "-mstring はリトルエンディアンシステム上ではサポートされていません"
-
-#, fuzzy
-#~| msgid "-mcmodel incompatible with other toc options"
-#~ msgid "-mpower9-minmax incompatible with explicitly disabled options"
-#~ msgstr "-mcmodel は他の toc オプションと互換性がありません"
-
-#, fuzzy
-#~| msgid "-msingle-float option equivalent to -mhard-float"
-#~ msgid "-mhard-dfp requires -mhard-float"
-#~ msgstr "-msingle-float オプションは -mhard-float と等価です"
-
-#~ msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
-#~ msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
-
-#~ msgid "target attribute or pragma changes single precision floating point"
-#~ msgstr "target 属性または pragma が単精度浮動小数点を変更します"
-
-#~ msgid "target attribute or pragma changes double precision floating point"
-#~ msgstr "target 属性または pragma が倍精度浮動小数点を変更します"
-
-#, fuzzy
-#~| msgid "internal error: builtin function to %s already processed"
-#~ msgid "internal error: builtin function %s already processed"
-#~ msgstr "内部エラー: %s への組み込み関数は既に処理されています"
-
-#~ msgid "argument 1 of __builtin_altivec_predicate must be a constant"
-#~ msgstr "__builtin_altivec_predicate の第一引数は定数でなければいけません"
-
-#~ msgid "argument 1 of __builtin_altivec_predicate is out of range"
-#~ msgstr "__builtin_altivec_predicate の第一引数が範囲外です"
-
-#, fuzzy
-#~| msgid "%srtd%s is ignored in 64bit mode"
-#~ msgid "builtin %s is only valid in 64-bit mode"
-#~ msgstr "%srtd%s は 64 ビットモードでは無視されます"
-
-#, fuzzy
-#~| msgid "%s only accepts 1 argument"
-#~ msgid "builtin %s only accepts a string argument"
-#~ msgstr "%s は 1 個の引数のみ受け付けます"
-
-#, fuzzy
-#~| msgid "%qs is an invalid argument to -mcpu="
-#~ msgid "cpu %s is an invalid argument to builtin %s"
-#~ msgstr "%qs は -mcpu= への引数としては無効です"
-
-#, fuzzy
-#~| msgid "%qs is an invalid argument to -mcpu="
-#~ msgid "hwcap %s is an invalid argument to builtin %s"
-#~ msgstr "%qs は -mcpu= への引数としては無効です"
-
-#~ msgid "argument to dss must be a 2-bit unsigned literal"
-#~ msgstr "dss への引数は 2 ビット符号無しリテラルでなければいけません"
-
-#, fuzzy
-#~| msgid "third argument to %<__builtin_prefetch%> must be a constant"
-#~ msgid "third argument to vec_vinsert4b must be 0..12"
-#~ msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
-
-#~ msgid "argument 1 of __builtin_paired_predicate must be a constant"
-#~ msgstr "__builtin_paired_predicate の第一引数は定数でなければいけません"
-
-#~ msgid "argument 1 of __builtin_paired_predicate is out of range"
-#~ msgstr "__builtin_paired_predicate の第一引数が範囲外です"
-
-#~ msgid "argument 1 of __builtin_spe_predicate must be a constant"
-#~ msgstr "__builtin_spe_predicate の第一引数は定数でなければいけません"
-
-#~ msgid "argument 1 of __builtin_spe_predicate is out of range"
-#~ msgstr "__builtin_spe_predicate の第一引数が範囲外です"
-
-#, fuzzy
-#~| msgid "this builtin function is only available on the fr450"
-#~ msgid "Builtin function %s is only valid for the cell processor"
-#~ msgstr "この組み込み関数は fr450 上でのみ利用できます"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mvsx option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mhtm option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -maltivec option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mspe option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mhard-dfp option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mpower8-vector option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mcpu=power9 option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mhard-float option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#, fuzzy
-#~| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
-#~ msgid "Builtin function %s requires the -mfloat128 option"
-#~ msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
-
-#~ msgid "internal error: builtin function %s had an unexpected return type %s"
-#~ msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
-
-#~ msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
-#~ msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
-
-#~ msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
-#~ msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
-
-#~ msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
-#~ msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
-
-#~ msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
-#~ msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
-
-#~ msgid "emitting microcode insn %s\t[%s] #%d"
-#~ msgstr "マイクロコード命令 %s\t[%s] #%d を発行しています"
-
-#~ msgid "emitting conditional microcode insn %s\t[%s] #%d"
-#~ msgstr "条件付きマイクロコード命令 %s\t[%s] #%d を発行しています"
-
-#~ msgid "invalid cpu \"%s\" for %s\"%s\"%s"
-#~ msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
-
-#~ msgid "%s\"%s\"%s is not allowed"
-#~ msgstr "%s\"%s\"%s は許可されていません"
-
-#~ msgid "%s\"%s\"%s is invalid"
-#~ msgstr "%s\"%s\"%s は無効です"
-
-#, fuzzy
-#~| msgid "AltiVec and E500 instructions cannot coexist"
-#~ msgid "AltiVec and SPE instructions cannot coexist"
-#~ msgstr "AltiVec と E500 命令は同時に存在できません"
-
-#, fuzzy
-#~| msgid "VSX and E500 instructions cannot coexist"
-#~ msgid "VSX and SPE instructions cannot coexist"
-#~ msgstr "VSX と E500 命令は同時に存在できません"
-
-#, fuzzy
-#~| msgid "64-bit E500 not supported"
-#~ msgid "64-bit SPE not supported"
-#~ msgstr "64 ビット E500 はサポートされていません"
-
-#~ msgid "E500 and FPRs not supported"
-#~ msgstr "E500 と FPR はサポートされていません"
-
-#~ msgid "bad value for -mcall-%s"
-#~ msgstr "-mcall-%s 用の間違った値です"
-
-#~ msgid "bad value for -msdata=%s"
-#~ msgstr "-msdata=%s 用の間違った値です"
-
-#~ msgid "-mrelocatable and -msdata=%s are incompatible"
-#~ msgstr "-mrelocatable と -msdata=%s は併用できません"
-
-#~ msgid "-f%s and -msdata=%s are incompatible"
-#~ msgstr "-f%s と -msdata=%s は併用できません"
-
-#~ msgid "-msdata=%s and -mcall-%s are incompatible"
-#~ msgstr "-msdata=%s と -mcall-%s は併用できません"
-
-#~ msgid "-mrelocatable and -mno-minimal-toc are incompatible"
-#~ msgstr "-mrelocatable と -mno-minimal-toc は併用できません"
-
-#~ msgid "-mrelocatable and -mcall-%s are incompatible"
-#~ msgstr "-mrelocatable と -mcall-%s は併用できません"
-
-#~ msgid "-fPIC and -mcall-%s are incompatible"
-#~ msgstr "-fPIC と -mcall-%s は併用できません"
-
-#~ msgid "-msecure-plt not supported by your assembler"
-#~ msgstr "-msecure-plt は使用するアセンブラでサポートされていません"
-
-#~ msgid "-m%s not supported in this configuration"
-#~ msgstr "-m%s はこの設定ではサポートされていません"
-
-#, fuzzy
-#~| msgid "ifunc is not supported in this configuration"
-#~ msgid "builtin function %qs not supported in this compiler configuration"
-#~ msgstr "ifunc はこの設定ではサポートされていません"
-
-#, fuzzy
-#~| msgid "argument must be a constant"
-#~ msgid "argument 1 of %s must be a constant"
-#~ msgstr "引数は定数でなければいけません"
-
-#, fuzzy
-#~| msgid "constant argument out of range for %qs"
-#~ msgid "constant argument %d for builtin %qF is out of range ("
-#~ msgstr "%qs 用の定数引数が範囲外です"
-
-#, fuzzy
-#~| msgid "-fPIC and -fpic are not supported for this target"
-#~ msgid "CPUs older than z900 are not supported for -fsplit-stack"
-#~ msgstr "-fPIC and -fpic はこのターゲットではサポートされていません"
-
-#~ msgid "z/Architecture mode not supported on %s"
-#~ msgstr "z/Architecture モードは %s 上ではサポートされていません"
-
-#~ msgid "bad value (%s) for -mcmodel= switch"
-#~ msgstr "-mcmodel= スイッチ用の誤った値 %s です"
-
-#~ msgid "insufficient arguments to overloaded function %s"
-#~ msgstr "オーバーロードされた関数 %s への不十分な引数です"
-
-#~ msgid "too many arguments to overloaded function %s"
-#~ msgstr "オーバーロードされた関数 %s への引数が多すぎます"
-
-#, fuzzy
-#~ msgid "bad value (%s) for -march= switch"
-#~ msgstr "-mcmodel= スイッチ用の誤った値 %s です"
-
-#, fuzzy
-#~ msgid "bad value (%s) for -mtune= switch"
-#~ msgstr "-mtune スイッチ用の間違った値 %qs です"
-
-#~ msgid "creating run-time relocation for %qD"
-#~ msgstr "%qD 用の実行時再配置を作成しています"
-
-#~ msgid "creating run-time relocation"
-#~ msgstr "実行時再配置を作成しています"
-
-#~ msgid "wide string literal in %<asm%>"
-#~ msgstr "ワイド文字列リテラルが %<asm%> 内にあります"
-
-#~ msgid "%E qualifier ignored on asm"
-#~ msgstr "asm に関数 %E 修飾子が無視されました"
-
-#, fuzzy
-#~| msgid "ISO C does not support %<__int128%> type"
-#~ msgid "ISO C does not support %<__FUNCTION__%> predefined identifier"
-#~ msgstr "ISO C は %<__int128%> 型をサポートしません"
-
-#, fuzzy
-#~| msgid "expected integer expression"
-#~ msgid "expected integer expression before ')'"
-#~ msgstr "整数式が予期されます"
-
-#, fuzzy
-#~| msgid "expected %<throw%>"
-#~ msgid "expected %<tofrom%>"
-#~ msgstr "%<throw%> が予期されます"
-
-#, fuzzy
-#~| msgid "expected %<class%>"
-#~ msgid "expected %<scalar%>"
-#~ msgstr "%<class%> が予期されます"
-
-#, fuzzy
-#~| msgid "dereferencing pointer to incomplete type"
-#~ msgid "dereferencing pointer to incomplete type %qT"
-#~ msgstr "不完全型のポインタへの間接参照"
-
-#, fuzzy
-#~ msgid "cannot pass rvalue to reference parameter"
-#~ msgstr "参照型に対して new を適用できません"
-
-#~ msgid "char-array initialized from wide string"
-#~ msgstr "ワイド文字列から char 配列が初期化されています"
-
-#~ msgid "wide character array initialized from non-wide string"
-#~ msgstr "非ワイド文字列でワイド文字配列が初期化されています"
-
-#~ msgid "wide character array initialized from incompatible wide string"
-#~ msgstr "互換性のないワイド文字列でワイド文字配列が初期化されています"
-
-#, fuzzy
-#~| msgid "invalid offset operand of MEM_REF"
-#~ msgid "invalid number of operands to __FMA"
-#~ msgstr "MEM_REF の無効なオフセット被演算子です"
-
-#, fuzzy
-#~| msgid "expected statement"
-#~ msgid "expected semicolon"
-#~ msgstr "文が予期されます"
-
-#, fuzzy
-#~| msgid "expected labeled-statement"
-#~ msgid "expected case label or goto statement"
-#~ msgstr "ラベル付き文が予期されます"
-
-#~ msgid "  (you can disable this with -fno-deduce-init-list)"
-#~ msgstr "  (-fno-deduce-init-list でこれを無効に出来ます)"
-
-#~ msgid "field %q+D invalidly declared method type"
-#~ msgstr "フィールド %q+D はメソッド型として無効な宣言をされました"
-
-#~ msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
-#~ msgstr "%q+D は定数参照を取るように宣言されていますが、暗黙的な宣言では非定数参照を取ります"
-
-#~ msgid "declaration of %q#D"
-#~ msgstr "%q#D が宣言されています"
-
-#, fuzzy
-#~| msgid "changes meaning of %qD from %q+#D"
-#~ msgid "changes meaning of %qD from %q#D"
-#~ msgstr "%qD の意味の %q+#D からの変更です"
-
-#, fuzzy
-#~| msgid "section of %q+D conflicts with previous declaration"
-#~ msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
-#~ msgstr "%q+D のセクションが前の宣言と競合しています"
-
-#, fuzzy
-#~| msgid "type is deprecated"
-#~ msgid "%<-fno-for-scope%> is deprecated"
-#~ msgstr "型は廃止されました"
-
-#, fuzzy
-#~ msgid "cannot declare %<::main%> to be %<constexpr%>"
-#~ msgstr "`::main' を inline としては宣言できません"
-
-#, fuzzy
-#~ msgid "size of array %qD is negative"
-#~ msgstr "配列 `%s' の大きさが負です"
-
-#~ msgid "%<signed%> or %<unsigned%> invalid for %qs"
-#~ msgstr "%<signed%> または %<unsigned%> は %qs に対しては無効です"
-
-#~ msgid "%<long long%> invalid for %qs"
-#~ msgstr "%<long long%> は %qs に対しては無効です"
-
-#~ msgid "%<long%> invalid for %qs"
-#~ msgstr "%<long%> は %qs に対しては無効です"
-
-#~ msgid "%<short%> invalid for %qs"
-#~ msgstr "%<short%> は %qs に対しては無効です"
-
-#~ msgid "%<long%> or %<short%> invalid for %qs"
-#~ msgstr "%<long%> または %<short%> は %qs に対しては無効です"
-
-#~ msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
-#~ msgstr "%<long%>、%<int%>、%<short%>、または %<char%> は %qs に対しては無効です"
-
-#~ msgid "%<long%> or %<short%> specified with char for %qs"
-#~ msgstr "%<long%> または %<short%> が char と共に %qs に対して指定されています"
-
-#~ msgid "%<short%> or %<long%> invalid for %qs"
-#~ msgstr "%<short%> または %<long%> は %qs に対しては無効です"
-
-#~ msgid "long, short, signed or unsigned used invalidly for %qs"
-#~ msgstr "long, short, signed または unsigned の使用は %qs に対しては無効です"
-
-#~ msgid "storage class specifiers invalid in parameter declarations"
-#~ msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
-
-#, fuzzy
-#~| msgid "a parameter cannot be declared %<constexpr%>"
-#~ msgid "a parameter cannot be declared %<concept%>"
-#~ msgstr "仮引数は %<constexpr%> として宣言してはいけません"
-
-#, fuzzy
-#~| msgid "Warn when an inlined function cannot be inlined"
-#~ msgid "structured binding declaration cannot be %<inline%>"
-#~ msgstr "インライン関数をインライン化できない場合に警告する"
-
-#, fuzzy
-#~ msgid "structured binding declaration cannot be %<typedef%>"
-#~ msgstr "`%s' の extern 宣言がネストしています"
-
-#, fuzzy
-#~ msgid "structured binding declaration cannot be %<constexpr%>"
-#~ msgstr "デストラクタを静的メンバ関数とすることはできません"
-
-#, fuzzy
-#~ msgid "structured binding declaration cannot be %<concept%>"
-#~ msgstr "デストラクタを静的メンバ関数とすることはできません"
-
-#, fuzzy
-#~ msgid "structured binding declaration cannot be %<register%>"
-#~ msgstr "`register' と宣言された配列に添字をつけようとしています"
-
-#, fuzzy
-#~| msgid "nested function %qE declared %<extern%>"
-#~ msgid "structured binding declaration cannot be %<extern%>"
-#~ msgstr "入れ子になった関数 %qE が %<extern%> と宣言されています"
-
-#, fuzzy
-#~ msgid "structured binding declaration cannot be %<mutable%>"
-#~ msgstr "関数 `%s' を `mutable' としては宣言できません"
-
-#, fuzzy
-#~ msgid "conversion to a reference to void will never use a type conversion operator"
-#~ msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
-
-#, fuzzy
-#~ msgid "invalid function declaration"
-#~ msgstr "無効な宣言です"
-
-#, fuzzy
-#~ msgid "invalid member function declaration"
-#~ msgstr "無効な宣言です"
-
-#~ msgid "junk at end of #pragma %s"
-#~ msgstr "#pragma %s の末尾にゴミ"
-
-#, fuzzy
-#~ msgid "name lookup of %qD changed"
-#~ msgstr "`%s' の名前引きは変更されました"
-
-#, fuzzy
-#~ msgid "name lookup of %qD changed for ISO %<for%> scoping"
-#~ msgstr "`%s' の名前引きは新たな ISO `for' スコープに変わりました"
-
-#, fuzzy
-#~ msgid "attributes ignored on local using directive"
-#~ msgstr "インスタンス化されない型に対する無効な操作です"
-
-#, fuzzy
-#~| msgid "expected template-argument"
-#~ msgid "lambda-expression in template-argument"
-#~ msgstr "テンプレート引数が予期されます"
-
-#, fuzzy
-#~| msgid "Enable multiply instructions"
-#~ msgid "empty introduction-list"
-#~ msgstr "乗算命令を有効にする"
-
-#~ msgid "        <anonymous>"
-#~ msgstr "        <無名>"
-
-#~ msgid "-frepo must be used with -c"
-#~ msgstr "-frepo は -c 付きでなければなりません"
-
-#~ msgid "mysterious repository information in %s"
-#~ msgstr "%s に不可解なリポジトリ情報があります"
-
-#, fuzzy
-#~ msgid "looser throw specifier for %q+#F"
-#~ msgstr "`%s' に対して char とともに long または short が指定されています"
-
-#, fuzzy
-#~| msgid "%<num_threads%> value must be positive"
-#~ msgid "%<num_tasks%> expression must be integral"
-#~ msgstr "%<num_threads%> 値は正でなければいけません"
-
-#, fuzzy
-#~ msgid "lambda-expression in a constant expression"
-#~ msgstr "定数式がオーバーフローしました"
-
-#, fuzzy
-#~| msgid "cannot disable built-in function %qs"
-#~ msgid "cannot call function %qD"
-#~ msgstr "組み込み関数 %qs を無効に出来ません"
-
-#, fuzzy
-#~ msgid "left rotate count is negative"
-#~ msgstr "%s ローテート回数が負の値です"
-
-#, fuzzy
-#~ msgid "right rotate count is negative"
-#~ msgstr "%s ローテート回数が負の値です"
-
-#, fuzzy
-#~ msgid "left rotate count >= width of type"
-#~ msgstr "%s ローテート回数 >= 型の幅です"
-
-#, fuzzy
-#~ msgid "right rotate count >= width of type"
-#~ msgstr "%s ローテート回数 >= 型の幅です"
-
-#~ msgid "reference to non-lvalue returned"
-#~ msgstr "非左辺値への参照が返されました"
-
-#~ msgid "int-array initialized from non-wide string"
-#~ msgstr "非ワイド文字列から int の配列が初期化されました"
-
-#, fuzzy
-#~ msgid "int-array initialized from incompatible wide string"
-#~ msgstr "非ワイド文字列から int の配列が初期化されました"
-
-#, fuzzy
-#~ msgid "Change of value in conversion from  %qs to %qs at %L"
-#~ msgstr "NaN から整数への変換です"
-
-#, fuzzy
-#~ msgid "BACK argument to %qs intrinsic not yet implemented"
-#~ msgstr "Trampoline は、まだ実装されていません"
-
-#, fuzzy
-#~| msgid "nonconstant array index in initializer"
-#~ msgid "Expected constant array-spec in initializer list at %L"
-#~ msgstr "初期化子内に非定数の配列インデックスがあります"
-
-#, fuzzy
-#~ msgid "Type of argument %qs in call to %qs at %L should be %s, not %s"
-#~ msgstr "関数 `%s' に対する引数が多すぎます"
-
-#, fuzzy
-#~ msgid "Missing %<(%> in statement at or before %L"
-#~ msgstr "`*' の前に型の名前があるべきです"
-
-#, fuzzy
-#~ msgid "gfc_variable_attr(): Bad array reference"
-#~ msgstr "配列参照での添字を欠いています"
-
-#, fuzzy
-#~ msgid "Second argument of MOD at %L is zero"
-#~ msgstr "`%s' の第二引数は `char **' とすべきです"
-
-#~ msgid "pex_init failed"
-#~ msgstr "pex_init に失敗しました"
-
-#~ msgid "%s:not a gcov graph file\n"
-#~ msgstr "%s: gcov グラフファイルではありません\n"
-
-#~ msgid "%s:unknown function '%u'\n"
-#~ msgstr "%s: 不明な関数 '%u' です\n"
-
-#~ msgid "%s:%d:%d: Invalid state file; %s"
-#~ msgstr "%s:%d:%d: 無効な状態ファイルです。%s"
-
-#~ msgid "%s:%d: Invalid state file; %s"
-#~ msgstr "%s:%d: 無効な状態ファイルです。%s"
-
-#~ msgid "%s:%d:%d: Invalid state file; "
-#~ msgstr "%s:%d:%d: 無効な状態ファイルです。 "
-
-#~ msgid "%s:%d: Invalid state file; "
-#~ msgstr "%s:%d: 無効な状態ファイルです。 "
-
-#~ msgid "Option tag unknown"
-#~ msgstr "オプションタグが不明です"
-
-#~ msgid "Unexpected type in write_state_scalar_type"
-#~ msgstr "write_state_scalar_type 内で予期しない型です"
-
-#~ msgid "Unexpected type in write_state_string_type"
-#~ msgstr "write_state_string_type 内で予期しない型です"
-
-#~ msgid "Unexpected type..."
-#~ msgstr "予期しない型..."
-
-#~ msgid "failed to write state trailer [%s]"
-#~ msgstr "状態追跡の書き込みに失敗しました [%s]"
-
-#~ msgid "Failed to open file %s for writing state: %s"
-#~ msgstr "状態書き込み用ファイル %s を開くのに失敗しました: %s"
-
-#~ msgid "output error when writing state file %s [%s]"
-#~ msgstr "状態ファイル %s  の書き込み時に出力エラーが発生しました [%s]"
-
-#~ msgid "failed to close state file %s [%s]"
-#~ msgstr "状態ファイル %s を閉じるのに失敗しました [%s]"
-
-#~ msgid "failed to rename %s to state file %s [%s]"
-#~ msgstr "%s から状態ファイル %s へ名前を変更するのに失敗しました [%s]"
-
-#~ msgid "Failed to open state file %s for reading [%s]"
-#~ msgstr "状態ファイル %s を読み込みように開くのに失敗しました [%s]"
-
-#~ msgid "assuming that the loop is not infinite"
-#~ msgstr "ループが無限でないと仮定しています"
-
-#~ msgid "cannot optimize possibly infinite loops"
-#~ msgstr "無限ループの可能性があるものを最適化できません"
-
-#~ msgid "assuming that the loop counter does not overflow"
-#~ msgstr "ループカウンタが溢れないと仮定しています"
-
-#~ msgid "cannot optimize loop, the loop counter may overflow"
-#~ msgstr "ループを最適化できません。ループカウンタが溢れるかもしれません"
-
-#~ msgid "%s terminated with signal %d [%s], core dumped"
-#~ msgstr "%s はシグナル %d [%s] で終了しました。コアダンプしました"
-
-#~ msgid "%s terminated with signal %d [%s]"
-#~ msgstr "%s はシグナル %d [%s] で終了しました"
-
-#~ msgid "could not write to temporary file %s"
-#~ msgstr "一時ファイル %s を書き込むことができませんでした"
-
-#~ msgid "enabled by default"
-#~ msgstr "デフォルトで有効"
-
-#~ msgid "out of memory"
-#~ msgstr "メモリが足りません"
-
-#~ msgid "<unnamed-signed:"
-#~ msgstr "<名前無し符号付き:"
-
-#~ msgid "function parameters cannot have __fp16 type"
-#~ msgstr "関数パラメータは __fp16 型を持てません"
-
-#~ msgid " (frv)"
-#~ msgstr " (frv)"
-
-#~ msgid "operand is neither a constant nor a condition code, invalid operand code 'C'"
-#~ msgstr "被演算子は定数でも条件コードでもありません。無効な被演算子コード 'C' です"
-
-#~ msgid "operand is neither a constant nor a condition code, invalid operand code 'F'"
-#~ msgstr "被演算子は定数でも条件コードでもありません。無効な被演算子コード 'F' です"
-
-#~ msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
-#~ msgstr "被演算子は定数でも条件コードでもありません。無効な被演算子コード 'c' です"
-
-#~ msgid "operand is neither a constant nor a condition code, invalid operand code 'f'"
-#~ msgstr "被演算子は定数でも条件コードでもありません。無効な被演算子コード 'f' です"
-
-#~ msgid "invalid register in the move instruction"
-#~ msgstr "move 命令内で無効なレジスタです"
-
-#~ msgid "invalid operand in the instruction"
-#~ msgstr "命令に対して無効な被演算子です"
-
-#~ msgid "registers IX, IY and Z used in the same INSN"
-#~ msgstr "同じ命令内で IX、IY および Z が使用されました"
-
-#~ msgid "cannot do z-register replacement"
-#~ msgstr "z レジスタ置換を行えません"
-
-#~ msgid "mips_debugger_offset called with non stack/frame/arg pointer"
-#~ msgstr "stack/frame/arg ポインタ無しで mips_debugger_offset が呼ばれました"
-
-#~ msgid "Bad address, not (reg+disp):"
-#~ msgstr "誤ったアドレスです。 (reg+disp) ではありません:"
-
-#~ msgid "-mvsx used with little endian code"
-#~ msgstr "-mvsx がリトルエンディアンコードで使用されました"
-
-#~ msgid "invalid %%c value"
-#~ msgstr "無効な %%c 値です"
-
-#~ msgid "invalid %%S value"
-#~ msgstr "無効な %%S 値です"
-
-#~ msgid "memory reference expected for 'O' output modifier"
-#~ msgstr "'O' 出力修飾子用にはメモリ参照が予期されます"
-
-#~ msgid "memory reference expected for 'R' output modifier"
-#~ msgstr "'R' 出力修飾子用にはメモリ参照が予期されます"
-
-#~ msgid "invalid operand for code: '%c'"
-#~ msgstr "コード '%c' に対する無効な被演算子です"
-
-#~ msgid "long long constant not a valid immediate operand"
-#~ msgstr "long long 定数は有効な即値被演算子ではありません"
-
-#~ msgid "candidates are: %+#D"
-#~ msgstr "候補: %+#D"
-
-#~ msgid "candidate is: %+#D"
-#~ msgstr "候補: %+#D"
-
-#~ msgid "<anonymous %s>"
-#~ msgstr "<無名 %s>"
-
-#~ msgid "{unknown}"
-#~ msgstr "{不明}"
-
-#~ msgid "%s:%d:%d:   recursively instantiated from %qs\n"
-#~ msgstr "%s:%d:%d:   %qs から再帰的に実体化されました\n"
-
-#~ msgid "%s:%d:%d:   recursively instantiated from here"
-#~ msgstr "%s:%d:%d:   ここから再帰的に実体化されました"
-
-#~ msgid "%s:%d:%d:   instantiated from here"
-#~ msgstr "%s:%d:%d:   ここから実体化されました"
-
-#~ msgid "%s:%d:   instantiated from here"
-#~ msgstr "%s:%d:   ここから実体化されました"
-
-#~ msgid ""
-#~ "GNU Fortran comes with NO WARRANTY, to the extent permitted by law.\n"
-#~ "You may redistribute copies of GNU Fortran\n"
-#~ "under the terms of the GNU General Public License.\n"
-#~ "For more information about these matters, see the file named COPYING\n"
-#~ "\n"
-#~ msgstr ""
-#~ "GNU Fortran comes with NO WARRANTY, to the extent permitted by law.\n"
-#~ "You may redistribute copies of GNU Fortran\n"
-#~ "under the terms of the GNU General Public License.\n"
-#~ "For more information about these matters, see the file named COPYING\n"
-#~ "\n"
-
-#, fuzzy
-#~ msgid "internal function"
-#~ msgstr "内部エラー"
-
-#~ msgid "Not a valid Java .class file.\n"
-#~ msgstr "有効な Java .class ファイルではありません。\n"
-
-#~ msgid "error while parsing constant pool\n"
-#~ msgstr "constant プールを構文解析中にエラーが発生しました\n"
-
-#~ msgid "error in constant pool entry #%d\n"
-#~ msgstr "constant プール項目 #%d 内でエラーが発生しました\n"
-
-#~ msgid "error while parsing fields\n"
-#~ msgstr "フィールドを構文解析中にエラーが発生しました\n"
-
-#~ msgid "error while parsing methods\n"
-#~ msgstr "メソッドを構文解析中にエラーが発生しました\n"
-
-#~ msgid "error while parsing final attributes\n"
-#~ msgstr "final 属性を構文解析中にエラーが発生しました\n"
-
-#~ msgid "Try 'jcf-dump --help' for more information.\n"
-#~ msgstr "詳しくは 'jcf-dump --help' を参照してください。\n"
-
-#~ msgid ""
-#~ "Usage: jcf-dump [OPTION]... CLASS...\n"
-#~ "\n"
-#~ msgstr ""
-#~ "使用法: jcf-dump [OPTION]... CLASS...\n"
-#~ "\n"
-
-#~ msgid ""
-#~ "Display contents of a class file in readable form.\n"
-#~ "\n"
-#~ msgstr ""
-#~ "可読形式でクラスファイルの内容を表示します。\n"
-#~ "\n"
-
-#~ msgid "  -c                      Disassemble method bodies\n"
-#~ msgstr "  -c                      メソッド本体を逆アセンブルする\n"
-
-#~ msgid "  --javap                 Generate output in 'javap' format\n"
-#~ msgstr "  --javap                 'javap' 形式で出力を生成する\n"
-
-#~ msgid "  --classpath PATH        Set path to find .class files\n"
-#~ msgstr "  --classpath PATH        .class ファイルを探すパスを設定する\n"
-
-#~ msgid "  -IDIR                   Append directory to class path\n"
-#~ msgstr "  -IDIR                   クラスパスにディレクトリを追加する\n"
-
-#~ msgid "  --bootclasspath PATH    Override built-in class path\n"
-#~ msgstr "  --bootclasspath PATH    組み込みクラスパスを上書きする\n"
-
-#~ msgid "  --extdirs PATH          Set extensions directory path\n"
-#~ msgstr "  --extdirs PATH          拡張のディレクトリパスを設定する\n"
-
-#~ msgid "  -o FILE                 Set output file name\n"
-#~ msgstr "  -o FILE                 出力ファイル名を FILE に設定する\n"
-
-#~ msgid "  --help                  Print this help, then exit\n"
-#~ msgstr "  --help                  このヘルプを表示して終了する\n"
-
-#~ msgid "  --version               Print version number, then exit\n"
-#~ msgstr "  --version               バージョン番号を表示して終了する\n"
-
-#~ msgid ""
-#~ "For bug reporting instructions, please see:\n"
-#~ "%s.\n"
-#~ msgstr ""
-#~ "バグレポートの手順については\n"
-#~ "  %s\n"
-#~ "を参照してください。\n"
-
-#~ msgid "jcf-dump: no classes specified\n"
-#~ msgstr "jcf-dump: クラスが指定されていません\n"
-
-#~ msgid "Cannot open '%s' for output.\n"
-#~ msgstr "'%s' を出力用に開けませんでした。\n"
-
-#~ msgid "bad format of .zip/.jar archive\n"
-#~ msgstr ".zip/.jar 書庫の形式が間違っています。\n"
-
-#~ msgid "Bad byte codes.\n"
-#~ msgstr "間違ったバイトコードです。\n"
-
-#~ msgid "%s: Failed to close output file %s\n"
-#~ msgstr "%s: 出力ファイル %s を閉じるのに失敗しました\n"
-
-#~ msgid "-fjni and -femit-class-files are incompatible"
-#~ msgstr "-fjni と -femit-class-files は併用できません"
-
-#~ msgid "-fjni and -femit-class-file are incompatible"
-#~ msgstr "-fjni と -femit-class-file は併用できません"
-
-#~ msgid "-femit-class-file should used along with -fsyntax-only"
-#~ msgstr "-femit-class-file は -fsyntax-only に合わせて使用してください"
-
-#~ msgid "ax ; {int $0x80 | syscall"
-#~ msgstr "ax ; {int $0x80 | syscall"
-
-#~ msgid "Warn if .class files are out of date"
-#~ msgstr ".class ファイルがソースファイルより古ければ警告する"
-
-#~ msgid "Warn if modifiers are specified when not necessary"
-#~ msgstr "指定された修飾子が不要なものであれば警告する"
-
-#~ msgid "--CLASSPATH\tDeprecated; use --classpath instead"
-#~ msgstr "--CLASSPATH\t廃止されました。代わりに --classpath を使用してください"
-
-#~ msgid "Permit the use of the assert keyword"
-#~ msgstr "assert 予約語の使用を許可する"
-
-#~ msgid "--bootclasspath=<path>\tReplace system path"
-#~ msgstr "--bootclasspath=<path>\tシステムパスを置換する"
-
-#~ msgid "--classpath=<path>\tSet class path"
-#~ msgstr "--classpath=<path>\tクラスパスを設定する"
-
-#~ msgid "Output a class file"
-#~ msgstr "クラスファイルを出力する"
-
-#~ msgid "Alias for -femit-class-file"
-#~ msgstr "-femit-class-file の別名"
-
-#~ msgid "--encoding=<encoding>\tChoose input encoding (defaults from your locale)"
-#~ msgstr "--encoding=<encoding>\t入力エンコーディングを選択する (デフォルトはロケール)"
-
-#~ msgid "--extdirs=<path>\tSet the extension directory path"
-#~ msgstr "--extdirs=<path>\t拡張のディレクトリパスを設定する"
-
-#~ msgid "Input file is a file with a list of filenames to compile"
-#~ msgstr "入力ファイルをコンパイルするファイル名の一覧にする"
-
-#~ msgid "Always check for non gcj generated classes archives"
-#~ msgstr "gcj が生成していないクラスアーカイブを常に検査する"
-
-#~ msgid "Generate instances of Class at runtime"
-#~ msgstr "実行時にクラスのインスタンスを生成する"
-
-#~ msgid "Use offset tables for virtual method calls"
-#~ msgstr "仮想メソッド呼び出し用のオフセット表を使用する"
-
-#~ msgid "Assume native functions are implemented using JNI"
-#~ msgstr "native 関数が JNI を利用して実装しているものとみなす"
-
-#~ msgid "Enable optimization of static class initialization code"
-#~ msgstr "静的クラス初期化コードの最適化を有効にする"
-
-#~ msgid "Call a library routine to do integer divisions"
-#~ msgstr "整数の割り算を実行時にライブラリルーチンを呼び出す"
-
-#~ msgid "Set the source language version"
-#~ msgstr "ソース言語バージョンを設定する"
-
-#~ msgid "Use big-endian format for unformatted files"
-#~ msgstr "形式が定められていないファイルではビッグエンディアン形式を使用する"
-
-#~ msgid "Use little-endian format for unformatted files"
-#~ msgstr "形式が定められていないファイルではリトルエンディアン形式を使用する"
-
-#~ msgid "Swap endianness for unformatted files"
-#~ msgstr "形式が定められていないファイルではエンディアンのバイト順を交換する"
-
-#~ msgid "Assume GAS"
-#~ msgstr "GAS を使用すると見なす"
-
-#~ msgid "Do not assume GAS"
-#~ msgstr "GAS を使用すると見なさない"
-
-#~ msgid "SYMBOL_VECTOR=(__divdi3=PROCEDURE)"
-#~ msgstr "SYMBOL_VECTOR=(__divdi3=PROCEDURE)"
-
-#~ msgid "Generate code for little-endian"
-#~ msgstr "リトルエンディアン用のコードを生成する"
-
-#~ msgid "Generate code for big-endian"
-#~ msgstr "ビッグエンディアン用コードを生成する"
-
-#~ msgid "Ignored (obsolete)"
-#~ msgstr "無視される (廃止)"
-
-#~ msgid "Use POWER instruction set"
-#~ msgstr "POWER 命令セットを使用する"
-
-#~ msgid "Do not use POWER instruction set"
-#~ msgstr "POWER 命令セットを使用しない"
-
-#~ msgid "Use POWER2 instruction set"
-#~ msgstr "POWER2 命令セットを使用する"
-
-#~ msgid "Use PowerPC instruction set"
-#~ msgstr "PowerPC 命令セットを使用する"
-
-#~ msgid "Use new mnemonics for PowerPC architecture"
-#~ msgstr "PowerPC アーキテクチャ用の新しいニーモニックを使用する"
-
-#~ msgid "Use old mnemonics for PowerPC architecture"
-#~ msgstr "PowerPC アーキテクチャ用の古いニーモニックを使用する"
-
-#~ msgid "-mabi=\tSpecify ABI to use"
-#~ msgstr "-mabi=\t使用する ABI を指定する"
-
-#~ msgid "Prepend the name of the cpu to all public symbol names"
-#~ msgstr "すべての公開シンボル名の前に CPU 名を付ける"
-
-#~ msgid "-mtext=SECTION\tPut functions in SECTION"
-#~ msgstr "-mtext=SECTION\tSECTION 内に関数を配置する"
-
-#~ msgid "-mdata=SECTION\tPut data in SECTION"
-#~ msgstr "-mdata=SECTION\tSECTION 内にデータを配置する"
-
-#~ msgid "-mrodata=SECTION\tPut read-only data in SECTION"
-#~ msgstr "-mrodata=SECTION\tSECTION 内に読み取り専用データを配置する"
-
-#~ msgid "Generate 32-bit SHmedia code"
-#~ msgstr "32 ビット SHmedia コードを生成する"
-
-#~ msgid "Generate 32-bit FPU-less SHmedia code"
-#~ msgstr "32 ビット FPU 無し SHmedia コードを生成する"
-
-#~ msgid "Generate 64-bit SHmedia code"
-#~ msgstr "64 ビット SHmedia コードを生成する"
-
-#~ msgid "Generate 64-bit FPU-less SHmedia code"
-#~ msgstr "64 ビット FPU 無し SHmedia コードを生成する"
-
-#~ msgid "Generate SHcompact code"
-#~ msgstr "SHcompact コードを生成する"
-
-#~ msgid "Generate FPU-less SHcompact code"
-#~ msgstr "FPU 無し SHcompact コードを生成する"
-
-#~ msgid "Emit cmpeqdi_t pattern even when -mcbranchdi is in effect."
-#~ msgstr "-mcbranchdi が有効だとしても cmpeqdi_t パターンを発行する"
-
-#~ msgid "Enable SH5 cut2 workaround"
-#~ msgstr "SH5 cut2 回避を有効にする"
-
-#~ msgid "Division strategy, one of: call, call2, fp, inv, inv:minlat, inv20u, inv20l, inv:call, inv:call2, inv:fp, call-div1, call-fp, call-table"
-#~ msgstr "除算戦略、次のいずれか: call, call2, fp, inv, inv:minlat, inv20u, inv20l, inv:call, inv:call2, inv:fp, call-div1, call-fp, call-table"
-
-#~ msgid "Cost to assume for gettr insn"
-#~ msgstr "gettr 命令用のコストを設定する"
-
-#~ msgid "Assume pt* instructions won't trap"
-#~ msgstr "pt* 命令がトラップされないと見なす"
-
-#~ msgid "Cirrus: Place NOPs to avoid invalid instruction combinations"
-#~ msgstr "Cirrus: 無効な命令の組み合わせを回避するために NOP を配置する"
-
-#~ msgid "Alias for -mfloat-abi=hard"
-#~ msgstr "-mfloat-abi=hard の別名"
-
-#~ msgid "Alias for -mfloat-abi=soft"
-#~ msgstr "-mfloat-abi=soft の別名"
-
-#~ msgid "Compile for the Thumb not the ARM"
-#~ msgstr "ARM ではなく Thumb 用にコンパイルする"
-
-#~ msgid "Assume big endian bytes, little endian words"
-#~ msgstr "byte がビッグエンディアンで word がリトルエンディアンとみなす"
-
-#~ msgid "Ignore dllimport attribute for functions"
-#~ msgstr "関数の dllimport 属性を無視する"
-
-#~ msgid "Use rjmp/rcall (limited range) on >8K devices"
-#~ msgstr "8K より大きいデバイス上で rjmp/rcall (制限された範囲) を使用する"
-
-#~ msgid "Do not use push to store function arguments"
-#~ msgstr "関数の引数を保存するために push を使用しない"
-
-#~ msgid "Restrict doloop to the given nesting level"
-#~ msgstr "doloop を与えられた入れ子階層に制限する"
-
-#~ msgid "Compile for a 68HC11"
-#~ msgstr "68HC11 用にコンパイルする"
-
-#~ msgid "Compile for a 68HC12"
-#~ msgstr "68HC12 用にコンパイルする"
-
-#~ msgid "Compile for a 68HCS12"
-#~ msgstr "68HCS12 用にコンパイルする"
-
-#~ msgid "Auto pre/post decrement increment allowed"
-#~ msgstr "自動 前置/後置 減分/増分 を許容する"
-
-#~ msgid "Min/max instructions allowed"
-#~ msgstr "min/max 命令を許可する"
-
-#~ msgid "Auto pre/post decrement increment not allowed"
-#~ msgstr "自動 前置/後置 減分/増分を許容しない"
-
-#~ msgid "Use jsr and rts for function calls and returns"
-#~ msgstr "関数呼び出しと戻り用に jsr と rts を使用する"
-
-#~ msgid "Min/max instructions not allowed"
-#~ msgstr "min/max 命令を許可しない"
-
-#~ msgid "Use direct addressing mode for soft registers"
-#~ msgstr "ソフトレジスタ用に直接アドレスモードを使用する"
-
-#~ msgid "Compile with 16-bit integer mode"
-#~ msgstr "16 ビット整数モードでコンパイルする"
-
-#~ msgid "Indicate the number of soft registers available"
-#~ msgstr "利用可能ソフトレジスタの数を示す"
-
-#~ msgid "Support Green Hills ABI"
-#~ msgstr "Green Hill の ABI をサポートする"
-
-#~ msgid "Specify whether the byte access instructions should be used. Enabled by default."
-#~ msgstr "バイトアクセス命令を使用するかどうかを指定する。デフォルトでは有効となる"
-
-#~ msgid "Enable debug output to be generated."
-#~ msgstr "デバッグ出力の生成を有効にする"
-
-#~ msgid "Allow a symbol value to be used as an immediate value in an instruction."
-#~ msgstr "命令内でシンボル値が即値として使用されることを許可する"
-
-#~ msgid "Generate warnings when inefficient code is known to be generated."
-#~ msgstr "非効率なコードが生成された時に警告する"
-
-#~ msgid "Disable bcnz instruction"
-#~ msgstr "bcnz 命令を無効にする"
-
-#~ msgid "Support SCORE 7 ISA"
-#~ msgstr "SCORE 7 ISA をサポートする"
-
-#~ msgid "Support SCORE 7D ISA"
-#~ msgstr "SCORE 7D ISA をサポートする"
-
-#~ msgid "Enable average instructions"
-#~ msgstr "平均命令を有効にする"
-
-#~ msgid "Configuration name"
-#~ msgstr "設定名"
-
-#~ msgid "Enable MeP Coprocessor"
-#~ msgstr "MeP コプロセッサを有効にする"
-
-#~ msgid "Enable MeP Coprocessor with 32-bit registers"
-#~ msgstr "32 ビットレジスタ付き MeP コプロセッサを有効にする"
-
-#~ msgid "Enable MeP Coprocessor with 64-bit registers"
-#~ msgstr "64 ビットレジスタ付き MeP コプロセッサを有効にする"
-
-#~ msgid "Enable IVC2 scheduling"
-#~ msgstr "IVC2 スケジュールを有効にする"
-
-#~ msgid "Enable 32-bit divide instructions"
-#~ msgstr "32 ビット除算命令を有効にする"
-
-#~ msgid "__io vars are volatile by default"
-#~ msgstr "__io 変数をデフォルトで volatile にする"
-
-#~ msgid "Enable min/max instructions"
-#~ msgstr "min/max 命令を有効にする"
-
-#~ msgid "Use sdram version of runtime"
-#~ msgstr "sdram バージョンのランタイムを使用する"
-
-#~ msgid "Use simulator runtime without vectors"
-#~ msgstr "ベクトル無しのシミュレータランタイムを使用する"
-
-#~ msgid "Reduce the size of object files"
-#~ msgstr "オブジェクトファイルのサイズを小さくする"
-
-#~ msgid "Use the same size for double as for float"
-#~ msgstr "double と float を同じサイズとして使用する"
-
-#~ msgid "Conform to the ISO 1998 C++ standard, with extensions that are likely to"
-#~ msgstr "ISO 1998 C++ 標準に準拠させる。拡張も同様にする"
-
-#~ msgid "Generate debug information to support Identical Code Folding (ICF)"
-#~ msgstr "Identical Code Folding (ICF) をサポートするためのデバッグ情報を生成する"
-
-#~ msgid "Pay attention to the \"inline\" keyword"
-#~ msgstr "\"inline\" 予約語に注意を払う"
-
-#~ msgid "Integrate simple functions into their callers"
-#~ msgstr "単純な関数を呼び出し側に統合する"
-
-#~ msgid "Perform structure layout optimizations based"
-#~ msgstr "構造体の配置を最適化に基づいて行う"
-
-#~ msgid "Add mudflap bounds-checking instrumentation for single-threaded program"
-#~ msgstr "シングルスレッドプログラム用の mudflap 境界検査機構を加える"
-
-#~ msgid "Add mudflap bounds-checking instrumentation for multi-threaded program"
-#~ msgstr "マルチスレッドプログラム用の mudflap 境界検査機構を加える"
-
-#~ msgid "Ignore read operations when inserting mudflap instrumentation"
-#~ msgstr "mudflap 機構を加える時に読み取り操作を無視する"
-
-#~ msgid "Allow loop optimizations to assume that the loops behave in normal way"
-#~ msgstr "ループが通常の方法で振る舞うと見なせる場合にループ最適化を許可する"
-
-#~ msgid "Generate debug information in COFF format"
-#~ msgstr "COFF 形式でデバッグ情報を生成する"
-
-#~ msgid "floating point constant truncated to integer"
-#~ msgstr "浮動小数点定数が整数に切り詰められました"
-
-#~ msgid "invalid operand for unary %<&%>"
-#~ msgstr "単項演算子 %<&%> への無効な被演算子です"
-
-#~ msgid "method call without object"
-#~ msgstr "オブジェクト無しのメソッド呼び出しです"
-
-#~ msgid "invalid unsafe.Pointer conversion"
-#~ msgstr "無効な unsafe.Pointer 変換です"
-
-#~ msgid "no object for method call"
-#~ msgstr "メソッド呼び出し用のオブジェクトがありません"
-
-#~ msgid "implicit assignment of %s%s%s hidden field %s%s%s"
-#~ msgstr "暗黙的な代入 %s%s%s が隠されたフィールド %s%s%s に行われます"
-
-#~ msgid "invalid argument to %<__builtin_return_address%>"
-#~ msgstr "%<__builtin_return_address%> への無効な引数です"
-
-#~ msgid "unsupported argument to %<__builtin_frame_address%>"
-#~ msgstr "%<__builtin_frame_address%> へのサポートされていない引数です"
-
-#~ msgid "declaration of %q+D shadows a global declaration"
-#~ msgstr "%q+D の宣言は大域宣言を隠します"
-
-#~ msgid "declaration of %q+D shadows a previous local"
-#~ msgstr "%q+D の再宣言は前の局所宣言を隠します"
-
-#~ msgid "the size of array %qE can%'t be evaluated"
-#~ msgstr "配列 %qE のサイズを評価できません"
-
-#~ msgid "the size of array can %'t be evaluated"
-#~ msgstr "配列のサイズを評価できません"
-
-#~ msgid "function definition declared %<__thread%>"
-#~ msgstr "関数定義が %<__thread%> と宣言されています"
-
-#~ msgid "%<%s %E%> declared inside parameter list"
-#~ msgstr "仮引数リスト内で %<%s %E%> が宣言されています"
-
-#~ msgid "anonymous %s declared inside parameter list"
-#~ msgstr "無名 %s が仮引数リスト内で宣言されています"
-
-#~ msgid "its scope is only this definition or declaration, which is probably not what you want"
-#~ msgstr "そのスコープはこの定義または宣言のみです。これは多分希望したものではないでしょう"
-
-#~ msgid "%<__thread%> used with %qE"
-#~ msgstr "%<__thread%> が %qE と併せて使用されています"
-
-#~ msgid "increment of pointer to unknown structure"
-#~ msgstr "不明な構造体へのポインタの増分です"
-
-#~ msgid "decrement of pointer to unknown structure"
-#~ msgstr "不明な構造体へのポインタの減分です"
-
-#~ msgid "return makes pointer from integer without a cast"
-#~ msgstr "戻りで整数からキャスト無しにポインタを作成しています"
-
-#~ msgid "return makes integer from pointer without a cast"
-#~ msgstr "戻りでポインタからキャスト無しに整数を作成しています"
-
-#~ msgid "mis-aligned access used for structure member"
-#~ msgstr "構造体メンバ用に整列されていないアクセスが使用されました"
-
-#~ msgid "mis-aligned access used for structure bitfield"
-#~ msgstr "構造体ビットフィールド用に整列されていないアクセスが使用されました"
-
-#~ msgid "%s (program %s)"
-#~ msgstr "%s (プログラム %s)"
-
-#~ msgid "use of obsolete %%[ operator in specs"
-#~ msgstr "spec 内で廃止された %%[ 演算子が使用されています"
-
-#~ msgid "can%'t seek PCH file: %m"
-#~ msgstr "PCH ファイルを探査 (seek) 出来ません: %m"
-
-#~ msgid "the file is not in OpenScop format"
-#~ msgstr "ファイルは OpenScop 形式ではありません"
-
-#~ msgid "the language is not recognized"
-#~ msgstr "言語が認識できません"
-
-#~ msgid "can%'t open %s for reading: %m"
-#~ msgstr "%s を読み込み用に開けません: %m"
-
-#~ msgid "unrecognized command line option \"%s\""
-#~ msgstr "認識できないコマンドラインオプション \"%s\" です"
-
-#~ msgid "-fira-algorithm=CB does not work on this architecture"
-#~ msgstr "-fira-algorithm=CB はこのアーキテクチャ上では動作しません"
-
-#~ msgid "only one -flto-partition value can be specified"
-#~ msgstr "-flto-partition の値は一つのみ指定できます"
-
-#~ msgid "malformed option -fplugin-arg-%s (multiple '=' signs)"
-#~ msgstr "間違った形式のオプション -fplugin-arg-%s です (複数の '=' 符号があります)"
-
-#, fuzzy
-#~ msgid "corrupted profile info: edge count exceeds maximal count"
-#~ msgstr "破損したプロファイル情報: run_max * runs < sum_max です"
-
-#~ msgid "correcting inconsistent profile data"
-#~ msgstr "一貫性のないプロファイルデータを訂正しています"
-
-#~ msgid "try reducing the number of local variables"
-#~ msgstr "ローカル変数の数を削減してみてください"
-
-#~ msgid "type size can%'t be explicitly evaluated"
-#~ msgstr "型のサイズが明示的に評価できません"
-
-#~ msgid "variable-size type declared outside of any function"
-#~ msgstr "可変サイズ型が関数の外側で宣言されました"
-
-#~ msgid "-ffunction-sections disabled; it makes profiling impossible"
-#~ msgstr "-ffunction-sections が無効です。これによりプロファイルが不可能になります"
-
-#~ msgid "type mismatch in binary truth expression"
-#~ msgstr "二進真偽式内で型不一致です"
-
-#~ msgid "invalid COND_EXPR in gimple assignment"
-#~ msgstr "gimple 代入内で無効な COND_EXPR です"
-
-#~ msgid "invalid GIMPLE statement"
-#~ msgstr "無効な GIMPLE 文です"
-
-#~ msgid "verify_stmts failed"
-#~ msgstr "verify_stmts に失敗しました"
-
-#~ msgid "mudflap checking not yet implemented for ARRAY_RANGE_REF"
-#~ msgstr "mudflap 検査は ARRAY_RANGE_REF 用にはまだ実装されていません"
-
-#~ msgid "mudflap cannot track %qE in stub function"
-#~ msgstr "mudflap はスタブ関数内の %qE を追跡できません"
-
-#~ msgid "mudflap cannot track unknown size extern %qE"
-#~ msgstr "mudflap は不明なサイズの外部 (extern) %qE を追跡できません"
-
-#~ msgid "mudflap: this language is not supported"
-#~ msgstr "mudflap: この言語はサポートされていません"
-
-#~ msgid "unimplemented functionality"
-#~ msgstr "未実装の機能です"
-
-#~ msgid "statement makes a memory store, but has no VDEFS"
-#~ msgstr "文はメモリ記憶域を作成しますが、VDEFS がありません"
-
-#~ msgid "statement has VDEF operand not in defs list"
-#~ msgstr "文は VDEF 被演算子を持っていますが、定義リスト内にありません"
-
-#~ msgid "statement has VDEF but no VUSE operand"
-#~ msgstr "文は VDEF を持っていますが VUSE 被演算子がありません"
-
-#~ msgid "VDEF and VUSE do not use the same symbol"
-#~ msgstr "VDEF と VUSE が同じシンボルを使用していません"
-
-#~ msgid "statement has VUSE operand not in uses list"
-#~ msgstr "文は VUSE 被演算子を持っていますが、使用リスト内にありません"
-
-#~ msgid "number of operands and imm-links don%'t agree in statement"
-#~ msgstr "文内で被演算子の数と imm-links が一致しません"
-
-#~ msgid "%qD is deprecated (declared at %s:%d): %s"
-#~ msgstr "%qD は廃止されました (宣言位置 %s:%d): %s"
-
-#~ msgid "%qD is deprecated (declared at %s:%d)"
-#~ msgstr "%qD は廃止されました (宣言位置 %s:%d)"
-
-#~ msgid "%qE is deprecated (declared at %s:%d): %s"
-#~ msgstr "%qE は廃止されました (宣言位置 %s:%d): %s"
-
-#~ msgid "%qE is deprecated (declared at %s:%d)"
-#~ msgstr "%qE は廃止されました (宣言位置 %s:%d)"
-
-#~ msgid "type is deprecated (declared at %s:%d): %s"
-#~ msgstr "型は廃止されました (宣言位置 %s:%d): %s"
-
-#~ msgid "type is deprecated (declared at %s:%d)"
-#~ msgstr "型は廃止されました (宣言位置 %s:%d)"
-
-#~ msgid "correcting inconsistent value profile: %s profiler overall count (%d) does not match BB count (%d)"
-#~ msgstr "一貫性がない値を持つプロファイルを修正しています: %s プロファイルの総合計数 (%d) は BB 数 (%d) と一致しません"
-
-#~ msgid "negative integer implicitly converted to unsigned type"
-#~ msgstr "負の整数が暗黙的に符号無し型に変換されました"
-
-#~ msgid "conversion of unsigned constant value to negative integer"
-#~ msgstr "符号無し定数値から負の整数への変換です"
-
-#~ msgid "conversion to %qT alters %qT constant value"
-#~ msgstr "%qT への変換は %qT 定数値を変更します"
-
-#~ msgid "large integer implicitly truncated to unsigned type"
-#~ msgstr "大きな整数が暗黙に符号無し型に切り詰められました"
-
-#~ msgid "overflow in implicit constant conversion"
-#~ msgstr "暗黙の定数変換でオーバーフローしました"
-
-#~ msgid "bad option %s to optimize attribute"
-#~ msgstr "最適化属性への間違ったオプション %s です"
-
-#~ msgid "comparison between signed and unsigned integer expressions"
-#~ msgstr "符号付きと符号無しの整数式の間での比較です"
-
-#~ msgid "unknown conversion type character 0x%x in format"
-#~ msgstr "書式内に不明な型変換文字 0x%x があります"
-
-#~ msgid "-Werror=normalized=: set -Wnormalized=nfc"
-#~ msgstr "-Werror=normalized=: -Wnormalized=nfc を設定します"
-
-#~ msgid "can%'t seek in %s: %m"
-#~ msgstr "%s 内で探査 (seek) できません: %m"
-
-#~ msgid "#pragma extern_prefix not supported on this target"
-#~ msgstr "#pragma extern_prefix はこのターゲットではサポートされていません"
-
-#~ msgid "internal and protected visibility attributes not supported in this configuration; ignored"
-#~ msgstr "現在の設定では internal および protected visibility 属性はサポートされません。無視されました"
-
-#~ msgid "-mieee not supported on Unicos/Mk"
-#~ msgstr "-mieee は Unicos/Mk 上ではサポートされていません"
-
-#~ msgid "-mieee-with-inexact not supported on Unicos/Mk"
-#~ msgstr "-mieee-with-inexact は Unicos/Mk 上ではサポートされていません"
-
-#~ msgid "trap mode not supported on Unicos/Mk"
-#~ msgstr "Unicos/Mk 上ではトラップモードはサポートされていません"
-
-#~ msgid "bad value (%s) for %s switch"
-#~ msgstr "間違った値 (%s) が %s スイッチ用に指定されています"
-
-#~ msgid "invalid ABI option: -mabi=%s"
-#~ msgstr "無効な ABI オプションです: -mabi=%s"
-
-#~ msgid "invalid floating point emulation option: -mfpe=%s"
-#~ msgstr "無効な浮動小数点エミュレーションオプションです: -mfpe=%s"
-
-#~ msgid "invalid floating point abi: -mfloat-abi=%s"
-#~ msgstr "無効な浮動小数点 ABI です: -mfloat-abi=%s"
-
-#~ msgid "iWMMXt and hardware floating point"
-#~ msgstr "iWMMXt およびハードウェア浮動小数点"
-
-#~ msgid "Thumb-2 iWMMXt"
-#~ msgstr "Thumb-2 iWMMXt"
-
-#~ msgid "the mangling of %<va_list%> has changed in GCC 4.4"
-#~ msgstr "%<va_list%> の名前符号化 (mangle) 方法は GCC 4.4 で変更されました"
-
-#~ msgid "static variable %q+D is marked dllimport"
-#~ msgstr "静的変数 %q+D が dllimport とマークされています"
-
-#~ msgid "%qs appears to be a misspelled interrupt handler"
-#~ msgstr "%qs は綴りが間違った割り込みハンドラのように見えます"
-
-#~ msgid "%slarge-data-threshold=%d%s is negative"
-#~ msgstr "%slarge-data-threshold=%d%s が負です"
-
-#~ msgid "pc%d is not valid precision setting (32, 64 or 80)"
-#~ msgstr "pc%d は有効な精度設定 (32、64 または 80) ではありません"
-
-#~ msgid "%qE attribute only available for 64-bit"
-#~ msgstr "%qE 属性は 64 ビットでのみ使用できます"
-
-#~ msgid "vector permutation requires vector constant"
-#~ msgstr "ベクトル順列はベクトル定数である必要があります"
-
-#~ msgid "vector permutation (%d %d)"
-#~ msgstr "ベクトル順列 (%d %d)"
-
-#~ msgid "vector permutation (%d %d %d %d)"
-#~ msgstr "ベクトル順列 (%d %d %d %d)"
-
-#~ msgid "vector permutation (%d %d %d %d %d %d %d %d)"
-#~ msgstr "ベクトル順列 (%d %d %d %d %d %d %d %d)"
-
-#~ msgid "vector permutation (%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d %d)"
-#~ msgstr "ベクトル順列 (%d %d %d %d %d %d %d %d %d %d %d %d %d %d %d %d)"
-
-#~ msgid "%q+D:'selectany' attribute applies only to initialized objects"
-#~ msgstr "%q+D:'selectany' 属性は初期化されたオブジェクトにのみ適用できます"
-
-#~ msgid "%q+D causes a section type conflict"
-#~ msgstr "%q+D はセクション型の競合の原因となります"
-
-#~ msgid "-fPIC ignored for target (all code is position independent)"
-#~ msgstr "-fPIC はターゲットでは無視されます (全てのコード配置非依存です)"
-
-#~ msgid "-f%s ignored for target (all code is position independent)"
-#~ msgstr "-f%s はターゲットでは無視されます (全てのコードは位置非依存です)"
-
-#~ msgid "-mbnu210 is ignored (option is obsolete)"
-#~ msgstr "-mbnu210 は無視されます (オプションは廃止されています)"
-
-#~ msgid "ms-bitfields not supported for objc"
-#~ msgstr "ms-bitfields は objc 用にはサポートされていません"
-
-#~ msgid "bad value %<%s%> for -mtune= switch"
-#~ msgstr "-mtune= スイッチ用の間違った値 %<%s%> です"
-
-#~ msgid "-f%s ignored for 68HC11/68HC12 (not supported)"
-#~ msgstr "-f%s は 68HC11/68HC12 用としては無視されました (サポートされません)"
-
-#~ msgid "%<trap%> and %<far%> attributes are not compatible, ignoring %<far%>"
-#~ msgstr "%<trap%> と %<far%> 属性は併用できません。%<far%> を無視しています"
-
-#~ msgid "%<trap%> attribute is already used"
-#~ msgstr "%<trap%> は既に使用されています"
-
-#~ msgid "junk at end of #pragma io_volatile"
-#~ msgstr "#pragma io_volatile の末尾にゴミがあります"
-
-#~ msgid "#pragma io_volatile takes only on or off"
-#~ msgstr "#pragma io_volatile は on または off のいずれかのみをとります"
-
-#~ msgid "invalid coprocessor register range"
-#~ msgstr "無効なコプロセッサレジスタ範囲です"
-
-#~ msgid "invalid coprocessor register %qE"
-#~ msgstr "無効なコプロセッサレジスタ %qE です"
-
-#~ msgid "malformed coprocessor register"
-#~ msgstr "間違った形式のコプロセッサレジスタです"
-
-#~ msgid "junk at end of #pragma GCC coprocessor width"
-#~ msgstr "#pragma GCC coprocessor width の末尾にゴミがあります"
-
-#~ msgid "#pragma GCC coprocessor width takes only 32 or 64"
-#~ msgstr "#pragma GCC coprocessor width は 32 または 64 のみをとります"
-
-#~ msgid "#pragma GCC coprocessor subclass letter must be in [ABCD]"
-#~ msgstr "#pragma GCC coprocessor subclass の文字は [ABCD] のどれかでなければいけません"
-
-#~ msgid "#pragma GCC coprocessor subclass '%c' already defined"
-#~ msgstr "#pragma GCC coprocessor subclass '%c' は既に定義されています"
-
-#~ msgid "malformed #pragma GCC coprocessor subclass"
-#~ msgstr "間違った形式の #pragma GCC coprocessor subclass です"
-
-#~ msgid "malformed #pragma disinterrupt"
-#~ msgstr "間違った形式の #pragma disinterrupt です"
-
-#~ msgid "malformed #pragma GCC coprocessor"
-#~ msgstr "間違った形式の #pragma GCC coprocessor です"
-
-#~ msgid "malformed #pragma call"
-#~ msgstr "間違った形式の #pragma call です"
-
-#~ msgid "only one of -ms and -mm may be given"
-#~ msgstr "-ms と -mm のうち一つだけ指定できます"
-
-#~ msgid "only one of -ms and -ml may be given"
-#~ msgstr "-ms と -ml のうち一つだけ指定できます"
-
-#~ msgid "only one of -mm and -ml may be given"
-#~ msgstr "-mm と -ml のうち一つだけ指定できます"
-
-#~ msgid "only one of -ms and -mtiny= may be given"
-#~ msgstr "-ms と -mtiny= のうち一つだけ指定できます"
-
-#~ msgid "only one of -mm and -mtiny= may be given"
-#~ msgstr "-mm と -mtiny= のうち一つだけ指定できます"
-
-#~ msgid "-mclip currently has no effect without -mminmax"
-#~ msgstr "-mclip は現在のところ -mminmax が無い場合には効果がありません"
-
-#~ msgid "-mc= must be -mc=tiny, -mc=near, or -mc=far"
-#~ msgstr "-mc= は -mc=tiny、-mc=near または -mc=far でなければいけません"
-
-#~ msgid "unconvertible operand %c %qs"
-#~ msgstr "変換できない被演算子 %c %qs です"
-
-#~ msgid "address region attributes not allowed with auto storage class"
-#~ msgstr "アドレス範囲 (address region) 属性は自動記憶域クラスでは許可されていません"
-
-#~ msgid "address region attributes on pointed-to types ignored"
-#~ msgstr "型を指しているアドレス範囲 (address region) 属性は無視されました"
-
-#~ msgid "duplicate address region attribute %qE in declaration of %qE on line %d"
-#~ msgstr "重複したアドレス範囲 (address region) 属性 %qE が宣言 %qE (%d 行) 内にあります"
-
-#~ msgid "cannot inline interrupt function %qE"
-#~ msgstr "割り込み関数 %qE をインライン化できません"
-
-#~ msgid "interrupt function must have return type of void"
-#~ msgstr "割り込み関数の戻り型は void でなければいけません"
-
-#~ msgid "to describe a pointer to a VLIW function, use syntax like this:"
-#~ msgstr "VLIW 関数へのポインタを記述するためには次のような構文を使用してください:"
-
-#~ msgid "  typedef int (__vliw *vfuncptr) ();"
-#~ msgstr "  typedef int (__vliw *vfuncptr) ();"
-
-#~ msgid "to describe an array of VLIW function pointers, use syntax like this:"
-#~ msgstr "VLIW 関数ポインタの配列を記述するためには次のような構文を使用してください:"
-
-#~ msgid "  typedef int (__vliw *vfuncptr[]) ();"
-#~ msgstr "  typedef int (__vliw *vfuncptr[]) ();"
-
-#~ msgid "VLIW functions are not allowed without a VLIW configuration"
-#~ msgstr "VLIW 関数は VLIW 設定外では許可されていません"
-
-#~ msgid "\"#pragma disinterrupt %s\" not used"
-#~ msgstr "\"#pragma disinterrupt %s\" が使用されていません"
-
-#~ msgid "__io address 0x%x is the same for %qE and %qE"
-#~ msgstr "__io address 0x%x が %qE と %qE 用で同一です"
-
-#~ msgid "variable %s (%ld bytes) is too large for the %s section (%d bytes)"
-#~ msgstr "変数 %s (%ld バイト) は %s セクション (%d バイト) 用には大きすぎます"
-
-#~ msgid "variable %D of type %<io%> must be uninitialized"
-#~ msgstr "%<io%> 型の変数 %D を初期化してはいけません"
-
-#~ msgid "variable %D of type %<cb%> must be uninitialized"
-#~ msgstr "%<cb%> 型の変数 %D を初期化してはいけません"
-
-#~ msgid "%qs is not available in VLIW functions"
-#~ msgstr "%qs は VLIW 関数内では使用出来ません"
-
-#~ msgid "%qs is not available in non-VLIW functions"
-#~ msgstr "%qs は非 VLIW 関数内では使用出来ません"
-
-#~ msgid "unexpected %d byte cop instruction"
-#~ msgstr "予期しない %d バイト cop 命令です"
-
-#~ msgid "MIPS16 TLS"
-#~ msgstr "MIPS16 TLS"
-
-#~ msgid "the %<interrupt%> attribute requires %<-msoft-float%>"
-#~ msgstr "%<interrupt%> 属性は %<-msoft-float%> が必要です"
-
-#~ msgid "CPU names must be lower case"
-#~ msgstr "CPU 名は小文字でなければいけません"
-
-#~ msgid "invalid AE type specified (%s)"
-#~ msgstr "無効な AE 型が指定されています (%s)"
-
-#~ msgid "%s: at least one operand can%'t be handled"
-#~ msgstr "%s: 一つ以上の被演算子を取り扱えません"
-
-#~ msgid "unknown short branch in %s (type %d)"
-#~ msgstr "%s 内に不明な短い分岐があります (型 %d)"
-
-#~ msgid "unknown long branch in %s (type %d)"
-#~ msgstr "%s 内に不明な長い分岐があります (型 %d)"
-
-#~ msgid "too many ALU instructions emitted (%d)"
-#~ msgstr "多すぎる ALU 命令が発行されました (%d)"
-
-#~ msgid "unknown -m%s= option specified: '%s'"
-#~ msgstr "不明な -m%s= オプションが指定されました: '%s'"
-
-#~ msgid "invalid option for -mcmodel: '%s'"
-#~ msgstr "-mcmodel 用の無効なオプションです: '%s'"
-
-#~ msgid "bad value (%s) for -mcpu"
-#~ msgstr "-mcpu 用の間違った値 %s です"
-
-#~ msgid "bad value (%s) for -mtune"
-#~ msgstr "-mtune 用の間違った値 %s です"
-
-#~ msgid "unknown -mtraceback arg %qs; expecting %<full%>, %<partial%> or %<none%>"
-#~ msgstr "不明な -mtraceback 引数 %qs です。%<full%>、%<partial%> または %<none%> が予期されます"
-
-#~ msgid "invalid option for -mfloat-gprs: '%s'"
-#~ msgstr "-mfloat-gprs 用の無効なオプションです: '%s'"
-
-#~ msgid "unknown -malign-XXXXX option specified: '%s'"
-#~ msgstr "不明な -malign-XXXXX オプションが指定されました: '%s'"
-
-#~ msgid "internal error: builtin function %s had no type"
-#~ msgstr "内部エラー: 組み込み関数 %s に型がありません"
-
-#~ msgid "-maix64 and POWER architecture are incompatible"
-#~ msgstr "-maix64 と POWER アーキテクチャは互換性がありません"
-
-#~ msgid "-m64 not supported in this configuration"
-#~ msgstr "-m64 はこの設定ではサポートされていません"
-
-#~ msgid "RETURN_ADDRESS_OFFSET not supported"
-#~ msgstr "RETURN_ADDRESS_OFFSET はサポートされていません"
-
-#~ msgid "-mcall-aixdesc must be big endian"
-#~ msgstr "-mcall-aixdesc はビッグエンディアンでなければいけません"
-
-#~ msgid "frame size of function %qs is "
-#~ msgstr "関数 %qs のフレームサイズ: "
-
-#~ msgid "ambiguous overload for ternary %<operator?:%> in %<%E ? %E : %E%>"
-#~ msgstr "三項演算子 %<operator?:%> 用の %<%E ? %E : %E%> 内にあるオーバーロードが曖昧です"
-
-#~ msgid "ambiguous overload for %<operator%s%> in %<%E%s%>"
-#~ msgstr "%<operator%s%> 用の %<%E%s%> 内にあるオーバーロードが曖昧です"
-
-#~ msgid "ambiguous overload for %<operator[]%> in %<%E[%E]%>"
-#~ msgstr "%<%E[%E]%> 内にある %<operator[]%> 用のオーバーロードが曖昧です"
-
-#~ msgid "ambiguous overload for %<operator%s%> in %<%E %s %E%>"
-#~ msgstr "%<operator%s%> 用の %<%E %s %E%> 内にあるオーバーロードが曖昧です"
-
-#~ msgid "ambiguous overload for %<operator%s%> in %<%s%E%>"
-#~ msgstr "%<operator%s%> 用の %<%s%E%> 内にあるオーバーロードが曖昧です"
-
-#~ msgid "%q+#D is private"
-#~ msgstr "%q+#D は非公開です"
-
-#~ msgid "%q+#D is protected"
-#~ msgstr "%q+#D は保護されています"
-
-#, fuzzy
-#~ msgid "scoped enum %qT will not promote to an integral type in a future version of GCC"
-#~ msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
-
-#~ msgid "Java class %qT cannot have a destructor"
-#~ msgstr "Java クラス %qT はデストラクタを持つことは出来ません"
-
-#~ msgid "repeated using declaration %q+D"
-#~ msgstr "宣言 %q+D の使用が繰り返されています"
-
-#~ msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
-#~ msgstr "%q+#D は無効です。無名構造体は非静的データメンバのみ持つことが出来ます"
-
-#~ msgid "private member %q+#D in anonymous struct"
-#~ msgstr "無名構造体内に非公開メンバ %q+#D があります"
-
-#~ msgid "protected member %q+#D in anonymous struct"
-#~ msgstr "無名構造体内内に保護されたメンバ %q+#D があります"
-
-#~ msgid "offset of virtual base %qT is not ABI-compliant and may change in a future version of GCC"
-#~ msgstr "仮想基底 %qT のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
-
-#~ msgid "size assigned to %qT may not be ABI-compliant and may change in a future version of GCC"
-#~ msgstr "%qT へ代入されたサイズは ABI に適合していないかもしれないため将来のバージョンの GCC では変更になるかもしれません"
-
-#~ msgid "the offset of %qD may not be ABI-compliant and may change in a future version of GCC"
-#~ msgstr "%qD のオフセットは ABI に適合していないかもしれないため将来のバージョンの GCC では変更になるかもしれません"
-
-#~ msgid "%q+D contains empty classes which may cause base classes to be placed at different locations in a future version of GCC"
-#~ msgstr "%q+D は空のクラスを含んでいるため将来のバージョンの GCC では基底クラスが別の場所に配置されるかもしれません"
-
-#~ msgid "layout of classes derived from empty class %qT may change in a future version of GCC"
-#~ msgstr "空のクラス %qT から得られたクラスの配置は将来のバージョンの GCC では変更になるかもしれません"
-
-#~ msgid "continue statement not within loop or switch"
-#~ msgstr "ループまたは switch 内に無い continue です"
-
-#, fuzzy
-#~ msgid "jump to label %q+D"
-#~ msgstr "case ラベルにジャンプしています"
-
-#, fuzzy
-#~ msgid "%q+D declared here"
-#~ msgstr "`%s' は前にここで宣言されました"
-
-#, fuzzy
-#~ msgid "an anonymous struct cannot have function members"
-#~ msgstr "無名構造体が名前つき型の中にありません"
-
-#, fuzzy
-#~ msgid "%qD cannot be initialized by a non-constant expression when being declared"
-#~ msgstr "非定数配列式から配列が初期化されました"
-
-#~ msgid "%<__int128%> invalid for %qs"
-#~ msgstr "%<__int128%> は %qs に対しては無効です"
-
-#, fuzzy
-#~ msgid "size of array %qs is too large"
-#~ msgstr "配列 `%s' の大きさが大きすぎます"
-
-#, fuzzy
-#~ msgid "qualified function types cannot be used to declare static member functions"
-#~ msgstr "デストラクタを静的メンバ関数とすることはできません"
-
-#, fuzzy
-#~ msgid "qualified function types cannot be used to declare free functions"
-#~ msgstr "関数の返す型が関数であってはなりません"
-
-#, fuzzy
-#~ msgid "type qualifiers specified for friend class declaration"
-#~ msgstr "一つの空の宣言中に、二つの型が指定されています"
-
-#, fuzzy
-#~ msgid "  in instantiation of template %qT"
-#~ msgstr "%s: `%s' の初期化:\n"
-
-#, fuzzy
-#~ msgid "ISO C++ forbids initialization of member %qD"
-#~ msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
-
-#, fuzzy
-#~ msgid "parameter %qD has Java class type"
-#~ msgstr "仮引数 `%s' は不完全型です"
-
-#, fuzzy
-#~ msgid "return type has Java class type %q#T"
-#~ msgstr "戻り値の型が不完全型です"
-
-#, fuzzy
-#~ msgid "no previous declaration for %q+D"
-#~ msgstr "`%s' の前方宣言がありません"
-
-#~ msgid "Java method %qD has non-Java parameter type %qT"
-#~ msgstr "Java メソッド %qD が非 Java 仮引数型 %qT を持ちます"
-
-#~ msgid "field initializer is not constant"
-#~ msgstr "フィールド初期化子が定数ではありません"
-
-#, fuzzy
-#~ msgid "call to Java %<catch%> or %<throw%> with %<jthrowable%> undefined"
-#~ msgstr "Java `catch' や `throw' が呼ばれましたが、`jthrowable' は未定義です"
-
-#~ msgid "mixing C++ and Java catches in a single translation unit"
-#~ msgstr "C++ と Java の `catch' を一つの翻訳ユニットにまとめます"
-
-#~ msgid "bad array initializer"
-#~ msgstr "配列の不正な初期化"
-
-#, fuzzy
-#~ msgid "call to Java constructor with %qs undefined"
-#~ msgstr "Java コンストラクタが呼ばれましたが、`%s' は未定義です"
-
-#, fuzzy
-#~ msgid "non-constant array size in new, unable to verify length of initializer-list"
-#~ msgstr "初期化子内に非定数の配列インデックスがあります"
-
-#, fuzzy
-#~ msgid "call to Java constructor, while %<jclass%> undefined"
-#~ msgstr "Java コンストラクタが呼ばれましたが、`jclass' は未定義です"
-
-#~ msgid "junk at end of #pragma GCC java_exceptions"
-#~ msgstr "#pragma GCC java_exceptions の末尾にゴミ"
-
-#, fuzzy
-#~ msgid "mangling new-expression"
-#~ msgstr "無効な型表現です"
-
-#, fuzzy
-#~ msgid "defaulted declaration %q+D"
-#~ msgstr "無効な宣言です"
-
-#, fuzzy
-#~ msgid "redeclaration of %<wchar_t%> as %qT"
-#~ msgstr "`%s' が再宣言されました"
-
-#, fuzzy
-#~ msgid "type mismatch with previous external decl of %q#D"
-#~ msgstr "型が前方の外部宣言と一致しません"
-
-#, fuzzy
-#~ msgid "previous external decl of %q+#D"
-#~ msgstr "前方の `%s' の外部宣言"
-
-#, fuzzy
-#~ msgid "declaration of %qD shadows a member of 'this'"
-#~ msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
-
-#, fuzzy
-#~ msgid "range-based-for loops are not allowed in C++98 mode"
-#~ msgstr "#if 式の中では文字列定数が使えません"
-
-#~ msgid "declaration of %q+#D"
-#~ msgstr "%q+#D の宣言です"
-
-#, fuzzy
-#~ msgid "instantiation of %q+D as type %qT"
-#~ msgstr "%s: `%s' の初期化:\n"
-
-#, fuzzy
-#~ msgid "%s %+#T"
-#~ msgstr "%s: %s"
-
-#, fuzzy
-#~ msgid "deprecated covariant return type for %q+#D"
-#~ msgstr "ファイル \"%s\" に戻るはずでした"
-
-#, fuzzy
-#~ msgid "invalid use of non-static data member %q+D"
-#~ msgstr "メンバへのポインタでの無効な `%s' の使用"
-
-#, fuzzy
-#~ msgid "%qE has reference type for %qs"
-#~ msgstr "無効な参照型です"
-
-#, fuzzy
-#~ msgid "%qD has no member named %qE"
-#~ msgstr "%s に `%s' という名前のメンバはありません"
-
-#~ msgid "ISO C++ forbids subscripting non-lvalue array"
-#~ msgstr "ISO C++ は左辺値ではない配列の添字を禁じます"
-
-#~ msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
-#~ msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
-
-#, fuzzy
-#~ msgid "invalid use of Boolean expression as operand to %<operator--%>"
-#~ msgstr "オペランドとして無効な式"
-
-#, fuzzy
-#~ msgid "  since type %qT has pure virtual functions"
-#~ msgstr "使われない仮想関数を切り捨てる"
-
-#, fuzzy
-#~ msgid "%q+D has incomplete type"
-#~ msgstr "`%s' は不完全型です"
-
-#~ msgid "cannot initialize arrays using this syntax"
-#~ msgstr "この文法を使って配列を初期化することはできません"
-
-#, fuzzy
-#~ msgid "member %qD with uninitialized const fields"
-#~ msgstr "未初期化定数を ROM に置かない"
-
-#, fuzzy
-#~ msgid "Function name '%s' not allowed at %C"
-#~ msgstr "セクション属性は `%s' には使えません"
-
-#, fuzzy
-#~ msgid "Internal Error at (1):"
-#~ msgstr "内部エラー: %s"
-
-#, fuzzy
-#~ msgid "Extension: argument list function at %C"
-#~ msgstr "関数 `%s' に対する引数が多すぎます"
-
-#, fuzzy
-#~ msgid "Invalid second argument of IBCLR at %L"
-#~ msgstr "`%s' の引数として無効な型"
-
-#, fuzzy
-#~ msgid "Invalid second argument of IBITS at %L"
-#~ msgstr "`%s' の引数として無効な型"
-
-#, fuzzy
-#~ msgid "Invalid second argument of ISHFTC at %L"
-#~ msgstr "`%s' の引数として無効な型"
-
-#, fuzzy
-#~ msgid "Invalid third argument of ISHFTC at %L"
-#~ msgstr "`%s' の引数として無効な型"
-
-#~ msgid "Use of -fdefault-double-8 requires -fdefault-real-8"
-#~ msgstr "-fdefault-double-8 を使用するには -fdefault-real-8 が必要です"
-
-#~ msgid "bad method signature"
-#~ msgstr "不正なメソッドシグネイチャです"
-
-#~ msgid "misplaced ConstantValue attribute (not in any field)"
-#~ msgstr "ConstantValue 属性の場所を間違えています（どのフィールドでもありません）"
-
-#, fuzzy
-#~ msgid "duplicate ConstantValue attribute for field '%s'"
-#~ msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
-
-#, fuzzy
-#~ msgid "ConstantValue attribute of field '%s' has wrong type"
-#~ msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
-
-#~ msgid "abstract method in non-abstract class"
-#~ msgstr "abstract メソッドが非抽象クラスにあります"
-
-#, fuzzy
-#~ msgid "non-static method %q+D overrides static method"
-#~ msgstr "非静的メソッド '%s' が静的メソッドをオーバーライドしています"
-
-#, fuzzy
-#~ msgid "%q+D used prior to declaration"
-#~ msgstr "`%s' は宣言よりも先に使用されました"
-
-#, fuzzy
-#~ msgid "In %+D: overlapped variable and exception ranges at %d"
-#~ msgstr "%s 内: 変数と例外範囲が %d で重なっています"
-
-#~ msgid "bad type in parameter debug info"
-#~ msgstr "仮引数デバッグ情報に不正な型があります"
-
-#, fuzzy
-#~ msgid "bad PC range for debug info for local %q+D"
-#~ msgstr "ローカルの `%s' 用デバッグ情報のための PC 範囲が不正です"
-
-#~ msgid "stack underflow - dup* operation"
-#~ msgstr "スタックアンダーフロー - dup* 操作"
-
-#, fuzzy
-#~ msgid "reference %qs is ambiguous: appears in interface %qs and interface %qs"
-#~ msgstr "参照 `%s' は曖昧です: interface `%s' と interface `%s' に現れました"
-
-#~ msgid "method '%s' not found in class"
-#~ msgstr "メソッド '%s' はクラス内に見つかりません"
-
-#~ msgid "failed to find class '%s'"
-#~ msgstr "'%s' クラスを見つけるのに失敗しました"
-
-#, fuzzy
-#~ msgid "class '%s' has no method named '%s' matching signature '%s'"
-#~ msgstr "クラス '%s' は名前が '%s' でシグネイチャ '%s' と一致するメソッドを持っていません"
-
-#~ msgid "invokestatic on non static method"
-#~ msgstr "非静的メソッドに invokestatic しました"
-
-#~ msgid "invokestatic on abstract method"
-#~ msgstr "抽象メソッドに invokestatic しました"
-
-#~ msgid "invoke[non-static] on static method"
-#~ msgstr "静的メソッドに invoke[非 static] しました"
-
-#, fuzzy
-#~ msgid "missing field '%s' in '%s'"
-#~ msgstr "フィールド '%s'('%s' 内) を欠いています"
-
-#, fuzzy
-#~ msgid "mismatching signature for field '%s' in '%s'"
-#~ msgstr "フィールド '%s'('%s' 内) のシグネイチャが一致しません"
-
-#~ msgid "invalid PC in line number table"
-#~ msgstr "無効な PC が行番号テーブルにあります"
-
-#, fuzzy
-#~ msgid "unreachable bytecode from %d to before %d"
-#~ msgstr "%d から %d の前までのバイトコードには到達できません"
-
-#, fuzzy
-#~ msgid "unreachable bytecode from %d to the end of the method"
-#~ msgstr "%d からメソッドの終りまでのバイトコードには到達できません"
-
-#~ msgid "unrecogized wide sub-instruction"
-#~ msgstr "認識できない wide sub 命令です"
-
-#~ msgid "bad string constant"
-#~ msgstr "不正な文字列定数です"
-
-#~ msgid "bad value constant type %d, index %d"
-#~ msgstr "不正な定数値型 %d, インデックス %d"
-
-#~ msgid "not a valid Java .class file"
-#~ msgstr "正常な Java .class ファイルではありません"
-
-#~ msgid "error while parsing constant pool"
-#~ msgstr "constant プールの構文解析中にエラーが発生しました"
-
-#~ msgid "reading class %s for the second time from %s"
-#~ msgstr "class %s を読込むのは %s から二回目になります"
-
-#~ msgid "error while parsing fields"
-#~ msgstr "フィールドの構文解析中にエラーが発生しました"
-
-#~ msgid "error while parsing methods"
-#~ msgstr "メソッドの構文解析中にエラーが発生しました"
-
-#~ msgid "error while parsing final attributes"
-#~ msgstr "final 属性の構文解析中にエラーが発生しました"
-
-#, fuzzy
-#~ msgid "error while reading %s from zip file"
-#~ msgstr "フィールドの構文解析中にエラーが発生しました"
-
-#~ msgid "cannot specify both -C and -o"
-#~ msgstr "-C と -o は両方を一緒に指定できません"
-
-#~ msgid "cannot create temporary file"
-#~ msgstr "一時ファイルを作成できません"
-
-#~ msgid "using both @FILE with multiple files not implemented"
-#~ msgstr "@FILE での複数ファイルの使用は実装されていません"
-
-#~ msgid "internal error - invalid Utf8 name"
-#~ msgstr "内部エラー - 無効な Utf8 名です"
-
-#~ msgid "junk at end of signature string"
-#~ msgstr "シグネイチャ文字列の終りにゴミがあります"
-
-#, fuzzy
-#~ msgid "verification failed at PC=%d: %s"
-#~ msgstr "検証エラー (PC=%d)"
-
-#~ msgid "bad pc in exception_table"
-#~ msgstr "exception_table に不正な pc があります"
-
-#~ msgid "invalid LTO mode"
-#~ msgstr "無効な LTO モードです"
-
-#~ msgid "Enforce table jump"
-#~ msgstr "表によるジャンプを強制する"
-
-#~ msgid "Support SCORE 5 ISA"
-#~ msgstr "SCORE 5 ISA をサポートする"
-
-#~ msgid "Support SCORE 5U ISA"
-#~ msgstr "SCORE 5U ISA をサポートする"
-
-#~ msgid "Support SCORE 3 ISA"
-#~ msgstr "SCORE 3 ISA をサポートする"
-
-#~ msgid "Support SCORE 3d ISA"
-#~ msgstr "SCORE 3d ISA をサポートする"
-
-#~ msgid "redefinition of typedef %q+D may be a constraint violation at runtime"
-#~ msgstr "typedef %q+D の再定義は実行時に制約違反になるかもしれません"
-
-#~ msgid "attributes may not be specified before"
-#~ msgstr "属性は前に指定されていないようです"
diff --git a/gcc/po/sv.po b/gcc/po/sv.po
index 36807ff7d43..79196976ab4 100644
--- a/gcc/po/sv.po
+++ b/gcc/po/sv.po
@@ -8,6 +8,7 @@
 #
 # Dictionary:
 # assumed type		antagen typ
+# bb (basic block)	gb (grundblock)
 # bundle		bunt
 # cast			typkonvertering
 # chunk			stycke
@@ -24,12 +25,12 @@
 # thunk			snutt
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 10.1.0\n"
+"Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2020-07-20 18:08+0000\n"
-"PO-Revision-Date: 2020-07-08 15:44+0200\n"
+"PO-Revision-Date: 2020-07-29 21:10+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
-"Language-Team: Swedish <tp-sv-list@lists.sourceforge.net>\n"
+"Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -310,7 +311,7 @@ msgstr "  --target-help            Visa specifika kommandoradsflaggor för mål.
 
 #: gcc.c:3549
 msgid "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...].\n"
-msgstr "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,…]-\n"
+msgstr "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,…].\n"
 
 #: gcc.c:3550
 msgid "                           Display specific types of command line options.\n"
@@ -593,7 +594,7 @@ msgid ""
 msgstr ""
 "\n"
 "Synpunkter på översättningen till svenska rapporteras till\n"
-"<tp-sv-list@lists.sourceforge.net>.\n"
+"<tp-sv@listor.tp-sv.se>.\n"
 "För felrapporteringsinstruktioner i övrigt, se:\n"
 
 #: gcc.c:8038 gcov-tool.c:527
@@ -654,7 +655,9 @@ msgstr ""
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
 "\n"
-msgstr "Använd ”-Wa,FLAGGA” för att skicka ”FLAGGA” till assemblern.\n"
+msgstr ""
+"Använd ”-Wa,FLAGGA” för att skicka ”FLAGGA” till assemblern.\n"
+"\n"
 
 #: gcov-tool.c:175
 #, c-format
@@ -734,7 +737,7 @@ msgstr "    -F, --fullname                      Skriv fullständiga filnamn\n"
 #: gcov-tool.c:422
 #, c-format
 msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Skriv endast info om heta objekt/funktioner\n"
+msgstr "    -h, --hotonly                       Skriv endast info om varma objekt/funktioner\n"
 
 #: gcov-tool.c:423
 #, c-format
@@ -756,7 +759,9 @@ msgstr "Användning av underkommandot overlap:"
 msgid ""
 "Usage: %s [OPTION]... SUB_COMMAND [OPTION]...\n"
 "\n"
-msgstr "Användning: %s [FLAGGA]… UNDERKOMMANDO [FLAGGA]…\n"
+msgstr ""
+"Användning: %s [FLAGGA]… UNDERKOMMANDO [FLAGGA]…\n"
+"\n"
 
 #: gcov-tool.c:511
 #, c-format
@@ -787,7 +792,7 @@ msgstr ""
 "\n"
 "För att rapportera fel, se:\n"
 "%s.\n"
-"Fel på översättningen rapporteras till <tp-sv-list@lists.sourceforge.net>\n"
+"Fel på översättningen rapporteras till <tp-sv@listor.tp-sv.se>\n"
 
 #: gcov-tool.c:528
 #, c-format
@@ -908,7 +913,7 @@ msgstr "  -p, --preserve-paths            Bevara alla sökvägskomponenter\n"
 #: gcov.c:907
 #, c-format
 msgid "  -q, --use-hotness-colors        Emit perf-like colored output for hot lines\n"
-msgstr "  -q, --use-hotness-colors        Mata ut perf-liknande färgad utmata för heta rader\n"
+msgstr "  -q, --use-hotness-colors        Mata ut perf-liknande färgad utmata för varma rader\n"
 
 #: gcov.c:908
 #, c-format
@@ -1390,7 +1395,7 @@ msgstr "*** VARNING *** det finns aktiva insticksmoduler, rapportera inte detta
 
 #: postreload-gcse.c:1354
 msgid "using simple load CSE after register allocation"
-msgstr "användning av enkel laddning av CSE efter registertilldelning."
+msgstr "användning av enkel laddning av CSE efter registertilldelning"
 
 #. It's the compiler's fault.
 #: reload1.c:5998
@@ -2307,7 +2312,7 @@ msgstr "ogiltig const_double-operand"
 
 #: config/bpf/bpf.c:743
 msgid "invalid address in operand"
-msgstr "ogiltigt adress i operanden"
+msgstr "ogiltig adress i operanden"
 
 #. Fallthrough.
 #: config/bpf/bpf.c:750
@@ -2381,7 +2386,7 @@ msgstr "ogiltig operand för ”T”-modifierare"
 
 #: config/cris/cris.c:1129 config/ft32/ft32.c:236 config/moxie/moxie.c:178
 msgid "invalid operand modifier letter"
-msgstr "ogiltig operand för modifierarebokstav"
+msgstr "ogiltig operand för modifierarbokstav"
 
 #: config/cris/cris.c:1183
 msgid "unexpected multiplicative operand"
@@ -2951,7 +2956,7 @@ msgstr "%<-mno-altivec%> avaktiverar vsx"
 
 #: config/rs6000/rs6000.c:3845
 msgid "%<-mquad-memory%> requires 64-bit mode"
-msgstr "%<--mquad-memory%> kräver 64-bitarsläge"
+msgstr "%<-mquad-memory%> kräver 64-bitarsläge"
 
 #: config/rs6000/rs6000.c:3848
 msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
@@ -2970,10 +2975,9 @@ msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
 #: config/rs6000/rs6000.c:12859
-#, fuzzy, c-format
-#| msgid "invalid %%J value"
+#, c-format
 msgid "invalid %%A value"
-msgstr "ogiltigt %%J-värde"
+msgstr "ogiltigt %%A-värde"
 
 #: config/rs6000/rs6000.c:12868 config/xtensa/xtensa.c:2371
 #, c-format
@@ -3099,52 +3103,36 @@ msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
 #: config/rs6000/rs6000.c:26740
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__vector_quad%>"
-msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
+msgstr "ogiltig konvertering från typen %<__vector_quad%>"
 
 #: config/rs6000/rs6000.c:26742
-#, fuzzy
-#| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__vector_quad%>"
-msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
+msgstr "ogiltig konvertering till typen %<__vector_quad%>"
 
 #: config/rs6000/rs6000.c:26744
-#, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
-msgstr "ogiltig konvertering från %<__fpreg%>"
+msgstr "ogiltig konvertering från typen %<__vector_pair%>"
 
 #: config/rs6000/rs6000.c:26746
-#, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
-msgstr "ogiltig konvertering till %<__fpreg%>"
+msgstr "ogiltig konvertering till typen %<__vector_pair%>"
 
 #: config/rs6000/rs6000.c:26754
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<* __vector_quad%>"
-msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
+msgstr "ogiltig konvertering från typen %<* __vector_quad%>"
 
 #: config/rs6000/rs6000.c:26757
-#, fuzzy
-#| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<* __vector_quad%>"
-msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
+msgstr "ogiltig konvertering till typen %<* __vector_quad%>"
 
 #: config/rs6000/rs6000.c:26760
-#, fuzzy
-#| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<* __vector_pair%>"
-msgstr "ogiltig konvertering från %<__fpreg%>"
+msgstr "ogiltig konvertering från typen %<* __vector_pair%>"
 
 #: config/rs6000/rs6000.c:26763
-#, fuzzy
-#| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<* __vector_pair%>"
-msgstr "ogiltig konvertering till %<__fpreg%>"
+msgstr "ogiltig konvertering till typen %<* __vector_pair%>"
 
 #: config/s390/s390.c:7787
 #, c-format
@@ -3154,7 +3142,7 @@ msgstr "symboliska minnesreferenser stödjs endast på z10 eller senare"
 #: config/s390/s390.c:7798
 #, c-format
 msgid "cannot decompose address"
-msgstr "kan inte dekomponera adress."
+msgstr "kan inte dekomponera adress"
 
 #: config/s390/s390.c:7878
 #, c-format
@@ -3433,7 +3421,7 @@ msgstr "ogiltig operand detekterad"
 
 #: config/visium/visium.c:3362
 msgid "illegal operand "
-msgstr "ogiltig operand"
+msgstr "ogiltig operand "
 
 #: config/visium/visium.c:3413
 msgid "illegal operand address (1)"
@@ -3731,7 +3719,7 @@ msgstr "vtabell för "
 
 #: cp/error.c:1200
 msgid "<return value> "
-msgstr "<returvärde>"
+msgstr "<returvärde> "
 
 #: cp/error.c:1215
 msgid "{anonymous}"
@@ -4002,7 +3990,7 @@ msgstr "Heltal utanför symmetriskt intervall implicerat av Standard Fortran vid
 
 #: fortran/arith.c:120
 msgid "Illegal type in character concatenation at %L"
-msgstr "Otillåtet typ i teckenkonkatenering vid %L"
+msgstr "Otillåten typ i teckenkonkatenering vid %L"
 
 #: fortran/arith.c:1391
 msgid "elemental binary operation"
@@ -5521,7 +5509,7 @@ msgstr "Använd negativt tecken på nollvärden."
 #: fortran/lang.opt:799
 #, no-c-format
 msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
-msgstr "Tillåt inte svansanrposoptimering när en anropande rutin kan ha utelämnat teckenlängder."
+msgstr "Tillåt inte svansanropsoptimering när en anropande rutin kan ha utelämnat teckenlängder."
 
 #: fortran/lang.opt:803
 #, no-c-format
@@ -5729,7 +5717,7 @@ msgstr "-Walloc-size-larger-than=<byte>\tVarna för anrop till allokeringsfunkti
 #: c-family/c.opt:317
 #, no-c-format
 msgid "Disable Walloc-size-larger-than= warning.  Equivalent to Walloc-size-larger-than=<SIZE_MAX> or larger."
-msgstr "Avaktivera varningen Walloc-size-larger-than=.  Eqvivalent med Walloc-size-larger-than=<SIZE_MAX> eller större."
+msgstr "Avaktivera varningen Walloc-size-larger-than=.  Ekvivalent med Walloc-size-larger-than=<SIZE_MAX> eller större."
 
 #: c-family/c.opt:321
 #, no-c-format
@@ -6216,7 +6204,7 @@ msgstr "Varna när indenteringen av koden inte avspeglar blockstrukturen."
 #: c-family/c.opt:760
 #, no-c-format
 msgid "Warn when a class is redeclared or referenced using a mismatched class-key."
-msgstr "Varna när en klass är om deklarerad eller refereras med en klassnyckel som inte stämmer."
+msgstr "Varna när en klass är omdeklarerad eller refereras med en klassnyckel som inte stämmer."
 
 #: c-family/c.opt:764
 #, no-c-format
@@ -6306,7 +6294,7 @@ msgstr "Varna för funktioner som kan vara kandidater för formatattribut."
 #: c-family/c.opt:836
 #, no-c-format
 msgid "Suggest that the override keyword be used when the declaration of a virtual function overrides another."
-msgstr "Föreslå att använda nyckelordet override när deklarationen av en virtuell funktion åsidosätter en annan"
+msgstr "Föreslå att använda nyckelordet override när deklarationen av en virtuell funktion åsidosätter en annan."
 
 #: c-family/c.opt:841
 #, no-c-format
@@ -6708,6 +6696,7 @@ msgstr "Varna för tveksam användning av de makron som används för att hämta
 msgid "Warn if a variable length array is used."
 msgstr "Varna om en vektor med variabel längd används."
 
+# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=96249
 #: c-family/c.opt:1248
 #, no-c-format
 msgid "-Wvla-larger-than=<number>\tWarn on unbounded uses of variable-length arrays, and on bounded uses of variable-length arrays whose bound can be larger than <number> bytes. <number> bytes."
@@ -6827,7 +6816,7 @@ msgstr "När de är kortare, använd kanoniska sökvägar till systemhuvuden."
 #: c-family/c.opt:1358
 #, no-c-format
 msgid "Enable the char8_t fundamental type and use it as the type for UTF-8 string and character literals."
-msgstr "Aktivera den fundamentala typen char8_t och använd den som typen för UTF-8-sträng- och -teckenliteraler."
+msgstr "Aktivera den fundamentala typen char8_t och använd den som typen för UTF-8-sträng- och -teckenlitteraler."
 
 #: c-family/c.opt:1446
 #, no-c-format
@@ -6917,7 +6906,7 @@ msgstr "-fmacro-prefix-map=<gammal>=<ny>\tÖversätt ett katalognamn till ett an
 #: c-family/c.opt:1526
 #, no-c-format
 msgid "Write all declarations as Ada code transitively."
-msgstr "Skriv alla deklarationer som Adakod transitivt."
+msgstr "Skriv alla deklarationer som Adakod transitivitet."
 
 #: c-family/c.opt:1530
 #, no-c-format
@@ -7012,7 +7001,7 @@ msgstr "Tillåt implicit konvertering mellan vektorer med olika antal underdelar
 #: c-family/c.opt:1633
 #, no-c-format
 msgid "fmax-include-depth=<number> Set the maximum depth of the nested #include."
-msgstr "fmax-include-depth=<antal> Ange meximalt djup på nästade #include."
+msgstr "fmax-include-depth=<antal> Ange maximalt djup på nästade #include."
 
 #: c-family/c.opt:1637
 #, no-c-format
@@ -7157,7 +7146,7 @@ msgstr "Används i Fix-and-Continue-läge för att objektfiler kan bytas ut vid
 #: c-family/c.opt:1801
 #, no-c-format
 msgid "Removed in GCC 10.  This switch has no effect."
-msgstr "Borttagen i GCC 9.  Denna flagga har ingen effekt."
+msgstr "Borttagen i GCC 10.  Denna flagga har ingen effekt."
 
 #: c-family/c.opt:1805
 #, no-c-format
@@ -7693,7 +7682,7 @@ msgstr "Anta att standard D-körtidsbibliotek och ”D main” finns."
 #: d/lang.opt:238
 #, no-c-format
 msgid "Display the frontend AST after parsing and semantic passes."
-msgstr "Visa framände-AST:n efter tolkning och senamtiska pass."
+msgstr "Visa framände-AST:n efter tolkning och semantiska pass."
 
 #: d/lang.opt:242
 #, no-c-format
@@ -7738,7 +7727,7 @@ msgstr "Generera kod för förhandsvillkorskontrakt."
 #: d/lang.opt:274
 #, no-c-format
 msgid "Compile release version."
-msgstr "Kompilera utgåverversion."
+msgstr "Kompilera utgåveversion."
 
 #: d/lang.opt:282
 #, no-c-format
@@ -7768,7 +7757,7 @@ msgstr "Implementera DIP1000: pekare med räckvidd (experimentellt)."
 #: d/lang.opt:302
 #, no-c-format
 msgid "Implement DIP25: Sealed references (experimental)."
-msgstr "Implementera DIP25: förseglade referenser (expermimentellt)."
+msgstr "Implementera DIP25: förseglade referenser (experimentellt)."
 
 #: d/lang.opt:306
 #, no-c-format
@@ -7793,7 +7782,7 @@ msgstr "Lista alla variabler som hamnar i trådlokal lagring."
 #: d/lang.opt:322
 #, no-c-format
 msgid "Compile in unittest code."
-msgstr "Kompilera in enhetsstestkod."
+msgstr "Kompilera in enhetstestkod."
 
 #: d/lang.opt:326
 #, no-c-format
@@ -7948,7 +7937,7 @@ msgstr "Varna för kodvägar i vilka en async-signal-unsafe-funktion anropas fr
 #: analyzer/analyzer.opt:79
 #, no-c-format
 msgid "Warn about code paths in which NULL is passed to a must-not-be-NULL function argument."
-msgstr "Varna för kodvägar i vilka NULL skickas till ett får-inte-vara-NULL-funktionsargument"
+msgstr "Varna för kodvägar i vilka NULL skickas till ett får-inte-vara-NULL-funktionsargument."
 
 #: analyzer/analyzer.opt:83
 #, no-c-format
@@ -8313,12 +8302,12 @@ msgstr "-mtarget-linker <version>\tAnge att ld64 <version> är verktygskedjelän
 #: config/darwin.opt:94
 #, no-c-format
 msgid "Load all members of archive libraries, rather than only those that satisfy undefined symbols."
-msgstr "Läs in alla medlemmar i arkivbibliotek, istället gör endast de som uppfyller odefinierade symboler."
+msgstr "Läs in alla medlemmar i arkivbibliotek, istället för endast de som uppfyller odefinierade symboler."
 
 #: config/darwin.opt:98
 #, no-c-format
 msgid "-allowable_client <name>\tThe output dylib is private to the client <name>."
-msgstr "-allowable_client <namn>\tDylib-utdata är privat till klienten <namn>"
+msgstr "-allowable_client <namn>\tDylib-utdata är privat till klienten <namn>."
 
 #: config/darwin.opt:102
 #, no-c-format
@@ -8348,12 +8337,12 @@ msgstr "Generera en Mach-O-bunt (filtyp MH_BUNDLE)."
 #: config/darwin.opt:122
 #, no-c-format
 msgid "-bundle_loader <executable>\tTreat <executable> (that will be loading this bundle) as if it was one of the dynamic libraries the bundle is linked against for symbol resolution."
-msgstr "-bundle_loader <körbar> \tBehandla <körbar> (som kommer att ladda denna bunt) som om den vore en av de dynamiska bibliotek bunten länkas mot vid symbolupplösning"
+msgstr "-bundle_loader <körbar> \tBehandla <körbar> (som kommer att ladda denna bunt) som om den vore en av de dynamiska bibliotek bunten länkas mot vid symbolupplösning."
 
 #: config/darwin.opt:126
 #, no-c-format
 msgid "-client_name <name>\tEnable the executable being built to link against a private dylib (using allowable_client)."
-msgstr "-client_name <namn>\tAktivera tt den körbara byggs för att länka mot ett privat dylib (användande allowable_client)."
+msgstr "-client_name <namn>\tAktivera att den körbara byggs för att länka mot ett privat dylib (användande allowable_client)."
 
 #: config/darwin.opt:130
 #, no-c-format
@@ -8363,7 +8352,7 @@ msgstr "-compatibility_version <nummer>\tSätt versionen för klientgränssnitte
 #: config/darwin.opt:134
 #, no-c-format
 msgid "-current_version <number>\tSet the current version for the library to <number>."
-msgstr "-current_version <nummer>\tSätt den aktuella versionen på bibliteket till <nummer>."
+msgstr "-current_version <nummer>\tSätt den aktuella versionen på biblioteket till <nummer>."
 
 #: config/darwin.opt:138
 #, no-c-format
@@ -8393,7 +8382,7 @@ msgstr "Producera ett Mach-O delat bibliotek (filtyp MH_DYLIB), synonym till ”
 #: config/darwin.opt:161
 #, no-c-format
 msgid "-exported_symbols_list <filename>\tExport global symbols in <filename> in linked output file; any symbols not mentioned will be treated as \"hidden\"."
-msgstr "-exported_symbols_list <filnamn>\tExportera globala symboler i <filenamn> i den länkade utdatafilen; alla symboler som inte nämns kommer hanteras som ”hidden”."
+msgstr "-exported_symbols_list <filnamn>\tExportera globala symboler i <filnamn> i den länkade utdatafilen; alla symboler som inte nämns kommer hanteras som ”hidden”."
 
 #: config/darwin.opt:165
 #, no-c-format
@@ -8408,12 +8397,12 @@ msgstr "Använd för att generera kod för några äldre kärnversioner."
 #: config/darwin.opt:173
 #, no-c-format
 msgid "Ignore the normal two-level namespace; resolve symbols in command line order and do not record which library provided the resolved symbol."
-msgstr "Ignorera den normala tvånivånamnrymden; slå upp symboler i kommandoradsordning och notera inte vilket bibliotek som tillhandahäll den upplösta symbolen."
+msgstr "Ignorera den normala tvånivånamnrymden; slå upp symboler i kommandoradsordning och notera inte vilket bibliotek som tillhandahöll den upplösta symbolen."
 
 #: config/darwin.opt:177
 #, no-c-format
 msgid "For the assembler (and linker) permit any architecture sub-variant to be used without error."
-msgstr "För assemblern (och länkaren) tillåt alla arkitekturundervarienter att användas utan fel."
+msgstr "För assemblern (och länkaren) tillåt alla arkitekturundervarianter att användas utan fel."
 
 #: config/darwin.opt:181
 #, no-c-format
@@ -8423,7 +8412,7 @@ msgstr "Sätt utdataobjektet så att, vid laddning, dyld kommer ignorera tvåniv
 #: config/darwin.opt:185
 #, no-c-format
 msgid "-framework <name>\tThe linker should search for the framework <name> in the framework search path."
-msgstr "-framework <namn>\tLäkaren skall söka efter ramverket <namn> i sökvägen för ramverk."
+msgstr "-framework <namn>\tLänkaren skall söka efter ramverket <namn> i sökvägen för ramverk."
 
 #: config/darwin.opt:193
 #, no-c-format
@@ -8473,7 +8462,7 @@ msgstr "(Föråldrat efter 10.4) -multiply_defined <hantering>\tTillhandahåller
 #: config/darwin.opt:229
 #, no-c-format
 msgid "(Obsolete after 10.4) -multiply_defined_unused <treatment>\tProvided a mechanism for warning about symbols defined in the current executable also being defined in linked dylibs."
-msgstr "(Föråldrat efter 10.4) -multiply_defined_unused <hantering>\tTillhandahåller en mekansism för varningar för symboler definierade i den aktuella körbara som också är definierade i inlänkade dylib."
+msgstr "(Föråldrat efter 10.4) -multiply_defined_unused <hantering>\tTillhandahåller en mekanism för varningar för symboler definierade i den aktuella körbara som också är definierade i inlänkade dylib."
 
 #: config/darwin.opt:233
 #, no-c-format
@@ -8513,12 +8502,12 @@ msgstr "Producerar en Mach-O-fil lämplig för inbäddad/ROM-användning."
 #: config/darwin.opt:272
 #, no-c-format
 msgid "(Obsolete) Allowed linking to proceed with \"-flat_namespace\" when a linked bundle contained a symbol also exported from the main executable."
-msgstr "(Föråldrat) Tillåt läkningen att gå vidare med ”-flat_namespace” när en läkad bunt innehåller en symbol som också exporteras från huvudprogrammet."
+msgstr "(Föråldrat) Tillåt länkningen att gå vidare med ”-flat_namespace” när en länkad bunt innehåller en symbol som också exporteras från huvudprogrammet."
 
 #: config/darwin.opt:279
 #, no-c-format
 msgid "Synonym for \"-export-dynamic\" for linker versions that support it."
-msgstr "Synonym för ”-export-dynamic” för läkarversioner som stödjer det."
+msgstr "Synonym för ”-export-dynamic” för länkarversioner som stödjer det."
 
 #: config/darwin.opt:283
 #, no-c-format
@@ -8533,7 +8522,7 @@ msgstr "-sectalign <segnamn> <sektnamn> <värde>\tSätt sektionen <sektnamn> i s
 #: config/darwin.opt:291
 #, no-c-format
 msgid "-sectcreate <segname> <sectname> <file>\tCreate section <sectname> in segment <segname> from the contents of <file>."
-msgstr "-sectcreate <segnamn> <sektnamn> <fil>\tSkapa sektionen <sektname> i segmentet <segnamn> från innehållet i <file>."
+msgstr "-sectcreate <segnamn> <sektnamn> <fil>\tSkapa sektionen <sektname> i segmentet <segnamn> från innehållet i <fil>."
 
 #: config/darwin.opt:295
 #, no-c-format
@@ -8578,7 +8567,7 @@ msgstr "(Föråldrat) Objektfiler med LINKEDIT-sektioner stödjs inte längre."
 #: config/darwin.opt:329
 #, no-c-format
 msgid "-segprot <segname> <max_prot> <init_prot>\tThe virtual memory protections for segment <segname> have maximum and initial values <max_prot> and <init_prot> respectively.  The specified values may contain \"r\", \"w\", \"x\" or \"-\" the latter meaning \"no access\"."
-msgstr "-segprot <segnamn> <max_skydd> <init_skydd>\tDet virtuella minnets skydd för segment <segnamn> har maximala och initiala värden <max_skydd> respektive <init_skydd>.  Det angivna värdet kan innehålla ”r”, ”w”, ”x” eller ”-” det sistnmända betyder ”ingen åtkomst”."
+msgstr "-segprot <segnamn> <max_skydd> <init_skydd>\tDet virtuella minnets skydd för segment <segnamn> har maximala och initiala värden <max_skydd> respektive <init_skydd>.  Det angivna värdet kan innehålla ”r”, ”w”, ”x” eller ”-” det sistnämnda betyder ”ingen åtkomst”."
 
 #: config/darwin.opt:333
 #, no-c-format
@@ -8613,7 +8602,7 @@ msgstr "Detta är standard."
 #: config/darwin.opt:357
 #, no-c-format
 msgid "Add extra information to the executable that can speed up dynamic loading (provided that dependent libraries are unchanged)."
-msgstr "Lägg till extra information till den körbara som kan snabba upp den dynamiska laddningen (förutsatt att de beroenden biblioteken är oförändrade)."
+msgstr "Lägg till extra information till den körbara som kan snabba upp den dynamiska laddningen (förutsatt att de beroende biblioteken är oförändrade)."
 
 #: config/darwin.opt:361
 #, no-c-format
@@ -9102,7 +9091,7 @@ msgstr "-memregs=\tAntal memreg-byte (standard: 16, intervall: 0..16)."
 #: config/msp430/msp430.opt:7
 #, no-c-format
 msgid "Use a lightweight configuration of printf and puts to reduce code size. For single-threaded applications, not requiring reentrant I/O only. Requires Newlib Nano IO."
-msgstr "Använd en lättviktig konfiguration av printf och puts för att reducera kodstorlek.  För enkeltrådade program kräver ej återanropsbar I/O.  Kräver Newlib Nano IO."
+msgstr "Använd en lättviktig konfiguration av printf och puts för att reducera kodstorlek.  Endast för enkeltrådade program som ej kräver återanropsbar I/O.  Kräver Newlib Nano IO."
 
 #: config/msp430/msp430.opt:11
 #, no-c-format
@@ -9122,7 +9111,7 @@ msgstr "Varna om ett MCU-namn inte känns igen eller står i konflikt med andra
 #: config/msp430/msp430.opt:23
 #, no-c-format
 msgid "Warn if devices.csv is not found or there are problem parsing it (default: on)."
-msgstr "Varna om  devices.csv inte finns eller det är problem med att tolkan den (standard: på)."
+msgstr "Varna om devices.csv inte finns eller det är problem med att tolka den (standard: på)."
 
 #: config/msp430/msp430.opt:27
 #, no-c-format
@@ -9182,7 +9171,7 @@ msgstr "Skickar vidare en begäran till assemblern att varna för diverse kisele
 #: config/msp430/msp430.opt:110
 #, no-c-format
 msgid "The path to devices.csv.  The GCC driver can normally locate devices.csv itself and pass this option to the compiler, so the user shouldn't need to pass this."
-msgstr "Söktvägen till devices.csv.  GCC drivrutinen kan normalt hitta devices.csv själv och skicka denna flagga till kompilatorn, så skall inte behöva skicka denna."
+msgstr "Sökvägen till devices.csv.  GCC-drivrutinen kan normalt hitta devices.csv själv och skicka denna flagga till kompilatorn, så skall inte behöva skicka denna."
 
 #: config/aarch64/aarch64.opt:43
 #, no-c-format
@@ -9355,17 +9344,17 @@ msgstr "Generera lokala anrop till atomära operationer utanför linjen."
 #: config/aarch64/aarch64.opt:264
 #, no-c-format
 msgid "When vectorizing for SVE, consider using unpacked vectors for smaller elements and use the cost model to pick the cheapest approach.  Also use the cost model to choose between SVE and Advanced SIMD vectorization."
-msgstr "Vid vektorisering för SVE, överväg att använda opackade vektorer för mindre element och använd kostnadsmodellen för att välja den billigaste metoden.  Använd även kostnadsmodellen för att välja mellan SVE- och avanserad SIMD-vektorisering."
+msgstr "Vid vektorisering för SVE, överväg att använda opackade vektorer för mindre element och använd kostnadsmodellen för att välja den billigaste metoden.  Använd även kostnadsmodellen för att välja mellan SVE- och avancerad SIMD-vektorisering."
 
 #: config/aarch64/aarch64.opt:268
 #, no-c-format
 msgid "The number of Newton iterations for calculating the reciprocal for float type.  The precision of division is proportional to this param when division approximation is enabled.  The default value is 1."
-msgstr "Antalet Newtoniterationer för att beräkna inversen för en typen float.  Precisionen i divisionen är proprotionell mot denna parameter när divisionsapproximering är aktiverat.  Standardvärdet är 1."
+msgstr "Antalet Newtoniterationer för att beräkna inversen för typen float.  Precisionen i divisionen är proportionell mot denna parameter när divisionsapproximering är aktiverat.  Standardvärdet är 1."
 
 #: config/aarch64/aarch64.opt:272
 #, no-c-format
 msgid "The number of Newton iterations for calculating the reciprocal for double type.  The precision of division is proportional to this param when division approximation is enabled.  The default value is 2."
-msgstr "Antalet Newtoniterationer för att beräkna inversen för en typen double.  Precisionen i divisionen är proprotionell mot denna parameter när divisionsapproximering är aktiverat.  Standardvärdet är 2."
+msgstr "Antalet Newtoniterationer för att beräkna inversen för typen double.  Precisionen i divisionen är proportionell mot denna parameter när divisionsapproximering är aktiverat.  Standardvärdet är 2."
 
 #: config/linux.opt:24
 #, no-c-format
@@ -10811,7 +10800,7 @@ msgstr "Instrumentera funktionsutgångar i instrumenterade funktioner med __fent
 #: config/i386/i386.opt:1087
 #, no-c-format
 msgid "Known choices for return instrumentation with -minstrument-return=:"
-msgstr "Kända val för returintstrumentering med -minstrument-return=:"
+msgstr "Kända val för returinstrumentering med -minstrument-return=:"
 
 #: config/i386/i386.opt:1100
 #, no-c-format
@@ -11597,7 +11586,7 @@ msgstr "Generera sektionerna .s390_indirect_jump, .s390_indirect_call, .s390_ret
 #: config/s390/s390.opt:296
 #, no-c-format
 msgid "Emit profiling counter call at function entry before prologue. The compiled code will require a 64-bit CPU and glibc 2.29 or newer to run."
-msgstr "Generera profileringsräknaranrop vid funktionsstart före prologen.  Den kompilerade kodden kommer kräva en 64-bitars CPU och glibc 2.29 eller senare för att köra."
+msgstr "Generera profileringsräknaranrop vid funktionsstart före prologen.  Den kompilerade koden kommer kräva en 64-bitars CPU och glibc 2.29 eller senare för att köra."
 
 #: config/s390/s390.opt:301
 #, no-c-format
@@ -11988,7 +11977,7 @@ msgstr "Använd UltraSPARC:s utökningar Fused Multiply-Add."
 #: config/sparc/sparc.opt:98
 #, no-c-format
 msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
-msgstr "Använd instruktionen Flyttalsmultiplikation enkel till dubbel (FsMULd)"
+msgstr "Använd instruktionen flyttalsmultiplikation enkel till dubbel (FsMULd)."
 
 #: config/sparc/sparc.opt:102
 #, no-c-format
@@ -12501,10 +12490,9 @@ msgid "Enable default conversions between __float128 & long double."
 msgstr "Aktivera standardkonvertering mellan __float128 & long double."
 
 #: config/rs6000/rs6000.opt:572
-#, fuzzy, no-c-format
-#| msgid "Use vector instructions added in ISA 3.0."
+#, no-c-format
 msgid "Use instructions added in ISA 3.1."
-msgstr "Använd vektorinstruktioner som lades till i ISA 3.0."
+msgstr "Använd instruktioner som lades till i ISA 3.1."
 
 #: config/rs6000/rs6000.opt:576
 #, no-c-format
@@ -12517,10 +12505,9 @@ msgid "Generate (do not generate) pc-relative memory addressing."
 msgstr "Generera (generera inte) pc-relativ minnesadressering."
 
 #: config/rs6000/rs6000.opt:584
-#, fuzzy, no-c-format
-#| msgid "Generate (do not generate) prefixed memory instructions."
+#, no-c-format
 msgid "Generate (do not generate) MMA instructions."
-msgstr "Generera (generera inte) prefixade minnesinstruktioner."
+msgstr "Generera (generera inte) MMA-instruktioner."
 
 #: config/rs6000/sysv4.opt:24
 #, no-c-format
@@ -12832,7 +12819,7 @@ msgstr "Aktivera generering av binärer som använder funktioner från libgcc f
 #: config/or1k/or1k.opt:51
 #, no-c-format
 msgid "Enable generation of hardware floating point instructions. The default is -msoft-float."
-msgstr "Aktivera generering av flyttalsinstruktioner i hårdvara.  Standard -r -msoft-float."
+msgstr "Aktivera generering av flyttalsinstruktioner i hårdvara.  Standard är -msoft-float."
 
 #: config/or1k/or1k.opt:56
 #, no-c-format
@@ -12847,7 +12834,7 @@ msgstr "När -mhard-float är valt, aktiverar generering av instruktioner för o
 #: config/or1k/or1k.opt:68
 #, no-c-format
 msgid "Enable generation of conditional move (l.cmov) instructions.  By default the equivalent will be generated using set and branch."
-msgstr "Aktivera generering instruktioner för villkorlig förflyttning (l.cmov).  Som standard kommer det motsvarande genereras med set och branch."
+msgstr "Aktivera generering av instruktioner för villkorlig förflyttning (l.cmov).  Som standard kommer det motsvarande genereras med set och branch."
 
 #: config/or1k/or1k.opt:73
 #, no-c-format
@@ -13999,7 +13986,7 @@ msgstr "Markera inte ABI-byten i e_flags."
 #: config/frv/frv.opt:199
 #, no-c-format
 msgid "Remove redundant membars."
-msgstr "Ta bort överflödiga medlemmar."
+msgstr "Ta bort överflödiga minnesbarriärer."
 
 #: config/frv/frv.opt:203
 #, no-c-format
@@ -14229,7 +14216,7 @@ msgstr "Ange säkerhetsnivån av c-isr för hela filen."
 #: config/nds32/nds32.opt:167
 #, no-c-format
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
-msgstr "Ange storleken på varje cache-block, som måste vara en exponent av 2 mellan 4 och 512."
+msgstr "Ange storleken på varje cache-block, som måste vara en potens av 2 mellan 4 och 512."
 
 #: config/nds32/nds32.opt:175
 #, no-c-format
@@ -15394,7 +15381,7 @@ msgstr "Använd instruktioner för Cyclic Redundancy Check (CRC)."
 #: config/mips/mips.opt:425
 #, no-c-format
 msgid "Use Global INValidate (GINV) instructions."
-msgstr "Använd instruktioner för Global INValiderings (GINV)."
+msgstr "Använd instruktioner för Global INValidering (GINV)."
 
 #: config/mips/mips.opt:429
 #, no-c-format
@@ -15664,7 +15651,7 @@ msgstr "Kostnad att anta för en multiplikationsinstruktion, med 4 lika med en n
 #: config/arc/arc.opt:254
 #, no-c-format
 msgid "-mtune=TUNE\tTune code for given ARC variant."
-msgstr "-mcpu=TUNE\tTrimma kod för angiven ARC-variant."
+msgstr "-mtune=TRIMMA\tTrimma kod för angiven ARC-variant."
 
 #: config/arc/arc.opt:285
 #, no-c-format
@@ -15779,7 +15766,7 @@ msgstr "Aktivera utökningsinstruktionen för byte-ordningsväxling."
 #: config/arc/arc.opt:385
 #, no-c-format
 msgid "Enable 64-bit Time-Stamp Counter extension instruction."
-msgstr "Aktivera utökningsingsinstruktioner för 64-bitars tidsstämpelräknare."
+msgstr "Aktivera utökningsinstruktioner för 64-bitars tidsstämpelräknare."
 
 #: config/arc/arc.opt:389
 #, no-c-format
@@ -17454,7 +17441,7 @@ msgstr "Instrumentera endast funktioner från filer där namnen matchar något r
 #: common.opt:2181
 #, no-c-format
 msgid "Instrument only functions from files where names do not match all the regular expressions (separated by a semi-colon)."
-msgstr "Instrumentera endast funktioner från filer där namnen inte matchar något reguljärt uttryck (separerade av ett semikolon)."
+msgstr "Instrumentera endast funktioner från filer där namnen inte matchar något av de reguljära uttrycken (separerade av semikolon)."
 
 #: common.opt:2197
 #, no-c-format
@@ -17462,10 +17449,9 @@ msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl leve
 msgstr "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tStyr nivån av reproducerbarhet av profilen som samlas av -fprofile-generate."
 
 #: common.opt:2213
-#, fuzzy, no-c-format
-#| msgid "Remove prefix from absolute path before manging name for -fprofile-generate= and -fprofile-use=."
+#, no-c-format
 msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
-msgstr "Ta bort prefix från absoluta sökvägar före hantering av namn för -fprofile-generate= och -fprofile-use=."
+msgstr "Ta bort prefix från absoluta sökvägar före mangling av namn för -fprofile-generate= och -fprofile-use=."
 
 #: common.opt:2217
 #, no-c-format
@@ -17535,7 +17521,7 @@ msgstr "Berätta för DSE att lagringen för ett C++-objekt är dött när konst
 #: common.opt:2289
 #, no-c-format
 msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
-msgstr "-flive-patching=[inline-only-static|inline-clone]\tStyr IPA-optimeringar till att ge en säker kompilering för uppdateringar i drift.  På samma gång ger flernivåstyrning av de aktiverade IPA-optimeringar."
+msgstr "-flive-patching=[inline-only-static|inline-clone]\tStyr IPA-optimeringar till att ge en säker kompilering för uppdateringar i drift.  Ger på samma gång flernivåstyrning av de aktiverade IPA-optimeringarna."
 
 #: common.opt:2304
 #, no-c-format
@@ -18540,7 +18526,7 @@ msgstr "Ange den uppskattade sannolikheten i procent för den inbyggda expect.
 #: params.opt:79
 #, no-c-format
 msgid "The maximum length of a constant string for a builtin string cmp call eligible for inlining. The default value is 3."
-msgstr "Den maximala längden på en konstant sträng för att ett inbyggt strängjämförelseanrop skall vara tänkbar för inline:ing.  Standardvärdet är 3."
+msgstr "Den maximala längden på en konstant sträng för att ett inbyggt strängjämförelseanrop skall vara tänkbart för inline:ing.  Standardvärdet är 3."
 
 #: params.opt:83
 #, no-c-format
@@ -18641,12 +18627,12 @@ msgstr "Maximalt antal parameter i en SCoP."
 #: params.opt:159
 #, no-c-format
 msgid "The number of elements for which hash table verification is done for each searched element."
-msgstr "Antalet element för vilka verfiering av hashtabellen görs för varje sökt element."
+msgstr "Antalet element för vilka verifiering av hashtabellen görs för varje sökt element."
 
 #: params.opt:163
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
-msgstr "Nämnaren n i bråket 1/n av det maximala antalet körningar av ett grundblock i hela programmet som ett grundblock åtminstone måste ha för att anses hett (används i icke-LTO-läge)."
+msgstr "Nämnaren n i bråket 1/n av det maximala antalet körningar av ett grundblock i hela programmet som ett grundblock åtminstone måste ha för att anses varmt (används i icke-LTO-läge)."
 
 #: params.opt:167
 #, no-c-format
@@ -18656,7 +18642,7 @@ msgstr "Antalet mest exekverade promille av den profilerade körningen av hela p
 #: params.opt:171
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
-msgstr "Nämnaren n i bråket 1/n av frekvensen av antalet körningar av ingångsblocket till en funktion som ett grundblock för denna funktion åtminstone måste ha för att anses hett."
+msgstr "Nämnaren n i bråket 1/n av frekvensen av antalet körningar av ingångsblocket till en funktion som ett grundblock för denna funktion åtminstone måste ha för att anses varmt."
 
 #: params.opt:175
 #, no-c-format
@@ -18741,7 +18727,7 @@ msgstr "Maximalt antal operationer i ett parameteruttryck som kan hanteras av IP
 #: params.opt:239
 #, no-c-format
 msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
-msgstr "Maximala antalet gränsändpunkter för case-intervall i switch-satser som är oanvända under IPA-funktionssammanfattningsgenerering."
+msgstr "Maximala antalet gränsändpunkter för case-intervall i switch-satser som används under IPA-funktionssammanfattningsgenerering."
 
 #: params.opt:243
 #, no-c-format
@@ -18876,7 +18862,7 @@ msgstr "Det maximala antalet instruktioner i en inre slinga som beaktas för ver
 #: params.opt:347
 #, no-c-format
 msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
-msgstr "Det maximala antalet instruktioner i en yttre slinga som beaktas vör versionering, ovanpå instruktionerna i inre slingor."
+msgstr "Det maximala antalet instruktioner i en yttre slinga som beaktas för versionering, ovanpå instruktionerna i inre slingor."
 
 #: params.opt:351
 #, no-c-format
@@ -19367,7 +19353,7 @@ msgstr "Använd internt funktions-id i profileringsuppslagningar."
 #: params.opt:765
 #, no-c-format
 msgid "Maximum depth of a loop nest to fully value-number optimistically."
-msgstr "Maximalt djup av ett nästade slingor för fullständigt värde-tal optimistiskt."
+msgstr "Maximalt djup av en slingnästning för fullständig optimistisk värdenumrering."
 
 #: params.opt:769
 #, no-c-format
@@ -19577,7 +19563,7 @@ msgstr "Tid inräknad för funktionssnuttsomkostnader."
 #: params.opt:933
 #, no-c-format
 msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
-msgstr "Nämnaren n i bråket 1/n för antalet profileringskörningar av hela programmet under vilken exekveringsräknare för att givet grundblock måste vara för att inte anses osannolik."
+msgstr "Nämnaren n i bråket 1/n för antalet profileringskörningar av hela programmet under vilken exekveringsräknare för att ett givet grundblock måste vara för att inte anses osannolik."
 
 #: params.opt:937
 #, no-c-format
@@ -20226,8 +20212,8 @@ msgstr "%qE implicerar standardsynlighet, men %qD har redan deklarerats med anna
 #, gcc-internal-format
 msgid "%qD specifies more restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
-msgstr[0] "%qD anger ett mer restriktivt attribut en sitt mål %qD: %s"
-msgstr[1] "%qD anger mer restriktiva attribut en sitt mål %qD: %s"
+msgstr[0] "%qD anger ett mer restriktivt attribut än sitt mål %qD: %s"
+msgstr[1] "%qD anger mer restriktiva attribut än sitt mål %qD: %s"
 
 #: attribs.c:1996 attribs.c:2016
 #, gcc-internal-format
@@ -20238,8 +20224,8 @@ msgstr "%qD målet deklarerades här"
 #, gcc-internal-format
 msgid "%qD specifies less restrictive attribute than its target %qD: %s"
 msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
-msgstr[0] "%qD anger ett mindre restriktivt attribut en sitt mål %qD: %s"
-msgstr[1] "%qD anger mindre restriktiva attribut en sitt mål %qD: %s"
+msgstr[0] "%qD anger ett mindre restriktivt attribut än sitt mål %qD: %s"
+msgstr[1] "%qD anger mindre restriktiva attribut än sitt mål %qD: %s"
 
 #: auto-profile.c:365
 #, gcc-internal-format
@@ -20284,7 +20270,7 @@ msgstr "argumentet till %qs saknar avslutande nolltecken"
 #: builtins.c:559 builtins.c:3160 builtins.c:3214 gimple-ssa-sprintf.c:3281
 #, gcc-internal-format
 msgid "referenced argument declared here"
-msgstr "det referade argumentet deklarerades här"
+msgstr "det refererade argumentet deklarerades här"
 
 #: builtins.c:811
 #, gcc-internal-format
@@ -20329,22 +20315,22 @@ msgstr "%K%qD angiven gräns på %E överskrider storleken %E på oavslutad vekt
 #: builtins.c:3155
 #, gcc-internal-format
 msgid "%K%qD specified bound %E may exceed the size of at most %E of unterminated array"
-msgstr "%K%qD angivna gräns %E kan överskrida storleken på högst %E av oterminerad vektor"
+msgstr "%K%qD angivna gränsen %E kan överskrida storleken på högst %E av oavslutad vektor"
 
 #: builtins.c:3184
 #, gcc-internal-format
 msgid "%K%qD specified bound [%wu, %wu] exceeds maximum object size %E"
-msgstr "%K%qD angivna gräns [%wu, %wu] överskrider den maximala objektstorleken %E"
+msgstr "%K%qD angivna gränsen [%wu, %wu] överskrider den maximala objektstorleken %E"
 
 #: builtins.c:3207
 #, gcc-internal-format
 msgid "%K%qD specified bound [%wu, %wu] exceeds the size %E of unterminated array"
-msgstr "%K%qD angivna gräns [%wu, %wu] överskrider storleken %E på oavslutad vektor"
+msgstr "%K%qD angivna gränsen [%wu, %wu] överskrider storleken %E på oavslutad vektor"
 
 #: builtins.c:3209
 #, gcc-internal-format
 msgid "%K%qD specified bound [%wu, %wu] may exceed the size of at most %E of unterminated array"
-msgstr "%K%qD angivna gräns [%wu, %wu] kan överskrida storleken högst %E på oavslutad vektor"
+msgstr "%K%qD angivna gränsen [%wu, %wu] kan överskrida storleken högst %E på oavslutad vektor"
 
 #: builtins.c:3440
 #, gcc-internal-format
@@ -20581,14 +20567,14 @@ msgstr "otillåtet argument 0 till %qs"
 #: builtins.c:7931 expr.c:11102
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
-msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack ()%>"
+msgstr "%Kogiltig användning av %<__builtin_va_arg_pack ()%>"
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
 #: builtins.c:7937
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
-msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack_len ()%>"
+msgstr "%Kogiltig användning av %<__builtin_va_arg_pack_len ()%>"
 
 #: builtins.c:8269
 #, gcc-internal-format
@@ -20703,7 +20689,7 @@ msgstr "i ett anrop av allokeringsfunktionen %qD deklarerad här"
 #: calls.c:1681
 #, gcc-internal-format
 msgid "%K%qD specified bound [%E, %E] exceeds maximum object size %E"
-msgstr "%K%qD angivna gräns [%E, %E] överskrider maximal objektstorlek %E"
+msgstr "%K%qD angivna gränsen [%E, %E] överskrider maximal objektstorlek %E"
 
 #: calls.c:1824
 #, gcc-internal-format
@@ -21141,7 +21127,7 @@ msgstr "slinga %d:s huvud tillhör inte direkt till den"
 #: cfgloop.c:1561
 #, gcc-internal-format
 msgid "loop %d%'s latch is marked as part of irreducible region"
-msgstr "slinga %d:s koppling är markerad som en del av an oreducerbar region"
+msgstr "slinga %d:s koppling är markerad som en del av en oreducerbar region"
 
 #: cfgloop.c:1595
 #, gcc-internal-format, gfc-internal-format
@@ -21186,7 +21172,7 @@ msgstr "utgång %d->%d inte noterad"
 #: cfgloop.c:1707
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong list of exited loops for edge %d->%d"
-msgstr "fel lista över lämnade slingor för båge  %d→%d"
+msgstr "fel lista över lämnade slingor för båge %d→%d"
 
 #: cfgloop.c:1716
 #, gcc-internal-format
@@ -21406,7 +21392,7 @@ msgstr "spekulativa bågar är inte närliggande"
 #: cgraph.c:3275
 #, gcc-internal-format, gfc-internal-format
 msgid "direct call to %s in speculative call sequence has no speculative flag"
-msgstr "direkt anrop av %s i en spekulativ anropssekven har ingen spekulativ flagga"
+msgstr "direkt anrop av %s i en spekulativ anropssekvens har ingen spekulativ flagga"
 
 #: cgraph.c:3281 cgraph.c:3311
 #, gcc-internal-format, gfc-internal-format
@@ -21416,17 +21402,17 @@ msgstr "direkt anrop av %s i en spekulativ anropssekvens har speculative_id %i u
 #: cgraph.c:3288
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
-msgstr "dubblerat direkt anrop av %s i en spekulativ anropssekvens med spekulativ_id %i"
+msgstr "dubblerat direkt anrop av %s i en spekulativ anropssekvens med speculative_id %i"
 
 #: cgraph.c:3299
 #, gcc-internal-format
 msgid "call stmt hash does not point to first direct edge of speculative call sequence"
-msgstr "call stmt-hachen pekar inte på den första direkta bågen av en spekulativ anropssekvens"
+msgstr "call stmt-hashen pekar inte på den första direkta bågen av en spekulativ anropssekvens"
 
 #: cgraph.c:3318
 #, gcc-internal-format, gfc-internal-format
 msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
-msgstr "dubblerad referens %s i en spekulativ anropssekvens med spekulativ_id %i"
+msgstr "dubblerad referens %s i en spekulativ anropssekvens med speculative_id %i"
 
 #: cgraph.c:3331
 #, gcc-internal-format, gfc-internal-format
@@ -21681,7 +21667,7 @@ msgstr "verify_cgraph_node misslyckades"
 #: cgraph.c:3923 varpool.c:303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s.%d is missing"
-msgstr "%s sektion %s.%d saknas"
+msgstr "%s: sektion %s.%d saknas"
 
 #: cgraphunit.c:727
 #, gcc-internal-format
@@ -21857,7 +21843,7 @@ msgstr "kan inte ta programstatus: %m"
 #: collect-utils.c:82
 #, gcc-internal-format, gfc-internal-format
 msgid "%s terminated with signal %d [%s]%s"
-msgstr "%s terminerade med signal %d [%s]%s"
+msgstr "%s avslutat med signal %d [%s]%s"
 
 #: collect-utils.c:98
 #, gcc-internal-format, gfc-internal-format
@@ -22016,7 +22002,7 @@ msgstr "kan inte konvertera till en pekartyp"
 #: convert.c:332
 #, gcc-internal-format
 msgid "pointer value used where a floating-point was expected"
-msgstr "pekarvärde använd där ett flyttalsvärde förväntades"
+msgstr "pekarvärde använt där ett flyttalsvärde förväntades"
 
 #: convert.c:336
 #, gcc-internal-format
@@ -22031,7 +22017,7 @@ msgstr "konvertering till ofullständig typ"
 #: convert.c:946
 #, gcc-internal-format
 msgid "cannot convert a vector of type %qT to type %qT which has different size"
-msgstr "det går inte att konvertera en vektor av typen %qT till typen %qT som har annan storlekar"
+msgstr "det går inte att konvertera en vektor av typen %qT till typen %qT som har annan storlek"
 
 #: convert.c:954
 #, gcc-internal-format
@@ -22151,7 +22137,7 @@ msgstr "bytekodström: för lång sträng för strängtabellen"
 #: data-streamer-in.c:84 data-streamer-in.c:113
 #, gcc-internal-format
 msgid "bytecode stream: found non-null terminated string"
-msgstr "bytekodström: hittade sträng som inte var nollterminerad"
+msgstr "bytekodström: hittade sträng som inte var nollavslutad"
 
 #: dbgcnt.c:128
 #, gcc-internal-format
@@ -22166,7 +22152,7 @@ msgstr "%<-fdbg-cnt=%s:%d-%d%> har mindre övre gräns än den undre"
 #: dbgcnt.c:155
 #, gcc-internal-format
 msgid "cannot find a valid counter name %qs of %<-fdbg-cnt=%> option"
-msgstr "kan inte hitta ett giltigt räknarenamn %qs till flaggan %<-fdbg-cnt=%>"
+msgstr "kan inte hitta ett giltigt räknarnamn %qs till flaggan %<-fdbg-cnt=%>"
 
 #: dbgcnt.c:226
 #, gcc-internal-format
@@ -22236,7 +22222,7 @@ msgstr "ignorerar flaggan %<-fopt-info-%s%> som möjligen står i konflikt"
 #: dwarf2out.c:1120
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
-msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet %<.cfi.personality%>."
+msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet %<.cfi.personality%>"
 
 #: dwarf2out.c:10992
 #, gcc-internal-format
@@ -22598,7 +22584,7 @@ msgstr "%<-x %s%> efter sista indatafilen har ingen effekt"
 #: gcc.c:4926
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
-msgstr "kan inte lokalisera standardlänkskriptet %qs i bilblioteksökvägarna"
+msgstr "kan inte lokalisera standardlänkskriptet %qs i biblioteksökvägarna"
 
 #: gcc.c:5133
 #, gcc-internal-format
@@ -22812,7 +22798,7 @@ msgstr "multilib-undantag %qs är ogiltigt"
 #: gcc.c:9398
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
-msgstr "omgivningsvariabeln %qs är inte definierad"
+msgstr "miljövariabeln %qs är inte definierad"
 
 #: gcc.c:9538 gcc.c:9543
 #, gcc-internal-format
@@ -23371,19 +23357,19 @@ msgstr "argumentet %qE %Z och kanske %Z överlappar destinationsobjektet %qE"
 #: gimple-ssa-sprintf.c:3917
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
-msgstr[0] "%qE:s argument %qE överlappar destinationsobjektet %qE"
-msgstr[1] "%qE:s argument %qE överlappar destinationsobjektet %qE"
+msgstr[0] "%qE:s argument %Z överlappar destinationsobjektet %qE"
+msgstr[1] "%qE:s argument %Z överlappar destinationsobjektet %qE"
 
 #: gimple-ssa-sprintf.c:3928
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
-msgstr[0] "%qE:s argument %qE kan överlappa destinationsobjektet %qE"
-msgstr[1] "%qE:s argument %qE kan överlappa destinationsobjektet %qE"
+msgstr[0] "%qE:s argument %Z kan överlappa destinationsobjektet %qE"
+msgstr[1] "%qE:s argument %Z kan överlappa destinationsobjektet %qE"
 
 #: gimple-ssa-sprintf.c:3948
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
-msgstr "destinationtionsobjektet som refereras av det %<restrict%>-kvalificerade argument 1 deklarerades här"
+msgstr "destinationsobjektet som refereras av det %<restrict%>-kvalificerade argument 1 deklarerades här"
 
 #: gimple-ssa-sprintf.c:4538
 #, gcc-internal-format
@@ -23836,7 +23822,7 @@ msgstr "reduktionsmodifieraren %<task%> på en konstruktion med en klausul %<now
 #: gimplify.c:8543 gimplify.c:12337
 #, gcc-internal-format
 msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
-msgstr "invalid %<task%> reduction modifier on construct other than %<parallel%>, %<for%> or %<sections%>"
+msgstr "felaktig reduktionsmodifierare %<task%> på en annan konstruktion än %<parallel%>, %<for%> eller %<sections%>"
 
 #: gimplify.c:8553 gimplify.c:8559 gimplify.c:8565 gimplify.c:8571
 #: gimplify.c:12330
@@ -23917,7 +23903,7 @@ msgstr "ogiltig privat reduktion av %qE"
 #: gimplify.c:10623
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
-msgstr "en %<inscan%> %<reduction%>-klausul använd tillsammans med en %<linear%>-klausul för en annan variabel en slingitereraren"
+msgstr "en %<inscan%> %<reduction%>-klausul använd tillsammans med en %<linear%>-klausul för en annan variabel än slingitereraren"
 
 #: gimplify.c:10957
 #, gcc-internal-format
@@ -24421,7 +24407,7 @@ msgstr "Åtkomstavstånd före föräldraavståndet"
 #: ipa-sra.c:1475
 #, gcc-internal-format
 msgid "Access size greater or equal to its parent size"
-msgstr "Atkomststorleken är större eller lika med sin förälderstorlek"
+msgstr "Åtkomststorleken är större eller lika med sin föräldrastorlek"
 
 #: ipa-sra.c:1480
 #, gcc-internal-format
@@ -24436,7 +24422,7 @@ msgstr "Åtkomsten överlappar med sitt syskon"
 #: ipa-sra.c:1511
 #, gcc-internal-format
 msgid "IPA-SRA access verification failed"
-msgstr "IPA-SRA åtmkomstverifiering misslyckades"
+msgstr "IPA-SRA åtkomstverifiering misslyckades"
 
 #: ipa-sra.c:2472
 #, gcc-internal-format
@@ -24788,7 +24774,7 @@ msgstr "flera %<default%>-mål sattes"
 #: omp-expand.c:2163
 #, gcc-internal-format
 msgid "%<depend%> clause with %<sink%> modifier waiting for lexically later iteration"
-msgstr "%<depend%>-klausul med %<sink%>-modifireare väntar på en lexikalt senare iteration"
+msgstr "%<depend%>-klausul med %<sink%>-modifierare väntar på en lexikalt senare iteration"
 
 #: omp-expand.c:2300
 #, gcc-internal-format
@@ -24808,7 +24794,7 @@ msgstr "… till den tidigare %qs-klausulen här"
 #: omp-general.c:1841
 #, gcc-internal-format
 msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
-msgstr "%<%s%> kan inte används på %qD, som redan har markerats med ett OpenMC ”declare target”-direktiv"
+msgstr "%<%s%> kan inte användas på %qD, som redan har markerats med ett OpenMP ”declare target”-direktiv"
 
 #: omp-general.c:1883
 #, gcc-internal-format
@@ -25201,12 +25187,12 @@ msgstr "kommandoradsflaggan %qs är giltig för %s men inte för %s"
 #: opts-global.c:112
 #, gcc-internal-format
 msgid "%<-Werror=%> argument %qs is not valid for %s"
-msgstr "%<-Werror=%>-argumentet %qs är inte giltigt för %qs"
+msgstr "%<-Werror=%>-argumentet %qs är inte giltigt för %s"
 
 #: opts-global.c:144
 #, gcc-internal-format
 msgid "unrecognized command-line option %qs may have been intended to silence earlier diagnostics"
-msgstr "okänd kommandoradsflagga %s kan ha varit avsedd att tysta tidare felmeddelanden"
+msgstr "okänd kommandoradsflagga %qs kan ha varit avsedd att tysta tidigare felmeddelanden"
 
 #: opts-global.c:389
 #, gcc-internal-format
@@ -25426,12 +25412,12 @@ msgstr "%<-fsanitize-address-use-after-scope%> förutsätter flaggan %<-fstack-r
 #: opts.c:1153
 #, gcc-internal-format
 msgid "transactional memory is not supported with %<-fsanitize=address%>"
-msgstr "transaktionsminne stödjs inte i med %<-fsanitize=address%>"
+msgstr "transaktionsminne stödjs inte med %<-fsanitize=address%>"
 
 #: opts.c:1156
 #, gcc-internal-format
 msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
-msgstr "transaktionsminne stödjs inte i med %<-fsanitize=kernel-address%>"
+msgstr "transaktionsminne stödjs inte med %<-fsanitize=kernel-address%>"
 
 #: opts.c:1161
 #, gcc-internal-format
@@ -25571,7 +25557,7 @@ msgstr "ej igenkänd felsökningsflagga för gcc: %c"
 #: opts.c:3077
 #, gcc-internal-format
 msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
-msgstr "%<-W%serror=%s%>: inge flagga %<-%s%>; menade du %<-%s%>?"
+msgstr "%<-W%serror=%s%>: ingen flagga %<-%s%>; menade du %<-%s%>?"
 
 #: opts.c:3081
 #, gcc-internal-format
@@ -26946,7 +26932,7 @@ msgstr "ogiltiga operander binär operation"
 #: tree-cfg.c:3927
 #, gcc-internal-format
 msgid "invalid non-vector operands to %qs"
-msgstr "ogiltig operander som inte är vektor till %qs"
+msgstr "ogiltiga operander som inte är vektor till %qs"
 
 #: tree-cfg.c:3938
 #, gcc-internal-format
@@ -26986,7 +26972,7 @@ msgstr "vektortyper förväntades i %qs"
 #: tree-cfg.c:4283
 #, gcc-internal-format
 msgid "vectors with different element number found in %qs"
-msgstr "vektorer med olika elementantal funna %qs"
+msgstr "vektorer med olika elementantal funna i %qs"
 
 #: tree-cfg.c:4299
 #, gcc-internal-format
@@ -27273,13 +27259,11 @@ msgstr "etikett "
 msgid "control flow in the middle of basic block %d"
 msgstr "flödesstyrning mitt i grundblock %d"
 
-# bb -> basic block -> grundblock -> gb
 #: tree-cfg.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after a control statement in bb %d"
 msgstr "fall igenom-båge efter styrsats i gb %d"
 
-# bb -> basic block -> grundblock -> gb
 #: tree-cfg.c:5640
 #, gcc-internal-format, gfc-internal-format
 msgid "true/false edge after a non-GIMPLE_COND in bb %d"
@@ -27353,22 +27337,22 @@ msgstr "i expansionen av makrot %qs"
 #: tree-eh.c:4904
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
-msgstr "BB %i har flera EH-bågar"
+msgstr "GB %i har flera EH-bågar"
 
 #: tree-eh.c:4916
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i cannot throw but has an EH edge"
-msgstr "BB %i kan inte kasta men har en EH-båge"
+msgstr "GB %i kan inte kasta men har en EH-båge"
 
 #: tree-eh.c:4924
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
-msgstr "BB %i:s sista sats har felaktigt satt lp"
+msgstr "GB %i:s sista sats har felaktigt satt lp"
 
 #: tree-eh.c:4930
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
-msgstr "BB %i sakar en EH-båge"
+msgstr "GB %i saknar en EH-båge"
 
 #: tree-eh.c:4936
 #, gcc-internal-format, gfc-internal-format
@@ -27378,22 +27362,22 @@ msgstr "Felaktig EH-båge %i->%i"
 #: tree-eh.c:4970 tree-eh.c:4989
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
-msgstr "BB %i saknar en båge"
+msgstr "GB %i saknar en båge"
 
 #: tree-eh.c:5006
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
-msgstr "BB %i har för många fall-igenom-bågar"
+msgstr "GB %i har för många fall-igenom-bågar"
 
 #: tree-eh.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
-msgstr "BB %i har felaktig båge"
+msgstr "GB %i har felaktig båge"
 
 #: tree-eh.c:5021
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
-msgstr "BB %i har felaktig fall-igenom-båge"
+msgstr "GB %i har felaktig fall-igenom-båge"
 
 #: tree-inline.c:3832
 #, gcc-internal-format
@@ -28360,7 +28344,7 @@ msgstr "dött histogram"
 #: value-prof.c:505
 #, gcc-internal-format
 msgid "histogram value statement does not correspond to the statement it is associated with"
-msgstr "histogramvärdesats motsvarar inte satsen den är associerat med"
+msgstr "histogramvärdesats motsvarar inte satsen den är associerad med"
 
 #: value-prof.c:574
 #, gcc-internal-format, gfc-internal-format
@@ -28631,83 +28615,83 @@ msgstr "ej stödd postlayout"
 #: c-family/c-attribs.c:548
 #, gcc-internal-format
 msgid "%qE attribute argument is invalid"
-msgstr "attributet %qE argument är ogiltigt"
+msgstr "argumentet till attributet %qE argument är ogiltigt"
 
 #: c-family/c-attribs.c:551
 #, gcc-internal-format
 msgid "%qE attribute argument %i is invalid"
-msgstr "attributet %qE argument %i är ogiltigt"
+msgstr "argument %2$i till attributet %1$qE är ogiltigt"
 
 #: c-family/c-attribs.c:563
 #, gcc-internal-format
 msgid "%qE attribute argument has type %qT"
-msgstr "attributet %qE argument har typen %qT"
+msgstr "argumentet till attributet %qE har typen %qT"
 
 #: c-family/c-attribs.c:567
 #, gcc-internal-format
 msgid "%qE attribute argument %i has type %qT"
-msgstr "attributet %qE argument %i har typen %qT"
+msgstr "argument %2$i till attributet %1$qE har typen %3$qT"
 
 #: c-family/c-attribs.c:578 c-family/c-attribs.c:3610
 #: c-family/c-attribs.c:3614
 #, gcc-internal-format
 msgid "%qE attribute argument value %qE is not an integer constant"
-msgstr "attributet %qE argumentet %qE värde är inte en heltalskonstant"
+msgstr "värdet %2$qE på attributet %1$qE är inte en heltalskonstant"
 
 #: c-family/c-attribs.c:583
 #, gcc-internal-format
 msgid "%qE attribute argument %i value %qE is not an integer constant"
-msgstr "attributet %qE argument %i värde %qE är inte en heltalskonstant"
+msgstr "värdet %3$qE på argument %2$i till attributet %1$qE är inte en heltalskonstant"
 
 #: c-family/c-attribs.c:599
 #, gcc-internal-format
 msgid "%qE attribute argument value %qE does not refer to a function parameter"
-msgstr "attributet %qE argumentets värde %qE refererar inte till en funktionsparameter"
+msgstr "värdet %2$qE till attributet %1$qE refererar inte till en funktionsparameter"
 
 #: c-family/c-attribs.c:604
 #, gcc-internal-format
 msgid "%qE attribute argument %i value %qE does not refer to a function parameter"
-msgstr "attributet %qE argumentet %i värde %qE refererar inte till en funktionsparameter"
+msgstr "värdet %3$qE på argument %2$i till attributet %1$qE refererar inte till en funktionsparameter"
 
 #: c-family/c-attribs.c:627
 #, gcc-internal-format
 msgid "%qE attribute argument value %qE exceeds the number of function parameters %u"
-msgstr "attributetet %qE argumentvärde %qE överskrider antalet funktionsparametrar %u"
+msgstr "värdet %2$qE på argumentet till attributet %1$qE överskrider antalet funktionsparametrar %3$u"
 
 #: c-family/c-attribs.c:632
 #, gcc-internal-format
 msgid "%qE attribute argument %i value %qE exceeds the number of function parameters %u"
-msgstr "attributet %qE argument %i värde %qE överskrider antalet funktionsparametrar %u"
+msgstr "värdet %3$qE på argument %2$i till attributet %1$qE överskrider antalet funktionsparametrar %4$u"
 
 #: c-family/c-attribs.c:650
 #, gcc-internal-format
 msgid "%qE attribute argument value %qE does not refer to a variable argument list"
-msgstr "attributet %qE argumentvärde %qE refererar inte till en variabelargumentlista"
+msgstr "värdet %2$qE på argumentet till attributet %1$qE refererar inte till en variabelargumentlista"
 
 #: c-family/c-attribs.c:654
 #, gcc-internal-format
 msgid "%qE attribute argument %i value %qE does not refer to a variable argument list"
-msgstr "attributet %qE argument %i värde %qE refererar inte till en variabelargumentlista"
+msgstr "värdet %3$qE på argument %2$i till attributet %1$qE refererar inte till en variabelargumentlista"
 
 #: c-family/c-attribs.c:681 c-family/c-attribs.c:694
 #, gcc-internal-format
 msgid "%qE attribute argument value %qE refers to parameter type %qT"
-msgstr "attributet %qE argumentvärdet %qE refererar till parametertypen %qT"
+msgstr "värdet %2$qE på argumentet till attributet %1$qE refererar till parametertypen %3$qT"
 
 #: c-family/c-attribs.c:685 c-family/c-attribs.c:699
 #, gcc-internal-format
 msgid "%qE attribute argument %i value %qE refers to parameter type %qT"
-msgstr "attributet %qE argumentet %i värde %qE refererar till parametertypen %qT"
+msgstr "värdet %3$qE på argumentet %2$i till attributet %1$qE refererar till parametertypen %4$qT"
 
 #: c-family/c-attribs.c:709
 #, gcc-internal-format
 msgid "%qE attribute argument value %qE refers to a variadic function parameter of unknown type"
-msgstr "attributet %qE argumentvärdet %qE refererar till en variadisk funktionsparameter av okänd typ"
+msgstr "värdet %2$qE på argumentet till attributet %1$qE refererar till en variadisk funktionsparameter av okänd typ"
 
 #: c-family/c-attribs.c:714
 #, gcc-internal-format
 msgid "%qE attribute argument %i value %qE refers to a variadic function parameter of unknown type"
-msgstr "attributet %qE argument %i värde %qE refererar till en varidadisk funktionsparameter av okänd typ"
+msgstr "värdet %3$qE på argument %2$i på attributet %1$qE refererar till en variadisk funktionsparameter av okänd typ"
 
 #: c-family/c-attribs.c:738
 #, gcc-internal-format
@@ -28770,7 +28754,7 @@ msgstr "attributet %qE stödjs inte eftersom byteordningen inte är enhetlig"
 #: c-family/c-attribs.c:1464
 #, gcc-internal-format
 msgid "attribute %qE argument must be one of %qs or %qs"
-msgstr "attributargumentet %qE måste vara en av %qs eller %qs"
+msgstr "argumentet till attributet %qE måste vara en av %qs eller %qs"
 
 #: c-family/c-attribs.c:1560
 #, gcc-internal-format
@@ -28998,7 +28982,7 @@ msgstr "attributet %qE ignoreras vid en omdeklaration av den refererade symbolen
 #: c-family/c-attribs.c:2548
 #, gcc-internal-format
 msgid "%qE attribute ignored on a declaration of a different kind than referenced symbol"
-msgstr "attributet %qE ignoreras vid en deklareration av en annan sort än den referade symbolen"
+msgstr "attributet %qE ignoreras vid en deklaration av en annan sort än den referade symbolen"
 
 #: c-family/c-attribs.c:2553
 #, gcc-internal-format
@@ -29215,7 +29199,7 @@ msgstr "positionsargument 2 till attributet %qs står i konflikt med tidigare be
 #: c-family/c-attribs.c:3909
 #, gcc-internal-format
 msgid "attribute %qs missing positional argument 2 provided in previous designation"
-msgstr "attributet %qs saknar positionsargument 2 tillhandahållet in den föregående beteckningen"
+msgstr "attributet %qs saknar positionsargument 2 tillhandahållet i den föregående beteckningen"
 
 #: c-family/c-attribs.c:3923
 #, gcc-internal-format
@@ -29380,7 +29364,7 @@ msgstr "%qD är inte definierad utanför funktionsnivå"
 #: c-family/c-common.c:787
 #, gcc-internal-format
 msgid "size of string literal is too large"
-msgstr "storleken på strängliteralen är för stor"
+msgstr "storleken på stränglitteralen är för stor"
 
 #: c-family/c-common.c:810
 #, gcc-internal-format
@@ -29742,7 +29726,7 @@ msgstr "argument 3 i anropet av funktionen %qE har typen pekare till boolean"
 #: c-family/c-common.c:6046
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to %<const%> type (%qT)"
-msgstr "argument 3 i anropet av funktionen %qE har typen pekare till en %<const%>-typ (%qT) "
+msgstr "argument 3 i anropet av funktionen %qE har typen pekare till en %<const%>-typ (%qT)"
 
 #: c-family/c-common.c:6070
 #, gcc-internal-format
@@ -29909,7 +29893,7 @@ msgstr "storleken på vektorn %qE överskrider maximal objektstorlek %qE"
 #: c-family/c-common.c:8296
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
-msgstr "sotrleken på vektorn överskrider maximal objektstorlek %qE"
+msgstr "storleken på vektorn överskrider maximal objektstorlek %qE"
 
 #: c-family/c-common.c:8367
 #, gcc-internal-format
@@ -29999,7 +29983,7 @@ msgstr "%<$%>-operandnummer använt efter format utan operandnummer"
 #: c-family/c-format.c:1453
 #, gcc-internal-format
 msgid "format argument %d unused before used argument %d in %<$%>-style format"
-msgstr "formatargument %d oanvänt för använt argument %d i %<$%>-stilsformat"
+msgstr "formatargument %d oanvänt före använt argument %d i %<$%>-stilsformat"
 
 #: c-family/c-format.c:1556
 #, gcc-internal-format
@@ -30044,7 +30028,7 @@ msgstr "formatsträngen är inte en vektor av typen %qs"
 #: c-family/c-format.c:1613
 #, gcc-internal-format
 msgid "unterminated format string"
-msgstr "icke terminerad formatsträng"
+msgstr "oavslutad formatsträng"
 
 #: c-family/c-format.c:2027
 #, gcc-internal-format
@@ -30254,7 +30238,7 @@ msgstr "vilsekommet alternativnamn %<%.*s%> i format"
 #: c-family/c-format.c:3505
 #, gcc-internal-format
 msgid "unbalanced punctuation character %qc in format"
-msgstr "obalancerat interpunktionstecken %qc i format"
+msgstr "obalanserat interpunktionstecken %qc i format"
 
 #: c-family/c-format.c:3524
 #, gcc-internal-format
@@ -30329,7 +30313,7 @@ msgstr "obalanserat interpunktionstecken %<%c%> i format"
 #: c-family/c-format.c:3753
 #, gcc-internal-format
 msgid "unterminated quoting directive"
-msgstr "icke terminerat citationsdirektiv"
+msgstr "oavslutat citationsdirektiv"
 
 #: c-family/c-format.c:3762
 #, gcc-internal-format
@@ -30469,7 +30453,7 @@ msgstr "strftime-format kan inte formatera argument"
 #: c-family/c-indentation.c:67
 #, gcc-internal-format
 msgid "%<-Wmisleading-indentation%> is disabled from this point onwards, since column-tracking was disabled due to the size of the code/headers"
-msgstr "%<-Wmisleading-indentation%> är avaktiverad härifrån och framåt, eftersom kolumnspårning avaktiverades på grund av storleken på kod/huvuden."
+msgstr "%<-Wmisleading-indentation%> är avaktiverad härifrån och framåt, eftersom kolumnspårning avaktiverades på grund av storleken på kod/huvuden"
 
 #: c-family/c-indentation.c:614
 #, gcc-internal-format
@@ -30755,7 +30739,7 @@ msgstr "%<-fexcess-precision=standard%> för C++"
 #: c-family/c-opts.c:841
 #, gcc-internal-format
 msgid "%<-fno-gnu89-inline%> is only supported in GNU99 or C99 mode"
-msgstr "%<-fno-gnu89-inline%> stödjs endast i GNU99- C99-läge"
+msgstr "%<-fno-gnu89-inline%> stödjs endast i GNU99- eller C99-läge"
 
 #: c-family/c-opts.c:887
 #, gcc-internal-format
@@ -30965,7 +30949,7 @@ msgstr "justering måste vara två upphöjt till ett litet tal, inte %d"
 #: c-family/c-pragma.c:262
 #, gcc-internal-format
 msgid "applying %<#pragma weak %+D%> after first use results in unspecified behavior"
-msgstr "applicering av %<#pragma weak %q+D%> efter första användningen ger odefinierat beteende"
+msgstr "applicering av %<#pragma weak %+D%> efter första användningen ger odefinierat beteende"
 
 #: c-family/c-pragma.c:359 c-family/c-pragma.c:364
 #, gcc-internal-format
@@ -31942,17 +31926,17 @@ msgstr "jämförelse av heltalsuttryck av olika teckenläge: %qT och %qT"
 #: c-family/c-warn.c:2346
 #, gcc-internal-format
 msgid "promoted bitwise complement of an unsigned value is always nonzero"
-msgstr "befordrad bitvis komplement av ett teckenlöst värde är alltid skilt från noll"
+msgstr "befordrat bitvis komplement av ett teckenlöst värde är alltid skilt från noll"
 
 #: c-family/c-warn.c:2350
 #, gcc-internal-format
 msgid "comparison of promoted bitwise complement of an unsigned value with constant"
-msgstr "jämförelse av befordrad bitvis komplement av ett teckenlöst värde med konstant"
+msgstr "jämförelse av befordrat bitvis komplement av ett teckenlöst värde med konstant"
 
 #: c-family/c-warn.c:2361
 #, gcc-internal-format
 msgid "comparison of promoted bitwise complement of an unsigned value with unsigned"
-msgstr "jämförelse av befordrad bitvis komplement av ett teckenlöst värde med teckenlöst"
+msgstr "jämförelse av befordrat bitvis komplement av ett teckenlöst värde med teckenlöst"
 
 #: c-family/c-warn.c:2416
 #, gcc-internal-format
@@ -32023,7 +32007,7 @@ msgstr "några delar av makroexpansionen är inte skyddade av denna %qs-klausul"
 #: c-family/c-warn.c:2980
 #, gcc-internal-format
 msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
-msgstr "konverterar en packad %qT-pekare (justering %d) till en %qT-pekare (justering %d) kan resultera i ett ojusterat pekarvärde"
+msgstr "att konvertera en packad %qT-pekare (justering %d) till en %qT-pekare (justering %d) kan resultera i ett ojusterat pekarvärde"
 
 #: c-family/c-warn.c:2987 c-family/c-warn.c:2990 cp/init.c:635
 #, gcc-internal-format
@@ -32033,7 +32017,7 @@ msgstr "definierad här"
 #: c-family/c-warn.c:3077
 #, gcc-internal-format
 msgid "taking address of packed member of %qT may result in an unaligned pointer value"
-msgstr "att ta adressen till en packad medlem i %qT kan resultera i ett ojusterar pekarvärde"
+msgstr "att ta adressen till en packad medlem i %qT kan resultera i ett ojusterat pekarvärde"
 
 #: c-family/cppspec.c:94
 #, gcc-internal-format
@@ -32402,7 +32386,7 @@ msgstr "denna målarkitektur stödjer inte %s"
 #: config/darwin-driver.c:324
 #, gcc-internal-format
 msgid "%qs is not valid for %<mmacosx-version-min%>"
-msgstr "%qs är inte ett giltigt värde till %<-mmacosx-version-min%>"
+msgstr "%qs är inte ett giltigt värde till %<mmacosx-version-min%>"
 
 #: config/darwin-driver.c:358
 #, gcc-internal-format
@@ -32507,7 +32491,7 @@ msgstr "CFString-litteraluttryck är inte en strängkonstant"
 #: config/darwin.c:3622
 #, gcc-internal-format
 msgid "non-ASCII character in CFString literal"
-msgstr "icke-ASCII-tecklen i CFString-litteral"
+msgstr "icke-ASCII-tecken i CFString-litteral"
 
 #: config/darwin.c:3623
 #, gcc-internal-format
@@ -32680,7 +32664,7 @@ msgstr "funktionsmodifieraren %qs är inkompatibel med användningen av flyttals
 #: config/aarch64/aarch64.c:1939
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with the use of vector types"
-msgstr "funktionsmodifieraren %qs är inkompatibel med med användningen av vektortyper"
+msgstr "funktionsmodifieraren %qs är inkompatibel med användningen av vektortyper"
 
 #: config/aarch64/aarch64.c:1955
 #, gcc-internal-format
@@ -32719,7 +32703,7 @@ msgstr "%qE behöver ISA-utökningen SVE"
 #: config/aarch64/aarch64.c:6004
 #, gcc-internal-format
 msgid "calls to functions of type %qT require the SVE ISA extension"
-msgstr "anropt till funktioner av typen %qT behöver ISA-utökningen SVE"
+msgstr "anrop till funktioner av typen %qT behöver ISA-utökningen SVE"
 
 #: config/aarch64/aarch64.c:6180
 #, gcc-internal-format
@@ -32946,18 +32930,14 @@ msgstr "felformaterat pragma eller attribut %<target(\"%s\")%>"
 #: config/aarch64/aarch64.c:16925 config/arm/arm.c:6425
 #: config/rs6000/rs6000-call.c:5777 config/s390/s390.c:11970
 #: config/s390/s390.c:12047
-#, fuzzy
-#| msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
-msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 9.1"
+msgstr "parameterskickandet för argument av typen %qT med %<[[no_unique_address]]%>-medlemmar ändrades %{i GCC 10.1%}"
 
 #: config/aarch64/aarch64.c:16930 config/arm/arm.c:6430
 #: config/rs6000/rs6000-call.c:5772 config/s390/s390.c:11965
 #: config/s390/s390.c:12042
-#, fuzzy
-#| msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 in GCC 10.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
-msgstr "parameterskickandet för argument av typen %qT när C++17 är aktiverades ändrades till att matcha C++14 i GCC 10.1"
+msgstr "parameterskickandet för argument av typen %qT när C++17 är aktiverat ändrades till att matcha C++14 %{i GCC 10.1%}"
 
 #: config/aarch64/aarch64.c:18004
 #, gcc-internal-format
@@ -33138,12 +33118,12 @@ msgstr "flaggan %<-mrgf-banked-regs%> är giltig endast för ARC v2-processorer"
 #: config/arc/arc.c:1365
 #, gcc-internal-format
 msgid "option %<%s=%s%> is not available for %qs CPU"
-msgstr "flaggan %<%s=%s%> är inte tillgänglig för CPU:n %qs."
+msgstr "flaggan %<%s=%s%> är inte tillgänglig för CPU:n %qs"
 
 #: config/arc/arc.c:1370
 #, gcc-internal-format
 msgid "option %qs is ignored, the default value %qs is considered for %qs CPU"
-msgstr "flaggan %s ignoreras, standardvärdet %qs antas för CPU:n %qs."
+msgstr "flaggan %qs ignoreras, standardvärdet %qs antas för CPU:n %qs"
 
 #: config/arc/arc.c:1378
 #, gcc-internal-format
@@ -33153,7 +33133,7 @@ msgstr "flaggan %qs är inte tillgänglig för CPU:n %qs"
 #: config/arc/arc.c:1383
 #, gcc-internal-format
 msgid "unset option %qs is ignored, it is always enabled for %qs CPU"
-msgstr "den nollställda flaggan %qs ignoreras, den är alltid aktiverad för CPU:n %qs."
+msgstr "den nollställda flaggan %qs ignoreras, den är alltid aktiverad för CPU:n %qs"
 
 #: config/arc/arc.c:1950
 #, gcc-internal-format, gfc-internal-format
@@ -33362,7 +33342,7 @@ msgstr "denna inbyggda stödjs inte på denna målarkitektur"
 #: config/arm/arm-builtins.c:3332
 #, gcc-internal-format
 msgid "%Ksaturation bit range must be in the range [%wd, %wd]"
-msgstr "%Kmättnatsbitsintervallet måste ligga i intervallet [%wd, %wd]"
+msgstr "%Kmättnadsbitsintervallet måste ligga i intervallet [%wd, %wd]"
 
 #: config/arm/arm-builtins.c:3336
 #, gcc-internal-format
@@ -33372,7 +33352,7 @@ msgstr "%Kmättnadsbitsintervallet måste vara en konstant omedelbar"
 #: config/arm/arm-builtins.c:3359
 #, gcc-internal-format
 msgid "You must enable MVE instructions to use these intrinsics"
-msgstr "Du måste aktivera MVE-instruktioner för att använda dessa inbyggda."
+msgstr "Du måste aktivera MVE-instruktioner för att använda dessa inbyggda"
 
 #: config/arm/arm-builtins.c:3381
 #, gcc-internal-format
@@ -34870,7 +34850,7 @@ msgstr "argument %2$qs till attribut %1$qs är okänt"
 #: config/i386/i386-options.c:1174
 #, gcc-internal-format
 msgid "attribute value %qs was already specified in %qs attribute"
-msgstr "attributvärdet %qs specifcerades redan i attributet %qs"
+msgstr "attributvärdet %qs specificerades redan i attributet %qs"
 
 #: config/i386/i386-options.c:1212
 #, gcc-internal-format
@@ -34952,12 +34932,12 @@ msgstr "%<-mabi=ms%> stödjs inte med X32 ABI"
 #: config/i386/i386-options.c:1870
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
-msgstr "%<-mabi=%s%> stödjs inte i med %<-fsanitize=address%>"
+msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=address%>"
 
 #: config/i386/i386-options.c:1873
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
-msgstr "%<-mabi=%s%> stödjs inte i med %<-fsanitize=kernel-address%>"
+msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=kernel-address%>"
 
 #: config/i386/i386-options.c:1877
 #, gcc-internal-format
@@ -35243,7 +35223,7 @@ msgstr "%s-instruktioner är inte tillåtna i en avbrottshanteringsrutin"
 #: config/i386/i386-options.c:3234
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
-msgstr "%s-instruktioner är inte tillåtna i en funktion attributet %<no_caller_saved_registers%>"
+msgstr "%s-instruktioner är inte tillåtna i en funktion med attributet %<no_caller_saved_registers%>"
 
 #: config/i386/i386-options.c:3281 config/i386/i386-options.c:3332
 #, gcc-internal-format
@@ -35575,17 +35555,17 @@ msgstr "definition av statisk datamedlem %q+D i dllimport:erad klass"
 #: config/i386/xm-djgpp.h:85
 #, gcc-internal-format
 msgid "environment variable DJGPP not defined"
-msgstr "omgivningsvariabeln DJGPP är inte definierad"
+msgstr "miljövariabeln DJGPP är inte definierad"
 
 #: config/i386/xm-djgpp.h:87
 #, gcc-internal-format
 msgid "environment variable DJGPP points to missing file %qs"
-msgstr "omgivningsvariabeln DJGPP pekar på en saknad fil %qs"
+msgstr "miljövariabeln DJGPP pekar på en saknad fil %qs"
 
 #: config/i386/xm-djgpp.h:90
 #, gcc-internal-format
 msgid "environment variable DJGPP points to corrupt file %qs"
-msgstr "omgivningsvariabeln DJGPP pekar på en trasig fil %qs"
+msgstr "miljövariabeln DJGPP pekar på en trasig fil %qs"
 
 #: config/ia64/ia64-c.c:50
 #, gcc-internal-format
@@ -36124,7 +36104,7 @@ msgstr "%<-mtune=%> förväntar sig mn10300, am33, am33-2 eller am34"
 #: config/msp430/driver-msp430.c:38
 #, gcc-internal-format
 msgid "expected an argument to %<msp430_select_cpu%>"
-msgstr "ett argument förväntades till till %<msp430_select_cpu%>"
+msgstr "ett argument förväntades till %<msp430_select_cpu%>"
 
 #: config/msp430/driver-msp430.c:69
 #, gcc-internal-format
@@ -36266,7 +36246,7 @@ msgstr "Okänt MCU-namn %qs."
 #: config/msp430/msp430.c:262
 #, gcc-internal-format
 msgid "%<-mlarge%> requires a 430X-compatible %<-mmcu=%>"
-msgstr "%<-mlarge%> behöver en 430X-kompatibel %<-mmcu=%<"
+msgstr "%<-mlarge%> behöver en 430X-kompatibel %<-mmcu=%>"
 
 #: config/msp430/msp430.c:265
 #, gcc-internal-format
@@ -37511,7 +37491,7 @@ msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har 
 #: config/rs6000/rs6000.c:9945
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you can't set it to other values."
-msgstr ""
+msgstr "%qs är en ogenomskinlig typ, och det går inte att sätta den till andra värden."
 
 #: config/rs6000/rs6000.c:16978
 #, gcc-internal-format
@@ -37696,6 +37676,7 @@ msgstr "%<-mcall-aixdesc%> är inkompatibel med %<-mabi=elfv2%>"
 msgid "%<-m64%> requires a PowerPC64 cpu"
 msgstr "%<-m64%> kräver en PowerPC64-CPU"
 
+# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=96248
 #: config/rs6000/linux64.h:142
 #, gcc-internal-format
 msgid "%<-mcmodel incompatible with other toc options%>"
@@ -37851,7 +37832,7 @@ msgstr "%qs-matchning kräver z15 eller högre"
 #: config/s390/s390-c.c:1002
 #, gcc-internal-format
 msgid "%qs matching variant is deprecated."
-msgstr "%qs-matchningsvariant bör undvikas"
+msgstr "%qs-matchningsvariant bör undvikas."
 
 #: config/s390/s390-c.c:1042
 #, gcc-internal-format
@@ -37942,7 +37923,7 @@ msgstr "%qs använder dynamisk stackallokering"
 #: config/s390/s390.c:12966
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
-msgstr "nästade funktioner kan inte profileras med %<-fentry%> på s390"
+msgstr "nästade funktioner kan inte profileras med %<-mfentry%> på s390"
 
 #: config/s390/s390.c:15224
 #, gcc-internal-format
@@ -39790,7 +39771,7 @@ msgstr "omdeklaration av %<enum %E%>"
 #: c/c-decl.c:8862 cp/decl.c:15545
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
-msgstr "angiven sort för liten för uppräkningvärden"
+msgstr "angiven sort för liten för uppräkningsvärden"
 
 #: c/c-decl.c:8877
 #, gcc-internal-format
@@ -40178,7 +40159,7 @@ msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 #: c/c-decl.c:11571
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
-msgstr "%<__auto_type%> följt av  %<[[]]%>-attribut"
+msgstr "%<__auto_type%> följt av %<[[]]%>-attribut"
 
 #: c/c-decl.c:11597 c/c-decl.c:11613 c/c-decl.c:11639
 #, gcc-internal-format
@@ -40972,7 +40953,7 @@ msgstr "decimalt flyttalsargument %u till endast binär typgenerisk funktion"
 #: c/c-parser.c:9727 c/c-parser.c:9757
 #, gcc-internal-format
 msgid "both complex and decimal floating-point arguments to type-generic function"
-msgstr "både komplexa och desimala flyttalsargument till en typgenerisk funktion"
+msgstr "både komplexa och decimala flyttalsargument till en typgenerisk funktion"
 
 #: c/c-parser.c:9735 c/c-parser.c:9777
 #, gcc-internal-format
@@ -41196,7 +41177,7 @@ msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 #: c/c-parser.c:12401 cp/parser.c:43868
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
-msgstr "%<#pragma omp scan%> får bara användas en slingkonstruktion med %<inscan%> %<reduction%>-klausul"
+msgstr "%<#pragma omp scan%> får bara användas i en slingkonstruktion med %<inscan%> %<reduction%>-klausul"
 
 #: c/c-parser.c:12408 cp/parser.c:43874
 #, gcc-internal-format
@@ -41375,7 +41356,7 @@ msgstr "%<concurrent%> förväntades"
 #: c/c-parser.c:14491 cp/parser.c:35577
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
-msgstr "%<teams%>, %<prarallel%> eller %<thread%> förväntades"
+msgstr "%<teams%>, %<parallel%> eller %<thread%> förväntades"
 
 #: c/c-parser.c:14544 cp/parser.c:35645
 #, gcc-internal-format
@@ -41600,7 +41581,7 @@ msgstr "för många atomära klausuler"
 #: c/c-parser.c:17303 cp/parser.c:37692
 #, gcc-internal-format
 msgid "too many memory order clauses"
-msgstr "för många ordningsklausuler"
+msgstr "för många minnesordningsklausuler"
 
 #: c/c-parser.c:17358 cp/parser.c:37747
 #, gcc-internal-format
@@ -41665,7 +41646,7 @@ msgstr "%<flush%>-lista specificerat tillsammans med minnesordningsklausul"
 #: c/c-parser.c:17975 cp/parser.c:38889
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
-msgstr "en %<includsive%>- eller %<exclusive%>-klausul förväntades"
+msgstr "en %<inclusive%>- eller %<exclusive%>-klausul förväntades"
 
 #: c/c-parser.c:17980 cp/parser.c:38895
 #, gcc-internal-format
@@ -41955,7 +41936,7 @@ msgstr "klausulen %qs på direktivet %<requires%> stödjs inte ännu"
 #: c/c-parser.c:21201 cp/parser.c:42716
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
-msgstr "klausulen %qs använd lexikalt efter första målkonstruktionern eller avlastnings-API:et"
+msgstr "klausulen %qs använd lexikalt efter första målkonstruktionen eller avlastnings-API:et"
 
 #: c/c-parser.c:21213 cp/parser.c:42728
 #, gcc-internal-format
@@ -41965,7 +41946,7 @@ msgstr "mer än en klausul %<atomic_default_mem_order%> i en enskild kompilering
 #: c/c-parser.c:21222 cp/parser.c:42737
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
-msgstr "klausulen %<atomic_default_mem_order%> använd lexikalt efter första konsstruktionen %<atomic%> utan minnesordningsklausul"
+msgstr "klausulen %<atomic_default_mem_order%> använd lexikalt efter första konstruktionen %<atomic%> utan minnesordningsklausul"
 
 #: c/c-parser.c:21236 cp/parser.c:42751
 #, gcc-internal-format
@@ -42484,7 +42465,7 @@ msgstr "pekartyper stämmer inte i villkorsuttryck"
 #: c/c-typeck.c:5384 c/c-typeck.c:5395
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
-msgstr "pekar-/heltalstyper stämmer inte  i villkorsuttryck"
+msgstr "pekar-/heltalstyper stämmer inte i villkorsuttryck"
 
 #: c/c-typeck.c:5409
 #, gcc-internal-format
@@ -42799,7 +42780,7 @@ msgstr "tilldelning till %qT från inkompatibel pekartyp %qT"
 #: c/c-typeck.c:7317
 #, gcc-internal-format
 msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
-msgstr "initiering av %qT från pekare til %qD inkompatibel typ %qT"
+msgstr "initiering av %qT från pekare till %qD med inkompatibel typ %qT"
 
 #: c/c-typeck.c:7322
 #, gcc-internal-format
@@ -42809,7 +42790,7 @@ msgstr "initiering av %qT från inkompatibel pekartyp %qT"
 #: c/c-typeck.c:7329
 #, gcc-internal-format
 msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
-msgstr "returnerar pekaer till %qD av typen %qT från en funktion med inkompatibel typ %qT"
+msgstr "returnerar pekare till %qD av typen %qT från en funktion med inkompatibel typ %qT"
 
 #: c/c-typeck.c:7334
 #, gcc-internal-format
@@ -42889,7 +42870,7 @@ msgstr "initiering av medlem som är en flexibel vektor"
 #: c/c-typeck.c:7804 cp/typeck2.c:1196
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
-msgstr "det går inte att initiera vektorn av %qT från en strängliteral med typvektor %qT"
+msgstr "det går inte att initiera vektorn av %qT från en stränglitteral med typvektor %qT"
 
 #: c/c-typeck.c:7844
 #, gcc-internal-format
@@ -43326,7 +43307,7 @@ msgstr "längden %qE i vektorsektion har inte heltalstyp"
 #: c/c-typeck.c:13066 cp/semantics.c:4888
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
-msgstr "en enda pekare förväntades i en %s-klausul"
+msgstr "en enda pekare förväntades i en %qs-klausul"
 
 #: c/c-typeck.c:13083 c/c-typeck.c:13149 c/c-typeck.c:13421
 #: cp/semantics.c:4905 cp/semantics.c:4971
@@ -43414,17 +43395,17 @@ msgstr "typ av iteratorn %qD refererar till den yttre iteratorn %qD"
 #: c/c-typeck.c:13723 cp/semantics.c:6241
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
-msgstr "startuttrycket refererar till den yttre iteratiorn %qD"
+msgstr "startuttrycket refererar till den yttre iteratorn %qD"
 
 #: c/c-typeck.c:13729 cp/semantics.c:6247
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
-msgstr "slututtrycket refererar till den yttre iteratiorn %qD"
+msgstr "slututtrycket refererar till den yttre iteratorn %qD"
 
 #: c/c-typeck.c:13735 cp/semantics.c:6253
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
-msgstr "steguttrycket refererar till den yttre iteratiorn %qD"
+msgstr "steguttrycket refererar till den yttre iteratorn %qD"
 
 #: c/c-typeck.c:13772 cp/semantics.c:6301
 #, gcc-internal-format
@@ -43597,7 +43578,7 @@ msgstr "%qE har inte en typ %<omp_depend_t%> i klausulen %<depend%> med beroende
 #: c/c-typeck.c:14447 cp/semantics.c:7247
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
-msgstr "%qE skall inte ha en typ %<omp_depend_t%> i klausulen %<depend%> med beroendetyp %<depobj%>"
+msgstr "%qE skall inte ha en typ %<omp_depend_t%> i klausulen %<depend%> med annan beroendetyp än %<depobj%>"
 
 #: c/c-typeck.c:14490 cp/semantics.c:7292
 #, gcc-internal-format
@@ -43716,7 +43697,7 @@ msgstr "andra argumentet till %<va_arg%> är av ofullständig typ %qT"
 #: c/c-typeck.c:15256
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
-msgstr "C++ kräver en befordrad typ, inte en uppräkningstyp, i %<va_arg%>"
+msgstr "C++ kräver en befordrad typ, inte en enum-typ, i %<va_arg%>"
 
 #: c/gimple-parser.c:166
 #, gcc-internal-format
@@ -43761,7 +43742,7 @@ msgstr "slingnummer förväntades"
 #: c/gimple-parser.c:539
 #, gcc-internal-format
 msgid "unknown block specifier"
-msgstr "okänd blockspecifiserare"
+msgstr "okänd blockspecificerare"
 
 #: c/gimple-parser.c:552 c/gimple-parser.c:1942
 #, gcc-internal-format
@@ -43958,7 +43939,7 @@ msgstr "%s%#qD (raderad)"
 #: cp/call.c:3737
 #, gcc-internal-format
 msgid "%s%#qD (reversed)"
-msgstr "%s%#qD (raderad)"
+msgstr "%s%#qD (omvänd)"
 
 #: cp/call.c:3739
 #, gcc-internal-format
@@ -44907,7 +44888,7 @@ msgstr "icke-statisk datamedlem %q+D i en union får inte ha referenstyp %qT"
 #: cp/class.c:3631
 #, gcc-internal-format
 msgid "data member %q+D invalidly declared function type"
-msgstr "datamedlammen %q+D ogiltigt deklarerad funktionstyp"
+msgstr "datamedlemmen %q+D ogiltigt deklarerad funktionstyp"
 
 #: cp/class.c:3637
 #, gcc-internal-format
@@ -45323,12 +45304,12 @@ msgstr "den statiska typen %qT av sin operand är en icke-publik basklass av den
 #: cp/constexpr.c:2016
 #, gcc-internal-format
 msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
-msgstr "%qT är en tvetydig basklass till den dynamiska type %qT av sin operand"
+msgstr "%qT är en tvetydig basklass till den dynamiska typen %qT av sin operand"
 
 #: cp/constexpr.c:2019
 #, gcc-internal-format
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
-msgstr "den dynamiska typen %qT av sin operan har inte en otvetydig publik basklass %qT"
+msgstr "den dynamiska typen %qT av sin operand har inte en otvetydig publik basklass %qT"
 
 #: cp/constexpr.c:2144
 #, gcc-internal-format
@@ -45464,7 +45445,7 @@ msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 #: cp/constexpr.c:4471
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
-msgstr "innehållet av den oinitierade lagringen inte användbart i ett konstant uttryck"
+msgstr "innehållet av den oinitierade lagringen är inte användbart i ett konstant uttryck"
 
 #: cp/constexpr.c:4473 cp/constexpr.c:4480
 #, gcc-internal-format
@@ -45544,7 +45525,7 @@ msgstr "inline-assembler är inte ett konstant uttryck"
 #: cp/constexpr.c:5440
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++2a"
-msgstr "endast oevaluerade inline:ade assember är tillåten i en %<constexpr%>-funktion i C++2a"
+msgstr "endast oevaluerad inline:ad assembler är tillåten i en %<constexpr%>-funktion i C++2a"
 
 #: cp/constexpr.c:5505
 #, gcc-internal-format
@@ -45554,7 +45535,7 @@ msgstr "värdet %qE av typen %qT är inte ett konstant uttryck"
 #: cp/constexpr.c:5518
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
-msgstr "antalet %<constexpr%>-evalueringsoperationer överskrider gränsen på %wd (använd %<-fconstexpr-loop-limit=%> för att öka gränsen)"
+msgstr "antalet %<constexpr%>-evalueringsoperationer överskrider gränsen på %wd (använd %<-fconstexpr-ops-limit=%> för att öka gränsen)"
 
 #: cp/constexpr.c:5700 cp/constexpr.c:8003
 #, gcc-internal-format
@@ -45589,7 +45570,7 @@ msgstr "oväntat mall-id %qE"
 #: cp/constexpr.c:6406
 #, gcc-internal-format
 msgid "function concept must be called"
-msgstr "funktionkoncept måste anropas"
+msgstr "funktionskoncept måste anropas"
 
 #: cp/constexpr.c:6436
 #, gcc-internal-format
@@ -45715,7 +45696,7 @@ msgstr "oväntat AST av sorten %s"
 #: cp/cp-gimplify.c:214
 #, gcc-internal-format
 msgid "both branches of %<if%> statement marked as %qs"
-msgstr "båda grenarna av en %<if%>-satsen markerad som %qs"
+msgstr "båda grenarna av en %<if%>-sats markerad som %qs"
 
 #: cp/cp-gimplify.c:1596
 #, gcc-internal-format
@@ -46574,7 +46555,7 @@ msgstr "mallparametrar stämmer inte med mallen %qD"
 #: cp/decl.c:4400
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
-msgstr "%<-faligned-new=%d%> är inte en exponent av två"
+msgstr "%<-faligned-new=%d%> är inte en potens av två"
 
 #: cp/decl.c:4892
 #, gcc-internal-format
@@ -47282,7 +47263,7 @@ msgstr "konceptet %qD har ingen definition"
 #: cp/decl.c:9379
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
-msgstr "ett funktionkoncept kan inte begränsas"
+msgstr "ett funktionskoncept kan inte begränsas"
 
 #: cp/decl.c:9387
 #, gcc-internal-format
@@ -47602,7 +47583,7 @@ msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 #: cp/decl.c:10705
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
-msgstr "kvalificerare är inte tillåtna vid kontruerardeklaration"
+msgstr "kvalificerare är inte tillåtna vid konstruerardeklaration"
 
 #: cp/decl.c:10716
 #, gcc-internal-format
@@ -47732,7 +47713,7 @@ msgstr "%qs kan inte förekomma i en typedef-deklaration"
 #: cp/decl.c:11289
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
-msgstr "man kan använda högst en av specificerarna %<constinit%> och %<constexpr%> specifiers"
+msgstr "man kan använda högst en av specificerarna %<constinit%> och %<constexpr%>"
 
 #: cp/decl.c:11299
 #, gcc-internal-format
@@ -48641,22 +48622,22 @@ msgstr "konvertering av %qT till %<void%> kommer aldrig använda en typkonverter
 #: cp/decl.c:14554
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
-msgstr "konvertering till %qT till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
+msgstr "konvertering av %qT till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
 #: cp/decl.c:14556
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
-msgstr "konvertering till %qT till samma typ kommer aldrig använda en typkonverteringsoperator"
+msgstr "konvertering av %qT till samma typ kommer aldrig använda en typkonverteringsoperator"
 
 #: cp/decl.c:14565
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
-msgstr "konvertering till %qT till en referens till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
+msgstr "konvertering av %qT till en referens till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
 #: cp/decl.c:14567
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
-msgstr "konvertering till %qT till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
+msgstr "konvertering av %qT till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
 #: cp/decl.c:14583
 #, gcc-internal-format
@@ -48770,7 +48751,7 @@ msgstr "%qT definierad med flera direkta baser"
 #: cp/decl.c:15129
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
-msgstr "%qT definerad med en direkt virtuell bas"
+msgstr "%qT definierad med en direkt virtuell bas"
 
 #: cp/decl.c:15154
 #, gcc-internal-format
@@ -48930,7 +48911,7 @@ msgstr "malldeklaration av %q#D"
 #: cp/decl2.c:622
 #, gcc-internal-format
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
-msgstr "mallparametrerlistan som ges stämmer inte mallparametrarna till %qD"
+msgstr "mallparameterlistan som ges stämmer inte mallparametrarna till %qD"
 
 #: cp/decl2.c:637 cp/pt.c:5733
 #, gcc-internal-format
@@ -49119,7 +49100,7 @@ msgstr "en förstörande %<operator delete%> måste vara medlemsfunktion"
 #: cp/decl2.c:1841
 #, gcc-internal-format
 msgid "%<operator delete[]%> cannot be a destroying delete"
-msgstr "%<operator delete[]%> kan inte vara en förstörade delete"
+msgstr "%<operator delete[]%> kan inte vara en förstörande delete"
 
 #: cp/decl2.c:1843
 #, gcc-internal-format
@@ -49253,7 +49234,7 @@ msgstr "implicit deklarerad %qD bör undvikas"
 #: cp/decl2.c:5423
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
-msgstr "för att %qT ha användarleverad %qD"
+msgstr "för att %qT har användarlevererad %qD"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
@@ -49551,7 +49532,7 @@ msgstr "vändeklaration %q#D deklarerar en icke-mall-funktion"
 #: cp/friend.c:641
 #, gcc-internal-format
 msgid "(if this is not what you intended, make sure the function template has already been declared and add %<<>%> after the function name here)"
-msgstr "(om detta inte är vad du avsåg, se till att funktionsmallen redan har deklarerats och lägg till %<<>%> efter funktionsnamnet här) "
+msgstr "(om detta inte är vad du avsåg, se till att funktionsmallen redan har deklarerats och lägg till %<<>%> efter funktionsnamnet här)"
 
 #: cp/init.c:393
 #, gcc-internal-format
@@ -50110,31 +50091,29 @@ msgid "defaulted %qD must be %<const%>"
 msgstr "standarddefinierad %qD måste vara %<const%>"
 
 #: cp/method.c:1128
-#, fuzzy, gcc-internal-format
-#| msgid "non-member function %qD cannot have ref-qualifier"
+#, gcc-internal-format
 msgid "defaulted %qD must not have %<&&%> ref-qualifier"
-msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
+msgstr "standarddefinierad %qD får inte ha en %<&&%> ref-kvalificerare"
 
 #: cp/method.c:1155
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is already a friend of %qT"
+#, gcc-internal-format
 msgid "defaulted %qD is not a friend of %qT"
-msgstr "%qD är redan en vän till %qT"
+msgstr "standarddefinierad %qD är inte en vän till %qT"
 
 #: cp/method.c:1164
 #, gcc-internal-format
 msgid "defaulted member %qD must have parameter type %<const %T&%>"
-msgstr "standarddefinerad medlem %qD måste ha parametertyp %<const %T&%>"
+msgstr "standarddefinierad medlem %qD måste ha parametertyp %<const %T&%>"
 
 #: cp/method.c:1167
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
-msgstr "standarddefinerad %qD måste ha parametrar av antingen typen %<const %T&%> eller %qT"
+msgstr "standarddefinierad %qD måste ha parametrar av antingen typen %<const %T&%> eller %qT"
 
 #: cp/method.c:1170
 #, gcc-internal-format
 msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
-msgstr "standarddefinerad %qD måste ha parametrar av antingen typen %<const %T&%> eller %qT, inte båda"
+msgstr "standarddefinierad %qD måste ha parametrar av antingen typen %<const %T&%> eller %qT, inte båda"
 
 #: cp/method.c:1324
 #, gcc-internal-format
@@ -50154,12 +50133,12 @@ msgstr "det går inte att standardjämföra en anonym unions medlem"
 #: cp/method.c:1394
 #, gcc-internal-format
 msgid "three-way comparison of %qD has type %qT, not a comparison category type"
-msgstr ""
+msgstr "trevägsjämförelsen av %qD har typen %qT, inte en jämförelsekategorityp"
 
 #: cp/method.c:1605
 #, gcc-internal-format
 msgid "synthesized method %qD first required here"
-msgstr "syntetiserad metod %qD krävs första gången här "
+msgstr "syntetiserad metod %qD krävs första gången här"
 
 #: cp/method.c:1974
 #, gcc-internal-format
@@ -50264,7 +50243,7 @@ msgstr "standarddefinierad funktion %q+D med standardargument"
 #: cp/name-lookup.c:2272
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
-msgstr "omdeklaration av %q+#D med andra mallparametrar"
+msgstr "omdeklaration av %q#D med andra mallparametrar"
 
 #: cp/name-lookup.c:2278
 #, gcc-internal-format
@@ -50843,7 +50822,7 @@ msgstr "flyttalskonstant avkortas till noll"
 #: cp/parser.c:4543
 #, gcc-internal-format
 msgid "failed to translate literal to execution character set %qT"
-msgstr "misslyckades att översätta literalen till körningsteckenuppsättningen %qT"
+msgstr "misslyckades att översätta litteralen till körningsteckenuppsättningen %qT"
 
 #: cp/parser.c:4577
 #, gcc-internal-format
@@ -51003,7 +50982,7 @@ msgstr "funktionsmalls-id %qD i nästad namnspecificerare"
 #: cp/parser.c:6536
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
-msgstr "variabelmall-id %qD  i nästad namnspecificerare"
+msgstr "variabelmall-id %qD i nästad namnspecificerare"
 
 #: cp/parser.c:6710
 #, gcc-internal-format
@@ -51071,10 +51050,9 @@ msgid "types may not be defined in %qs expressions"
 msgstr "typer får inte definieras i en %qs-uttryck"
 
 #: cp/parser.c:8683
-#, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_thread_pointer%> is not supported on this target"
+#, gcc-internal-format
 msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
-msgstr "%<__builtin_thread_pointer%> stödjs inte på denna målarkitektur"
+msgstr "%<__builtin_has_attribute%> med beroende argument stödjs inte ännu"
 
 #: cp/parser.c:8769
 #, gcc-internal-format
@@ -51330,7 +51308,7 @@ msgstr "intervallbaserat %<for%>-uttryck av typen %qT har ofullständig typ"
 #: cp/parser.c:12785
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
-msgstr "inkonsistenta start-/sluttyper i intervallbaserat %<for%>-sats: %qT och %qT"
+msgstr "inkonsistenta start-/sluttyper i intervallbaserad %<for%>-sats: %qT och %qT"
 
 #: cp/parser.c:12928 cp/parser.c:30681
 #, gcc-internal-format
@@ -51622,7 +51600,7 @@ msgstr "ett funktionsnamn som vänster operand av %<<%> är felformad i C++2a; s
 #: cp/parser.c:16694
 #, gcc-internal-format
 msgid "expected %<(%> after template-argument-list"
-msgstr "%<(%> förväntadess efter mallargumentlista"
+msgstr "%<(%> förväntades efter mallargumentlista"
 
 #: cp/parser.c:16798
 #, gcc-internal-format
@@ -52140,7 +52118,7 @@ msgstr "%<...%> är inte tillåtet i en designerad initierarlista"
 #: cp/parser.c:23580
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
-msgstr "designeraren %<.%s%> använd flera gånger i samma intierarlista"
+msgstr "designeraren %<.%s%> använd flera gånger i samma initierarlista"
 
 #: cp/parser.c:23639 cp/parser.c:23767
 #, gcc-internal-format
@@ -52356,7 +52334,7 @@ msgstr "en identifierare förväntades som attributnamn"
 #: cp/parser.c:26920
 #, gcc-internal-format
 msgid "parentheses must be omitted if %qE attribute argument list is empty"
-msgstr "parenteser måste utelämnas om %qE-attributargumentlistan är tom"
+msgstr "parenteser måste utelämnas om argumentlistan till attributet %qE är tom"
 
 #: cp/parser.c:26949
 #, gcc-internal-format
@@ -52396,7 +52374,7 @@ msgstr "resultattypen är inte en enkel typbegränsning"
 #: cp/parser.c:28081
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
-msgstr "returtybskravet är inte en typbegränsning"
+msgstr "returtypskravet är inte en typbegränsning"
 
 #: cp/parser.c:28572
 #, gcc-internal-format
@@ -52430,7 +52408,7 @@ msgstr "namngivna returvärden stödjs inte längre"
 #: cp/parser.c:29152
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
-msgstr "ISO C++ antog inte mallar för strängliteralsoperatorer som tar argumentpaket av tecken"
+msgstr "ISO C++ antog inte mallar för stränglitteralsoperatorer som tar argumentpaket av tecken"
 
 #: cp/parser.c:29161
 #, gcc-internal-format
@@ -52826,7 +52804,7 @@ msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 #: cp/parser.c:39056
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
-msgstr "en %<ordered%>-klausul med parameter på en intervallbaserat %<for%>-slinga"
+msgstr "en %<ordered%>-klausul med parameter på en intervallbaserad %<for%>-slinga"
 
 #: cp/parser.c:39143 cp/pt.c:17593
 #, gcc-internal-format
@@ -52927,7 +52905,7 @@ msgstr "skräp vid slutet av %<#pragma GCC pch_preprocess%>"
 #: cp/parser.c:43840
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
-msgstr "%<pragma omp requires%> kan endast användas med fil- eller namnrymdsräckvidd"
+msgstr "%<#pragma omp requires%> kan endast användas med fil- eller namnrymdsräckvidd"
 
 #: cp/parser.c:43883
 #, gcc-internal-format
@@ -54012,7 +53990,7 @@ msgstr "ogiltig användning av paketexpansionsuttryck"
 #: cp/pt.c:16944 cp/pt.c:18748
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
-msgstr "använd %<...%>  för att expandera argumentpaket"
+msgstr "använd %<...%> för att expandera argumentpaket"
 
 #: cp/pt.c:18886
 #, gcc-internal-format
@@ -54488,7 +54466,7 @@ msgstr "ett satsuttryck är otillräckligt sammanhang för upplösning av överl
 #: cp/semantics.c:2610
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
-msgstr "det går inte att anropa et koncept som en funktion"
+msgstr "det går inte att anropa ett koncept som en funktion"
 
 #: cp/semantics.c:2678
 #, gcc-internal-format
@@ -55908,7 +55886,7 @@ msgstr "adress till lokal variabel %qD returnerad"
 #: cp/typeck.c:9800
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
-msgstr "att flytta ett lokalt objekt i en retursats förhindrar att kopiering undviks."
+msgstr "att flytta ett lokalt objekt i en retursats förhindrar att kopiering undviks"
 
 #: cp/typeck.c:9802 cp/typeck.c:9825
 #, gcc-internal-format
@@ -56515,7 +56493,7 @@ msgstr "Teckenkonstanten vid %L huggs av i konverteringen till %s"
 #: fortran/array.c:98 fortran/array.c:130 fortran/array.c:151
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid BOZ literal constant used in subscript at %C"
-msgstr "Felaktig BOZ-litteralkonstant använd index vid %C"
+msgstr "Felaktig BOZ-litteralkonstant använd i index vid %C"
 
 #: fortran/array.c:103
 #, gcc-internal-format, gfc-internal-format
@@ -57020,10 +56998,9 @@ msgid "Different type kinds at %L"
 msgstr "Olika typsorter vid %L"
 
 #: fortran/check.c:1439
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
+#, gcc-internal-format
 msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
-msgstr "NULL-pekare vid %L är inte tillåtet som aktuellt argument till inbyggd funktion %qs"
+msgstr "NULL vid %L är inte tillåtet som aktuellt argument till den inbyggda funktionen %qs"
 
 #: fortran/check.c:1461
 #, gcc-internal-format
@@ -57299,7 +57276,7 @@ msgstr "COMPLEX-argumentet %qs till inbyggd %qs vid %L"
 #: fortran/check.c:3063
 #, gcc-internal-format
 msgid "Arguments of %qs have different kind type parameters at %L"
-msgstr "Argument till %qs har olika sorts typeparametrar vid %L"
+msgstr "Argument till %qs har olika sorts typparametrar vid %L"
 
 #: fortran/check.c:3159
 #, gcc-internal-format, gfc-internal-format
@@ -57569,7 +57546,7 @@ msgstr "is_c_interoperable(): gfc_simplify_expr misslyckades"
 #: fortran/check.c:5300
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
-msgstr "Argumentet %qs till inbyggd %qs vid %L måste vara en interoperabel dataenhet: %s"
+msgstr "Argumentet %qs till inbyggd %qs vid %L måste vara en interoperabel dataentitet: %s"
 
 #: fortran/check.c:5339
 #, gcc-internal-format, gfc-internal-format
@@ -57774,7 +57751,7 @@ msgstr "argumentet %<MOLD%> till den inbyggda %<TRANSFER%> vid %L är en vektor
 #: fortran/check.c:6180
 #, gcc-internal-format
 msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
-msgstr "%<MOLD%>-argumentet till inbyggd %<TRANSFER%> vid %L får inte vara %s"
+msgstr "%<SOURCE%>-argumentet till inbyggd %<TRANSFER%> vid %L får inte vara %s"
 
 #: fortran/check.c:6199
 #, gcc-internal-format
@@ -57814,7 +57791,7 @@ msgstr "För många argument till %s vid %L"
 #: fortran/check.c:6701
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
-msgstr "fe_runtime_error-sträng måste vara null-terminerad"
+msgstr "fe_runtime_error-sträng måste vara null-avslutad"
 
 #: fortran/check.c:6713
 #, gcc-internal-format, gfc-internal-format
@@ -57859,7 +57836,7 @@ msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER, LOGICAL elle
 #: fortran/check.c:7458
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
-msgstr "Den inbyggda funktionen NULL vid %L kan inte vara ett aktuellt argument till STORATE_SIZE, eftersom den returnerar en disassocierad pekare"
+msgstr "Den inbyggda funktionen NULL vid %L kan inte vara ett aktuellt argument till STORAGE_SIZE, eftersom den returnerar en disassocierad pekare"
 
 #: fortran/class.c:648
 #, gcc-internal-format, gfc-internal-format
@@ -57931,7 +57908,7 @@ msgstr "ominitiering av %qs vid %L"
 #: fortran/data.c:515
 #, gcc-internal-format
 msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
-msgstr "Objectet %qs som inte är en pekare, med standardinitierare skall inte förekomma i en DATA-sats vid %L"
+msgstr "Objektet %qs som inte är en pekare, med standardinitierare skall inte förekomma i en DATA-sats vid %L"
 
 #: fortran/data.c:738
 #, gcc-internal-format
@@ -57966,7 +57943,7 @@ msgstr "Ogiltig initierare %s på DATA-sats vid %C"
 #: fortran/decl.c:587
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable in an old-style initialization"
-msgstr "literal BOZZ-konstant nära %L kan inte tilldelas till en %qs-variabel i en initiering i gammal stil"
+msgstr "litteral BOZ-konstant nära %L kan inte tilldelas till en %qs-variabel i en initiering i gammal stil"
 
 #: fortran/decl.c:597
 #, gcc-internal-format, gfc-internal-format
@@ -58411,7 +58388,7 @@ msgstr "BOZ-litteralkonstanten vid %L kan inte förekomma som en initierare"
 #: fortran/decl.c:2970
 #, gcc-internal-format
 msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
-msgstr "Inkomatibel initiering mellan en härledd typenhet och en enhet med typen %qs vid %C"
+msgstr "Inkompatibel initiering mellan en härledd typentitet och en entitet med typen %qs vid %C"
 
 #: fortran/decl.c:3033 fortran/decl.c:3069
 #, gcc-internal-format, gfc-internal-format
@@ -58564,7 +58541,7 @@ msgstr "CLASS-sats vid %C"
 #: fortran/decl.c:4443
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
-msgstr "Typnamnet %qs vid %C står i konflikt med tidigare deklarerad enhet vid %L, som har samma namn"
+msgstr "Typnamnet %qs vid %C står i konflikt med tidigare deklarerad entitet vid %L, som har samma namn"
 
 #: fortran/decl.c:4586
 #, gcc-internal-format, gfc-internal-format
@@ -58624,7 +58601,7 @@ msgstr "Det går inte att IMPORT:era %qs från värdräckviddsenhet vid %C — f
 #: fortran/decl.c:4931
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
-msgstr "%qs är redan IMPORT:erad från värdräckviddsenhet vid %C."
+msgstr "%qs är redan IMPORT:erad från värdräckviddsenhet vid %C"
 
 #: fortran/decl.c:4972
 #, gcc-internal-format, gfc-internal-format
@@ -60019,7 +59996,7 @@ msgstr "transformerande inbyggd %qs vid %L är inte tillåten i ett initieringsu
 #: fortran/expr.c:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of nonstandard initialization expression at %L"
-msgstr "Beräkning av ett initieringuttryck utanför standarden vid %L"
+msgstr "Beräkning av ett initieringsuttryck utanför standarden vid %L"
 
 #: fortran/expr.c:2909 fortran/resolve.c:2720
 #, gcc-internal-format
@@ -60185,7 +60162,7 @@ msgstr "POINTER-värd funktion förekommer på högersidan av tilldelning vid %L
 #: fortran/expr.c:3734
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
-msgstr "literal BOZ-konstant nära %L kan inte tilldelas till en %qs-variabel"
+msgstr "litteral BOZ-konstant nära %L kan inte tilldelas till en %qs-variabel"
 
 #: fortran/expr.c:3741
 #, gcc-internal-format, gfc-internal-format
@@ -60358,7 +60335,7 @@ msgstr "Måluttryck i pekartilldelning vid %L måste leverera ett pekarresultat"
 #: fortran/expr.c:4284
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
-msgstr "Målet för pekartilldelingen i initieraruttrycket har inte attributet TARGET vid %L"
+msgstr "Målet för pekartilldelningen i initieraruttrycket har inte attributet TARGET vid %L"
 
 #: fortran/expr.c:4294
 #, gcc-internal-format, gfc-internal-format
@@ -60488,7 +60465,7 @@ msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett variabeldefini
 #: fortran/expr.c:6215
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
-msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
+msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L i en PURE-procedur"
 
 #: fortran/expr.c:6274
 #, gcc-internal-format
@@ -60825,7 +60802,7 @@ msgstr "Ordning stämmer inte i argument %qs vid %L (ordning %d och ordning %d)"
 #: fortran/interface.c:2228
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
-msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt afgument vid %L (skalär och ordning %d)"
+msgstr "Ordning stämmer inte mellan aktuellt argument vid %L och aktuellt argument vid %L (skalär och ordning %d)"
 
 #: fortran/interface.c:2232
 #, gcc-internal-format, gfc-internal-format
@@ -60880,7 +60857,7 @@ msgstr "Aktuellt argument till %qs vid %L måste ha samma deklarerade typ"
 #: fortran/interface.c:2471
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
-msgstr "Aktuella argument till %qs vid %L måste vara obegränsat polymorfa eftersom det formella argumentet är en pekare eller allokerbar obegränsat polymorf enhet [F2008: 12.5.2.5]"
+msgstr "Aktuella argument till %qs vid %L måste vara obegränsat polymorfa eftersom det formella argumentet är en pekare eller allokerbar obegränsat polymorf entitet [F2008: 12.5.2.5]"
 
 #: fortran/interface.c:2482
 #, gcc-internal-format
@@ -60975,12 +60952,12 @@ msgstr "Fler aktuella än formella argument i proceduranrop vid %L"
 #: fortran/interface.c:3110
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing alternate return specifier in subroutine call at %L"
-msgstr "Alternativ returspecifierare saknas i subrutinanrop vid %L"
+msgstr "Alternativ returspecificerare saknas i subrutinanrop vid %L"
 
 #: fortran/interface.c:3122
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected alternate return specifier in subroutine call at %L"
-msgstr "Oväntad alternativ returspecifierare i subrutinanrop vid %L"
+msgstr "Oväntad alternativ returspecificerare i subrutinanrop vid %L"
 
 #: fortran/interface.c:3151
 #, gcc-internal-format
@@ -61295,7 +61272,7 @@ msgstr "Resultaten stämmer inte överens för den åsidosättande proceduren %q
 #: fortran/interface.c:4824
 #, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
-msgstr "%qs vid %L åsidosätter en PURE-procedur och får inte vara PRIVATE"
+msgstr "%qs vid %L åsidosätter en PUBLIC-procedur och får inte vara PRIVATE"
 
 #: fortran/interface.c:4854
 #, gcc-internal-format
@@ -61425,17 +61402,17 @@ msgstr "make_generic(): Kan inte hitta den generiska symbolen %qs"
 #: fortran/intrinsic.c:4267
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATED intrinsic at %L requires an array or scalar allocatable entity"
-msgstr "ALLOCATED inbyggd vid %L kräver en vektor eller skalär allokerbar enhet"
+msgstr "ALLOCATED inbyggd vid %L kräver en vektor eller skalär allokerbar entitet"
 
 #: fortran/intrinsic.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar entity required at %L"
-msgstr "En skalär enhet krävs vid %L"
+msgstr "En skalär entitet krävs vid %L"
 
 #: fortran/intrinsic.c:4291
 #, gcc-internal-format, gfc-internal-format
 msgid "Array entity required at %L"
-msgstr "En vektorenhet krävs vid %L"
+msgstr "En vektorentitet krävs vid %L"
 
 #: fortran/intrinsic.c:4298
 #, gcc-internal-format
@@ -61634,7 +61611,7 @@ msgstr "Vänsterparentes krävs efter %<*%> i formatsträngen vid %L"
 #: fortran/io.c:685
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected P edit descriptor in format string at %L"
-msgstr "P-redigeringsbeskrivare förvändades i formatsträng vid %L"
+msgstr "P-redigeringsbeskrivare förväntades i formatsträng vid %L"
 
 #. P requires a prior number.
 #: fortran/io.c:693
@@ -61720,7 +61697,7 @@ msgstr "Högerparentes förväntades vid %C i formatsträngen vid %L"
 #: fortran/io.c:1108
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier in format string at %L"
-msgstr "Punkt krävs i formatspecifieraren i formatsträngen vid %L"
+msgstr "Punkt krävs i formatspecificeraren i formatsträngen vid %L"
 
 #: fortran/io.c:1114
 #, gcc-internal-format, gfc-internal-format
@@ -62146,7 +62123,7 @@ msgstr "Intern fil vid %L med namnlista"
 #: fortran/io.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
-msgstr "IO UNIT i %s-satsen vid %L måste en intern fil i en PURE-procedur"
+msgstr "IO UNIT i %s-satsen vid %L måste vara en intern fil i en PURE-procedur"
 
 #: fortran/io.c:3944
 #, gcc-internal-format, gfc-internal-format
@@ -62367,7 +62344,7 @@ msgstr "Blocketikett är inte tillämplig för IF-sats vid %C"
 #: fortran/match.c:1679 fortran/match.c:1686
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IF-clause after %C"
-msgstr " Syntaxfel i IF-klausul efter %C"
+msgstr "Syntaxfel i IF-klausul efter %C"
 
 #: fortran/match.c:1729
 #, gcc-internal-format, gfc-internal-format
@@ -62670,12 +62647,12 @@ msgstr "Överflödig UNTIL_COUNT-tagg funnen vid %L"
 #: fortran/match.c:3421
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
-msgstr "ENTRY POST-sats vid %C"
+msgstr "EVENT POST-sats vid %C"
 
 #: fortran/match.c:3431
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
-msgstr "ENTRY WAIT-sats vid %C"
+msgstr "EVENT WAIT-sats vid %C"
 
 #: fortran/match.c:3443
 #, gcc-internal-format, gfc-internal-format
@@ -62825,7 +62802,7 @@ msgstr "Entitetens typ vid %L är typinkompatibel med typspecifikationen"
 #: fortran/match.c:4385
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
-msgstr "Sorttypparameter för enheten vid %L skiljer sig från sorttypparametern i typspecifikationen"
+msgstr "Sorttypparameter för entiteten vid %L skiljer sig från sorttypparametern i typspecifikationen"
 
 #: fortran/match.c:4402
 #, gcc-internal-format, gfc-internal-format
@@ -62965,7 +62942,7 @@ msgstr "Typbunden procedurreferens eller procedurpekarkomponent förväntades vi
 #: fortran/match.c:5052
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
-msgstr "En literal BOZ-konstant vid %L kan inte förekomma som ett faktiskt argument i en subrutinreferens"
+msgstr "En litteral BOZ-konstant vid %L kan inte förekomma som ett faktiskt argument i en subrutinreferens"
 
 #: fortran/match.c:5192
 #, gcc-internal-format, gfc-internal-format
@@ -63098,7 +63075,7 @@ msgstr "Blocknamnet %qs förväntades av SELECT-konstruktionen vid %C"
 #: fortran/match.c:6401
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT TYPE at %C cannot appear in this scope"
-msgstr "SELECT SCOP vid %C får inte förekomma i denna räckvidd"
+msgstr "SELECT TYPE vid %C får inte förekomma i denna räckvidd"
 
 #: fortran/match.c:6442
 #, gcc-internal-format, gfc-internal-format
@@ -63790,7 +63767,7 @@ msgstr "Oväntat skräp efter TASKYIELD-klausul vid %C"
 #: fortran/openmp.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
-msgstr "Oväntat skräp efter $OMP ORDERED-sats vid %C"
+msgstr "Oväntat skräp efter $OMP WORKSHARE-sats vid %C"
 
 #: fortran/openmp.c:3665
 #, gcc-internal-format, gfc-internal-format
@@ -64510,7 +64487,7 @@ msgstr "Fast radlängd måste vara minst sju"
 #: fortran/options.c:482
 #, gcc-internal-format
 msgid "Free line length must be at least three"
-msgstr "Fri radlängd måste vara minst tre."
+msgstr "Fri radlängd måste vara minst tre"
 
 #: fortran/options.c:485
 #, gcc-internal-format, gfc-internal-format
@@ -64935,7 +64912,7 @@ msgstr "CRITICAL-block inuti OpenACC-region vid %C"
 #: fortran/parse.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
-msgstr "CRITICAL-block i unuti OpenMP-region vid %C"
+msgstr "CRITICAL-block inuti OpenMP-region vid %C"
 
 #: fortran/parse.c:4542
 #, gcc-internal-format, gfc-internal-format
@@ -65308,7 +65285,7 @@ msgstr "Co-vektorbeteckning vid %C men %qs är inte en co-vektor"
 #: fortran/primary.c:2205
 #, gcc-internal-format
 msgid "Symbol %qs at %C has no IMPLICIT type"
-msgstr "Symbolen  %qs vid %C har ingen IMPLICIT-typ"
+msgstr "Symbolen %qs vid %C har ingen IMPLICIT-typ"
 
 #: fortran/primary.c:2212
 #, gcc-internal-format
@@ -65725,12 +65702,12 @@ msgstr "I Fortran 2003 är COMMON %qs-block vid %L en global identifierare och m
 #: fortran/resolve.c:1040
 #, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
-msgstr "COMMON-block %qs vid %L använder samma globala identifierare som en enhet vid %L"
+msgstr "COMMON-block %qs vid %L använder samma globala identifierare som en entitet vid %L"
 
 #: fortran/resolve.c:1048
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
-msgstr "Fortran 2008: COMMON-block %qs med bindningsetikett vid %L delar identifierare med ett globalt ej-COMMON-blockenhet vid %L"
+msgstr "Fortran 2008: COMMON-block %qs med bindningsetikett vid %L delar identifierare med ett globalt ej-COMMON-blockentitet vid %L"
 
 #: fortran/resolve.c:1070
 #, gcc-internal-format
@@ -65795,7 +65772,7 @@ msgstr "Elementet i postkonstrueraren vid %L, för pekarkomponent %qs, borde var
 #: fortran/resolve.c:1477
 #, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
-msgstr "Ogiltigt uttryck i postkonstrueraren för pekarkomponent %qs vidl %L i PURE-procedur"
+msgstr "Ogiltigt uttryck i postkonstrueraren för pekarkomponent %qs vid %L i PURE-procedur"
 
 #: fortran/resolve.c:1601
 #, gcc-internal-format
@@ -65835,7 +65812,7 @@ msgstr "Den inbyggda %qs deklarerad INTRINSIC vid %L är inte tillgänglig i den
 #: fortran/resolve.c:1861
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
-msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>."
+msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>"
 
 #: fortran/resolve.c:1919 fortran/resolve.c:10182 fortran/resolve.c:11881
 #, gcc-internal-format, gfc-internal-format
@@ -65875,7 +65852,7 @@ msgstr "Det går inte att hitta en angiven INTRINSIC-procedur för referensen %q
 #: fortran/resolve.c:2041
 #, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
-msgstr "Symbolen  %qs vid %L är tvetydig"
+msgstr "Symbolen %qs vid %L är tvetydig"
 
 #: fortran/resolve.c:2096
 #, gcc-internal-format, gfc-internal-format
@@ -65990,7 +65967,7 @@ msgstr "ABSTRACT INTERFACE %qs får inte refereras vid %L"
 #: fortran/resolve.c:3173
 #, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
-msgstr "ABSTRACT INTERFACE %qs vid %L får inte ha ett antagen teckenlängdsresultat (F2008: C418)"
+msgstr "ABSTRACT INTERFACE %qs vid %L får inte ha ett antaget teckenlängdsresultat (F2008: C418)"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
 #: fortran/resolve.c:3216
@@ -66006,7 +65983,7 @@ msgstr "resolve_function(): felaktig funktionstyp"
 #: fortran/resolve.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
-msgstr "En literal BOZ-konstant vid %L får inte förekomma som ett faktiskt argument i en funktionsreferens"
+msgstr "En litteral BOZ-konstant vid %L får inte förekomma som ett faktiskt argument i en funktionsreferens"
 
 #: fortran/resolve.c:3280
 #, gcc-internal-format
@@ -66400,7 +66377,7 @@ msgstr "%qs vid %L skulle vara en SUBROUTINE"
 #: fortran/resolve.c:6572
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
-msgstr "%qs vid %L skulle vara en SUBROUTINE"
+msgstr "%qs vid %L skulle vara en FUNCTION"
 
 #: fortran/resolve.c:7107
 #, gcc-internal-format
@@ -66495,7 +66472,7 @@ msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 #: fortran/resolve.c:7773
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
-msgstr "Typen på enheten vid %L är typinkompatibel med källuttrycket vid %L"
+msgstr "Typen på entiteten vid %L är typinkompatibel med källuttrycket vid %L"
 
 #: fortran/resolve.c:7785
 #, gcc-internal-format, gfc-internal-format
@@ -66674,7 +66651,7 @@ msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 #: fortran/resolve.c:8889
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
-msgstr "Den associerande enheten %qs vid %L är en procedurpekare"
+msgstr "Den associerande entiteten %qs vid %L är en procedurpekare"
 
 #: fortran/resolve.c:8898
 #, gcc-internal-format
@@ -66684,7 +66661,7 @@ msgstr "Den härledda typen %qs får inte användas som en variabel vid %L"
 #: fortran/resolve.c:8915
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
-msgstr "Den associerande neheten %qs vid %L är ett procedurnamn"
+msgstr "Den associerande entiteten %qs vid %L är ett procedurnamn"
 
 #: fortran/resolve.c:8931
 #, gcc-internal-format, gfc-internal-format
@@ -66764,7 +66741,7 @@ msgstr "RANK (*) vid %L upprepas vid %L"
 #: fortran/resolve.c:9704
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
-msgstr "RANK (%i) vid %L upprepas %L"
+msgstr "RANK (%i) vid %L upprepas vid %L"
 
 #: fortran/resolve.c:9714 fortran/resolve.c:9719
 #, gcc-internal-format, gfc-internal-format
@@ -66859,7 +66836,7 @@ msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 #: fortran/resolve.c:10130
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
-msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller ordning-1-uttryck"
+msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller INTEGER-uttryck av ordning 1"
 
 #: fortran/resolve.c:10134 fortran/resolve.c:10144
 #, gcc-internal-format, gfc-internal-format
@@ -67015,10 +66992,9 @@ msgid "The function result on the lhs of the assignment at %L must have the poin
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
 #: fortran/resolve.c:11812
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
+#, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
-msgstr "ASSIGNED GOTO-sats vid %L kräver en INTEGER-variabel"
+msgstr "ASSIGNED GOTO-sats vid %L kräver en skalär INTEGER-variabel"
 
 #: fortran/resolve.c:11816
 #, gcc-internal-format
@@ -67068,7 +67044,7 @@ msgstr "gfc_resolve_code(): Felaktig satskod"
 #: fortran/resolve.c:12280
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
-msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en enhet vid %L"
+msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en entitet vid %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
@@ -67885,12 +67861,12 @@ msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständi
 #: fortran/resolve.c:16089
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
-msgstr "DATA-objektet nära %L har pekarattributet och det motsvarande DATA-värde är inte en giltig initialt-data-mål"
+msgstr "DATA-objektet nära %L har pekarattributet och det motsvarande DATA-värdet är inte ett giltigt initialt-data-mål"
 
 #: fortran/resolve.c:16137
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
-msgstr "Ickekonstant vektorsektion vid %L i DATA-sats."
+msgstr "Ickekonstant vektorsektion vid %L i DATA-sats"
 
 #: fortran/resolve.c:16150
 #, gcc-internal-format, gfc-internal-format
@@ -68406,7 +68382,7 @@ msgstr "Element med ett värde på %d i ORDER vid %L måste ligga i intervallet
 #: fortran/simplify.c:6809
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDER at %L is not a permutation of the size of SHAPE at %L"
-msgstr "ORDER vid %L är är inte en permutation av storleken av SHAPE vid %L"
+msgstr "ORDER vid %L är inte en permutation av storleken av SHAPE vid %L"
 
 #: fortran/simplify.c:6861
 #, gcc-internal-format, gfc-internal-format
@@ -68436,7 +68412,7 @@ msgstr "Misslyckades att bestämma längden på en konstant vektor."
 #: fortran/simplify.c:7736
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
-msgstr "Antalet element (%d) i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
+msgstr "Antalet element (%d) i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>."
 
 #: fortran/simplify.c:7803
 #, gcc-internal-format, gfc-internal-format
@@ -68511,12 +68487,12 @@ msgstr "gfc_set_default_type(): symbolen har redan en typ"
 #: fortran/symbol.c:306
 #, gcc-internal-format
 msgid "Symbol %qs at %L has no IMPLICIT type; did you mean %qs?"
-msgstr "Symbolen  %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
+msgstr "Symbolen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
 #: fortran/symbol.c:310
 #, gcc-internal-format
 msgid "Symbol %qs at %L has no IMPLICIT type"
-msgstr "Symbolen  %qs vid %L har ingen IMPLICIT-typ"
+msgstr "Symbolen %qs vid %L har ingen IMPLICIT-typ"
 
 #. BIND(C) variables should not be implicitly declared.
 #: fortran/symbol.c:330
@@ -69144,7 +69120,7 @@ msgstr "valfri klassparameter"
 #: fortran/trans-openmp.c:2717
 #, gcc-internal-format
 msgid "unhandled derived-type component"
-msgstr "ohanterad härledd typ-argument"
+msgstr "ohanterad härledd typ-komponent"
 
 #: fortran/trans-openmp.c:5588
 #, gcc-internal-format
@@ -69364,7 +69340,7 @@ msgstr "%<-fwpa%> och %<-fltrans%> är ömsesidigt uteslutande"
 #: lto/lto-lang.c:898
 #, gcc-internal-format
 msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclussive"
-msgstr "%<-fwpa%> och %<-fltrans%> är ömsesidigt uteslutande"
+msgstr "%<-flinker-output=rel%> och %<-fltrans%> är ömsesidigt uteslutande"
 
 #: lto/lto-object.c:107
 #, gcc-internal-format, gfc-internal-format
@@ -70517,7 +70493,7 @@ msgstr "okänd pekarstorlekmodell %qs"
 #: config/i386/i386.opt:315
 #, gcc-internal-format
 msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
-msgstr "%<-mcpu=%> bör undvikas.  Använd %<-mtune=%> eller %<-march=%> istället."
+msgstr "%<-mcpu=%> bör undvikas.  Använd %<-mtune=%> eller %<-march=%> istället"
 
 #: config/i386/i386.opt:375
 #, gcc-internal-format
@@ -70537,7 +70513,7 @@ msgstr "enhet eller arkitektur saknas efter %qs"
 #: config/rs6000/rs6000.opt:316
 #, gcc-internal-format
 msgid "%<-mvrsave=no%> is deprecated; use %<-mno-vrsave%> instead"
-msgstr "%<-mvrsave=no%> bör undvikas; använd %<-mno-vrsave%> istället."
+msgstr "%<-mvrsave=no%> bör undvikas; använd %<-mno-vrsave%> istället"
 
 #: config/rs6000/rs6000.opt:320
 #, gcc-internal-format
@@ -70671,15 +70647,3 @@ msgstr "okänt synlighetsvärde %qs"
 #, gcc-internal-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
-
-#~ msgid "Warn about code paths in which an uninitialized value is used."
-#~ msgstr "Varna för kodvägar i vilka ett oinitierat värde används."
-
-#~ msgid "Use instructions for a future architecture."
-#~ msgstr "Använd instruktioner för en framtida arkitektur."
-
-#~ msgid "three-way comparison operator can only be defaulted in a class definition"
-#~ msgstr "trevägsjämförelseoperatorn kan endast standarddefinieras i en klassdefinition"
-
-#~ msgid "equality comparison operator can only be defaulted in a class definition"
-#~ msgstr "likhetsjämförelseoperatorn kan endast standarddefinieras i en klassdefinition"

commit b258a8b74765275e5d598b36af4fcc4e66da5c5a
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Jul 30 00:16:57 2020 +0000

    Daily bump.

diff --git a/contrib/ChangeLog b/contrib/ChangeLog
index 88c668a53ca..ed7d4c8c5ff 100644
--- a/contrib/ChangeLog
+++ b/contrib/ChangeLog
@@ -1,3 +1,7 @@
+2020-07-29  Martin Liska  <mliska@suse.cz>
+
+	* git-backport.py: fix how are ChangeLog paths combined.
+
 2020-07-23  Martin Liska  <mliska@suse.cz>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 273bf0e001a..35e844018cf 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200729
+20200730
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 8a22888fe52..e48f888ad88 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,57 @@
+2020-07-29  Iain Sandoe  <iain@sandoe.co.uk>
+
+	Backported from master:
+	2020-07-16  Iain Sandoe  <iain@sandoe.co.uk>
+
+	PR c++/95591
+	PR c++/95599
+	PR c++/95823
+	PR c++/95824
+	PR c++/95895
+	* coroutines.cc (struct coro_ret_data): Delete.
+	(coro_maybe_expand_co_return): Delete.
+	(co_return_expander): Delete.
+	(expand_co_returns): Delete.
+	(co_await_find_in_subtree): Remove unused name.
+	(build_actor_fn): Remove unused parm, remove handling
+	for co_return expansion.
+	(register_await_info): Demote duplicate info message to a
+	warning.
+	(coro_make_frame_entry): Move closer to use site.
+	(struct susp_frame_data): Add fields for final suspend label
+	and a flag to indicate await expressions with initializers.
+	(captures_temporary): Delete.
+	(register_awaits): Remove unused code, update comments.
+	(find_any_await): New.
+	(tmp_target_expr_p): New.
+	(struct interesting): New.
+	(find_interesting_subtree): New.
+	(struct var_nest_node): New.
+	(flatten_await_stmt): New.
+	(handle_nested_conditionals): New.
+	(process_conditional): New.
+	(replace_statement_captures): Rename to...
+	(maybe_promote_temps): ... this.
+	(maybe_promote_captured_temps): Delete.
+	(analyze_expression_awaits): Check for await expressions with
+	initializers.  Simplify handling for truth-and/or-if.
+	(expand_one_truth_if): Simplify (map cases that need expansion
+	to COND_EXPR).
+	(await_statement_walker): Handle CO_RETURN_EXPR. Simplify the
+	handling for truth-and/or-if expressions.
+	(register_local_var_uses): Ensure that we create names in the
+	implementation namespace.
+	(morph_fn_to_coro): Add final suspend label to suspend frame
+	callback data and remove it from the build_actor_fn call.
+
+2020-07-29  Iain Sandoe  <iain@sandoe.co.uk>
+
+	Backported from master:
+	2020-06-05  Iain Sandoe  <iain@sandoe.co.uk>
+
+	* cp-tree.def (CO_RETURN_EXPR): Correct the class
+	to use tcc_statement.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index fa391848912..10d1f9e2f78 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,12 @@
+2020-07-29  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	Backported from master:
+	2020-07-29  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	PR fortran/96319
+	* intrinsic.c (gfc_convert_type_warn):  Add check for
+	LOGICAL type so that warnings are not output.
+
 2020-07-27  Mark Eggleston  <markeggleston@gcc.gnu.org>
 
 	Backported from master:
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 7a18efafb55..2e53e585afb 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,7 @@
+2020-07-29  Joseph Myers  <joseph@codesourcery.com>
+
+	* ja.po, sv.po: Update.
+
 2020-07-27  Joseph Myers  <joseph@codesourcery.com>
 
 	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 57c3820b31f..1d74f9040b2 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,30 @@
+2020-07-29  Tiziano Müller  <tiziano.mueller@chem.uzh.ch>
+
+	* c-c++-common/cpp/has-include-1-traditional.c: New.
+
+2020-07-29  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	Backported from master:
+	2020-07-29  Mark Eggleston  <markeggleston@gcc.gnu.org>
+
+	PR fortran/96319
+	* gfortran.dg/pr96319.f90: New test.
+
+2020-07-29  Iain Sandoe  <iain@sandoe.co.uk>
+
+	Backported from master:
+	2020-07-16  Iain Sandoe  <iain@sandoe.co.uk>
+
+	PR c++/95591
+	PR c++/95599
+	PR c++/95823
+	PR c++/95824
+	PR c++/95895
+	* g++.dg/coroutines/pr95591.C: New test.
+	* g++.dg/coroutines/pr95599.C: New test.
+	* g++.dg/coroutines/pr95823.C: New test.
+	* g++.dg/coroutines/pr95824.C: New test.
+
 2020-07-28  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libcpp/ChangeLog b/libcpp/ChangeLog
index e7ad590aede..ca907cd2309 100644
--- a/libcpp/ChangeLog
+++ b/libcpp/ChangeLog
@@ -1,3 +1,8 @@
+2020-07-29  Tiziano Müller  <tiziano.mueller@chem.uzh.ch>
+
+	* init.c (builtin_array): Add xref comment.
+	* traditional.c (fun_like_macro): Add HAS_INCLUDE codes.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 0e630cb96b4..eefacc68540 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,43 @@
+2020-07-29  Julian Brown  <julian@codesourcery.com>
+
+	Backported from master:
+	2020-07-27  Julian Brown  <julian@codesourcery.com>
+		    Thomas Schwinge  <thomas@codesourcery.com>
+
+	* libgomp.h (struct target_var_desc): Rename do_detach field to
+	is_attach.
+	* oacc-mem.c (goacc_exit_datum_1): Add assert.  Don't set finalize for
+	GOMP_MAP_FORCE_DETACH. Update checking to use is_attach field.
+	(goacc_enter_data_internal): Don't affect reference counts
+	for attach mappings.
+	(goacc_exit_data_internal): Don't affect reference counts for detach
+	mappings.
+	* target.c (gomp_map_vars_existing): Don't affect reference counts for
+	attach mappings.
+	(gomp_map_vars_internal): Set renamed is_attach flag unconditionally to
+	mark attach mappings.
+	(gomp_unmap_vars_internal): Use is_attach flag to prevent affecting
+	reference count for attach mappings.
+	* testsuite/libgomp.oacc-c-c++-common/mdc-refcount-1.c: New test.
+	* testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c: New test.
+	* testsuite/libgomp.oacc-c-c++-common/mdc-refcount-2.c: New test.
+	* testsuite/libgomp.oacc-fortran/deep-copy-6-no_finalize.F90: Mark
+	test as shouldfail.
+	* testsuite/libgomp.oacc-fortran/deep-copy-6.f90: Adjust to fail
+	gracefully in no-finalize mode.
+	* testsuite/libgomp.oacc-c-c++-common/mdc-refcount-3.c: New file.
+
+2020-07-29  Julian Brown  <julian@codesourcery.com>
+
+	Backported from master:
+	2020-07-23  Julian Brown  <julian@codesourcery.com>
+		    Thomas Schwinge  <thomas@codesourcery.com>
+
+	* target.c (gomp_unmap_vars_internal): Remove unnecessary forcing of
+	finalization for detach operation.
+	* testsuite/libgomp.oacc-c-c++-common/structured-detach-underflow.c:
+	New test.
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.

commit afd90b44f70d29e8bc3ca76b2b1d93da1c558e66
Author: Martin Liska <mliska@suse.cz>
Date:   Mon Jun 1 11:21:33 2020 +0200

    Re-format zen memcpy/memset costs.
    
    The patch improves readability of the memcpy and memset
    expansion strategies.
    
    gcc/ChangeLog:
    
            * config/i386/x86-tune-costs.h: Change code formatting.
    
    (cherry picked from commit da346efd27eca48a8fe2e07d7e18b2c77ead0e2d)

diff --git a/gcc/config/i386/x86-tune-costs.h b/gcc/config/i386/x86-tune-costs.h
index c73917e5a62..1169178433f 100644
--- a/gcc/config/i386/x86-tune-costs.h
+++ b/gcc/config/i386/x86-tune-costs.h
@@ -1311,14 +1311,23 @@ const struct processor_costs bdver_cost = {
     very small blocks it is better to use loop.  For large blocks, libcall
     can do nontemporary accesses and beat inline considerably.  */
 static stringop_algs znver1_memcpy[2] = {
-  {libcall, {{6, loop, false}, {14, unrolled_loop, false},
+  /* 32-bit tuning.  */
+  {libcall, {{6, loop, false},
+	     {14, unrolled_loop, false},
 	     {-1, rep_prefix_4_byte, false}}},
-  {libcall, {{16, loop, false}, {8192, rep_prefix_8_byte, false},
+  /* 64-bit tuning.  */
+  {libcall, {{16, loop, false},
+	     {8192, rep_prefix_8_byte, false},
 	     {-1, libcall, false}}}};
 static stringop_algs znver1_memset[2] = {
-  {libcall, {{8, loop, false}, {24, unrolled_loop, false},
-	     {2048, rep_prefix_4_byte, false}, {-1, libcall, false}}},
-  {libcall, {{48, unrolled_loop, false}, {8192, rep_prefix_8_byte, false},
+  /* 32-bit tuning.  */
+  {libcall, {{8, loop, false},
+	     {24, unrolled_loop, false},
+	     {2048, rep_prefix_4_byte, false},
+	     {-1, libcall, false}}},
+  /* 64-bit tuning.  */
+  {libcall, {{48, unrolled_loop, false},
+	     {8192, rep_prefix_8_byte, false},
 	     {-1, libcall, false}}}};
 struct processor_costs znver1_cost = {
   {
@@ -1448,14 +1457,23 @@ struct processor_costs znver1_cost = {
     very small blocks it is better to use loop.  For large blocks, libcall
     can do nontemporary accesses and beat inline considerably.  */
 static stringop_algs znver2_memcpy[2] = {
-  {libcall, {{6, loop, false}, {14, unrolled_loop, false},
+  /* 32-bit tuning.  */
+  {libcall, {{6, loop, false},
+	     {14, unrolled_loop, false},
 	     {-1, rep_prefix_4_byte, false}}},
-  {libcall, {{16, loop, false}, {64, rep_prefix_4_byte, false},
+  /* 64-bit tuning.  */
+  {libcall, {{16, loop, false},
+	     {64, rep_prefix_4_byte, false},
 	     {-1, libcall, false}}}};
 static stringop_algs znver2_memset[2] = {
-  {libcall, {{8, loop, false}, {24, unrolled_loop, false},
-	     {2048, rep_prefix_4_byte, false}, {-1, libcall, false}}},
-  {libcall, {{24, rep_prefix_4_byte, false}, {128, rep_prefix_8_byte, false},
+  /* 32-bit tuning.  */
+  {libcall, {{8, loop, false},
+	     {24, unrolled_loop, false},
+	     {2048, rep_prefix_4_byte, false}
+	     {-1, libcall, false}}},
+  /* 64-bit tuning.  */
+  {libcall, {{24, rep_prefix_4_byte, false},
+	     {128, rep_prefix_8_byte, false},
 	     {-1, libcall, false}}}};
 
 struct processor_costs znver2_cost = {

commit 809b4d226c7f5ded392a88ffafe8d652f911b473
Author: Martin Liska <mliska@suse.cz>
Date:   Mon Jun 1 13:21:40 2020 +0200

    Tune memcpy and memset for Zen cores.
    
    Based on the collected numbers in PR95435, I suggest the following
    tuning changes:
    
    gcc/ChangeLog:
    
            PR target/95435
            * config/i386/x86-tune-costs.h: Use libcall for large sizes for
            -m32. Start using libcall from 128+ bytes.
    
    (cherry picked from commit dc65aba7a4725d1b464c8c64a5f739ee910e8943)

diff --git a/gcc/config/i386/x86-tune-costs.h b/gcc/config/i386/x86-tune-costs.h
index 1169178433f..3207404e514 100644
--- a/gcc/config/i386/x86-tune-costs.h
+++ b/gcc/config/i386/x86-tune-costs.h
@@ -1314,20 +1314,20 @@ static stringop_algs znver1_memcpy[2] = {
   /* 32-bit tuning.  */
   {libcall, {{6, loop, false},
 	     {14, unrolled_loop, false},
-	     {-1, rep_prefix_4_byte, false}}},
+	     {-1, libcall, false}}},
   /* 64-bit tuning.  */
   {libcall, {{16, loop, false},
-	     {8192, rep_prefix_8_byte, false},
+	     {128, rep_prefix_8_byte, false},
 	     {-1, libcall, false}}}};
 static stringop_algs znver1_memset[2] = {
   /* 32-bit tuning.  */
   {libcall, {{8, loop, false},
 	     {24, unrolled_loop, false},
-	     {2048, rep_prefix_4_byte, false},
+	     {128, rep_prefix_4_byte, false},
 	     {-1, libcall, false}}},
   /* 64-bit tuning.  */
   {libcall, {{48, unrolled_loop, false},
-	     {8192, rep_prefix_8_byte, false},
+	     {128, rep_prefix_8_byte, false},
 	     {-1, libcall, false}}}};
 struct processor_costs znver1_cost = {
   {
@@ -1460,7 +1460,7 @@ static stringop_algs znver2_memcpy[2] = {
   /* 32-bit tuning.  */
   {libcall, {{6, loop, false},
 	     {14, unrolled_loop, false},
-	     {-1, rep_prefix_4_byte, false}}},
+	     {-1, libcall, false}}},
   /* 64-bit tuning.  */
   {libcall, {{16, loop, false},
 	     {64, rep_prefix_4_byte, false},
@@ -1469,7 +1469,7 @@ static stringop_algs znver2_memset[2] = {
   /* 32-bit tuning.  */
   {libcall, {{8, loop, false},
 	     {24, unrolled_loop, false},
-	     {2048, rep_prefix_4_byte, false}
+	     {128, rep_prefix_4_byte, false},
 	     {-1, libcall, false}}},
   /* 64-bit tuning.  */
   {libcall, {{24, rep_prefix_4_byte, false},

commit e7d6233a82859b362252b87c62762970a009cc26
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Jul 31 00:16:58 2020 +0000

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 6a153ea0dca..8062bbcc9b6 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,19 @@
+2020-07-30  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2020-07-30  Martin Liska  <mliska@suse.cz>
+
+	PR target/95435
+	* config/i386/x86-tune-costs.h: Use libcall for large sizes for
+	-m32. Start using libcall from 128+ bytes.
+
+2020-07-30  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2020-07-30  Martin Liska  <mliska@suse.cz>
+
+	* config/i386/x86-tune-costs.h: Change code formatting.
+
 2020-07-28  Martin Liska  <mliska@suse.cz>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 35e844018cf..675c0b9e6b0 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200730
+20200731

commit 44d662cf6d9a974ef972d518507c9c52acf38e55
Author: Martin Liska <mliska@suse.cz>
Date:   Thu Jul 30 09:24:40 2020 +0200

    Do not allocate huge array in output_in_order.
    
    We noticed that when analyzing LTRANS memory peak that happens right
    after the start:
    https://gist.github.com/marxin/223890df4d8d8e490b6b2918b77dacad
    
    In case of chrome, we have symtab->order == 200M, so we allocate
    16B * 200M = 3.2GB.
    
    gcc/ChangeLog:
    
            * cgraph.h: Remove leading empty lines.
            * cgraphunit.c (enum cgraph_order_sort_kind): Remove
            ORDER_UNDEFINED.
            (struct cgraph_order_sort): Add constructors.
            (cgraph_order_sort::process): New.
            (cgraph_order_cmp): New.
            (output_in_order): Simplify and push nodes to vector.
    
    (cherry picked from commit 8bd062e8ad44e70be04108232e1ef597fc3b3e3e)

diff --git a/gcc/cgraph.h b/gcc/cgraph.h
index 5ddeb65269b..771c03aba72 100644
--- a/gcc/cgraph.h
+++ b/gcc/cgraph.h
@@ -2165,8 +2165,6 @@ private:
 /* Every top level asm statement is put into a asm_node.  */
 
 struct GTY(()) asm_node {
-
-
   /* Next asm node.  */
   asm_node *next;
   /* String for this asm node.  */
diff --git a/gcc/cgraphunit.c b/gcc/cgraphunit.c
index a1ace95879a..2e903d287f6 100644
--- a/gcc/cgraphunit.c
+++ b/gcc/cgraphunit.c
@@ -2491,7 +2491,6 @@ expand_all_functions (void)
 
 enum cgraph_order_sort_kind
 {
-  ORDER_UNDEFINED = 0,
   ORDER_FUNCTION,
   ORDER_VAR,
   ORDER_VAR_UNDEF,
@@ -2500,6 +2499,30 @@ enum cgraph_order_sort_kind
 
 struct cgraph_order_sort
 {
+  /* Construct from a cgraph_node.  */
+  cgraph_order_sort (cgraph_node *node)
+  : kind (ORDER_FUNCTION), order (node->order)
+  {
+    u.f = node;
+  }
+
+  /* Construct from a varpool_node.  */
+  cgraph_order_sort (varpool_node *node)
+  : kind (node->definition ? ORDER_VAR : ORDER_VAR_UNDEF), order (node->order)
+  {
+    u.v = node;
+  }
+
+  /* Construct from a asm_node.  */
+  cgraph_order_sort (asm_node *node)
+  : kind (ORDER_ASM), order (node->order)
+  {
+    u.a = node;
+  }
+
+  /* Assembly cgraph_order_sort based on its type.  */
+  void process ();
+
   enum cgraph_order_sort_kind kind;
   union
   {
@@ -2507,8 +2530,45 @@ struct cgraph_order_sort
     varpool_node *v;
     asm_node *a;
   } u;
+  int order;
 };
 
+/* Assembly cgraph_order_sort based on its type.  */
+
+void
+cgraph_order_sort::process ()
+{
+  switch (kind)
+    {
+    case ORDER_FUNCTION:
+      u.f->process = 0;
+      u.f->expand ();
+      break;
+    case ORDER_VAR:
+      u.v->assemble_decl ();
+      break;
+    case ORDER_VAR_UNDEF:
+      assemble_undefined_decl (u.v->decl);
+      break;
+    case ORDER_ASM:
+      assemble_asm (u.a->asm_str);
+      break;
+    default:
+      gcc_unreachable ();
+    }
+}
+
+/* Compare cgraph_order_sort by order.  */
+
+static int
+cgraph_order_cmp (const void *a_p, const void *b_p)
+{
+  const cgraph_order_sort *nodea = (const cgraph_order_sort *)a_p;
+  const cgraph_order_sort *nodeb = (const cgraph_order_sort *)b_p;
+
+  return nodea->order - nodeb->order;
+}
+
 /* Output all functions, variables, and asm statements in the order
    according to their order fields, which is the order in which they
    appeared in the file.  This implements -fno-toplevel-reorder.  In
@@ -2518,89 +2578,41 @@ struct cgraph_order_sort
 static void
 output_in_order (void)
 {
-  int max;
-  cgraph_order_sort *nodes;
   int i;
-  cgraph_node *pf;
-  varpool_node *pv;
-  asm_node *pa;
-  max = symtab->order;
-  nodes = XCNEWVEC (cgraph_order_sort, max);
+  cgraph_node *cnode;
+  varpool_node *vnode;
+  asm_node *anode;
+  auto_vec<cgraph_order_sort> nodes;
+  cgraph_order_sort *node;
 
-  FOR_EACH_DEFINED_FUNCTION (pf)
-    {
-      if (pf->process && !pf->thunk.thunk_p && !pf->alias)
-	{
-	  if (!pf->no_reorder)
-	    continue;
-	  i = pf->order;
-	  gcc_assert (nodes[i].kind == ORDER_UNDEFINED);
-	  nodes[i].kind = ORDER_FUNCTION;
-	  nodes[i].u.f = pf;
-	}
-    }
+  FOR_EACH_DEFINED_FUNCTION (cnode)
+    if (cnode->process && !cnode->thunk.thunk_p
+	&& !cnode->alias && cnode->no_reorder)
+      nodes.safe_push (cgraph_order_sort (cnode));
 
   /* There is a similar loop in symbol_table::output_variables.
      Please keep them in sync.  */
-  FOR_EACH_VARIABLE (pv)
-    {
-      if (!pv->no_reorder)
-	continue;
-      if (DECL_HARD_REGISTER (pv->decl)
-	  || DECL_HAS_VALUE_EXPR_P (pv->decl))
-	continue;
-      i = pv->order;
-      gcc_assert (nodes[i].kind == ORDER_UNDEFINED);
-      nodes[i].kind = pv->definition ? ORDER_VAR : ORDER_VAR_UNDEF;
-      nodes[i].u.v = pv;
-    }
-
-  for (pa = symtab->first_asm_symbol (); pa; pa = pa->next)
-    {
-      i = pa->order;
-      gcc_assert (nodes[i].kind == ORDER_UNDEFINED);
-      nodes[i].kind = ORDER_ASM;
-      nodes[i].u.a = pa;
-    }
-
-  /* In toplevel reorder mode we output all statics; mark them as needed.  */
-
-  for (i = 0; i < max; ++i)
-    if (nodes[i].kind == ORDER_VAR)
-      nodes[i].u.v->finalize_named_section_flags ();
-
-  for (i = 0; i < max; ++i)
-    {
-      switch (nodes[i].kind)
-	{
-	case ORDER_FUNCTION:
-	  nodes[i].u.f->process = 0;
-	  nodes[i].u.f->expand ();
-	  break;
+  FOR_EACH_VARIABLE (vnode)
+    if (vnode->no_reorder
+	&& !DECL_HARD_REGISTER (vnode->decl)
+	&& !DECL_HAS_VALUE_EXPR_P (vnode->decl))
+      nodes.safe_push (cgraph_order_sort (vnode));
 
-	case ORDER_VAR:
-	  nodes[i].u.v->assemble_decl ();
-	  break;
+  for (anode = symtab->first_asm_symbol (); anode; anode = anode->next)
+    nodes.safe_push (cgraph_order_sort (anode));
 
-	case ORDER_VAR_UNDEF:
-	  assemble_undefined_decl (nodes[i].u.v->decl);
-	  break;
+  /* Sort nodes by order.  */
+  nodes.qsort (cgraph_order_cmp);
 
-	case ORDER_ASM:
-	  assemble_asm (nodes[i].u.a->asm_str);
-	  break;
-
-	case ORDER_UNDEFINED:
-	  break;
+  /* In toplevel reorder mode we output all statics; mark them as needed.  */
+  FOR_EACH_VEC_ELT (nodes, i, node)
+    if (node->kind == ORDER_VAR)
+      node->u.v->finalize_named_section_flags ();
 
-	default:
-	  gcc_unreachable ();
-	}
-    }
+  FOR_EACH_VEC_ELT (nodes, i, node)
+    node->process ();
 
   symtab->clear_asm_symbols ();
-
-  free (nodes);
 }
 
 static void

commit 99e25dc10c1ef5d379baeaac9682df738b63310f
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Aug 1 00:16:58 2020 +0000

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 8062bbcc9b6..1d9e1ba8c4b 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,16 @@
+2020-07-31  Martin Liska  <mliska@suse.cz>
+
+	Backported from master:
+	2020-07-31  Martin Liska  <mliska@suse.cz>
+
+	* cgraph.h: Remove leading empty lines.
+	* cgraphunit.c (enum cgraph_order_sort_kind): Remove
+	ORDER_UNDEFINED.
+	(struct cgraph_order_sort): Add constructors.
+	(cgraph_order_sort::process): New.
+	(cgraph_order_cmp): New.
+	(output_in_order): Simplify and push nodes to vector.
+
 2020-07-30  Martin Liska  <mliska@suse.cz>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 675c0b9e6b0..b4bc243c22b 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200731
+20200801

commit 891bd1f15280def813bf6a363495d44951e13e04
Author: Iain Buclaw <ibuclaw@gdcproject.org>
Date:   Thu Jul 16 18:34:18 2020 +0200

    d: Fix ICE in expand_intrinsic_vaarg
    
    Both intrinsics did not handle the case where the va_list object comes
    from a ref parameter.
    
    gcc/d/ChangeLog:
    
            PR d/96140
            * intrinsics.cc (expand_intrinsic_vaarg): Handle ref parameters as
            arguments to va_arg().
            (expand_intrinsic_vastart): Handle ref parameters as arguments to
            va_start().
    
    gcc/testsuite/ChangeLog:
    
            PR d/96140
            * gdc.dg/pr96140.d: New test.
    
    (cherry picked from commit dfc420f8d4492dbf5f45df4fecf93cb9645c0d7b)

diff --git a/gcc/d/intrinsics.cc b/gcc/d/intrinsics.cc
index c7bde88e5cd..c32819885bb 100644
--- a/gcc/d/intrinsics.cc
+++ b/gcc/d/intrinsics.cc
@@ -511,8 +511,17 @@ expand_intrinsic_vaarg (tree callexp)
     {
       parmn = CALL_EXPR_ARG (callexp, 1);
       STRIP_NOPS (parmn);
-      gcc_assert (TREE_CODE (parmn) == ADDR_EXPR);
-      parmn = TREE_OPERAND (parmn, 0);
+
+      /* The `ref' argument to va_arg is either an address or reference,
+	 get the value of it.  */
+      if (TREE_CODE (parmn) == PARM_DECL && POINTER_TYPE_P (TREE_TYPE (parmn)))
+	parmn = build_deref (parmn);
+      else
+	{
+	  gcc_assert (TREE_CODE (parmn) == ADDR_EXPR);
+	  parmn = TREE_OPERAND (parmn, 0);
+	}
+
       type = TREE_TYPE (parmn);
     }
 
@@ -546,10 +555,16 @@ expand_intrinsic_vastart (tree callexp)
   /* The va_list argument should already have its address taken.  The second
      argument, however, is inout and that needs to be fixed to prevent a
      warning.  Could be casting, so need to check type too?  */
-  gcc_assert (TREE_CODE (ap) == ADDR_EXPR && TREE_CODE (parmn) == ADDR_EXPR);
+  gcc_assert (TREE_CODE (ap) == ADDR_EXPR
+	      || (TREE_CODE (ap) == PARM_DECL
+		  && POINTER_TYPE_P (TREE_TYPE (ap))));
 
   /* Assuming nobody tries to change the return type.  */
-  parmn = TREE_OPERAND (parmn, 0);
+  if (TREE_CODE (parmn) != PARM_DECL)
+    {
+      gcc_assert (TREE_CODE (parmn) == ADDR_EXPR);
+      parmn = TREE_OPERAND (parmn, 0);
+    }
 
   return call_builtin_fn (callexp, BUILT_IN_VA_START, 2, ap, parmn);
 }
diff --git a/gcc/testsuite/gdc.dg/pr96140.d b/gcc/testsuite/gdc.dg/pr96140.d
new file mode 100644
index 00000000000..d25bb5d3360
--- /dev/null
+++ b/gcc/testsuite/gdc.dg/pr96140.d
@@ -0,0 +1,15 @@
+// https://gcc.gnu.org/bugzilla/show_bug.cgi?id=96140
+// { dg-do compile }
+module pr94140;
+
+import core.stdc.stdarg;
+
+void test_va_arg(ref int a, ...)
+{
+    return va_arg!int(_argptr, a);
+}
+
+void test_va_start(ref va_list a, ...)
+{
+    return va_start(a, a);
+}

commit ba29532f78b3cc81d28829b4c05c50a69d993a61
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Aug 2 00:16:53 2020 +0000

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index b4bc243c22b..6eab4709860 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200801
+20200802
diff --git a/gcc/d/ChangeLog b/gcc/d/ChangeLog
index c613976f497..c973d64c7c2 100644
--- a/gcc/d/ChangeLog
+++ b/gcc/d/ChangeLog
@@ -1,3 +1,14 @@
+2020-08-01  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	Backported from master:
+	2020-07-30  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	PR d/96140
+	* intrinsics.cc (expand_intrinsic_vaarg): Handle ref parameters as
+	arguments to va_arg().
+	(expand_intrinsic_vastart): Handle ref parameters as arguments to
+	va_start().
+
 2020-07-23  Release Manager
 
 	* GCC 10.2.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 1d74f9040b2..3b42a7c12f9 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2020-08-01  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	Backported from master:
+	2020-07-30  Iain Buclaw  <ibuclaw@gdcproject.org>
+
+	PR d/96140
+	* gdc.dg/pr96140.d: New test.
+
 2020-07-29  Tiziano Müller  <tiziano.mueller@chem.uzh.ch>
 
 	* c-c++-common/cpp/has-include-1-traditional.c: New.

commit fd7f82855134bc40c46f06c66413f1ec78404eca
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Aug 3 00:16:52 2020 +0000

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 6eab4709860..72167a445ca 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20200802
+20200803

commit 30a66fb9616961264c291a4003ca1f41bebed5a1
Author: Rainer Orth <ro@CeBiTec.Uni-Bielefeld.DE>
Date:   Mon Aug 3 09:45:04 2020 +0200

    libsanitizer: Fix GetPcSpBp determination of SP on 32-bit Solaris/x86
    
    The latest Solaris 11.4/x86 update uncovered a libsanitizer bug that
    caused one test to FAIL for 32-bit:
    
    +FAIL: c-c++-common/asan/null-deref-1.c   -O0  output pattern test
    +FAIL: c-c++-common/asan/null-deref-1.c   -O1  output pattern test
    +FAIL: c-c++-common/asan/null-deref-1.c   -O2  output pattern test
    +FAIL: c-c++-common/asan/null-deref-1.c   -O2 -flto  output pattern test
    +FAIL: c-c++-common/asan/null-deref-1.c -O2 -flto -flto-partition=none
    output pattern test
    +FAIL: c-c++-common/asan/null-deref-1.c   -O3 -g  output pattern test
    +FAIL: c-c++-common/asan/null-deref-1.c   -Os  output pattern test
    
    I've identified the problem and the fix has just landed in upstream
    llvm-project:
    
            https://reviews.llvm.org/D83664
    
    Tested on i386-pc-solaris2.11 and x86_64-pc-linux.gnu.
    
            libsanitizer:
            * sanitizer_common/sanitizer_linux.cpp: Cherry-pick llvm-project
            revision f0e9b76c3500496f8f3ea7abe6f4bf801e3b41e7.

diff --git a/libsanitizer/sanitizer_common/sanitizer_linux.cpp b/libsanitizer/sanitizer_common/sanitizer_linux.cpp
index 3807a79b1cd..15ccd738d85 100644
--- a/libsanitizer/sanitizer_common/sanitizer_linux.cpp
+++ b/libsanitizer/sanitizer_common/sanitizer_linux.cpp
@@ -1924,13 +1924,13 @@ static void GetPcSpBp(void *context, uptr *pc, uptr *sp, uptr *bp) {
 # ifndef REG_EBP
 #  define REG_EBP  6 // REG_FP
 # endif
-# ifndef REG_ESP
-#  define REG_ESP 17 // REG_SP
+# ifndef REG_UESP
+#  define REG_UESP 17 // REG_SP
 # endif
 # endif
   *pc = ucontext->uc_mcontext.gregs[REG_EIP];
   *bp = ucontext->uc_mcontext.gregs[REG_EBP];
-  *sp = ucontext->uc_mcontext.gregs[REG_ESP];
+  *sp = ucontext->uc_mcontext.gregs[REG_UESP];
 # endif
 #elif defined(__powerpc__) || defined(__powerpc64__)
   ucontext_t *ucontext = (ucontext_t*)context;

commit a216daaa30bc8949086a16e7656f2025b692d03c
Author: Richard Sandiford <richard.sandiford@arm.com>
Date:   Mon Aug 3 09:48:36 2020 +0100

    c: Fix bogus vector initialisation error [PR96377]
    
    One of the problems in this PR was that if we had:
    
      vector_type1 array[] = { vector_value1 };
    
    process_init_element would only treat vector_value1 as initialising
    a vector_type1 if they had the same TYPE_MAIN_VARIANT.  This has
    several problems:
    
    (1) It gives confusing error messages if the vector types are
        incompatible.  (Tested by gcc.dg/pr96377-1.c.)
    
    (2) It means that we reject code that should be valid with
        -flax-vector-conversions.  (Tested by gcc.dg/pr96377-2.c.)
    
    (3) On arm and aarch64 targets, it means that we reject some
        initializers that mix Advanced SIMD and standard GNU vectors.
        These vectors have traditionally had different TYPE_MAIN_VARIANTs
        because they have different mangling schemes.  (Tested by
        gcc.dg/pr96377-[3-6].c.)
    
    (4) It means that we reject SVE initializers that should be valid.
        (Tested by gcc.target/aarch64/sve/gnu_vectors_[34].c.)
    
    (5) After r11-1741-g:31427b974ed7b7dd54e2 we reject:
    
          arm_neon_type1 array[] = { k ^ arm_neon_value1 };
    
        because applying the binary operator to arm_neon_value1 strips
        the "Advanced SIMD type" attributes that were added in that patch.
        Stripping the attributes is problematic for other reasons though,
        so that still needs to be fixed separately.
    
    g++.target/aarch64/sve/gnu_vectors_[34].C already pass.
    
    gcc/c/
            PR c/96377
            * c-typeck.c (process_init_element): Split test for whether to
            recurse into a record, union or array into...
            (initialize_elementwise_p): ...this new function.  Don't recurse
            into a vector type if the initialization value is also a vector.
    
    gcc/testsuite/
            PR c/96377
            * gcc.dg/pr96377-1.c: New test.
            * gcc.dg/pr96377-2.c: Likewise.
            * gcc.dg/pr96377-3.c: Likewise.
            * gcc.dg/pr96377-4.c: Likewise.
            * gcc.dg/pr96377-5.c: Likewise.
            * gcc.dg/pr96377-6.c: Likewise.
            * gcc.target/aarch64/pr96377-1.c: Likewise.
            * gcc.target/aarch64/sve/acle/general-c/gnu_vectors_3.c: Likewise.
            * gcc.target/aarch64/sve/acle/general-c/gnu_vectors_4.c: Likewise.
            * g++.target/aarch64/sve/acle/general-c++/gnu_vectors_3.C: Likewise.
            * g++.target/aarch64/sve/acle/general-c++/gnu_vectors_4.C: Likewise.
    
    (cherry picked from commit 7d599ad27b9bcf5165f87710f1abc64bbabd06ae)

diff --git a/gcc/c/c-typeck.c b/gcc/c/c-typeck.c
index eb4b641e6bb..58762f10a93 100644
--- a/gcc/c/c-typeck.c
+++ b/gcc/c/c-typeck.c
@@ -9910,6 +9910,47 @@ output_pending_init_elements (int all, struct obstack * braced_init_obstack)
   goto retry;
 }
 
+/* Expression VALUE coincides with the start of type TYPE in a braced
+   initializer.  Return true if we should treat VALUE as initializing
+   the first element of TYPE, false if we should treat it as initializing
+   TYPE as a whole.
+
+   If the initializer is clearly invalid, the question becomes:
+   which choice gives the best error message?  */
+
+static bool
+initialize_elementwise_p (tree type, tree value)
+{
+  if (type == error_mark_node || value == error_mark_node)
+    return false;
+
+  gcc_checking_assert (TYPE_MAIN_VARIANT (type) == type);
+
+  tree value_type = TREE_TYPE (value);
+  if (value_type == error_mark_node)
+    return false;
+
+  /* GNU vectors can be initialized elementwise.  However, treat any
+     kind of vector value as initializing the vector type as a whole,
+     regardless of whether the value is a GNU vector.  Such initializers
+     are valid if and only if they would have been valid in a non-braced
+     initializer like:
+
+	TYPE foo = VALUE;
+
+     so recursing into the vector type would be at best confusing or at
+     worst wrong.  For example, when -flax-vector-conversions is in effect,
+     it's possible to initialize a V8HI from a V4SI, even though the vectors
+     have different element types and different numbers of elements.  */
+  if (gnu_vector_type_p (type))
+    return !VECTOR_TYPE_P (value_type);
+
+  if (AGGREGATE_TYPE_P (type))
+    return type != TYPE_MAIN_VARIANT (value_type);
+
+  return false;
+}
+
 /* Add one non-braced element to the current constructor level.
    This adjusts the current position within the constructor's type.
    This may also start or terminate implicit levels
@@ -10089,11 +10130,7 @@ process_init_element (location_t loc, struct c_expr value, bool implicit,
 	  /* Otherwise, if we have come to a subaggregate,
 	     and we don't have an element of its type, push into it.  */
 	  else if (value.value != NULL_TREE
-		   && value.value != error_mark_node
-		   && TYPE_MAIN_VARIANT (TREE_TYPE (value.value)) != fieldtype
-		   && (fieldcode == RECORD_TYPE || fieldcode == ARRAY_TYPE
-		       || fieldcode == UNION_TYPE
-		       || gnu_vector_type_p (fieldtype)))
+		   && initialize_elementwise_p (fieldtype, value.value))
 	    {
 	      push_init_level (loc, 1, braced_init_obstack);
 	      continue;
@@ -10181,11 +10218,7 @@ process_init_element (location_t loc, struct c_expr value, bool implicit,
 	  /* Otherwise, if we have come to a subaggregate,
 	     and we don't have an element of its type, push into it.  */
 	  else if (value.value != NULL_TREE
-		   && value.value != error_mark_node
-		   && TYPE_MAIN_VARIANT (TREE_TYPE (value.value)) != fieldtype
-		   && (fieldcode == RECORD_TYPE || fieldcode == ARRAY_TYPE
-		       || fieldcode == UNION_TYPE
-		       || gnu_vector_type_p (fieldtype)))
+		   && initialize_elementwise_p (fieldtype, value.value))
 	    {
 	      push_init_level (loc, 1, braced_init_obstack);
 	      continue;
@@ -10224,11 +10257,7 @@ process_init_element (location_t loc, struct c_expr value, bool implicit,
 	  /* Otherwise, if we have come to a subaggregate,
 	     and we don't have an element of its type, push into it.  */
 	  else if (value.value != NULL_TREE
-		   && value.value != error_mark_node
-		   && TYPE_MAIN_VARIANT (TREE_TYPE (value.value)) != elttype
-		   && (eltcode == RECORD_TYPE || eltcode == ARRAY_TYPE
-		       || eltcode == UNION_TYPE
-		       || gnu_vector_type_p (elttype)))
+		   && initialize_elementwise_p (elttype, value.value))
 	    {
 	      push_init_level (loc, 1, braced_init_obstack);
 	      continue;
diff --git a/gcc/testsuite/g++.target/aarch64/sve/acle/general-c++/gnu_vectors_3.C b/gcc/testsuite/g++.target/aarch64/sve/acle/general-c++/gnu_vectors_3.C
new file mode 100644
index 00000000000..e607d58d726
--- /dev/null
+++ b/gcc/testsuite/g++.target/aarch64/sve/acle/general-c++/gnu_vectors_3.C
@@ -0,0 +1,15 @@
+/* { dg-options "-msve-vector-bits=256" } */
+
+#include <arm_sve.h>
+
+typedef uint8_t gnu_uint8_t __attribute__ ((vector_size (32)));
+typedef int8_t gnu_int8_t __attribute__ ((vector_size (32)));
+
+void
+f (svuint8_t sve_u1, svint8_t sve_s1,
+   gnu_uint8_t gnu_u1, gnu_int8_t gnu_s1)
+{
+  gnu_uint8_t arr1[] = { gnu_u1, sve_u1 };
+  gnu_uint8_t arr2[] = { gnu_s1 }; // { dg-error "cannot convert" }
+  gnu_uint8_t arr3[] = { sve_s1 }; // { dg-error "cannot convert" }
+}
diff --git a/gcc/testsuite/g++.target/aarch64/sve/acle/general-c++/gnu_vectors_4.C b/gcc/testsuite/g++.target/aarch64/sve/acle/general-c++/gnu_vectors_4.C
new file mode 100644
index 00000000000..ac4e0d12ff8
--- /dev/null
+++ b/gcc/testsuite/g++.target/aarch64/sve/acle/general-c++/gnu_vectors_4.C
@@ -0,0 +1,15 @@
+/* { dg-options "-msve-vector-bits=256 -flax-vector-conversions" } */
+
+#include <arm_sve.h>
+
+typedef uint8_t gnu_uint8_t __attribute__ ((vector_size (32)));
+typedef int8_t gnu_int8_t __attribute__ ((vector_size (32)));
+
+void
+f (svuint8_t sve_u1, svint8_t sve_s1,
+   gnu_uint8_t gnu_u1, gnu_int8_t gnu_s1)
+{
+  gnu_uint8_t arr1[] = { gnu_u1, sve_u1 };
+  gnu_uint8_t arr2[] = { gnu_s1 };
+  gnu_uint8_t arr3[] = { sve_s1 };
+}
diff --git a/gcc/testsuite/gcc.dg/pr96377-1.c b/gcc/testsuite/gcc.dg/pr96377-1.c
new file mode 100644
index 00000000000..2bf3f816331
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96377-1.c
@@ -0,0 +1,32 @@
+/* { dg-options "-fno-lax-vector-conversions" } */
+/* { dg-message "use '-flax-vector-conversions' to permit conversions" "" { target *-*-* } 0 } */
+
+typedef int v4si __attribute__((vector_size(16)));
+typedef short v8hi __attribute__((vector_size(16)));
+
+struct s { v8hi x; v4si y; };
+union u1 { v8hi x; v4si y; };
+union u2 { v4si s; v8hi y; };
+
+void
+foo (v4si i, v8hi h)
+{
+  struct s x1 = { i, i }; // { dg-error "incompatible types when initializing type '__vector" }
+  struct s x2 = { h, h }; // { dg-error "incompatible types" }
+  struct s x3 = { i, h }; // { dg-error "incompatible types" }
+  struct s x4 = { h, i };
+
+  union u1 y1 = { i }; // { dg-error "incompatible types" }
+  union u1 y2 = { h };
+  union u2 y3 = { i };
+  union u2 y4 = { h }; // { dg-error "incompatible types" }
+
+  v4si z1[] = { i, i };
+  v4si z2[] = { i, h }; // { dg-error "incompatible types" }
+  v4si z3[] = { h, i }; // { dg-error "incompatible types" }
+  v4si z4[] = { h, h }; // { dg-error "incompatible types" }
+  v8hi z5[] = { i, i }; // { dg-error "incompatible types" }
+  v8hi z6[] = { i, h }; // { dg-error "incompatible types" }
+  v8hi z7[] = { h, i }; // { dg-error "incompatible types" }
+  v8hi z8[] = { h, h };
+}
diff --git a/gcc/testsuite/gcc.dg/pr96377-2.c b/gcc/testsuite/gcc.dg/pr96377-2.c
new file mode 100644
index 00000000000..f58b06d9076
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96377-2.c
@@ -0,0 +1,31 @@
+/* { dg-options "-flax-vector-conversions" } */
+
+typedef int v4si __attribute__((vector_size(16)));
+typedef short v8hi __attribute__((vector_size(16)));
+
+struct s { v8hi x; v4si y; };
+union u1 { v8hi x; v4si y; };
+union u2 { v4si s; v8hi y; };
+
+void
+foo (v4si i, v8hi h)
+{
+  struct s x1 = { i, i };
+  struct s x2 = { h, h };
+  struct s x3 = { i, h };
+  struct s x4 = { h, i };
+
+  union u1 y1 = { i };
+  union u1 y2 = { h };
+  union u2 y3 = { i };
+  union u2 y4 = { h };
+
+  v4si z1[] = { i, i };
+  v4si z2[] = { i, h };
+  v4si z3[] = { h, i };
+  v4si z4[] = { h, h };
+  v8hi z5[] = { i, i };
+  v8hi z6[] = { i, h };
+  v8hi z7[] = { h, i };
+  v8hi z8[] = { h, h };
+}
diff --git a/gcc/testsuite/gcc.dg/pr96377-3.c b/gcc/testsuite/gcc.dg/pr96377-3.c
new file mode 100644
index 00000000000..66dce01f277
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96377-3.c
@@ -0,0 +1,33 @@
+/* { dg-do compile { target aarch64*-*-* } } */
+/* { dg-options "-fno-lax-vector-conversions" } */
+/* { dg-message "use '-flax-vector-conversions' to permit conversions" "" { target *-*-* } 0 } */
+
+typedef int v4si __attribute__((vector_size(16)));
+typedef short v8hi __attribute__((vector_size(16)));
+
+struct s { v8hi x; v4si y; };
+union u1 { v8hi x; v4si y; };
+union u2 { v4si s; v8hi y; };
+
+void
+foo (__Int32x4_t i, __Int16x8_t h)
+{
+  struct s x1 = { i, i }; // { dg-error "incompatible types when initializing type '__vector" }
+  struct s x2 = { h, h }; // { dg-error "incompatible types" }
+  struct s x3 = { i, h }; // { dg-error "incompatible types" }
+  struct s x4 = { h, i };
+
+  union u1 y1 = { i }; // { dg-error "incompatible types" }
+  union u1 y2 = { h };
+  union u2 y3 = { i };
+  union u2 y4 = { h }; // { dg-error "incompatible types" }
+
+  v4si z1[] = { i, i };
+  v4si z2[] = { i, h }; // { dg-error "incompatible types" }
+  v4si z3[] = { h, i }; // { dg-error "incompatible types" }
+  v4si z4[] = { h, h }; // { dg-error "incompatible types" }
+  v8hi z5[] = { i, i }; // { dg-error "incompatible types" }
+  v8hi z6[] = { i, h }; // { dg-error "incompatible types" }
+  v8hi z7[] = { h, i }; // { dg-error "incompatible types" }
+  v8hi z8[] = { h, h };
+}
diff --git a/gcc/testsuite/gcc.dg/pr96377-4.c b/gcc/testsuite/gcc.dg/pr96377-4.c
new file mode 100644
index 00000000000..f7aaf490031
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96377-4.c
@@ -0,0 +1,32 @@
+/* { dg-do compile { target aarch64*-*-* } } */
+/* { dg-options "-flax-vector-conversions" } */
+
+typedef int v4si __attribute__((vector_size(16)));
+typedef short v8hi __attribute__((vector_size(16)));
+
+struct s { v8hi x; v4si y; };
+union u1 { v8hi x; v4si y; };
+union u2 { v4si s; v8hi y; };
+
+void
+foo (__Int32x4_t i, __Int16x8_t h)
+{
+  struct s x1 = { i, i };
+  struct s x2 = { h, h };
+  struct s x3 = { i, h };
+  struct s x4 = { h, i };
+
+  union u1 y1 = { i };
+  union u1 y2 = { h };
+  union u2 y3 = { i };
+  union u2 y4 = { h };
+
+  v4si z1[] = { i, i };
+  v4si z2[] = { i, h };
+  v4si z3[] = { h, i };
+  v4si z4[] = { h, h };
+  v8hi z5[] = { i, i };
+  v8hi z6[] = { i, h };
+  v8hi z7[] = { h, i };
+  v8hi z8[] = { h, h };
+}
diff --git a/gcc/testsuite/gcc.dg/pr96377-5.c b/gcc/testsuite/gcc.dg/pr96377-5.c
new file mode 100644
index 00000000000..3d0c24befa6
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96377-5.c
@@ -0,0 +1,33 @@
+/* { dg-do compile { target aarch64*-*-* } } */
+/* { dg-options "-fno-lax-vector-conversions" } */
+/* { dg-message "use '-flax-vector-conversions' to permit conversions" "" { target *-*-* } 0 } */
+
+typedef int v4si __attribute__((vector_size(16)));
+typedef short v8hi __attribute__((vector_size(16)));
+
+struct s { __Int16x8_t x; __Int32x4_t y; };
+union u1 { __Int16x8_t x; __Int32x4_t y; };
+union u2 { __Int32x4_t s; __Int16x8_t y; };
+
+void
+foo (v4si i, v8hi h)
+{
+  struct s x1 = { i, i }; // { dg-error "incompatible types when initializing type '__Int16x8_t" }
+  struct s x2 = { h, h }; // { dg-error "incompatible types" }
+  struct s x3 = { i, h }; // { dg-error "incompatible types" }
+  struct s x4 = { h, i };
+
+  union u1 y1 = { i }; // { dg-error "incompatible types" }
+  union u1 y2 = { h };
+  union u2 y3 = { i };
+  union u2 y4 = { h }; // { dg-error "incompatible types" }
+
+  v4si z1[] = { i, i };
+  v4si z2[] = { i, h }; // { dg-error "incompatible types" }
+  v4si z3[] = { h, i }; // { dg-error "incompatible types" }
+  v4si z4[] = { h, h }; // { dg-error "incompatible types" }
+  v8hi z5[] = { i, i }; // { dg-error "incompatible types" }
+  v8hi z6[] = { i, h }; // { dg-error "incompatible types" }
+  v8hi z7[] = { h, i }; // { dg-error "incompatible types" }
+  v8hi z8[] = { h, h };
+}
diff --git a/gcc/testsuite/gcc.dg/pr96377-6.c b/gcc/testsuite/gcc.dg/pr96377-6.c
new file mode 100644
index 00000000000..165327fa292
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/pr96377-6.c
@@ -0,0 +1,32 @@
+/* { dg-do compile { target aarch64*-*-* } } */
+/* { dg-options "-flax-vector-conversions" } */
+
+typedef int v4si __attribute__((vector_size(16)));
+typedef short v8hi __attribute__((vector_size(16)));
+
+struct s { __Int16x8_t x; __Int32x4_t y; };
+union u1 { __Int16x8_t x; __Int32x4_t y; };
+union u2 { __Int32x4_t s; __Int16x8_t y; };
+
+void
+foo (v4si i, v8hi h)
+{
+  struct s x1 = { i, i };
+  struct s x2 = { h, h };
+  struct s x3 = { i, h };
+  struct s x4 = { h, i };
+
+  union u1 y1 = { i };
+  union u1 y2 = { h };
+  union u2 y3 = { i };
+  union u2 y4 = { h };
+
+  v4si z1[] = { i, i };
+  v4si z2[] = { i, h };
+  v4si z3[] = { h, i };
+  v4si z4[] = { h, h };
+  v8hi z5[] = { i, i };
+  v8hi z6[] = { i, h };
+  v8hi z7[] = { h, i };
+  v8hi z8[] = { h, h };
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/pr96377-1.c b/gcc/testsuite/gcc.target/aarch64/pr96377-1.c
new file mode 100644
index 00000000000..51e3e36edfc
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/pr96377-1.c
@@ -0,0 +1,20 @@
+/* { dg-options "" } */
+
+#include <arm_neon.h>
+
+struct aegis128_state {
+ uint8x16_t v[5];
+};
+
+void foo(const void *key, const void *iv, const void *const0, const void *const1)
+{
+ uint8x16_t k = vld1q_u8(key);
+ uint8x16_t kiv = k ^ vld1q_u8(iv);
+ struct aegis128_state st = {{
+  kiv,
+  vld1q_u8(const1),
+  vld1q_u8(const0),
+  k ^ vld1q_u8(const0),
+  k ^ vld1q_u8(const1),
+ }};
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/gnu_vectors_3.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/gnu_vectors_3.c
new file mode 100644
index 00000000000..0f1a2b0e46b
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/gnu_vectors_3.c
@@ -0,0 +1,15 @@
+/* { dg-options "-msve-vector-bits=256" } */
+
+#include <arm_sve.h>
+
+typedef uint8_t gnu_uint8_t __attribute__ ((vector_size (32)));
+typedef int8_t gnu_int8_t __attribute__ ((vector_size (32)));
+
+void
+f (svuint8_t sve_u1, svint8_t sve_s1,
+   gnu_uint8_t gnu_u1, gnu_int8_t gnu_s1)
+{
+  gnu_uint8_t arr1[] = { gnu_u1, sve_u1 };
+  gnu_uint8_t arr2[] = { gnu_s1 }; // { dg-error "incompatible types" }
+  gnu_uint8_t arr3[] = { sve_s1 }; // { dg-error "incompatible types" }
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/gnu_vectors_4.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/gnu_vectors_4.c
new file mode 100644
index 00000000000..ac4e0d12ff8
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general-c/gnu_vectors_4.c
@@ -0,0 +1,15 @@
+/* { dg-options "-msve-vector-bits=256 -flax-vector-conversions" } */
+
+#include <arm_sve.h>
+
+typedef uint8_t gnu_uint8_t __attribute__ ((vector_size (32)));
+typedef int8_t gnu_int8_t __attribute__ ((vector_size (32)));
+
+void
+f (svuint8_t sve_u1, svint8_t sve_s1,
+   gnu_uint8_t gnu_u1, gnu_int8_t gnu_s1)
+{
+  gnu_uint8_t arr1[] = { gnu_u1, sve_u1 };
+  gnu_uint8_t arr2[] = { gnu_s1 };
+  gnu_uint8_t arr3[] = { sve_s1 };
+}

commit 6eb69012ffc20bd79aa1ba74fc597d8082e2f6e9
Author: Qian Jianhua <qianjh@cn.fujitsu.com>
Date:   Mon Aug 3 14:03:25 2020 +0100

    aarch64: Add A64FX machine model
    
    This patch add support for Fujitsu A64FX, as the first step of adding
    A64FX machine model.
    
    A64FX is used in FUJITSU Supercomputer PRIMEHPC FX1000,
    PRIMEHPC FX700, and supercomputer Fugaku.
    The official microarchitecture information of A64FX can be read at
    https://github.com/fujitsu/A64FX.
    
    2020-08-03  Qian jianhua  <qianjh@cn.fujitsu.com>
    
    gcc/
            * config/aarch64/aarch64-cores.def (a64fx): New core.
            * config/aarch64/aarch64-tune.md: Regenerated.
            * config/aarch64/aarch64.c (a64fx_prefetch_tune, a64fx_tunings): New.
            * doc/invoke.texi: Add a64fx to the list.
    
    (cherry picked from commit 02f21aea0679c5cac094a3f575e839d44cb57a39)

diff --git a/gcc/config/aarch64/aarch64-cores.def b/gcc/config/aarch64/aarch64-cores.def
index bc89a14cb9e..a7dde38d768 100644
--- a/gcc/config/aarch64/aarch64-cores.def
+++ b/gcc/config/aarch64/aarch64-cores.def
@@ -119,6 +119,9 @@ AARCH64_CORE("octeontx2f95",   octeontx2f95,   cortexa57, 8_2A,  AARCH64_FL_FOR_
 AARCH64_CORE("octeontx2f95n",  octeontx2f95n,  cortexa57, 8_2A,  AARCH64_FL_FOR_ARCH8_2 | AARCH64_FL_CRYPTO | AARCH64_FL_PROFILE, cortexa57, 0x43, 0x0b4, -1)
 AARCH64_CORE("octeontx2f95mm", octeontx2f95mm, cortexa57, 8_2A,  AARCH64_FL_FOR_ARCH8_2 | AARCH64_FL_CRYPTO | AARCH64_FL_PROFILE, cortexa57, 0x43, 0x0b5, -1)
 
+/* Fujitsu ('F') cores. */
+AARCH64_CORE("a64fx", a64fx, a64fx, 8_2A,  AARCH64_FL_FOR_ARCH8_2 | AARCH64_FL_F16 | AARCH64_FL_SVE, a64fx, 0x46, 0x001, -1)
+
 /* HiSilicon ('H') cores. */
 AARCH64_CORE("tsv110",  tsv110, tsv110, 8_2A,  AARCH64_FL_FOR_ARCH8_2 | AARCH64_FL_CRYPTO | AARCH64_FL_F16 | AARCH64_FL_AES | AARCH64_FL_SHA2, tsv110,   0x48, 0xd01, -1)
 
diff --git a/gcc/config/aarch64/aarch64-tune.md b/gcc/config/aarch64/aarch64-tune.md
index 841af9da10e..ebf97c38fbd 100644
--- a/gcc/config/aarch64/aarch64-tune.md
+++ b/gcc/config/aarch64/aarch64-tune.md
@@ -1,5 +1,5 @@
 ;; -*- buffer-read-only: t -*-
 ;; Generated automatically by gentune.sh from aarch64-cores.def
 (define_attr "tune"
-	"cortexa34,cortexa35,cortexa53,cortexa57,cortexa72,cortexa73,thunderx,thunderxt88p1,thunderxt88,octeontx,octeontxt81,octeontxt83,thunderxt81,thunderxt83,emag,xgene1,falkor,qdf24xx,exynosm1,phecda,thunderx2t99p1,vulcan,thunderx2t99,cortexa55,cortexa75,cortexa76,cortexa76ae,cortexa77,cortexa65,cortexa65ae,ares,neoversen1,neoversee1,octeontx2,octeontx2t98,octeontx2t96,octeontx2t93,octeontx2f95,octeontx2f95n,octeontx2f95mm,tsv110,thunderx3t110,zeus,saphira,cortexa57cortexa53,cortexa72cortexa53,cortexa73cortexa35,cortexa73cortexa53,cortexa75cortexa55,cortexa76cortexa55"
+	"cortexa34,cortexa35,cortexa53,cortexa57,cortexa72,cortexa73,thunderx,thunderxt88p1,thunderxt88,octeontx,octeontxt81,octeontxt83,thunderxt81,thunderxt83,emag,xgene1,falkor,qdf24xx,exynosm1,phecda,thunderx2t99p1,vulcan,thunderx2t99,cortexa55,cortexa75,cortexa76,cortexa76ae,cortexa77,cortexa65,cortexa65ae,ares,neoversen1,neoversee1,octeontx2,octeontx2t98,octeontx2t96,octeontx2t93,octeontx2f95,octeontx2f95n,octeontx2f95mm,a64fx,tsv110,thunderx3t110,zeus,saphira,cortexa57cortexa53,cortexa72cortexa53,cortexa73cortexa35,cortexa73cortexa53,cortexa75cortexa55,cortexa76cortexa55"
 	(const (symbol_ref "((enum attr_tune) aarch64_tune)")))
diff --git a/gcc/config/aarch64/aarch64.c b/gcc/config/aarch64/aarch64.c
index b86434a6acf..d31c506fbed 100644
--- a/gcc/config/aarch64/aarch64.c
+++ b/gcc/config/aarch64/aarch64.c
@@ -868,6 +868,17 @@ static const cpu_prefetch_tune xgene1_prefetch_tune =
   -1			/* default_opt_level  */
 };
 
+static const cpu_prefetch_tune a64fx_prefetch_tune =
+{
+  8,			/* num_slots  */
+  64,			/* l1_cache_size  */
+  256,			/* l1_cache_line_size  */
+  32768,		/* l2_cache_size  */
+  true,			/* prefetch_dynamic_strides */
+  -1,			/* minimum_stride */
+  -1			/* default_opt_level  */
+};
+
 static const struct tune_params generic_tunings =
 {
   &cortexa57_extra_costs,
@@ -1325,6 +1336,32 @@ static const struct tune_params neoversen1_tunings =
   &generic_prefetch_tune
 };
 
+static const struct tune_params a64fx_tunings =
+{
+  &generic_extra_costs,
+  &generic_addrcost_table,
+  &generic_regmove_cost,
+  &generic_vector_cost,
+  &generic_branch_cost,
+  &generic_approx_modes,
+  SVE_512, /* sve_width  */
+  4, /* memmov_cost  */
+  7, /* issue_rate  */
+  (AARCH64_FUSE_AES_AESMC | AARCH64_FUSE_CMP_BRANCH), /* fusible_ops  */
+  "32",	/* function_align.  */
+  "16",	/* jump_align.  */
+  "32",	/* loop_align.  */
+  4,	/* int_reassoc_width.  */
+  2,	/* fp_reassoc_width.  */
+  2,	/* vec_reassoc_width.  */
+  2,	/* min_div_recip_mul_sf.  */
+  2,	/* min_div_recip_mul_df.  */
+  0,	/* max_case_values.  */
+  tune_params::AUTOPREFETCHER_WEAK,	/* autoprefetcher_model.  */
+  (AARCH64_EXTRA_TUNE_NONE),	/* tune_flags.  */
+  &a64fx_prefetch_tune
+};
+
 /* Support for fine-grained override of the tuning structures.  */
 struct aarch64_tuning_override_function
 {
diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
index a2794a67d1e..5b818edf62a 100644
--- a/gcc/doc/invoke.texi
+++ b/gcc/doc/invoke.texi
@@ -16976,6 +16976,7 @@ performance of the code.  Permissible values for this option are:
 @samp{octeontx2}, @samp{octeontx2t98}, @samp{octeontx2t96}
 @samp{octeontx2t93}, @samp{octeontx2f95}, @samp{octeontx2f95n},
 @samp{octeontx2f95mm}
+@samp{a64fx},
 @samp{thunderx}, @samp{thunderxt88},
 @samp{thunderxt88p1}, @samp{thunderxt81}, @samp{tsv110},
 @samp{thunderxt83}, @samp{thunderx2t99}, @samp{thunderx3t110}, @samp{zeus},

commit 72ecbb3710a51d86e0c180349dc5d66e4ccd411c
Author: Richard Sandiford <richard.sandiford@arm.com>
Date:   Mon Aug 3 14:03:26 2020 +0100

    doc: Add missing comma after octeontx2f95mm
    
    gcc/
            * doc/invoke.texi: Add missing comma after octeontx2f95mm entry.
    
    (cherry picked from commit 749abaa755faf47968a9d8817deb8de19e685bbc)

diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
index 5b818edf62a..8afe62ad619 100644
--- a/gcc/doc/invoke.texi
+++ b/gcc/doc/invoke.texi
@@ -16975,7 +16975,7 @@ performance of the code.  Permissible values for this option are:
 @samp{octeontx81},  @samp{octeontx83},
 @samp{octeontx2}, @samp{octeontx2t98}, @samp{octeontx2t96}
 @samp{octeontx2t93}, @samp{octeontx2f95}, @samp{octeontx2f95n},
-@samp{octeontx2f95mm}
+@samp{octeontx2f95mm},
 @samp{a64fx},
 @samp{thunderx}, @samp{thunderxt88},
 @samp{thunderxt88p1}, @samp{thunderxt81}, @samp{tsv110},

commit 23b917d7cb5b0f14c967fc52148d55fcdb0201ae
Author: Richard Sandiford <richard.sandiford@arm.com>
Date:   Mon Aug 3 16:33:11 2020 +0100

    testsuite: Add -Wno-psabi to gcc.dg/pr96377-[12].c
    
    2020-08-03  Richard Sandiford  <richard.sandiford@arm.com>
    
    gcc/testsuite/
            * gcc.dg/pr96377-1.c: Add -Wno-psabi.
            * gcc.dg/pr96377-2.c: Likewise.
    
    (cherry picked from commit 401070d8b4e90d4363b6566836c94ec7b6f9c5a2)

diff --git a/gcc/testsuite/gcc.dg/pr96377-1.c b/gcc/testsuite/gcc.dg/pr96377-1.c
index 2bf3f816331..75b0c9618ef 100644
--- a/gcc/testsuite/gcc.dg/pr96377-1.c
+++ b/gcc/testsuite/gcc.dg/pr96377-1.c
@@ -1,4 +1,4 @@
-/* { dg-options "-fno-lax-vector-conversions" } */
+/* { dg-options "-fno-lax-vector-conversions -Wno-psabi" } */
 /* { dg-message "use '-flax-vector-conversions' to permit conversions" "" { target *-*-* } 0 } */
 
 typedef int v4si __attribute__((vector_size(16)));
diff --git a/gcc/testsuite/gcc.dg/pr96377-2.c b/gcc/testsuite/gcc.dg/pr96377-2.c
index f58b06d9076..83550401156 100644
--- a/gcc/testsuite/gcc.dg/pr96377-2.c
+++ b/gcc/testsuite/gcc.dg/pr96377-2.c
@@ -1,4 +1,4 @@
-/* { dg-options "-flax-vector-conversions" } */
+/* { dg-options "-flax-vector-conversions -Wno-psabi" } */
 
 typedef int v4si __attribute__((vector_size(16)));
 typedef short v8hi __attribute__((vector_size(16)));
